/* -*- coding: cp866 -*- */
/* $Id: net_cher_15.c 614 2005-04-21 04:08:46Z jury $ */

/*
 * GCC
 * - ४  ⨪
 * -  ﭨ
 * - ab-祭
 * - 뢮  ⢥⮢
 * - ⨬ ஢ப  室  ""
 */

#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include <assert.h>

#define MAX_N 50
#define STATE_SIZE 21
#define MIN_X 0
#define MAX_X 50
#define MIN_Y 0
#define MAX_Y 50
#define MAX_CELL 100

#define HAS_LOW    1
#define HAS_HIGH   2
#define HAS_LEFT   4
#define HAS_RIGHT  8
#define WHOLE_CELL 15

typedef struct segment
{
  unsigned short x1, y1, x2, y2;
  short total;
} segment_t;

typedef struct cell
{
  int x, y;
  int segs[4];
  int total;
} cell_t;

int lineno;
int N;
segment_t segs[MAX_N];
int min_x = MAX_X + 2, max_x = MIN_X, min_y = MAX_Y + 2, max_y = MIN_Y;
unsigned char board[MAX_Y + 2][MAX_X + 2];
unsigned char cell_idx[MAX_Y + 2][MAX_X + 2];
unsigned long long interesting_segs;
unsigned char saved_sol[1 << (STATE_SIZE)];
cell_t cells[MAX_CELL];
int total_cells;

inline unsigned int get_saved_sol(unsigned long state, unsigned int who_moves)
{
  if (!saved_sol[state]) return 0;
  if (who_moves == 1) return saved_sol[state];
  return (saved_sol[state] & 1) + 1;
}
inline void set_saved_sol(unsigned long state, unsigned int who_moves, unsigned int val)
{
  if (who_moves == 1) saved_sol[state] = val;
  else saved_sol[state] = (val & 1) + 1;
}

int make_move(int num1, int num2, unsigned long cell_state, int who_moves, int nboxes)
{
  unsigned char saved[2];
  int saved_num = 0;
  int now_moves = who_moves % 2 + 1;
  unsigned int val;
  int xc, yc, i, nneighb, r, who_wins;
  int results[3];

  /*
  fprintf(stderr, "make_move: %d, %d, %lx, %d, %d\n", num1, num2, cell_state,
          who_moves, nboxes);
  */

  if (!nboxes) {
    //fprintf(stderr, "make_move return: empty board, %d\n", now_moves);
    return now_moves;
  }

  //assert(num1 > 0 && num1 < total_cells);
  //assert(board[cells[num1].y][cells[num1].x] == WHOLE_CELL);
  saved[saved_num++] = board[cells[num1].y][cells[num1].x];
  board[cells[num1].y][cells[num1].x] = 0;
  cell_state &= ~(1UL << (num1 - 1));
  nboxes--;
  if (num2 > 0) {
    //assert(num2 < total_cells);
    //assert(board[cells[num2].y][cells[num2].x] == WHOLE_CELL);
    saved[saved_num++] = board[cells[num2].y][cells[num2].x];
    board[cells[num2].y][cells[num2].x] = 0;
    cell_state &= ~(1UL << (num2 - 1));
    nboxes--;
  }

  val = get_saved_sol(cell_state, who_moves);
  if (val > 0) {
    //fprintf(stderr, "saved: %lx, %d, %d\n", cell_state, who_moves, val);
  }

  if (!val) {
    memset(results, 0, sizeof(results));
    for (i = 1; i < total_cells; i++) {
      if (!(cell_state & (1 << (i - 1)))) continue;

      xc = cells[i].x;
      yc = cells[i].y;
      nneighb = 0;

      //assert(board[yc][xc] == WHOLE_CELL);
      if (board[yc - 1][xc] == WHOLE_CELL) {
        r = make_move(i, cell_idx[yc - 1][xc], cell_state, now_moves, nboxes);
        nneighb++;
        results[r]++;
        if (results[now_moves] > 0) break;
      }
      if (board[yc + 1][xc] == WHOLE_CELL) {
        r = make_move(i, cell_idx[yc + 1][xc], cell_state, now_moves, nboxes);
        nneighb++;
        results[r]++;
        if (results[now_moves] > 0) break;
      }
      if (board[yc][xc + 1] == WHOLE_CELL) {
        r = make_move(i, cell_idx[yc][xc + 1], cell_state, now_moves, nboxes);
        nneighb++;
        results[r]++;
        if (results[now_moves] > 0) break;
      }
      if (board[yc][xc - 1] == WHOLE_CELL) {
        r = make_move(i, cell_idx[yc][xc - 1], cell_state, now_moves, nboxes);
        nneighb++;
        results[r]++;
        if (results[now_moves] > 0) break;
      }
      if (nneighb != 4) {
        r = make_move(i, 0, cell_state, now_moves, nboxes);
        results[r]++;
        if (results[now_moves] > 0) break;
      }
    }
  }

  board[cells[num1].y][cells[num1].x] = WHOLE_CELL;
  if (num2 > 0) {
    board[cells[num2].y][cells[num2].x] = WHOLE_CELL;
  }

  if (val) {
    //fprintf(stderr, "make_move saved returns: %d\n", val);
    return val;
  }

  //fprintf(stderr, "results: %d, %d, %d\n", results[0], results[1], results[2]);
  who_wins = who_moves;
  if (results[now_moves] > 0) {
    who_wins = now_moves;
  }
  set_saved_sol(cell_state, who_moves, who_wins);
  //fprintf(stderr, "make_move returns: %d\n", who_wins);
  return who_wins;
}

void start_solve(void)
{
  int i, r, results[3], x, y;
  unsigned long long winning_movies = 0;
  int nboxes = 0;
  unsigned long cell_state = 0;
  segment_t *pseg;
  int nums[2];
  int total_nums = 0;

  for (x = min_x; x < max_x; x++) {
    for (y = min_y; y < max_y; y++) {
      if (board[y][x] == WHOLE_CELL) nboxes++;
    }
  }

  for (i = 0; i < total_cells - 1; i++)
    cell_state |= (1UL << i);

  memset(results, 0, sizeof(results));
  for (i = 0; i < N; i++) {
    if (!(interesting_segs & (1ULL << i))) continue;

    nums[0] = 0;
    nums[1] = 0;
    total_nums = 0;
    pseg = &segs[i];
    if (pseg->x1 == pseg->x2) {
      if (board[pseg->y1][pseg->x1] == WHOLE_CELL) {
        nums[total_nums++] = cell_idx[pseg->y1][pseg->x1];
      }
      if (board[pseg->y1][pseg->x1 - 1] == WHOLE_CELL) {
        nums[total_nums++] = cell_idx[pseg->y1][pseg->x1 - 1];
      }
    } else if (pseg->y1 == pseg->y2) {
      if (board[pseg->y1][pseg->x1] == WHOLE_CELL) {
        nums[total_nums++] = cell_idx[pseg->y1][pseg->x1];
      }
      if (board[pseg->y1 - 1][pseg->x1] == WHOLE_CELL) {
        nums[total_nums++] = cell_idx[pseg->y1 - 1][pseg->x1];
      }
    }
 
    r = make_move(nums[0], nums[1], cell_state, 1, nboxes);
    results[r]++;
    if (r == 1) {
      winning_movies |= (1ULL << i);
    }
  }

  //fprintf(stderr, "results: %d, %d, %d\n", results[0], results[1], results[2]);

  if (results[1] > 0) {
    printf("1\n");
    for (i = 0; i < N; i++)
      if ((winning_movies & (1ULL << i))) printf("%d ", i + 1);
    printf("\n");
  } else if (results[0] > 0) {
    printf("0\n");
  } else {
    printf("2\n");
  }
}

void read_data(void)
{
  int x1, y1, x2, y2, i; 
  scanf("%d", &N);

  for (i = 0; i < N; i++) {
    scanf("%d%d%d%d", &x1, &y1, &x2, &y2);

    x1++, y1++, x2++, y2++;
    if (x1 > x2) x1 = x2, x2 = x1 + 1;
    if (y1 > y2) y1 = y2, y2 = y1 + 1;
    segs[i].x1 = x1;
    segs[i].y1 = y1;
    segs[i].x2 = x2;
    segs[i].y2 = y2;
    if (x1 < min_x) min_x = x1;
    if (x2 > max_x) max_x = x2;
    if (y1 < min_y) min_y = y1;
    if (y2 > max_y) max_y = y2;
    if (x1 == x2) {
      board[y1][x1] |= HAS_LEFT;
      board[y1][x1 - 1] |= HAS_RIGHT;
    } else if (y1 == y2) {
      board[y1][x1] |= HAS_LOW;
      board[y1 - 1][x1] |= HAS_HIGH;
    } else abort();
  }
}

int main(int argc, char *argv[])
{
  int i, x1, y1, j;

  if (argc == 2) {
    freopen(argv[1], "r", stdin);
  } else {
    freopen("net.in", "r", stdin);
    freopen("net.out", "w", stdout);
  }

  read_data();

  // calculate the set of cells
  total_cells = 1;
  for (x1 = min_x; x1 < max_x; x1++) {
    for (y1 = min_y; y1 < max_y; y1++) {
      if (board[y1][x1] == WHOLE_CELL) {
        cells[total_cells].x = x1;
        cells[total_cells].y = y1;
        cell_idx[y1][x1] = total_cells++;
      }
    }
  }

  if (total_cells > 21) abort();

  // calculate the set of potentially interesting segments
  interesting_segs = 0;
  for (i = 0; i < N; i++) {
    if (segs[i].x1 == segs[i].x2) {
      if (board[segs[i].y1][segs[i].x1] == WHOLE_CELL) {
        interesting_segs |= (1ULL << i);
        j = cell_idx[segs[i].y1][segs[i].x1];
        cells[j].segs[cells[j].total++] = i;
      }
      if (board[segs[i].y1][segs[i].x1 - 1] == WHOLE_CELL) {
        interesting_segs |= (1ULL << i);
        j = cell_idx[segs[i].y1][segs[i].x1 - 1];
        cells[j].segs[cells[j].total++] = i;
      }
    } else if (segs[i].y1 == segs[i].y2) {
      if (board[segs[i].y1][segs[i].x1] == WHOLE_CELL) {
        interesting_segs |= (1ULL << i);
        j = cell_idx[segs[i].y1][segs[i].x1];
        cells[j].segs[cells[j].total++] = i;
      }
      if (board[segs[i].y1 - 1][segs[i].x1] == WHOLE_CELL) {
        interesting_segs |= (1ULL << i);
        j = cell_idx[segs[i].y1 - 1][segs[i].x1];
        cells[j].segs[cells[j].total++] = i;
      }
    }
  }

  start_solve();

  return 0;
}

/*
 * Local variables:
 *  compile-command: "gcc -Wall -g net_cher_15.c -o net_cher_15"
 * End:
 */
