{$MINSTACKSIZE $00400000}
{$o-,q+,r+}
uses
    sysutils;
const
    max_n = 100000;
    max_c = 100000;

type
    tState = (_NONE_ = 0, _OK_, _BAR_, _FORK_, _FAIL_);
    tProc = procedure (vi, ei: longint);


var
    v, c, next: array [1..2 * max_n] of longint;
    b: array [1..2 * max_n] of boolean;
    r: array [1..max_n] of longint;
    ea, eb, ec: longint;
    col: array [1..max_n] of longint;
    fail: boolean;
    state: array [1..max_n] of tState;
    cg: longint;
    pe, pv, idx, kill: array [1..max_n] of longint;
    forked: array [1..max_n] of boolean;
    q: longint;

procedure doKill(vi, ei: longint);
begin
    kill[v[ei]] := kill[vi];
end;

procedure forChilds(vi: longint; proc: tProc);
var
    ei: longint;
begin
    ei := r[vi];
    while ei <> 0 do begin
        if pv[vi] <> v[ei] then begin
            proc(vi, ei);
        end;
        ei := next[ei];
    end;
end;

procedure mark(vi, ei: longint);
begin
    if col[c[ei]] <> 0 then begin
        b[ei] := true;
        b[col[c[ei]]] := true;

        if state[vi] = _OK_ then begin
            state[vi] := _FORK_;
        end else begin
            fail := true;
            state[vi] := _FAIL_;
        end;
    end else begin
        col[c[ei]] := ei;
    end;
end;

procedure unmark(vi, ei: longint);
begin
    col[c[ei]] := 0;
end;

procedure killChild(vi, ei: longint);
begin
    if not b[ei] then begin
        kill[v[ei]] := vi;
    end;
end;

function dfs(i: longint): boolean; forward;

procedure scan(vi, ei: longint);
begin
    pe[v[ei]] := ei;
    pv[v[ei]] := vi;
    if dfs(v[ei]) then begin
        if forked[vi] or ((state[vi] <> _OK_) and not b[ei]) then begin
            state[vi] := _FAIL_;
            fail := true;
        end;
        forked[vi] := true;
        kill[vi] := kill[v[ei]];
    end;
end;

function dfs(i: longint): boolean;
begin
    state[i] := _OK_;

    forChilds(i, mark);
    if (pe[i] <> 0) and (col[c[pe[i]]] <> 0) then begin
        if state[i] = _OK_ then begin
            state[i] := _BAR_;
        end else begin
            fail := true;
            state[i] := _FAIL_;
        end;
        b[col[c[pe[i]]]] := true;
    end;
    forChilds(i, unmark);

    if state[i] <> _OK_ then begin
        kill[i] := i;
    end;

    forked[i] := false;
    forChilds(i, scan);

    if (state[i] <> _OK_) then begin
        forChilds(i, killChild);
    end;

    inc(q);
    idx[q] := i;

    dfs := forked[i] or (state[i] = _FORK_);
end;

procedure add(ea, eb, ec: longint);
begin
    inc(q);
    v[q] := eb;
    c[q] := ec;
    next[q] := r[ea];
    r[ea] := q;
end;

var
    i, n: longint;
begin
    assign(input, 'robot.in'); reset(input);
    assign(output, 'robot.out'); rewrite(output);

    fillchar(r, sizeof(r), 0);
    fillchar(state, sizeof(state), 0);
    fillchar(col, sizeof(col), 0);

    read(n);
    assert((1 <= n) and (n <= max_n), 'N out of bounds');
    for i := 1 to n - 1 do begin
        read(ea, eb, ec);
        assert((1 <= ea) and (ea <= n), format('a[%d]', [i]));
        assert((1 <= eb) and (eb <= n), format('b[%d]', [i]));
        assert((1 <= ec) and (ec <= max_c), format('b[%d]', [i]));

        add(ea, eb, ec);
        add(eb, ea, ec);
    end;

    q := 0;
    dfs(1);

    for i := 1 to n do begin
        assert(state[i] <> _NONE_, format('Vertex %d is not accessible', [i]));
    end;

    for i := n downto 1 do begin
        if (kill[idx[i]] <> 0) and (kill[idx[i]] <> idx[i]) then begin
            forChilds(idx[i], doKill);
        end;
    end;

    if not fail then begin
        cg := 0;
        for i := 1 to n do begin
            if kill[i] = 0 then inc(cg);
        end;

        writeln(cg);
        for i := 1 to n do begin
            if kill[i] = 0 then write(i, ' ');
        end;
    end else begin
        writeln(0);
    end;
    close(input);
    close(output);
end.