{$R+,Q+}
program bike;

uses
    math;

const
    eps = 1e-8;

var
    x1, y1, r1, x2, y2, r2: longint;
    xs, ys, xt, yt: extended;
    ds1, ds2, dt1, dt2: extended;
    np: longint;
    an: array [1..8] of extended;
    cc: array [1..8] of longint;
    sp, tp: longint;
    la, lb, lc, qa, qb, qc: extended;
    dd: extended;
    x0, y0, dx, dy, xp, yp, t: extended;
    i, j, k: longint;
    can: array [1..8, 1..8] of boolean;
    d: array [1..8, 1..8] of extended;

function oncircle(xc, yc, r, xp, yp: extended): boolean;
var
    d: extended;
begin
    d := sqrt(sqr(xp - xc) + sqr(yp - yc));
    oncircle := abs(d - r) < eps;
end;

function circdist(r, a1, a2: extended): extended;
var
    a: extended;
begin
    a := a1 - a2;
    while a < 0 do
        a := a + 2 * pi;
    while a > 2 * pi do
        a := a - 2 * pi;
    if a > pi then a := 2 * pi - a;
    circdist := r * a;
end;

begin   
    reset(input, 'bike.in');
    rewrite(output, 'bike.out');

    read(x1, y1, r1);
    read(x2, y2, r2);

    read(xs, ys);
    read(xt, yt);

    ds1 := sqrt(sqr(x1 - xs) + sqr(y1 - ys));
    ds2 := sqrt(sqr(x2 - xs) + sqr(y2 - ys));
    dt1 := sqrt(sqr(x1 - xt) + sqr(y1 - yt));
    dt2 := sqrt(sqr(x2 - xt) + sqr(y2 - yt));

    assert((abs(ds1 - r1) < eps) or (abs(ds2 - r2) < eps));
    assert((abs(dt1 - r1) < eps) or (abs(dt2 - r2) < eps));

    np := 0;
    if abs(ds1 - r1) < eps then begin
        inc(np);
        an[np] := arctan2(ys - y1, xs - x1);
        cc[np] := 1;
        sp := np;
    end;
    if abs(ds2 - r2) < eps then begin
        inc(np);
        an[np] := arctan2(ys - y2, xs - x2);
        cc[np] := 2;
        sp := np;
    end;
    if abs(dt1 - r1) < eps then begin
        inc(np);
        an[np] := arctan2(yt - y1, xt - x1);
        cc[np] := 1;
        tp := np;
    end;
    if abs(dt2 - r2) < eps then begin
        inc(np);
        an[np] := arctan2(yt - y2, xt - x2);
        cc[np] := 2;
        tp := np;
    end;

    la := 2 * (x2 - x1);
    lb := 2 * (y2 - y1);
    lc := x1 * x1 - x2 * x2 + y1 * y1 - y2 * y2 - r1 * r1 + r2 * r2;

    if (la <> 0) or (lb <> 0) then begin
        dd := la * la + lb * lb;
        x0 := - la * lc / dd;
        y0 := - lb * lc / dd;
        assert(abs(x0 * la + y0 * lb + lc) < eps);

        dx := lb / dd;
        dy := -la / dd;

        qa := dx * dx + dy * dy;
        qb := 2 * dx * (x0 - x1) + 2 * dy * (y0 - y1);
        qc := sqr(x0 - x1) + sqr(y0 - y1) - r1 * r1;
        dd := qb * qb - 4 * qa * qc;
        if dd > -eps then begin
            if dd < 0 then
                dd := 0;

            t := (-qb - sqrt(dd)) / (2 * qa);
            xp := x0 + dx * t;
            yp := y0 + dy * t;
            assert(oncircle(x1, y1, r1, xp, yp));
            assert(oncircle(x2, y2, r2, xp, yp));

            inc(np);
            an[np] := arctan2(yp - y1, xp - x1);
            cc[np] := 1;
            inc(np);
            an[np] := arctan2(yp - y2, xp - x2);
            cc[np] := 2;
            can[np - 1][np] := true;
            can[np][np - 1] := true;

            t := (-qb + sqrt(dd)) / (2 * qa);
            xp := x0 + dx * t;
            yp := y0 + dy * t;
            assert(oncircle(x1, y1, r1, xp, yp));
            assert(oncircle(x2, y2, r2, xp, yp));

            inc(np);
            an[np] := arctan2(yp - y1, xp - x1);
            cc[np] := 1;
            inc(np);
            an[np] := arctan2(yp - y2, xp - x2);
            cc[np] := 2;
            can[np - 1][np] := true;
            can[np][np - 1] := true;
        end;
    end;

    for i := 1 to np do begin
        for j := 1 to np do begin
            if cc[i] = cc[j] then begin
                can[i][j] := true;
                if cc[i] = 1 then
                    d[i][j] := circdist(r1, an[i], an[j])
                else
                    d[i][j] := circdist(r2, an[i], an[j]);
            end;
        end;
    end;

    for i := 1 to np do begin
        for j := 1 to np do begin
            for k := 1 to np do begin
                if can[j][i] and can[i][k] and 
                        (not can[j][k] or (d[j][k] > d[j][i] + d[i][k])) then 
                begin
                    can[j][k] := true;
                    d[j][k] := d[j][i] + d[i][k];
                end;
            end;
        end;
    end;

    if not can[sp][tp] then
        writeln(-1)
    else
        writeln(d[sp][tp] :0 :10);

    close(input);
    close(output);
end.
