// SPb-JPC-Kirov-2004
// Problem: "Buses"
// Solution by Orshanskiy Sergey

{$APPTYPE CONSOLE}
Uses Math, SysUtils;
{$O-,Q+,R+}

const problem_id = 'buses';
      max_n  = 100; // Max. number of bus stations
      max_k  = 100; // Max. number of bus routes
      max_l  = 100; // Max. stops in a route
      max_np = 100; // Max. number of people
      max_st_plan = 100; // Max. locations in a plan
      max_single_trip = 100; // Max. stops in a segment of plan
var
  n : integer; // n - number of stations
  k : integer; // k - number of bus routes
  l : array [1..max_k] of integer; // i-th route consists of l[i] points
  a : array [1..max_k, 1..max_l] of integer; // routes
  np : integer; // number of people

  where : integer; // person's initial and current location
  nst : integer; // stations in his/her plan
  pl : array [1..max_st_plan] of integer; // plan itself

  st : array [1..max_k] of integer; // buses current locations (# in the route, not st.#)
  thru : array [1..max_k, 1..max_n] of boolean; // i-th bus visits j-th station
  ab_stop : array [1..max_n] of boolean; // abandoned stop - stop never visited by any means of transport ;-)
  time : integer; // current time

// All buses move "dist" stops along their routes
procedure iterate_buses(dist : integer);
var i : integer;
begin
  assert(dist >= 0);
  for i := 1 to k do
    st[i] := (st[i] + dist - 1) mod l[i] + 1;
  time := time + dist;
end;

const inf_time = 1 shl 30;

// returns the number of the chosen route
// src - person's location in the beginning of the period
function waitforbus (src : integer) : integer;
var i, tt, t2, j : integer;
begin
  tt := inf_time;
  for i := 1 to k do if thru[i][src] then
  begin
    t2 := 0;
    j := st[i];
    while a[i][j] <> src do
    begin
      inc(t2);
      if j < l[i] then inc(j) else j := 1;
    end;
    if t2 < tt then
    begin
      tt := t2;
      result := i;
    end;
  end;
  assert(tt < inf_time);
  iterate_buses(tt);
end;
var i, j, jj : integer;
begin
  if ParamCount < 1 then
	  AssignFile(input, problem_id + '.in') else
    AssignFile(input, ParamStr(1));
	reset(input);
  if ParamCount < 2 then
    AssignFile(output, problem_id + '.out') else
    AssignFile(output, ParamStr(2));
	rewrite(output);

  assert(not seekeoln);
  read(n);
  assert(not seekeoln);
  read(k);
  assert(seekeoln);
  readln;

  fillchar(thru, sizeof(thru), 0);
  fillchar(ab_stop, sizeof(ab_stop), true);

  assert((n >= 1) and (n <= max_n));
  assert((k >= 1) and (k <= max_k));
  for i := 1 to k do
  begin
    assert(not seekeoln);
    read(l[i]);
    assert((1 <= l[i]) and (l[i] <= max_l));
    for j := 1 to l[i] do
    begin
      assert(not seekeoln);
      read(a[i][j]);
      assert((1 <= a[i][j]) and (a[i][j] <= n));
      thru[i][a[i][j]] := true;
      ab_stop[a[i][j]] := false;
    end;
    assert(seekeoln);
    readln;
  end;

  assert(not seekeoln);
  read(np);
  assert((1 <= np) and (np <= max_np));
  assert(seekeoln);
  readln;

  for i := 1 to np do
  begin
    assert(not seekeoln);
    read(where); // initial location
    assert((1 <= where) and (where <= n));
    assert(not seekeoln);
    read(nst); // number of stations in that person's plan
    assert((1 <= nst) and (nst <= max_st_plan));
    for j := 1 to nst do
    begin
      assert(not seekeoln);
      read(pl[j]);
      assert((1 <= pl[j]) and (pl[j] <= max_single_trip));
    end;
    assert(seekeoln);
    readln;

    // now solving for that particular person

    if ab_stop[where] then
    begin
      assert(nst > 0); // to ensure one more time
      writeln('0 0');  // wait here till death 
      continue;
    end;

    // inital buses' locations
    for j := 1 to k do st[j] := 1;

    time := 0;

    for j := 1 to nst do
    begin
      where := waitforbus(where); // where means bus number
      jj := pl[j];
   	  while jj > 0 do
	  begin
		dec(jj);
 		iterate_buses(1);
   	  end;
      where := a[where][st[where]];   // where means bus stop number
      if j < nst then iterate_buses(1);
    end;

    writeln(time,' ',where);
  end;
  assert(seekeof);
end.