#include <stdio.h>
#include <memory.h>

const char in_file[]  = "chart.in";
const char out_file[] = "chart.out";
const char stops[]    = ".!?:-,;()";
const int  MAX_SIZE   = 10000;

bool IsChartChar(char ch)
{
	//uppercase letters
	if (('a' <= ch) && (ch <= 'z'))
		return true;

	//lowercase letters
	if (('A' <= ch) && (ch <= 'Z'))
		return true;

	//ciphers
	if (('0' <= ch) && (ch <= '9'))
		return true;

	//punctuation marks
	for (int i = 0; i < sizeof(stops)/sizeof(char); i++)
		if (ch == stops[i])
			return true;

	return false;
}

bool IsCharCorrect(char ch)
{
	if (IsChartChar(ch))
		return true;

	//space, line feed
	if ((ch == ' ') || (ch == '\n'))
		return true;

	return false;
}

void PrintErrorMessage(char *s)
{
	fclose(stdout);
	freopen("con", "wt", stdout);

	for (int i = 0; s[i] != 0; i++)
		printf("=");
	printf("\n");

	printf("%s\n", s);

	for (int i = 0; s[i] != 0; i++)
		printf("=");
	printf("\n");
}

void Solve()
{
	freopen(in_file, "rt", stdin);
	freopen(out_file, "wt", stdout);

	int arr[256];

	memset(arr, 0, sizeof(arr));

	int pos = 0;
	char ch;

	while (scanf("%c", &ch) > 0)
	{
		pos++;

		if ((!IsCharCorrect(ch)) || (pos > MAX_SIZE))
		{
			char s[1000];
			sprintf(s, "==== Symbol '%c' [%d] at position %d is unexpected ====", ch, ch, pos);
			PrintErrorMessage(s);

			throw "Incorrect input data";
		}

		if (IsChartChar(ch))
			arr[ch]++;
	}

	int max = 0;
	for (int i = 0; i < 256; i++)
		if (max < arr[i])
			max = arr[i];

	if (max == 0)
	{
		PrintErrorMessage("==== File has no chart symbols ====");
		throw "Incorrect input data";
	}

	for (int i = 0; i <= max; i++)
	{
		for (int j = 0; j < 256; j++)
		{
			if (arr[j] == 0)
				continue;

			if (arr[j]+i >= max)
			{
				if (i == max)
					printf("%c", j);
				else
					printf("#");
			}
			else
				printf(" ");
		}
		printf("\n");
	}

	fclose(stdout);
}

int main()
{
	Solve();

	return 0;
}