(*
  "Two Knights". Jury's solution.
  Antony Popovich, 20.10.2004.
  Used an algorythm, based on queue
*)

{$APPTYPE CONSOLE}
{$Q+,R+,O-}

uses
  math, sysutils;

const
  fn = 'knights';
  qsize = (64 * 64) + 10;

  {all possible directions of movements}
  dx1 : array[1..16] of longint = ( 1,  2,  1,  2, -1, -2, -1, -2,  0,  0,  0,  0,  0,  0,  0,  0);
  dy1 : array[1..16] of longint = ( 2,  1, -2, -1,  2,  1, -2, -1,  0,  0,  0,  0,  0,  0,  0,  0);
  dx2 : array[1..16] of longint = ( 0,  0,  0,  0,  0,  0,  0,  0,  1,  2,  1,  2, -1, -2, -1, -2);
  dy2 : array[1..16] of longint = ( 0,  0,  0,  0,  0,  0,  0,  0,  2,  1, -2, -1,  2,  1, -2, -1);

type
  tstate = record
    x1, y1, x2, y2 : longint;
  end;
  tqueue = object
    t : array[0..qsize - 1] of tstate;
    dist : array[0..qsize - 1] of longint;

    s, f : longint;
    procedure init;
    procedure add(_x1, _y1, _x2, _y2, _dist : longint);
    procedure get(var _x1, _y1, _x2, _y2, _dist : longint);
    function empty : boolean;
  end;

procedure tqueue.init;
begin
  s := 0; f := -1;
end;

procedure tqueue.add(_x1, _y1, _x2, _y2, _dist : longint);
begin
  inc(f);
  t[f].x1 := _x1; t[f].y1 := _y1; t[f].x2 := _x2; t[f].y2 := _y2; dist[f] := _dist;
end;

procedure tqueue.get(var _x1, _y1, _x2, _y2, _dist : longint);
begin
  _x1 := t[s].x1; _y1 := t[s].y1; _x2 := t[s].x2; _y2 := t[s].y2; _dist := dist[s];
  inc(s);
end;

function tqueue.empty : boolean;
begin
  result := (s = f + 1);
end;

var
  s : string;
  q : tqueue;
  i, dist : longint;
  st, fin, cur : tstate;
  prev : array[0..7, 0..7, 0..7, 0..7] of tstate;

  ans : array[1..qsize] of tstate;
  ansnum : longint;

begin
  assign(input, fn + '.in'); reset(input);
  assign(output, fn + '.out'); rewrite(output);

  {Reading input data as a string and checking the correctness of the test}
  readln(s);
  assert(s = trim(lowercase(s)), 'Incorrect test');

  st.x1 := ord(s[1]) - ord('a');
  st.y1 := ord(s[2]) - ord('1');
  st.x2 := ord(s[4]) - ord('a');
  st.y2 := ord(s[5]) - ord('1');

  fin.x1 := ord(s[7]) - ord('a');
  fin.y1 := ord(s[8]) - ord('1');
  fin.x2 := ord(s[10]) - ord('a');
  fin.y2 := ord(s[11]) - ord('1');

  q.init;
  q.add(st.x1, st.y1, st.x2, st.y2, 0);

  {initializing PREV array with values "never visited before"}
  fillchar(prev, sizeof(prev), -1);

  {processing all the queue, so long as we have enough time}
  while not q.empty do begin
    q.get(cur.x1, cur.y1, cur.x2, cur.y2, dist);

    if (cur.x1 = fin.x1) and (cur.y1 = fin.y1) and (cur.x2 = fin.x2) and (cur.y2 = fin.y2) then begin
      {answer found! backtracing}
      ansnum := 0;
      while true do begin
        inc(ansnum);
        ans[ansnum] := cur;
        if (cur.x1 = st.x1) and (cur.y1 = st.y1) and (cur.x2 = st.x2) and (cur.y2 = st.y2) then break;
        
        cur.x1 := prev[ans[ansnum].x1, ans[ansnum].y1, ans[ansnum].x2, ans[ansnum].y2].x1;
        cur.y1 := prev[ans[ansnum].x1, ans[ansnum].y1, ans[ansnum].x2, ans[ansnum].y2].y1;
        cur.x2 := prev[ans[ansnum].x1, ans[ansnum].y1, ans[ansnum].x2, ans[ansnum].y2].x2;
        cur.y2 := prev[ans[ansnum].x1, ans[ansnum].y1, ans[ansnum].x2, ans[ansnum].y2].y2;
      end;

      {output answer}
      writeln(ansnum - 1);
      for i := ansnum - 1 downto 1 do begin
        if (ans[i].x1 = ans[i + 1].x1) and (ans[i].y1 = ans[i + 1].y1) then begin
          writeln('B ', chr(ans[i].x2 + ord('a')), chr(ans[i].y2 + ord('1')));
        end else begin
          writeln('W ', chr(ans[i].x1 + ord('a')), chr(ans[i].y1 + ord('1')));
        end;


      end;

      halt;
    end;

    {adding new positions to queue}
    for i := 1 to 16 do begin
      if
      (cur.x1 + dx1[i] >= 0) and
      (cur.x1 + dx1[i] <= 7) and
      (cur.y1 + dy1[i] >= 0) and
      (cur.y1 + dy1[i] <= 7) and
      (cur.x2 + dx2[i] >= 0) and
      (cur.x2 + dx2[i] <= 7) and
      (cur.y2 + dy2[i] >= 0) and
      (cur.y2 + dy2[i] <= 7) and
      ((cur.x1 + dx1[i] <> cur.x2 + dx2[i]) or (cur.y1 + dy1[i] <> cur.y2 + dy2[i])) and
      (prev[cur.x1 + dx1[i], cur.y1 + dy1[i], cur.x2 + dx2[i], cur.y2 + dy2[i]].x1 = -1)
      then begin
        q.add(cur.x1 + dx1[i], cur.y1 + dy1[i], cur.x2 + dx2[i], cur.y2 + dy2[i], dist + 1);
        prev[cur.x1 + dx1[i], cur.y1 + dy1[i], cur.x2 + dx2[i], cur.y2 + dy2[i]].x1 := cur.x1;
        prev[cur.x1 + dx1[i], cur.y1 + dy1[i], cur.x2 + dx2[i], cur.y2 + dy2[i]].y1 := cur.y1;
        prev[cur.x1 + dx1[i], cur.y1 + dy1[i], cur.x2 + dx2[i], cur.y2 + dy2[i]].x2 := cur.x2;
        prev[cur.x1 + dx1[i], cur.y1 + dy1[i], cur.x2 + dx2[i], cur.y2 + dy2[i]].y2 := cur.y2;
      end;
    end;
  end;

  {Illegal condition - we did not found the answer}
  assert(false, 'Error in test or solution =)');
end.
