{$apptype CONSOLE}
{$O-,Q+,R+}

const
	IN_FILE = 'number.in';
	OUT_FILE = 'number.out';

	MAX_N = 1000;
	RADIX = 10;

type
	TVertex = record
		sum, res : integer;
	end;

var
	n : integer;
	firstq, nextq : array[0..MAX_N - 1] of integer;

	fused : array[0..MAX_N,0..MAX_N - 1] of boolean;
	bused : array[0..MAX_N,0..MAX_N - 1] of boolean;
	
	fd : array[0..MAX_N,0..MAX_N - 1] of integer;
	bd : array[0..MAX_N,0..MAX_N - 1] of integer;

	qhead, qtail : integer;
	queue : array[1..(1 + MAX_N) * MAX_N] of TVertex;
	
procedure ReadInput;
begin
	reset(input, IN_FILE);
	read(n);
	if (n < 1) or (n > MAX_N) then runerror(239);
	if not eoln then runerror(239);
	readln;
	if not eof then runerror(239);
	close(input);
end;

procedure InitQ;
var
	i, j : integer;
	
begin
	fillchar(firstq, sizeof(firstq), $ff);
	fillchar(nextq, sizeof(nextq), $ff);
	for i := 0 to n - 1 do begin
		j := (i * RADIX) mod n;
		nextq[i] := firstq[j];
		firstq[j] := i;
	end;
end;

procedure ForwardBFS;
var
	curv, newv : TVertex;
	i : integer;
		
begin
	fillchar(fused, sizeof(fused), false);
	qtail := 1;
	qhead := 1;
	queue[1].sum := 0;
	queue[1].res := 0;
	fused[0,0] := true;
	fd[0,0] := 0;
	
	while qtail <= qhead do begin
		curv := queue[qtail];
		inc(qtail);
		for i := 0 to RADIX - 1 do begin
			newv.sum := curv.sum + i;
			newv.res := (curv.res * RADIX + i) mod n;
			if (newv.sum <= n) and not fused[newv.sum,newv.res] then begin
				inc(qhead);
				queue[qhead] := newv;
				fused[newv.sum,newv.res] := true;
				fd[newv.sum,newv.res] := fd[curv.sum,curv.res] + 1;
			end;
		end;
	end;
end;

procedure BackwardBFS;
var
	curv, newv : TVertex;
	i, j : integer;
		
begin
	fillchar(bused, sizeof(bused), false);
	qtail := 1;
	qhead := 1;
	queue[1].sum := n;
	queue[1].res := 0;
	bused[n,0] := true;
    bd[n,0] := 0;

	while qtail <= qhead do begin
		curv := queue[qtail];
		inc(qtail);
		for i := 0 to RADIX - 1 do begin
			newv.sum := curv.sum - i;
			if newv.sum < 0 then
				continue;
			j := firstq[(curv.res - i + n) mod n];
			while j <> -1 do begin
				newv.res := j;
				if not bused[newv.sum,newv.res] then begin
					inc(qhead);
					queue[qhead] := newv;
					bused[newv.sum,newv.res] := true;
					bd[newv.sum,newv.res] := bd[curv.sum,curv.res] + 1;
				end;
				j := nextq[j];
			end;
		end;
	end;
end;

procedure WriteOutput;
var
	curv, newv : TVertex;
	i : integer;
	
begin
	rewrite(output, OUT_FILE);
	
	curv.sum := 0;
	curv.res := 0;
	while (curv.sum <> n) or (curv.res <> 0) do begin
		for i := 0 to RADIX - 1 do begin
			newv.sum := curv.sum + i;
			newv.res := (curv.res * RADIX + i) mod n;
			if (newv.sum <= n) and
				fused[newv.sum,newv.res] and bused[newv.sum,newv.res] and
				(fd[newv.sum,newv.res] = fd[curv.sum,curv.res] + 1) and
				(bd[newv.sum,newv.res] = bd[curv.sum,curv.res] - 1) then begin
				write(i);
				curv := newv;
				break;
			end;	
		end;
	end;
	writeln;
		
	close(output);	
end;

begin
	ReadInput;
	InitQ;
	ForwardBFS;
	BackwardBFS;
	WriteOutput;
end.
