{$R+,Q+,S+}
{$ASSERTIONS ON}
Program AFastSolution;

Type
  Real=Extended;
  Integer=LongInt;

Const
  TaskID='necklace2';
  InFile=TaskID+'.in';
  OutFile=TaskID+'.out';
  MaxN=100000;
  MaxK=10000;
  QSortEps=1e-13;
  CloseEps=1e-10;

Type
  THeapItem=Record
    ID:Integer;
    Value:Int64;
  End;
  THeap=Array[1..MaxK]Of THeapItem;
  TUnHeap=Array[1..MaxK]Of Integer;
  THigherFunc=Function(A,B:Int64):Boolean;
  TDiamond=Record
    Alpha:Real;
    Cost:Int64;
    At:Integer;
  End;

Var
  N,K:Integer;
  Diamond:Array[1..MaxN]Of TDiamond;
  Am:Array[1..MaxK]Of Int64;
  HeapMax,HeapMin:THeap;
  UnHeapMax,UnHeapMin:TUnHeap;
  Tmp:TDiamond;
  Res:Int64;

Procedure Load;
Var
  Cst:Integer;
  I:Integer;
Begin
  Assign(Input,InFile);
  ReSet(Input);
  Read(N,K);
  Assert((N>=1) And (N<=MaxN) And (K>=1) And (K<=MaxK));
  For I:=1 To N Do Begin
    Read(Diamond[I].Alpha,Cst);
    Diamond[I].Cost:=Cst;
  End;
  Assert(SeekEOF);
  Close(Input);
End;

Procedure QSort(L,R:Integer);
Var
  I,J:Integer;
  X:Real;
Begin
  X:=Diamond[L+Random(R-L+1)].Alpha;
  I:=L;
  J:=R;
  While I<=J Do Begin
    While Diamond[I].Alpha<X-QSortEps Do Inc(I);
    While X+QSortEps<Diamond[J].Alpha Do Dec(J);
    If I<=J Then Begin
      Tmp:=Diamond[I];
      Diamond[I]:=Diamond[J];
      Diamond[J]:=Tmp;
      Inc(I);
      Dec(J);
    End;
  End;
  If I<R Then QSort(I,R);
  If L<J Then QSort(L,J);
End;

Function HeapMaxHigher(A,B:Int64):Boolean;
Begin
  HeapMaxHigher:=(A>B);
End;

Function HeapMinHigher(A,B:Int64):Boolean;
Begin
  HeapMinHigher:=(A<B);
End;

Procedure Swap(Var H:THeap; Var U:TUnHeap; A,B:Integer);
Var
  T:THeapItem;
Begin
  T:=H[A];
  H[A]:=H[B];
  H[B]:=T;
  U[H[A].ID]:=A;
  U[H[B].ID]:=B;            
End;

Procedure HeapUp(Var H:THeap; Var U:TUnHeap; Higher:THigherFunc; At:Integer);
Begin
  While (At>1) And Higher(H[At].Value,H[At Div 2].Value) Do Begin
    Swap(H,U,At,At Div 2);
    At:=At Div 2;
  End;
End;

Procedure HeapDown(Var H:THeap; Var U:TUnHeap; Higher:THigherFunc; At:Integer);
Var
  I:Integer;
Begin
  While True Do Begin
    I:=At;
    If (2*At<=K) And Higher(H[2*At].Value,H[I].Value) Then I:=2*At;
    If (2*At+1<=K) And Higher(H[2*At+1].Value,H[I].Value) Then I:=2*At+1;
    If I=At Then Break;
    Swap(H,U,At,I);
    At:=I;
  End;
End;

Procedure Solve;
Const
  RandomShift=0.547139574319743191;
Var
  Pi,Slice:Real;
  Who,I:Integer;
  A:Real;
Begin
  Pi:=4*ArcTan(1);
  Slice:=(2*Pi)/K;
  FillChar(Am,SizeOf(Am),0);
  For I:=1 To N Do Begin
    A:=Diamond[I].Alpha+RandomShift;
    Who:=Trunc(A/Slice);
    A:=A-Who*Slice;
    Who:=Who Mod K+1;
    Diamond[I].At:=Who;
    Am[Who]:=Am[Who]+Diamond[I].Cost;
    Diamond[I].Alpha:=A;
  End;

  QSort(1,N);

  For I:=1 To N-1 Do Assert(Diamond[I+1].Alpha-Diamond[I].Alpha>CloseEps);

  For I:=1 To K Do Begin
    HeapMax[I].ID:=I;
    HeapMax[I].Value:=Am[I];
    UnHeapMax[I]:=I;
    HeapUp(HeapMax,UnHeapMax,@HeapMaxHigher,I);
    HeapMin[I].ID:=I;
    HeapMin[I].Value:=Am[I];
    UnHeapMin[I]:=I;
    HeapUp(HeapMin,UnHeapMin,@HeapMinHigher,I);
  End;

  Res:=HeapMax[1].Value-HeapMin[1].Value;

  For I:=1 To N Do Begin
    Who:=Diamond[I].At;
    Dec(Am[Who],Diamond[I].Cost);
    HeapMax[UnHeapMax[Who]].Value:=Am[Who];
    HeapDown(HeapMax,UnHeapMax,@HeapMaxHigher,UnHeapMax[Who]);
    HeapMin[UnHeapMin[Who]].Value:=Am[Who];
    HeapUp(HeapMin,UnHeapMin,@HeapMinHigher,UnHeapMin[Who]);
    Dec(Who);
    If Who=0 Then Who:=K;
    Inc(Am[Who],Diamond[I].Cost);
    HeapMax[UnHeapMax[Who]].Value:=Am[Who];
    HeapUp(HeapMax,UnHeapMax,@HeapMaxHigher,UnHeapMax[Who]);
    HeapMin[UnHeapMin[Who]].Value:=Am[Who];
    HeapDown(HeapMin,UnHeapMin,@HeapMinHigher,UnHeapMin[Who]);
    If HeapMax[1].Value-HeapMin[1].Value<Res Then
      Res:=HeapMax[1].Value-HeapMin[1].Value;
  End;
End;

Procedure Save;
Begin
  Assign(Output,OutFile);
  ReWrite(Output);
  WriteLn(Res);
  Close(Output);
End;

Begin
  RandSeed:=754717411;
  Load;
  Solve;
  Save;
End.
