#include <iostream>
#include <vector>
#include <map>
#include <set>
#include <algorithm>
#include <cassert>
#include <cstdio>

using namespace std;

#define forn(i, n) for (int i = 0; i < (n); i++)

#define INFILE "network.in"
#define OUTFILE "network.out"

#define NMAX (200)
#define INF (1000000000)

int n, l, k, m;
int A[NMAX];
int B[NMAX];
int p;
int ans;

typedef struct hub
{
    int d;
    int idx;
    int entry;
    int position;
    int link[NMAX];
} hub;

hub hubs[NMAX], best[NMAX];
int nhubs;
int nbest;

int solve()
{
    int zero = B[0];
    forn(i, n)
    {
        B[i] -= zero;
        while (B[i] < 0)
            B[i] += l;
    }

    if (n == 1)
        return 0;
    if (n == 2)
    {
        nhubs = 1;
        hubs[0].d = 2;
        hubs[0].link[0] = 0;
        hubs[0].link[1] = 1;
        hubs[0].position = 0;
        return abs(B[0] - B[1]);
    }

    int ADD[NMAX][NMAX];
    int P[NMAX][NMAX];
    forn(l, n)
    {
        forn(i, n - l)
        {
            int j = i + l;
            if (l == 0)
                ADD[i][j] = 0;
            else if (l == 1)
                ADD[i][j] = B[j] - B[i];
            else
            {
                ADD[i][j] = ADD[i + 1][j - 1] + B[j] - B[i];
            }
        }
    }

    int Z[NMAX][NMAX];
    /* Z[i][j] = solution for points 1..i and use j hubs
     */
    forn(j, m + 1)
        Z[0][j] = B[n - 1] - B[0];

    for (int i = 1; i <= n - 2; i++)
    {
        for (int j = 0; j <= m; j++)
        {
            if (j * (k - 1) < i)
                Z[i][j] = INF;
            else
            {
                Z[i][j] = Z[i][j - 1];
                for (int cnt = 1; cnt <= k - 1; cnt++)
                {
                    int prev = i - cnt;
                    if (prev >= 0)
                    {
                        int add = ADD[i - cnt + 1][i];
                        if (Z[i][j] > Z[prev][j - 1] + add)
                        {
                            Z[i][j] = Z[prev][j - 1] + add;
                            P[i][j] = prev;
                        }
                    }
                }
            }
        }
    }

    int ret = INF - 1;
    forn(i, m + 1)
    {
        if (ret > Z[n - 2][i])
        {
            nhubs = i;
            ret = min(ret, Z[n - 2][i]);
            memset(hubs, 0, sizeof(hubs));
            forn(j, i)
                hubs[j].d = 2, hubs[j].idx = j + 1;
            forn(j, i)
            {
                hubs[j].d = 2;
                if (j == 0)
                {
                    hubs[j].link[0] = 0;
                    if (nhubs > 1)
                        hubs[j].link[1] = - hubs[j + 1].idx;
                }
                if (j + 1 == i)
                {
                    if (nhubs > 1)
                        hubs[j].link[0] = - hubs[j - 1].idx;
                    hubs[j].link[1] = n - 1;
                }
                if (0 < j && j + 1 < i)
                {
                    hubs[j].link[0] = - hubs[j - 1].idx;
                    hubs[j].link[1] = - hubs[j + 1].idx;
                }
            }
            int row = n - 2;
            int col = i;

            while (col > 0)
            {
                int p = P[row][col];
                hubs[col - 1].position = row - (row - p) / 2; 
                forn(j, row - p)
                {
                    hubs[col - 1].link[hubs[col - 1].d++] = row - j;
                }
                row = p;
                col--;
            }

            assert(row == 0);
        }
    }

    return ret;
}

void rec(int idx, int entry, set <int> &used)
{
    if (used.count(idx))
        return;
    used.insert(idx);
    best[idx].entry = entry;
    forn(i, nbest)
        forn(j, best[i].d)
            if (best[i].link[j] == - best[idx].idx)
                rec(i, j, used);
}

int main()
{
    freopen(INFILE, "rt", stdin);
    freopen(OUTFILE, "wt", stdout);

    assert(cin >> n >> l >> k >> m);
    assert(1 <= n && n <= 100);
    assert(1 <= l && l <= 1000000);
    assert(1 <= k && k <= 100);
    assert(1 <= m && m <= 100);

    set <int> positions;
    positions.insert(0);

    A[0] = 0;
    forn(i, n)
    {
        assert(cin >> A[i + 1]);
        assert(0 < A[i + 1] && A[i + 1] < l);
        assert(A[i + 1] > A[i]);
        positions.insert(A[i + 1]);
    }
    n++;

    assert(positions.size() == n);

    ans = INF;

    forn(i, n)
    {
        forn(j, n)
            B[j] = A[(i + j) % n];
        int psolve = solve();
        if (psolve < ans)
        {
            ans = psolve;
            nbest = nhubs;
            forn(k, nhubs)
            {
                forn(j, hubs[k].d)
                    if (hubs[k].link[j] >= 0)
                        hubs[k].link[j] = (hubs[k].link[j] + i) % n;
                hubs[k].position = (hubs[k].position + i) % n;
            }
            memmove(best, hubs, sizeof(best));
        }
    }

    if (ans < INF / 2)
    {
        set <int> used;
        forn(i, nbest)
            forn(j, best[i].d)
                if (best[i].link[j] == 0)
                    rec(i, j, used);

        forn(i, nbest)
            swap(best[i].link[0], best[i].link[best[i].entry]);

        printf("%d\n", nbest);
        forn(i, nbest)
        {
            printf("%d", A[best[i].position]);
            forn(j, best[i].d)
                printf(" %d", best[i].link[j]);
            printf("\n");
        }
    }
    else
        printf("%d\n", -1);

    fclose(stdin);
    fclose(stdout);

    return 0;
}