#include <stdio.h>
#include <math.h>

#define NEDEBUG 1

#define FILE_IN "tractor.in"
#define FILE_OUT "tractor.out"

#define MAXN 80
#define MAXXY 1000.0
#define MINXY -1000.0
#define MAXSPEED 100.0
#define MINSPEED 0.1

#define eps 1e-7

#define assert(x,str) {if (!(x)) {printf("%s %s","Assert failed - ",str);return 222;}}

#ifdef NEDEBUG
#define sqrtl sqrt
#define fabsl fabs
#endif

typedef long double extended;

struct POINT {
  extended x,y;
};

int pos[(MAXN+1)*(MAXN+1)];
POINT a[(MAXN+1)*(MAXN+1)];
int n,all;
extended u,v,sing,tang;

extended b[(MAXN+1)*(MAXN+1)];
int be[(MAXN+1)*(MAXN+1)];

extended CrossProduct(POINT *a1,POINT *a2,POINT *b1,POINT *b2){
  return (a2->x-a1->x)*(b2->y-b1->y)-(b2->x-b1->x)*(a2->y-a1->y);
}

extended ScalProduct(POINT *a1,POINT *a2,POINT *b1,POINT *b2){
  return (a2->x-a1->x)*(b2->x-b1->x)+(a2->y-a1->y)*(b2->y-b1->y);
}

int sign(extended a){
  if (a>eps) return 1;
  else if (a>-eps) return 0;
  else return -1;
}

int Cross(POINT *a1,POINT *a2,POINT *b1,POINT *b2){
  if (sign(a1->x-b1->x)==0 &&  sign(a1->y-b1->y)==0) return 1;
  if (sign(a1->x-b2->x)==0 &&  sign(a1->y-b2->y)==0) return 1;
  if (sign(a2->x-b1->x)==0 &&  sign(a2->y-b1->y)==0) return 1;
  if (sign(a2->x-b2->x)==0 &&  sign(a2->y-b2->y)==0) return 1;
  
  int t1=sign(CrossProduct(a1,b1,a1,a2));
  int t2=sign(CrossProduct(a1,a2,a1,b2));
  if (t1*t2!=-1) {
    t1=sign(CrossProduct(b1,a1,b1,b2));
    t2=sign(CrossProduct(b1,b2,b1,a2));
    if (t1*t2==0) {
      if (sign(ScalProduct(a1,b2,a1,b1))==-1) return 1;
      if (sign(ScalProduct(a2,a2,a2,b1))==-1) return 1;
      if (sign(ScalProduct(b1,a2,b1,a1))==-1) return 1;
    } else if (t1*t2!=-1) return 1;
  }
  return 0;
}

int CrossPoint(POINT * a,POINT *b1,POINT *b2){
  if (sign(ScalProduct(a,b1,a,b2))==-1 && sign (CrossProduct(a,b1,a,b2))==0) return 1;
  else return 0;
}

extended Dist(POINT *a,POINT *b){
  return sqrtl((a->x-b->x)*(a->x-b->x)+(a->y-b->y)*(a->y-b->y));
}

extended GetH(POINT *a,POINT *b1,POINT *b2){
  return fabsl(CrossProduct(a,b1,a,b2)/Dist(b1,b2)); 
}

int  GetP(POINT *o, POINT *a1,POINT *a2, POINT *ans){
  POINT cen;
  cen.x=0;
  cen.y=0;
  ans->y=a2->x-a1->x;
  ans->x=a1->y-a2->y;
  extended coof=GetH(o,a1,a2);
  if (sign(coof)==0) return 0;
  coof/=Dist(&cen,ans);
  ans->x*=coof;
  ans->y*=coof;
  ans->x+=o->x;
  ans->y+=o->y;
  
  if (sign(CrossProduct(a1,a2,a1,ans))!=0){
    ans->x=2*o->x-ans->x;
    ans->y=2*o->y-ans->y;
  }
  
  return 1;
}

extended GetWay(int i,int j){
  if (i<j) {
    i=i+j;
    j=i-j;
    i=i-j;
  }
  if (i==j+1 && i<n+1) return Dist(&a[i],&a[j])/v;
  if (j<n+1 && i>=n+1 && (pos[i]==j || pos[i]==j-1)) return Dist(&a[i],&a[j])/v;
  if (i>=n+1 && j>=n+1 && pos[i]==pos[j]) return Dist(&a[i],&a[j])/v;
  return Dist(&a[i],&a[j])/u;
}

extended Deijkstra(int s,int f){
  be[s]=1;
  int i;
  for (i=0;i<all;i++) {
    b[i]=GetWay(s,i);
  }
  for(;;){
    int min=-1;
    for (i=0;i<all;i++)
      if (!be[i]){
        if (min==-1) min=i;
        else if (b[min]>b[i]) min=i;
      }
    be[min]=1;
    if (min==f) return b[f];
    for (i=0;i<all;i++)
      if (!be[i]){
        if (b[i]>b[min]+GetWay(min,i)) b[i]=b[min]+GetWay(min,i);
      }
  }
}

int main(){
  freopen(FILE_IN,"r",stdin);
  freopen(FILE_OUT,"w",stdout);

  assert(scanf("%d",&n)==1,"Wrong input");
  assert(scanf("%Lf",&u)==1,"Wrong input");
  assert(scanf("%Lf",&v)==1,"Wrong input");

  assert(n<=MAXN,"Wrong N");
  assert(1<=n,"Wrong N");

  assert(sign(v-u)==1,"v<=u");
  assert(sign(u-MINSPEED)>-1,"wrong u");
  assert(sign(v-MAXSPEED)<1,"wrong v");

  int i;
  for (i=0;i<n+1;i++) {
    assert(scanf("%Lf %Lf",&a[i].x,&a[i].y)==2,"Wrong input");
    assert(a[i].x<=MAXXY,"Wrong X");
    assert(a[i].y<=MAXXY,"Wrong Y");
    assert(MINXY<=a[i].x,"Wrong X");
    assert(MINXY<=a[i].y,"Wrong Y");
    pos[i]=-1;
  }

  sing=u/v;
  tang=sing/sqrtl(1-sing*sing);

  int j;
  for (i=0;i<n;i++){
    for (j=i+2;j<n;j++) {
      assert(!Cross(&a[i],&a[i+1],&a[j],&a[j+1]),"They are crossing!");
    }
  }
  for (i=0;i<n+1;i++)
    for (j=0;j<n;j++)
      if (j!=i && j!=i-1) assert(!CrossPoint(&a[i],&a[j],&a[j+1]),"point lies on the segment");

  all=n+1;
  POINT z,t;
  extended coof;
  for (i=0;i<n+1;i++) {
    for (j=0;j<n;j++) {
      if (GetP(&a[i],&a[j],&a[j+1],&z)) {
        coof=(GetH(&a[i],&a[j],&a[j+1])*tang)/Dist(&a[j],&a[j+1]);
        t.x=coof*(a[j].x-a[j+1].x);
        t.y=coof*(a[j].y-a[j+1].y);
        a[all].x=z.x+t.x;
        a[all].y=z.y+t.y;
        pos[all]=j;
        if (sign(ScalProduct(&a[all],&a[j],&a[all],&a[j+1]))==-1) {
          all++;
        }
        a[all].x=z.x-t.x;
        a[all].y=z.y-t.y;
        pos[all]=j;
        if (sign(ScalProduct(&a[all],&a[j],&a[all],&a[j+1]))==-1) {
          all++;
        }
      }
    }
  }

  for (i=0;i<all;i++) be[i]=0;

  extended path=0;
  extended ans=Deijkstra(0,n);
  for (i= 0; i < n; i++)
  {
    path += Dist(&a[i],&a[i + 1]) / v;
  }

  printf("%.15Lf",ans);//path);

  fclose(stdin);
  fclose(stdout);
  return 0;
}
