#include <stdio.h>
#include <math.h>

#define SQR(X) ((X) * (X))
#define MINI(A, B) ((A) < (B) ? (A) : (B))
#define MAXI(A, B) ((A) > (B) ? (A) : (B))
#define SIGN(A) ((A) > EPS ? 1 : ((A) < -EPS ? -1 : 0))

#define EPS 1e-9

#define MAX 209

typedef int mas[MAX * 2];
typedef double dbl;
typedef dbl mas2[MAX * MAX * 8];

int N, K, PN;
mas X, Y, KX, KY;
mas2 PX, PY;
dbl X1, Y1, X2, Y2, ResX, ResY;

void Add( dbl x, dbl y )
{
  PX[PN] = x, PY[PN++] = y;
}

int Intr( dbl R, int a, int b, int c )
{
  dbl d, a1, b1, c1, tmp, ab;

  if (!a && !b)
    return 0;
  ab = a * a + b * b;
  tmp = 1.0 / ab;
  d = c * c * tmp;
  if (R * R + EPS < d) 
    return 0;
  a1 = -b;
  b1 = a;
  c1 = sqrt(fabs(R * R - d) * ab);
  X1 = -(c * b1 - c1 * b) * tmp;
  Y1 = -(c * a1 - c1 * a) * -tmp;
  X2 = -(c * b1 + c1 * b) * tmp;
  Y2 = -(c * a1 + c1 * a) * -tmp;
  return 1;
}

void Intr1( int i, int j, dbl R )
{
  int cx = KX[j] - KX[i], cy = KY[j] - KY[i], a, b, c;

  a = 2 * cx;
  b = 2 * cy;
  c = -(cx * cx + cy * cy);
  if (!Intr(R, a, b, c))
    return;
  Add(X1 + KX[i], Y1 + KY[i]);
  Add(X2 + KX[i], Y2 + KY[i]);
}

void Intr2( int i, int p1, int p2, dbl R )
{
  int a, b, c, x1, y1, x2, y2;

  x1 = X[p1] - KX[i], y1 = Y[p1] - KY[i];
  x2 = X[p2] - KX[i], y2 = Y[p2] - KY[i];
  a = y2 - y1;
  b = x1 - x2;
  c = -(a * x1 + b * y1);
  if (!Intr(R, a, b, c))
    return;
  if (MINI(x1, x2) - EPS <= X1 && X1 <= MAXI(x1, x2) + EPS &&
      MINI(y1, y2) - EPS <= Y1 && Y1 <= MAXI(y1, y2) + EPS)
    Add(X1 + KX[i], Y1 + KY[i]);
  if (MINI(x1, x2) - EPS <= X2 && X2 <= MAXI(x1, x2) + EPS &&
      MINI(y1, y2) - EPS <= Y2 && Y2 <= MAXI(y1, y2) + EPS)
    Add(X2 + KX[i], Y2 + KY[i]);
}

int IsIn( dbl x, dbl y )
{
  int i, s1, s2;

  for (i = 0; i < N; i++)
  {
    s1 = SIGN((Y[i + 1] - Y[i]) * (x - X[i]) - (y - Y[i]) * (X[i + 1] - X[i]));
    s2 = SIGN((Y[i + 1] - Y[i]) * (X[i + 2] - X[i]) - (Y[i + 2] - Y[i]) * (X[i + 1] - X[i]));
    if (s1 && s2 && s1 != s2)
      return 0;
    if (N < 3 && s1)
      return 0;
  }            
  return 1;             
}

int F( dbl R )
{
  dbl R2;
  int i, j;

  R2 = R * R;
  PN = 0;
  for (i = 0; i < N; i++)
    Add(X[i], Y[i]);
  for (i = 0; i < K; i++)
  {
    for (j = i + 1; j < K; j++)
      Intr1(i, j, R);
    for (j = 0; j < N; j++)
      Intr2(i, j, j + 1, R);
  }
  for (i = 0; i < PN; i++)
  {
    for (j = 0; j < K; j++)
      if (SQR(KX[j] - PX[i]) + SQR(KY[j] - PY[i]) + EPS < R2)
        break;
    if (j < K)
      continue;
    if (!IsIn(PX[i], PY[i]))  
      continue;
    ResX = PX[i], ResY = PY[i];
    return 1;
  }
  return 0;
}

int main( void )
{
  dbl min = 0, ave, max = 3e3;
  int i;

  freopen("fire.in", "rt", stdin);
  freopen("fire.out", "wt", stdout);
  scanf("%d", &N);
  for (i = 0; i < N; i++)
    scanf("%d%d", &X[i], &Y[i]);
  for (i = 0; i < N; i++)
    X[N + i] = X[i], Y[N + i] = Y[i];
  scanf("%d", &K);
  for (i = 0; i < K; i++)
    scanf("%d%d", &KX[i], &KY[i]);
  if (N == 1)
  {
    printf("%d %d", X[0], Y[0]);
    return 0;
  }
  while (min + EPS < max)
  {
    ave = (min + max) * 0.5;
    if (F(ave))
      min = ave;
    else
      max = ave;
  }
  printf("%.4lf %.4lf", ResX, ResY);
  return 0;
}
