#include <cstdio>
#include <cmath>
#include <limits>
#include <utility>
#include <algorithm>
#include <vector>

using namespace std;


const long double inf=numeric_limits<long double>::max()/4.L;

struct point {
  long double x,y;
  int id;
  long double operator[](const point&arg) const {
    long double dx=x-arg.x,dy=y-arg.y;
    return(dx*dx+dy*dy);
  }
  point operator+(const point&arg) const {
    point res=*this;
    res.x+=arg.x;
    res.y+=arg.y;
    return(res);
  }
  point operator-(const point&arg) const {
    point res=*this;
    res.x-=arg.x;
    res.y-=arg.y;
    return(res);
  }
  point operator*(const long double arg) const {
    point res=*this;
    res.x*=arg;
    res.y*=arg;
    return(res);
  }
  long double operator*(const point&arg) const { return(x*arg.x+y*arg.y); }
  bool operator==(const point&arg) const { return((x==arg.x)&&(y==arg.y)); }
  bool operator!=(const point&arg) const { return((x!=arg.x)||(y!=arg.y)); }
};
typedef pair<point,point> segment;

int n_segs,n_pnts;
long double speed_0,speed_1,speed_fact;
vector<point> pnts;
vector<segment> segs;
vector<char> marks;
vector<long double> dists;

int main(void) {
  #ifndef OFFLINE
  freopen("tractor.in","rt",stdin);
  freopen("tractor.out","wt",stdout);
  #endif
  int i_seg,i_pnt;
  scanf("%d%Lf%Lf",&n_segs,&speed_0,&speed_1);
  speed_fact=speed_0/speed_1;
  speed_fact/=sqrt(1.L-speed_fact*speed_fact);
  pnts.reserve((n_segs+1)*(n_segs+1)*5);
  pnts.resize(n_segs+1);
  segs.resize(n_segs);
    scanf("%Lf%Lf",&pnts.front().x,&pnts.front().y);
    pnts.front().id=0;
  for (i_seg=0; i_seg<n_segs; ++i_seg) {
    scanf("%Lf%Lf",&pnts[i_seg+1].x,&pnts[i_seg+1].y);
    pnts[i_seg+1].id=i_seg;
    segs[i_seg].first=pnts[i_seg];
    segs[i_seg].second=pnts[i_seg+1];
  }
  for (i_pnt=0; i_pnt<=n_segs; ++i_pnt)
   for (i_seg=0; i_seg<n_segs; ++i_seg)
   if ((segs[i_seg].first!=pnts[i_pnt])&&(segs[i_seg].second!=pnts[i_pnt])) {
    point diff,norm,spot; long double fact;
    diff=segs[i_seg].second-segs[i_seg].first;
    if ((fact=diff*diff)<=0) continue;
    fact=((pnts[i_pnt]-segs[i_seg].first)*diff)/fact;
    norm=(spot=segs[i_seg].first+diff*fact)-pnts[i_pnt];
    //printf("%Lf\n",norm*diff);
    fact=sqrt((norm*norm)/(diff*diff))*speed_fact;
    norm.id=i_seg;
    pnts.push_back(norm);
    pnts.push_back(norm-diff*fact);
    pnts.push_back(norm+diff*fact);
  }
  int cur,to; long double dist;
  n_pnts=pnts.size();
  marks.resize(n_pnts); dists.resize(n_pnts);
  fill(dists.begin(),dists.end(),inf);
  dists[0]=0;
  for (;;) {
    for (cur=0; cur<n_pnts; ++cur) if (!marks[cur]) break;
    for (to=cur; to<n_pnts; ++to) if (!marks[to])
      if (dists[cur]>dists[to]) cur=to;
    if (cur>=n_pnts) break;
    marks[cur]=1;
    for (to=0; to<n_pnts; ++to) if (!marks[to]) {
      dist=sqrt(pnts[cur][pnts[to]]);
      if (pnts[cur].id!=pnts[to].id) dist/=speed_0; else dist/=speed_1;
      dist+=dists[cur];
      if (dists[to]>dist) dists[to]=dist;
    }
  }
  printf("%.15Lf\n",dists[n_segs]);
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


