#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>

using namespace std;

vector<char> string_buf(127);


enum { MODE_TRIVIAL=0,MODE_LUCK=1,MODE_AREA=2,MODE_TEST=4 };

const int mode=MODE_LUCK|MODE_AREA;
const unsigned seed=13;


class disjointsetunion {
    struct t_node {
      int id,head,rank;
      t_node*parent;
    };
  private:
    vector<t_node> nodes;
  protected:
    t_node* gettop(t_node*node) {
      t_node*top,*cur,*to;
      for (top=node; top->parent; top=top->parent);
      for (cur=node; (to=cur->parent); cur=to) cur->parent=top;
      return(top);
    }
  public:
    int operator[](int u) { return(gettop(&nodes[u])->head); }
    int joined(int v,int w) {
      t_node*a=gettop(&nodes[v]),*b=gettop(&nodes[w]);
      return(a->id==b->id);
    }
    int join(int v,int w) {
      t_node*a=gettop(&nodes[v]),*b=gettop(&nodes[w]);
      if (a->id==b->id) return(a->head);
      if (a->rank>=b->rank) {
        b->parent=a;
        if (a->rank==b->rank) ++a->rank;
      } else {
        a->parent=b;
        b->head=a->head;
      }
      return(a->head);
    }
    void init(int n_nodes) {
      int i_node;
      nodes.resize(n_nodes);
      for (i_node=0; i_node<n_nodes; ++i_node) {
        nodes[i_node].id=i_node;
        nodes[i_node].head=i_node;
        nodes[i_node].rank=0;
        nodes[i_node].parent=0;
      }
    }
    void reset(void) {
      vector<t_node>::iterator p_node;
      for (p_node=nodes.begin(); p_node!=nodes.end(); ++p_node) {
        p_node->rank=0;
        p_node->parent=0;
      }
    }
};

class game {
    enum { n_dirs=4 };
    struct t_cell {
      int color,part;
      int adj[n_dirs];
    };
    struct t_part {
      int color,size;
      char*parts_adj;
      int*sizes_adj;
    };
    struct t_colorinfo {
      int color,size,area,square;
      int luck;
      bool operator<(const t_colorinfo&arg) const {
        if (square*5>arg.square*6) return(true);
        if (square*6<arg.square*5) return(false);
        if (area>arg.area) return(true); if (area<arg.area) return(false);
        if (size>arg.size) return(true); if (size<arg.size) return(false);
        return(luck^arg.luck);
      }
    };
    int mode;
  private:
    int n_x,n_y,n_cells,i_cell_0,i_cell_1,diff_best;
    int n_colors,color_0,color_1,color_best;
    int n_parts,part_0,part_1;
    vector<t_cell> cont; vector<t_cell*> mtrx;
    vector<char> parts_parts_adj; vector<int> parts_sizes_adj;
    vector<t_part> parts; disjointsetunion groups;
    vector<int> que_in,que_out;
    void que(void) {
      while (!que_in.empty())
      que_out.push_back(que_in.back()),que_in.pop_back();
    }
  protected:
    void search(int cur) {
      int to; int i_dir;
      que_in.clear(); que_out.clear();
      t_part&part_cur=parts[n_parts];
      que_in.push_back(cur); cont[cur].part=n_parts;
      part_cur.color=cont[cur].color; part_cur.size=1;
      for (que(); !que_out.empty(); que()) while (!que_out.empty()) {
        cur=que_out.back(),que_out.pop_back();
        for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          if (cont[to].part<0) {
            if (cont[to].color!=cont[cur].color) continue;
            que_in.push_back(to);
            cont[to].part=n_parts;
            ++part_cur.size;
          } else if (cont[to].part<n_parts) {
            t_part&part_to=parts[cont[to].part];
            part_cur.parts_adj[cont[to].part]=1;
            part_to.parts_adj[n_parts]=1;
          }
        }
      }
    }
    void findparts(void) {
      int i_cell=0;
      for (i_cell=0; i_cell<n_cells; ++i_cell) cont[i_cell].part=-1;
      n_parts=0; part_0=-1; part_1=-1;
      fill(parts_parts_adj.begin(),parts_parts_adj.end(),0);
      for (i_cell=0; i_cell<n_cells; ++i_cell) if (cont[i_cell].part<0) {
        search(i_cell); ++n_parts;
      }
      part_0=cont[i_cell_0].part; part_1=cont[i_cell_1].part;
      groups.init(n_parts);
    }
    void calcadjsizes(void) {
      int cur,to;
      fill(parts_sizes_adj.begin(),parts_sizes_adj.end(),0);
      for (cur=0; cur<n_parts; ++cur) for (to=0; to<n_parts; ++to)
       if (parts[cur].parts_adj[to])
        parts[cur].sizes_adj[parts[to].color]+=parts[to].size;
    }
    int calcarea(const disjointsetunion&grps_base,
                  int part,int part_not,int color) {
      int cur,to,i_dir; int part_cur,part_to;
      int area=0;
      disjointsetunion grps(grps_base);
      part=grps[part]; part_not=grps[part_not];
      for (cur=0; cur<n_cells; ++cur) {
        part_cur=grps[cont[cur].part];
        if (part_cur==part)
         for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          part_to=grps[cont[to].part];
          if (part_to!=part)
          if (parts[part_to].color==color) grps.join(part,part_to);
        }
      }
      for (cur=0; cur<n_cells; ++cur) {
        part_cur=grps[cont[cur].part];
        if (part_cur!=part)
         for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          part_to=grps[cont[to].part];
          if (part_to!=part) grps.join(part_cur,part_to);
        }
      }
      for (part_cur=0; part_cur<n_parts; ++part_cur)
       if (!grps.joined(part_not,part_cur))
        area+=parts[part_cur].size;
      return(area);
    }
    void calcareasq(int&area,int&square,const disjointsetunion&grps_base,
                  int part,int part_not,int color) {
      int cur,to,i_dir; int part_cur,part_to;
      area=0;
      disjointsetunion grps(grps_base);
      part=grps[part]; part_not=grps[part_not];
      for (cur=0; cur<n_cells; ++cur) {
        part_cur=grps[cont[cur].part];
        if (part_cur!=part)
         for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          part_to=grps[cont[to].part];
          if (part_to!=part) grps.join(part_cur,part_to);
        }
      }
      for (part_cur=0; part_cur<n_parts; ++part_cur)
       if (grps[part_cur]!=part)
       if (!grps.joined(part_not,part_cur))
        area-=parts[part_cur].size;
      grps=disjointsetunion(grps_base);
      for (cur=0; cur<n_cells; ++cur) {
        part_cur=grps[cont[cur].part];
        if (part_cur==part)
         for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          part_to=grps[cont[to].part];
          if (part_to!=part)
          if (parts[part_to].color==color) grps.join(part,part_to);
        }
      }
      for (cur=0; cur<n_cells; ++cur) {
        part_cur=grps[cont[cur].part];
        if (part_cur!=part)
         for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          part_to=grps[cont[to].part];
          if (part_to!=part) grps.join(part_cur,part_to);
        }
      }
      for (part_cur=0; part_cur<n_parts; ++part_cur)
       if (!grps.joined(part_not,part_cur))
        area+=parts[part_cur].size;
      int x_1=-1,y_1=-1,xy_1=-1,x_0=n_x,y_0=n_y,xy_0=n_x+n_y,x,y,xy;
      for (cur=0; cur<n_cells; ++cur) {
        if (grps[cont[cur].part]!=part) continue;
        x=cur/n_y; y=cur%n_y;
        xy=x+y;
        if (x_0>x) x_0=x; if (x_1<x) x_1=x;
        if (y_0>y) y_0=y; if (y_1<y) y_1=y;
        if (xy_0>xy) xy_0=xy; if (xy_1<xy) xy_1=xy;
      } ++(x_1-=x_0); ++(y_1-=y_0); ++(xy_1-=xy_0);
      square=x_1*y_1+xy_1*xy_1;
    }
    void calccolorinfo(vector<t_colorinfo>&csinfo,int part,int part_not) {
      int color;
      for (color=0; color<n_colors; ++color) {
        csinfo[color].color=color;
        if ((color!=parts[part].color)&&(color!=parts[part_not].color)) {
          csinfo[color].size=parts[part].sizes_adj[color];
          if (mode&MODE_AREA)
            calcareasq(csinfo[color].area,csinfo[color].square,groups,
            part,part_not,color);
          else {
            csinfo[color].area=0;
            csinfo[color].square=0;
          }
          if (mode&MODE_LUCK) csinfo[color].luck=rand()&1;
          else csinfo[color].luck=0;
        } else {
          csinfo[color].size=-1;
          csinfo[color].area=-1;
          csinfo[color].square=-1;
          csinfo[color].luck=0;
        }
      }
      sort(csinfo.begin(),csinfo.end());
    }
    int rectest(const disjointsetunion&grps_base,
                int part,int part_not,int color,int level=0) {
      int cur,to,i_dir; int part_cur,part_to;
      disjointsetunion grps(grps_base);
      for (cur=0; cur<n_cells; ++cur) {
        part_cur=grps[cont[cur].part];
        if (part_cur==part)
         for (i_dir=0; i_dir<n_dirs; ++i_dir)
         if ((to=cont[cur].adj[i_dir])>=0) {
          part_to=grps[cont[to].part];
          if (part_to!=part)
          if (parts[part_to].color==color) grps.join(part_to,part);
        }
      } part=grps[part]; part_not=grps[part_not];
      vector<t_colorinfo> csinfo(n_colors);
      vector<t_colorinfo>::iterator p_cinfo;
      int color_with;
      calccolorinfo(csinfo,part_not,part);
      color_with=csinfo.front().color;
      if (level>0) {
        int diff_with,diff,color_to;
        diff_with=rectest(grps,part_not,part,color_best);
        for (p_cinfo=csinfo.begin(); p_cinfo!=csinfo.end(); ++p_cinfo) {
          color_to=p_cinfo->color;
          if ((color_to==parts[part].color)
            ||(color_to==parts[part_not].color)) continue;
          diff=rectest(grps,part_not,part,color_to,level-1);
          if (diff_with<diff) { color_with=color; diff_with=diff; }
        }
      }
      return(calcarea(grps,part,part_not,color)-
             calcarea(grps,part_not,part,color_with));
    }
  public:
    void findbest(void) {
      vector<t_colorinfo> csinfo(n_colors);
      vector<t_colorinfo>::iterator p_cinfo;
      findparts(); calcadjsizes();
      calccolorinfo(csinfo,part_0,part_1);
      color_best=csinfo.front().color;
      if (mode&MODE_TEST) {
        int level,diff,color;
        diff_best=rectest(groups,part_0,part_1,color_best);
        for (level=0; level<2; ++level)
         for (p_cinfo=csinfo.begin(); p_cinfo!=csinfo.end(); ++p_cinfo) {
          color=p_cinfo->color;
          if ((color==color_0)||(color==color_1)) continue;
          diff=rectest(groups,part_0,part_1,color,level);
          if (diff_best<diff) { color_best=color; diff_best=diff; }
        }
      }
    }
    void scan(void) {
      int x,y,i_cell;
      n_cells=(n_x=41)*(n_y=45); n_colors=6;
      i_cell_0=0; i_cell_1=n_cells-1;
      cont.resize(n_cells); mtrx.resize(n_x);
      for (x=0,y=0; x<n_x; ++x,y+=n_y) mtrx[x]=&cont[y];
      for (i_cell=0,x=0; x<n_x; ++x) {
        scanf("%s",&string_buf.front());
        for (y=0; y<n_y; ++i_cell,++y) {
          cont[i_cell].color=
            (static_cast<int>(string_buf[y]-'1')%n_colors+n_colors)%n_colors;
          cont[i_cell].adj[0]=(x>0?i_cell-n_y:-1);
          cont[i_cell].adj[1]=(y>0?i_cell-1:-1);
          cont[i_cell].adj[2]=(x+1<n_x?i_cell+n_y:-1);
          cont[i_cell].adj[3]=(y+1<n_y?i_cell+1:-1);
        }
      }
      color_0=cont[i_cell_0].color; color_1=cont[i_cell_1].color;
      color_best=-1;
      parts_parts_adj.resize(n_cells*n_cells);
      parts_sizes_adj.resize(n_cells*n_colors);
      parts.resize(n_cells);
      for (x=0,y=0; x<n_cells; ++x,y+=n_cells)
        parts[x].parts_adj=&parts_parts_adj[y];
      for (x=0,y=0; x<n_cells; ++x,y+=n_colors)
        parts[x].sizes_adj=&parts_sizes_adj[y];
      que_in.reserve(n_cells); que_out.reserve(n_cells);
    }
    void print(void) {
      printf("%d\n",color_best+1);
    }
    game(int mode_=0): mode(mode_) {}
};


game g(mode);

int main(void) {
  #ifndef OFFLINE
  freopen("filya.in","rt",stdin);
  freopen("filya.out","wt",stdout);
  #endif
  srand(seed);
  g.scan();
  g.findbest();
  g.print();
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


