#include <cstdio>
#include <cmath>
#include <vector>

using namespace std;


struct point {
  long double x,y;
  operator long double(void) const { return(x*x+y*y); }
  point operator~(void) const {
    point res=*this;
    res.x=-y;
    res.y=x;
    return(res);
  }
  point operator+(const point&arg) const {
    point res=*this;
    res.x+=arg.x;
    res.y+=arg.y;
    return(res);
  }
  point operator-(const point&arg) const {
    point res=*this;
    res.x-=arg.x;
    res.y-=arg.y;
    return(res);
  }
  point operator*(const long double arg) const {
    point res=*this;
    res.x*=arg;
    res.y*=arg;
    return(res);
  }
  point operator/(const long double arg) const {
    point res=*this;
    res.x/=arg;
    res.y/=arg;
    return(res);
  }
  long double operator*(const point&arg) const { return(x*arg.x+y*arg.y); }
  long double operator/(const point&arg) const { return(x*arg.y-y*arg.x); }
};
struct line {
  long double a,b,c;
  operator long double(void) const { return(a*a+b*b); }
  line& operator()(const point&v,const point&w) {
    a=v.y-w.y; b=w.x-v.x;
    c=v.x*w.y-w.x*v.y;
    return(*this);
  }
  point operator&(const line&arg) const {
    point res; long double dx,dy,dd;
    dx=b*arg.c-arg.b*c;
    dy=c*arg.a-arg.c*a;
    dd=a*arg.b-arg.a*b;
    res.x=dx/dd; res.y=dy/dd;
    return(res);
  }
  long double operator[](const point&arg) const { return(a*arg.x+b*arg.y+c); }
};


long double r;
int n_pnts;
vector<point> pnts;
point dir_0,dir_1,dir,pos;
int f_ok;

int main(void) {
  #ifndef OFFLINE
  freopen("glass.in","rt",stdin);
  freopen("glass.out","wt",stdout);
  #endif
  int i_pnt,i_pnt_to;
  scanf("%Lf%d",&r,&n_pnts);
  pnts.resize(n_pnts);
  for (i_pnt=0; i_pnt<n_pnts; ++i_pnt)
    scanf("%Lf%Lf",&pnts[i_pnt].x,&pnts[i_pnt].y);
  f_ok=1;
  if (n_pnts>2) {
    point cur_0,cur_1;
      dir_0=pnts[1]-pnts[0];
      dir_1=pnts[0]-pnts[1];
    for (i_pnt_to=1,i_pnt=2; i_pnt<n_pnts; i_pnt_to=i_pnt++) {
      cur_0=pnts[i_pnt]-pnts[i_pnt_to];
      cur_1=pnts[i_pnt_to]-pnts[i_pnt];
      if ((cur_0/dir_0>0)&&(cur_0/dir_1>0)) continue;
      if ((cur_1/dir_0>0)&&(cur_1/dir_1>0)) { f_ok=0; break; }
      if (cur_0/dir_0>0) { dir_1=cur_1; continue; }
      if (cur_0/dir_1>0) { dir_0=cur_0; continue; }
      if (cur_1/dir_0>0) { dir_0=cur_0; continue; }
      if (cur_1/dir_1>0) { dir_1=cur_1; continue; }
    }
    dir=dir_0+dir_1;
    if (!(dir>0)) f_ok=0;
  } else if (n_pnts>1) {
    dir=~(pnts[1]-pnts[0]);
  } else f_ok=0;
  if (f_ok) {
    point center,bound; line arrow,side;
    center=(pnts[0]+pnts[n_pnts-1])/2.L;
    long double dir_dir=dir,center_center=center,center_dir=center*dir;
    bound=center+dir*((
          sqrt(center_dir*center_dir+dir_dir*(r*r-center_center))-center_dir
      )/( dir_dir ));
    pos=center*2.L-bound;
    #ifdef DEBUG
    printf("%Lf %Lf  %Lf %Lf  %Lf %Lf\n",
      pos.x,pos.y,center.x,center.y,bound.x,bound.y);
    #endif
    arrow(center,center+dir);
    for (i_pnt_to=0,i_pnt=1; i_pnt<n_pnts; i_pnt_to=i_pnt++) {
      if (arrow[pnts[i_pnt_to]]*arrow[pnts[i_pnt]]>0) continue;
      if (!(side(pnts[i_pnt_to],pnts[i_pnt])>0)) continue;
      if (side[pos]*side[bound]>0) continue;
      pos=arrow&side;
    }
    pos=(pos+bound)/2.L;
  }
  if (f_ok) printf("%.12Lf %.12Lf %.12Lf %.12Lf\n",pos.x,pos.y,dir.x,dir.y);
  else printf("-1\n");
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


