#include <cstdio>
#include <cmath>
#include <limits>
#include <utility>
#include <algorithm>
#include <vector>

using namespace std;


const long double inf=numeric_limits<long double>::max()/4.L;


struct point {
  long double x,y;
  point operator-(const point&arg) const {
    point res=*this;
    res.x-=arg.x;
    res.y-=arg.y;
    return(res);
  }
  bool operator<(const point&arg) const {
    return(( (y<arg.y) )||( !(arg.y<y) && (x<arg.x) ));
  }
};

struct segment {
  long double k,b;
  segment& operator()(const point&v,const point&w) {
    point u=w-v;
    if (u.y) {
      k=u.x/u.y;
      b=v.x-k*v.y;
    } else { k=0; b=0; }
    return(*this);
  }
  long double square(long double y0,long double y1) const {
    return((k*(y0+y1)+b*2.L)*(y1-y0));
  }
  long double coord(long double s,long double y0) const {
    long double y=inf;
    if (k) {
      long double x0,xs,d,y1,y2;
      x0=y0*k+b; xs=s*k;
      d=x0*x0+xs;
      if (d>0) {
        d=sqrt(d);
        y1=(-b-d)/k; y2=(-b+d)/k;
        if (y2<y1) swap(y2,y1);
        y=(y1<y0?y2:y1);
        //fprintf(stderr,"%Lf %Lf %Lf %Lf %Lf %Lf %Lf\n",
        //  y0,y1,y2,y,s,square(y0,y1),square(y0,y2));
        //y=(y2<y1?y1:y2);
      } else if (!(d<0)) y=-b/k;
    } else if (b) y=y0+s/b/2.L;
    return(y);
  }
  segment& operator+=(const segment&arg) {
    k+=arg.k;
    b+=arg.b;
    return(*this);
  }
  segment& operator-=(const segment&arg) {
    k-=arg.k;
    b-=arg.b;
    return(*this);
  }
};

typedef pair<point,int> t_event;


const segment seg_zero={0,0};


int n_pnts,n_segs,n_events,n_parts,c_parts_left;
vector<point> pnts;
vector<segment> segs;
vector<t_event> events;
//vector<char> marks;
vector<long double> coords;
long double sq_total,sq_part;

int main(void) {
  #ifndef OFFLINE
  freopen("antiufo.in","rt",stdin);
  freopen("antiufo.out","wt",stdout);
  #endif
  int i_pnt,i_pnt_to,i_seg,i_ev;
  scanf("%d%d",&n_pnts,&n_parts); ++n_parts;
  pnts.resize(n_pnts);
  segs.resize(n_segs=n_pnts);
  events.resize(n_events=n_segs<<1);
  //marks.clear(),marks.resize(n_segs);
  coords.clear(); coords.reserve(n_parts);
  for (i_pnt=0; i_pnt<n_pnts; ++i_pnt)
    scanf("%Lf%Lf",&pnts[i_pnt].x,&pnts[i_pnt].y);
  sq_total=0;
  for (--(i_pnt_to=n_pnts),i_pnt=0,i_seg=0,i_ev=0; i_pnt<n_pnts;
       i_pnt_to=i_pnt++,++i_seg) {
    segs[i_seg](pnts[i_pnt_to],pnts[i_pnt]);
    events[i_ev++]=make_pair(pnts[i_pnt_to],i_seg);
    events[i_ev++]=make_pair(pnts[i_pnt],~i_seg);
    sq_total+=(pnts[i_pnt].y-pnts[i_pnt_to].y)
             *(pnts[i_pnt].x+pnts[i_pnt_to].x);
  } sq_part=sq_total/static_cast<long double>(n_parts);
  vector<t_event>::iterator p_ev,p_ev_to;
  segment sum; long double sq_left,coord,coord_bnd,coord_to; int f_sign;
  sort(events.begin(),events.end());
  c_parts_left=n_parts; sum=seg_zero; sq_left=sq_part;
  for (p_ev=events.begin(); p_ev!=events.end(); ++p_ev) {
    if (c_parts_left<=1) break;
    i_seg=p_ev->second;
    if (i_seg<0) { i_seg=~i_seg; f_sign=1; } else f_sign=0;
    //if (marks[i_seg]) { f_sign^=1; marks[i_seg]=0; } else marks[i_seg]=1;
    if (!f_sign) sum+=segs[i_seg]; else sum-=segs[i_seg];
    coord=p_ev->first.y;
    if (++(p_ev_to=p_ev)!=events.end()) coord_bnd=p_ev_to->first.y;
    else coord_bnd=inf;
    for (; coord<coord_bnd; coord=coord_to) {
      coord_to=sum.coord(sq_left,coord);
      if (coord_to>coord_bnd) {
        sq_left-=sum.square(coord,coord_bnd);
        break;
      }
      coords.push_back(coord_to);
      sq_left=sq_part;
      if (--c_parts_left<=1) break;
    }
  }
  vector<long double>::iterator p_coord;
  for (p_coord=coords.begin(); p_coord!=coords.end(); ++p_coord)
    printf("%.12Lf\n",*p_coord);
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


