#include <cstdio>
#include <functional>
#include <algorithm>
#include <numeric>
#include <vector>

using namespace std;


template <typename t_elem,typename t_op> class rangetree {
  private:
    t_op op; const t_elem zero;
    vector<t_elem> data;
    int n_elems,n_elems_bnd,i_elem_bnd;
  public:
    rangetree(const t_elem&zero_,t_op op_): op(op_),zero(zero_) {}
    rangetree& swap(rangetree&arg) {
      swap(op,arg.op);
      data.swap(arg.data);
      swap(n_elems,arg.n_elems);
      swap(n_elems_bnd,arg.n_elems_bnd);
      return(*this);
    }
    void init(int n_elems_) {
      n_elems=n_elems_;
      for (n_elems_bnd=2; n_elems_bnd<n_elems; n_elems_bnd<<=1);
      i_elem_bnd=(n_elems_bnd<<1)-1;
      data.clear(); data.resize(n_elems_bnd<<1,zero);
    }
    void reset(void) {
      fill(data.begin(),data.end(),zero);
    }
    t_elem& operator[](int i_elem) { return(data[i_elem]); }
    void operator()(int i_elem) {
      int i_elem_to; t_elem datum;
      for (i_elem_to=i_elem,(i_elem>>=1)|=n_elems_bnd; i_elem<i_elem_bnd;
           i_elem_to=i_elem,(i_elem>>=1)|=n_elems_bnd) {
        datum=op(data[i_elem_to],data[i_elem_to^1]);
        if (data[i_elem]==datum) break;
        data[i_elem]=datum;
      }
    }
    t_elem operator()(int i_elem_v,int i_elem_w) const {
      t_elem res=zero;
      while ((i_elem_v<=i_elem_w)&&(i_elem_w<i_elem_bnd)) {
        if (i_elem_v&1) res=op(res,data[i_elem_v++]);
        if (!(i_elem_w&1)) res=op(res,data[i_elem_w--]);
        (i_elem_v>>=1)|=n_elems_bnd; (i_elem_w>>=1)|=n_elems_bnd;
      }
      return(res);
    }
};

int n_nums,n_nums_row;
vector<int> nums;
vector<long long> cnts_prev,cnts_cur;
rangetree< long long,plus<long long> > cnts_rng(0LL,plus<long long>());
long long cnt_total;

int main(void) {
  #ifndef OFFLINE
  freopen("form.in","rt",stdin);
  freopen("form.out","wt",stdout);
  #endif
  int i_num,n_nums_row_now;
  scanf("%d%d",&n_nums,&n_nums_row);
  nums.resize(n_nums);
  for (i_num=0; i_num<n_nums; ++i_num) {
    scanf("%d",&nums[i_num]);
    --nums[i_num];
  }
  cnts_cur.clear(); cnts_prev.resize(n_nums); cnts_cur.resize(n_nums,1LL);
  cnts_rng.init(n_nums);
  for (n_nums_row_now=1; n_nums_row_now<=n_nums_row; ++n_nums_row_now) {
    cnts_prev.swap(cnts_cur);
    fill(cnts_cur.begin(),cnts_cur.end(),0LL);
    cnts_rng.reset();
    for (i_num=0; i_num<n_nums; ++i_num) {
      cnts_cur[i_num]=cnts_rng(0,nums[i_num]);
      cnts_rng[nums[i_num]]+=cnts_prev[i_num],cnts_rng(nums[i_num]);
    }
  } cnt_total=accumulate(cnts_cur.begin(),cnts_cur.end(),0LL);
  printf("%lld\n",cnt_total);
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


