#include <cstdio>
#include <limits>
#include <iterator>
#include <algorithm>
#include <vector>
#include <list>

using namespace std;


const long double inf=numeric_limits<long double>::max()/2.L;
const long double eps=1e-7L;


struct point {
  long double x,y;
  point operator+(const point&arg) const {
    point res=*this; res.x+=arg.x; res.y+=arg.y; return(res);
  }
  point operator-(const point&arg) const {
    point res=*this; res.x-=arg.x; res.y-=arg.y; return(res);
  }
  point operator*(long double arg) const {
    point res=*this; res.x*=arg; res.y*=arg; return(res);
  }
  point operator/(long double arg) const {
    point res=*this; res.x/=arg; res.y/=arg; return(res);
  }
  long double operator*(const point&arg) const { return(x*arg.x+y*arg.y); }
  bool operator<(const point&arg) const {
    return(( x<arg.x )||( !(arg.x<x) && (y<arg.y) ));
  }
  bool operator==(const point&arg) const { return((x==arg.x)&&(y==arg.y)); }
};
struct line {
  long double a,b,c;
  line(void): a(),b(),c() {}
  line(const point&v,const point&w) {
    a=v.y-w.y; b=w.x-v.x;
    c=v.x*w.y-v.y*w.x;
  }
  line(const line&l,const point&p) {
    c=-(a=l.a)*p.x-(b=l.b)*p.y;
  }
  line operator~(void) const {
    line res=*this; res.a=b; res.b=-a; return(res);
  }
  operator long double(void) { return(a*a+b*b); }
  long double operator[](const point&arg) const {
    return(a*arg.x+b*arg.y+c);
  }
  point operator&(const line&arg) const {
    point res;
    long double dx,dy,dd;
    dx=b*arg.c-arg.b*c;
    dy=c*arg.a-arg.c*a;
    dd=a*arg.b-arg.a*b;
    res.x=dx/dd; res.y=dy/dd;
    return(res);
  }
};


void dobroad(list<point>&area,const point&cent,const line&brk) {
  list<point>::iterator p_pnt,p_pnt_to;
  for (--(p_pnt_to=area.end()),p_pnt=area.begin(); p_pnt!=area.end();
       p_pnt_to=p_pnt++)
    if (brk[*p_pnt_to]*brk[*p_pnt]<-eps)
      ++(p_pnt=area.insert(p_pnt,brk&line(*p_pnt_to,*p_pnt)));
  for (p_pnt=area.begin(); p_pnt!=area.end(); )
    if (brk[*p_pnt]*brk[cent]<-eps) p_pnt=area.erase(p_pnt);
    else ++p_pnt;
}

int n_pnts_pol,n_pnts_fir,n_pnts_chk;
vector<point> pol,fir,chk;
list<point> area;
point best; long double dist_best;

int main(void) {
  #ifndef OFFLINE
  freopen("fire.in","rt",stdin);
  freopen("fire.out","wt",stdout);
  #endif
  int i_pnt,i_pnt_to; list<point>::iterator p_pnt;
  scanf("%d",&n_pnts_pol);
  pol.resize(n_pnts_pol);
  for (i_pnt=0; i_pnt<n_pnts_pol; ++i_pnt)
    scanf("%Lf%Lf",&pol[i_pnt].x,&pol[i_pnt].y);
  scanf("%d",&n_pnts_fir);
  fir.resize(n_pnts_fir);
  for (i_pnt=0; i_pnt<n_pnts_fir; ++i_pnt)
    scanf("%Lf%Lf",&fir[i_pnt].x,&fir[i_pnt].y);
  chk.reserve(n_pnts_fir*(n_pnts_pol+n_pnts_fir));
  line brk;
  for (i_pnt=0; i_pnt<n_pnts_fir; ++i_pnt) {
    area.assign(pol.begin(),pol.end());
    for (i_pnt_to=0; i_pnt_to<n_pnts_fir; ++i_pnt_to) {
      if (!( brk=line(fir[i_pnt],fir[i_pnt_to]) )) continue;
      brk=line(~brk,(fir[i_pnt]+fir[i_pnt_to])/2.L);
      dobroad(area,fir[i_pnt],brk);
    }
    copy(area.begin(),area.end(),back_inserter(chk));
    #ifdef DEBUG
    printf("%Lf %Lf\n",fir[i_pnt].x,fir[i_pnt].y);
    for (p_pnt=area.begin(); p_pnt!=area.end(); ++p_pnt)
      printf("%Lf %Lf\n",p_pnt->x,p_pnt->y);
    printf("\n");
    #endif
  }
  sort(chk.begin(),chk.end());
  chk.resize(unique(chk.begin(),chk.end())-chk.begin());
  n_pnts_chk=chk.size();
  point dir; long double dist_cur,dist;
  dist_best=-inf;
  #ifdef DEBUG
  printf("%d\n",n_pnts_chk);
  #endif
  for (i_pnt=0; i_pnt<n_pnts_chk; ++i_pnt) {
    dist_cur=inf;
    for (i_pnt_to=0; i_pnt_to<n_pnts_fir; ++i_pnt_to) {
      dir=chk[i_pnt]-fir[i_pnt_to];
      dist=dir*dir;
      if (dist_cur>dist) dist_cur=dist;
    }
    if (dist_best<dist_cur) { best=chk[i_pnt]; dist_best=dist_cur; }
    #ifdef DEBUG
    printf("%Lf %Lf  %Lf  %Lf\n",chk[i_pnt].x,chk[i_pnt].y,dist_cur,dist_best);
    #endif
  }
  #ifdef DEBUG
  printf("\n");
  #endif
  printf("%.6Lf %.6Lf\n",best.x,best.y);
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


