#include <stdio.h>
#include <math.h>

#define m 210
#define eps 1e-8
#define pi 3.14159265358979323846

typedef long double ldbl;

int n;
ldbl x[m], y[m], a[m], b[m], c[m], r, xx, yy;

int lies( ldbl xx, ldbl yy )
{
  int i;

  for (i = 1; i < n; i++)
    if (fabs(a[i] * xx + b[i] * yy + c[i]) < eps &&
        (xx > x[i] - eps || xx > x[i - 1] - eps) &&
        (xx < x[i] + eps || xx < x[i - 1] + eps) &&
        (yy > y[i] - eps || yy > y[i - 1] - eps) &&
        (yy < y[i] + eps || yy < y[i - 1] + eps))
      return 1;
  return 0;
}

int intsr( int i, ldbl xs, ldbl ys, ldbl dx, ldbl dy, int fl )
{
  ldbl t, xi, yi;

  if (fabs(a[i] * dx + b[i] * dy) < eps)
    return 0;
  t = -(c[i] + a[i] * xs + b[i] * ys) / (a[i] * dx + b[i] * dy);
  if (t < eps)
    return 0;
  xi = xs + t * dx, yi = ys + t * dy;
  if (((fabs(xi - x[i]) < eps && fabs(yi - y[i]) < eps) ||
       (fabs(xi - x[i - 1]) < eps && fabs(yi - y[i - 1]) < eps)) && fl)
    return 0;
  return (xi > x[i] - eps || xi > x[i - 1] - eps) &&
         (xi < x[i] + eps || xi < x[i - 1] + eps) &&
         (yi > y[i] - eps || yi > y[i - 1] - eps) &&
         (yi < y[i] + eps || yi < y[i - 1] + eps);
}

int inter( int i, ldbl dx, ldbl dy )
{
  int j;

  if (i > 0)
    for (j = 1; j < n; j++)
      if (intsr(j, (x[i] + x[i - 1]) * .5, (y[i] + y[i - 1]) * .5, dx, dy, 1))
        return 1;
  for (j = 1; j < n; j++)
    if (intsr(j, x[i], y[i], dx, dy, 1))
      return 1;
  return 0;
}

int test( ldbl dx, ldbl dy )
{
  int i;

  for (i = 1; i < n; i++)
    if (intsr(i, xx, yy, dx, dy, 0))
      return 0;
  for (i = 0; i < n; i++)
    if (inter(i, dx, dy))
      return 0;
  return 1;
}

int main( void )
{
  int i;

  freopen("glass.in", "rt", stdin);
  freopen("glass.out", "wt", stdout);
  scanf("%Lf%d", &r, &n);
  for (i = 0; i < n; i++)
    scanf("%Lf%Lf", &x[i], &y[i]);
  for (i = 1; i < n; i++)
    a[i] = y[i] - y[i - 1], b[i] = x[i - 1] - x[i], c[i] = -(a[i] * x[i] + b[i] * y[i]);
  for (i = 0; i < 100; i++)
  {
    xx = r / 2 * cos(i * pi / 50);
    yy = r / 2 * sin(i * pi / 50);
    if (!lies(xx, yy))
      break;
  }
  if (i == 100)
    xx = yy = 0;
  for (i = 1; i < n; i++)
    if (test(x[i] - x[i - 1], y[i] - y[i - 1]))
      printf("%.6Lf %.6Lf %.6Lf %.6Lf", xx, yy, x[i] - x[i - 1], y[i] - y[i - 1]), exit(0);
    else if (test(x[i - 1] - x[i], y[i - 1] - y[i]))
      printf("%.6Lf %.6Lf %.6Lf %.6Lf", xx, yy, x[i - 1] - x[i], y[i - 1] - y[i]), exit(0);
  printf("-1");
  return 0;
}
