#include <stdio.h>
#include <math.h>

#define m 210
#define eps2 1e-5
#define eps 1e-10
#define inf 1e4
#define sqr(x) ((x) * (x))

typedef struct
{
  long double x, y;
} pnt;

int n, k;
pnt p[m], f[m];

int inter( pnt c1, pnt c2, long double r, pnt *i1, pnt *i2 )
{
  long double a, b, c, dx, dy, sx, sy, a1, b1, cc1, d1;

  a = 2 * (c2.x - c1.x);
  b = 2 * (c1.y - c2.y);
  c = c1.x * c1.x - c2.x * c2.x + c1.y * c1.y - c2.y * c2.y;
  dx = -b, dy = a;
  if (fabs(a) < eps && fabs(b) < eps)
    return 0;
  if (fabs(a) > fabs(b))
    sy = 0, sx = -c / a;
  else
    sx = 0, sy = -c / b;
  a1 = dx * dx + dy * dy;
  b1 = 2 * dx * (sx - c1.x) + 2 * dy * (sy - c1.y);
  cc1 = (sx - c1.x) * (sx - c1.x) + (sy - c1.y) * (sy - c1.y) - r * r;
  d1 = b1 * b1 - 4 * a1 * cc1;
  if (d1 < -eps)
    return 0;
  d1 = sqrt(d1 + eps);
  a = (-b1 + d1) / (2 * a1);
  b = (-b1 - d1) / (2 * a1);
  i1->x = sx + dx * a, i1->y = sy + dy * a;
  i2->x = sx + dx * b, i2->y = sy + dy * b;
  return 1;
}

int interl( pnt c1, pnt s1, pnt s2, long double r, pnt *i1, pnt *i2 )
{
  long double a, b, c, dx, dy, sx, sy, a1, b1, cc1, d1;

  a = s2.y - s1.y;
  b = s1.x - s2.x;
  c = -(a * s1.x + b * s1.y);
  dx = -b, dy = a;
  if (fabs(a) > fabs(b))
    sy = 0, sx = -c / a;
  else
    sx = 0, sy = -c / b;
  a1 = dx * dx + dy * dy;
  b1 = 2 * dx * (sx - c1.x) + 2 * dy * (sy - c1.y);
  cc1 = (sx - c1.x) * (sx - c1.x) + (sy - c1.y) * (sy - c1.y) - r * r;
  d1 = b1 * b1 - 4 * a1 * cc1;
  if (d1 < -eps)
    return 0;
  d1 = sqrt(d1 + eps);
  a = (-b1 + d1) / (2 * a1);
  b = (-b1 - d1) / (2 * a1);
  i1->x = sx + dx * a, i1->y = sy + dy * a;
  i2->x = sx + dx * b, i2->y = sy + dy * b;
  return 1;
}

long double vec( pnt a, pnt b, pnt c )
{
  b.x -= a.x, b.y -= a.y;
  c.x -= a.x, c.y -= a.y;
  return b.x * c.y - b.y * c.x;
}

int check( pnt a, long double r )
{
  int o, ip, im;
  long double s;

  for (o = 0; o < k; o++)
    if (sqr(a.x - f[o].x) + sqr(a.y - f[o].y) < r * r - 2 * eps)
      return 0;
  for (o = ip = im = 0; o < n; o++)
  {
    if ((s = vec(p[o], a, p[(o + 1) % n])) > eps)
      ip = 1;
    else if (s < -eps)
      im = 1;
    if (ip && im)
      return 0;
  }
  return 1;
}

int main( void )
{
  int i, j, o, q;
  long double l, r, c;
  pnt be, i1, i2;

  freopen("fire.in", "rt", stdin);
  freopen("fire.out", "wt", stdout);
  scanf("%d", &n);
  for (i = 0; i < n; i++)
    scanf("%Lf%Lf", &p[i].x, &p[i].y);
  scanf("%d", &k);
  for (i = 0; i < k; i++)
    scanf("%Lf%Lf", &f[i].x, &f[i].y);
  l = 0, r = inf, be = p[0];
  while (fabs(l - r) > eps2)
  {
    c = (l + r) * .5;
    q = 0;
    for (i = 0; (i < k) && !q; i++)
      for (j = i + 1; j < k; j++)
      {
        if (!inter(f[i], f[j], c, &i1, &i2))
          continue;
        if (check(i1, c))
        {
          be = i1, q = 1;
          break;
        }
        if (check(i2, c))
        {
          be = i2, q = 1;
          break;
        }
      }
    if (!q)
      for (i = 0; (i < k) && !q; i++)
        for (j = 0; j < n; j++)
        {
          if (!interl(f[i], p[j], p[(j + 1) % n], c, &i1, &i2))
            continue;
          if (check(i1, c))
          {
            be = i1, q = 1;
            break;
          }
          if (check(i2, c))
          {
            be = i2, q = 1;
            break;
          }
        }
    if (q)
      l = c;
    else
      r = c;
  }
  printf("%.4Lf %.4Lf", be.x, be.y);
  return 0;
}
