program Antiufology;
const infile = 'antiufo.in';
      outfile = 'antiufo.out';
      MAXN = 50001;
      DELTA = 10001;
      EPS = 1e-10;
type
real = double;
tEvent = record
  etype : integer;
  x, y : real;
end;
var N, K : longint;
    x, y : array[0..MAXN] of real;
    events : array[1..MAXN, 1..2] of tEvent;
    id : array[1..MAXN] of longint;
    partsize, a, b, c : real;

procedure Init;
var area : real;
    i : longint;
begin
  area:=0;
  for i:=1 to N do
    area:=area+x[i]*y[i+1]-x[i+1]*y[i];
  area:=abs(area)/2;

  partsize:=area/(K+1);
end;

procedure ReadData;
var i : longint;
begin
  assign(input, infile);
  assign(output, outfile);
  reset(input);
  rewrite(output);

  read(N, K);
  for i:=1 to N do begin
    read(x[i], y[i]);

    x[i]:=x[i]+DELTA;
    y[i]:=y[i]+DELTA;
  end;

  x[0]:=x[N]; y[0]:=y[N];
  x[N+1]:=x[1]; y[N+1]:=y[1];

  for i:=1 to N do begin
    if abs(y[i]-y[i-1])<=EPS then
      events[i, 1].etype:=2
    else begin
      if y[i]<y[i-1] then events[i, 1].etype:=0;
      if y[i]>y[i-1] then events[i, 1].etype:=1;
    end;

    if abs(y[i]-y[i+1])<=EPS then
      events[i, 2].etype:=2
    else begin
      if y[i]<y[i+1] then events[i, 2].etype:=0;
      if y[i]>y[i+1] then events[i, 2].etype:=1;
    end;

    events[i, 1].x:=x[i-1]; events[i, 1].y:=y[i-1];
    events[i, 2].x:=x[i+1]; events[i, 2].y:=y[i+1];
  end;
end;

procedure HeapSort;
var i : longint;

procedure Swap(i, j : longint);
var t : longint;
begin
  t:=id[i]; id[i]:=id[j]; id[j]:=t;
end;

procedure Heapify(i, hs : longint);
var l, r, largest : longint;
begin
  while true do begin
    l:=i shl 1; r:=l+1; largest:=i;

    if (l<=hs) and (y[id[l]]>y[id[largest]]) then largest:=l;
    if (r<=hs) and (y[id[r]]>y[id[largest]]) then largest:=r;

    if largest=i then break;
    Swap(i, largest); i:=largest;
  end;
end;

begin
  for i:=(N div 2) downto 1 do
    Heapify(i, N);

  for i:=N downto 2 do begin
    Swap(i, 1);

    Heapify(1, i-1);
  end;
end;

procedure Change(q : longint);
var a0, b0, c0, dx : real;
begin
  if events[q, 1].etype<>2 then begin
    if events[q, 1].etype=0 then begin
      dx:=(events[q, 1].x-x[q])/(events[q, 1].y-y[q]);
      a0:=dx/2; b0:=x[q]; c0:=-y[q]*(2*x[q]+dx*y[q])/2;
    end;

    if events[q, 1].etype=1 then begin
      dx:=(x[q]-events[q, 1].x)/(y[q]-events[q, 1].y);
      a0:=-dx/2; b0:=-events[q, 1].x; c0:=events[q, 1].y*(2*events[q, 1].x+dx*events[q, 1].y)/2;
    end;

    a:=a+a0; b:=b+b0; c:=c+c0;
  end;

  if events[q, 2].etype<>2 then begin
    if events[q, 2].etype=0 then begin
      dx:=(events[q, 2].x-x[q])/(events[q, 2].y-y[q]);
      a0:=-dx/2; b0:=-x[q]; c0:=y[q]*(2*x[q]+dx*y[q])/2;
    end;

    if events[q, 2].etype=1 then begin
      dx:=(x[q]-events[q, 2].x)/(y[q]-events[q, 2].y);
      a0:=dx/2; b0:=events[q, 2].x; c0:=-events[q, 2].y*(2*events[q, 2].x+dx*events[q, 2].y)/2;
    end;

    a:=a+a0; b:=b+b0; c:=c+c0;
  end;
end;

procedure Solve;
var i, cur, count : longint;
    hmax : real;
    a1, b1, c1, d, x, x1, x2 : real;
begin
  for i:=1 to N do
    id[i]:=i;
  HeapSort; Init;

  count:=0; a:=0; b:=0; c:=0; cur:=1; Change(id[1]);

  while count<K do
    while true do begin
      hmax:=y[id[cur+1]];

      if (a*sqr(hmax)+b*hmax+c>partsize) then begin
        if abs(a)>EPS then begin
          a1:=a; b1:=b; c1:=c+partsize; d:=sqr(b1)-4*a1*c1+EPS;
          x1:=(-b1+sqrt(d))/(2*a1); x2:=(-b1-sqrt(d))/(2*a1);
          if x1>0 then x:=x1 else x:=x2;
        end else
          x:=(partsize-c)/b;

        inc(count); writeln(x-DELTA:0:4); break;
      end;

      inc(cur); Change(id[cur]);
      while abs(y[id[cur+1]]-y[id[cur]])<=EPS do begin
        inc(cur); Change(id[cur]);
      end;
    end;
end;

procedure WriteData;
begin
  close(input);
  close(output);
end;

begin
  ReadData;
  Solve;
  WriteData;
end.
