program Fire;
const infile = 'fire.in';
      outfile = 'fire.out';
      MAXP = 40000;
      MAXN = 201;
      EPS = 1e-6;
      inf = 1000000000;
type
real = double;
var ptsx, ptsy : array[1..MAXP] of real;
    xp, yp, xf, yf, fired : array[1..MAXN] of real;
    NPts : longint;
    N, K : integer;

procedure ReadData;
var i : integer;
begin
  assign(input, infile);
  assign(output, outfile);
  reset(input);
  rewrite(output);
  read(N);
  for i:=1 to N do
    read(xp[i], yp[i]);
  xp[N+1]:=xp[1]; yp[N+1]:=yp[1];
  read(K);
  for i:=1 to K do
    read(xf[i], yf[i]);
end;

procedure BuildPoints(r : real);
var i, j : integer;
    xn, yn, xc, yc, l, h, sqrd : real;
begin
  NPts:=0;

  for i:=1 to K do
    for j:=i+1 to K do begin
      sqrd:=sqr(xf[i]-xf[j])+sqr(yf[i]-yf[j]);

      if sqrd<sqr(2*r)+EPS then begin
        xn:=yf[i]-yf[j]; yn:=xf[j]-xf[i]; l:=sqrt(sqr(xn)+sqr(yn));
        xc:=(xf[i]+xf[j])/2; yc:=(yf[i]+yf[j])/2;

        if sqr(2*r)<sqrd then sqrd:=sqr(2*r);
        h:=sqrt(sqr(2*r)-sqrd)/2;

        xn:=xn/l*(h+EPS); yn:=yn/l*(h+EPS);

        inc(NPts);
        ptsx[NPts]:=xc+xn; ptsy[NPts]:=yc+yn;

        inc(NPts);
        ptsx[NPts]:=xc-xn; ptsy[NPts]:=yc-yn;
      end;
    end;
end;

function Sign(a : real) : integer;
begin
  Sign:=ord(a>0)-ord(a<0);
end;

function CheckInside(x, y : real) : boolean;
var s : array[1..MAXN] of integer;
    i, s0 : integer;
begin
  for i:=1 to N do
    s[i]:=Sign((xp[i+1]-xp[i])*(y-yp[i])-(x-xp[i])*(yp[i+1]-yp[i]));

  for i:=1 to N do
    if s[i]<>0 then begin s0:=s[i]; break; end;
  for i:=1 to N do
    if (s[i]<>0) and (s[i]<>s0) then begin CheckInside:=false; exit; end;

  CheckInside:=true;
end;

function CheckCover(x, y, r : real) : boolean;
var i : integer;
begin
  for i:=1 to K do
    if sqrt(sqr(xf[i]-x)+sqr(yf[i]-y))+EPS<r then begin
      CheckCover:=false; exit;
    end;

  CheckCover:=true;
end;

function GetFreePoint(r : real) : longint;
var i : longint;
begin
  if NPts=0 then begin GetFreePoint:=0; exit; end;

  for i:=1 to NPts do
    if CheckInside(ptsx[i], ptsy[i]) and CheckCover(ptsx[i], ptsy[i], r) then begin
      GetFreePoint:=i; exit;
    end;

  GetFreePoint:=-1;
end;

procedure Solve;
var l, r, m : real;
    last : longint;
    i, j, maxp : integer;
begin
  for i:=1 to N do
    fired[i]:=inf;
  for i:=1 to N do
    for j:=1 to K do
      if sqrt(sqr(xp[i]-xf[j])+sqr(yp[i]-yf[j]))<fired[i] then fired[i]:=sqrt(sqr(xp[i]-xf[j])+sqr(yp[i]-yf[j]));

  maxp:=1;
  for i:=2 to N do
    if fired[i]>fired[maxp] then maxp:=i;

  l:=0; r:=3000;
  while r-l>1e-5 do begin
    m:=(r+l)/2;
    BuildPoints(m);

    if GetFreePoint(m)=-1 then r:=m else l:=m;
  end;

  if (K=1) or (l<fired[maxp]) then begin
    writeln(xp[maxp]:0:4, ' ', yp[maxp]:0:4);
  end else begin
    BuildPoints(l);
    last:=GetFreePoint(l);
    writeln(ptsx[last]:0:4, ' ', ptsy[last]:0:4);
  end;
end;

procedure WriteData;
begin
  close(input);
  close(output);
end;

begin
  ReadData;
  Solve;
  WriteData;
end.
