{$I-,S-,Q-,R-}
Program Solution;
const
  MaxV = 10000;
  MaxE = 100000;

type
  TEdge = Record
    St, Fn, W: LongInt;
  End;
  THeap = Record
    N: LongInt;
    Key: Array[1..MaxV] of Int64;
    Num, Pos: Array[1..MaxV] of LongInt;
  End;
  TDSet = Record
    N: LongInt;
    Pr, Next, L, Tail: Array[1..MaxV] of LongInt;
  End;
  PList = ^TList;
  TList = Record
    Num: LongInt;
    W: Int64;
    Next: PList;
  End;

var
  V, E: LongInt;
  St, Fn: LongInt;
  Infinity: Int64;
  Result: Int64;
  Edge: Array[1..MaxE] of TEdge;
  EdgeList: Array[1..MaxE] of PList;
  L, R: Array[1..MaxV] of Int64;
  Heap: THeap;
  DSet: TDSet;

Procedure InputData;
var
  i: LongInt;

begin
  Assign(Input, 'input.txt');
  ReSet(Input);
  ReadLn(V, E);
  For i:= 1 to E do
    ReadLn(Edge[i].St, Edge[i].Fn, Edge[i].W);
  ReadLn(St, Fn);
  Close(Input);
end;

Function Partition(l, r: LongInt): LongInt;
var
  i, j: LongInt;
  X: Int64;
  S: TEdge;

begin
  i:= l-1; j:= r+1;
  X:= Edge[l+Random(r-l+1)].W;
  While True do begin
    Repeat
      Dec(j)
    Until Edge[j].W <= X;
    Repeat
      Inc(i)
    Until Edge[i].W >= X;
    If i < j then begin
      S:= Edge[i];
      Edge[i]:= Edge[j];
      Edge[j]:= S;
    end
    else begin
      Partition:= j;
      Exit;
    end;
  end;
end;

Procedure Sort(l, r: LongInt);
var
  q: LongInt;

begin
  If l < r then begin
    q:= Partition(l, r);
    Sort(l, q);
    Sort(q+1, r);
  end;
end;

Procedure HeapInit(N: LongInt);
var
  i: LongInt;

begin
  Heap.N:= N;
  For i:= 1 to N do begin
    Heap.Key[i]:= Infinity;
    Heap.Num[i]:= i;
    Heap.Pos[i]:= i;
  end;
end;

Procedure HeapChange(a, b: LongInt);
var
  S: Int64;

begin
  Heap.Pos[Heap.Num[a]]:= b;
  Heap.Pos[Heap.Num[b]]:= a;
  S:= Heap.Num[a];
  Heap.Num[a]:= Heap.Num[b];
  Heap.Num[b]:= S;
  S:= Heap.Key[a];
  Heap.Key[a]:= Heap.Key[b];
  Heap.Key[b]:= S;
end;

Procedure HeapChangeKey(num: LongInt; value: Int64);
var
  pos, min: LongInt;

begin
  pos:= Heap.Pos[num];
  If Heap.Key[pos] >= value then begin
    Heap.Key[pos]:= value;
    While (pos > 1) and (Heap.Key[pos] < Heap.Key[pos div 2]) do begin
      HeapChange(pos, pos div 2);
      pos:= pos div 2;
    end;
  end
  else begin
    Heap.Key[pos]:= value;
    While 2*pos <= Heap.N do begin
      If (2*pos < Heap.N) and
         (Heap.Key[2*pos] > Heap.Key[2*pos+1])
           then min:= 2*pos+1
           else min:= 2*pos;
      If Heap.Key[pos] <= Heap.Key[min]
        then Break;
      HeapChange(pos, min);
      pos:= min;
    end;
  end;
end;

Procedure DSetInit(N: LongInt);
var
  i: LongInt;

begin
  DSet.N:= N;
  For i:= 1 to N do begin
    DSet.Pr[i]:= i;
    DSet.Next[i]:= 0;
    DSet.Tail[i]:= i;
    DSet.Pr[i]:= i;
  end;
end;

Procedure DSetUnion(A, B: LongInt);
var
  S, X: LongInt;

begin
  If DSet.L[A] > DSet.L[B] then begin
    S:= A;
    A:= B;
    B:= S;
  end;
  DSet.Next[DSet.Tail[A]]:= B;
  DSet.Tail[A]:= DSet.Tail[B];
  DSet.L[A]:= DSet.L[A]+DSet.L[B];
  X:= B;
  While X <> 0 do begin
    DSet.Pr[X]:= A;
    X:= DSet.Next[X];
  end;
end;

Procedure MakeEdgeList;
var
  X: PList;
  i: LongInt;

begin
  For i:= 1 to E do begin
    New(X);
    X^.Num:= Edge[i].Fn;
    X^.W:= Edge[i].W;
    X^.Next:= EdgeList[Edge[i].St];
    EdgeList[Edge[i].St]:= X;
    New(X);
    X^.Num:= Edge[i].St;
    X^.W:= Edge[i].W;
    X^.Next:= EdgeList[Edge[i].Fn];
    EdgeList[Edge[i].Fn]:= X;
  end;
end;

Function min(a, b: Int64): Int64;
begin
  If a<b
    then min:= a
    else min:= b;
end;

Procedure Connect(num: LongInt; typ: Byte);
var
  X: LongInt;
  Temp: LongInt;
  Adj: PList;

begin
  X:= num;
  While X <> 0 do begin
    Adj:= EdgeList[X];
    While Adj <> nil do begin
      Temp:= DSet.Pr[Adj^.Num];
      If (Temp <> DSet.Pr[St]) and (Temp <> DSet.Pr[Fn]) then begin
           If typ = 0
             then L[Temp]:= min(L[Temp], Adj^.W)
             else R[Temp]:= min(R[Temp], Adj^.W);
           HeapChangeKey(Temp, L[Temp]+R[Temp]);
         end;
      Adj:= Adj^.Next;
    End;
    X:= DSet.Next[X];
  end;
  HeapChangeKey(num, Infinity);
  If typ = 0
    then DSetUnion(num, DSet.Pr[St])
    else DSetUnion(num, DSet.Pr[Fn]);
end;

Procedure ConnectMiddle(a, b: LongInt);
begin
  DSetUnion(a, b);
  L[DSet.Pr[a]]:= min(L[a], L[b]);
  R[DSet.Pr[a]]:= min(R[a], R[b]);
  HeapChangeKey(DSet.Pr[a], L[DSet.Pr[a]]+R[DSet.Pr[a]]);
  If DSet.Pr[a] = a
    then HeapChangeKey(b, Infinity)
    else HeapChangeKey(a, Infinity);
end;

Procedure FindResult;
var
  i: LongInt;
  Adj: PList;

begin
  Result:= Infinity;
  For i:= 1 to E do
  If ((Edge[i].St = St) and (Edge[i].Fn = Fn)) or
     ((Edge[i].St = Fn) and (Edge[i].Fn = St))
       then Result:= min(Result, Edge[i].W);

  HeapInit(V);
  For i:= 1 to V do begin
    L[i]:= Infinity;
    R[i]:= Infinity;
  end;
  For i:= 1 to V do begin
    Adj:= EdgeList[i];
    While Adj <> nil do begin
      If Adj^.Num = St
        then L[i]:= min(L[i], Adj^.W);
      If Adj^.Num = Fn
        then R[i]:= min(R[i], Adj^.W);
      Adj:= Adj^.Next;
    end;
  end;
  For i:= 1 to V do
    HeapChangeKey(i, L[i]+R[i]);
  Result:= min(Result, Heap.Key[1]);

  DSetInit(V);
  For i:= 1 to E do
  If DSet.Pr[Edge[i].St] <> DSet.Pr[Edge[i].Fn] then begin
    If ((DSet.Pr[Edge[i].St] = DSet.Pr[St])
         and (DSet.Pr[Edge[i].Fn] = DSet.Pr[Fn])) or
       ((DSet.Pr[Edge[i].St] = DSet.Pr[Fn])
         and (DSet.Pr[Edge[i].Fn] = DSet.Pr[St]))
         then Break;

    If DSet.Pr[Edge[i].St] = DSet.Pr[St]
      then Connect(DSet.Pr[Edge[i].Fn], 0)
      else
      If DSet.Pr[Edge[i].Fn] = DSet.Pr[St]
        then Connect(DSet.Pr[Edge[i].St], 0)
        else
        If DSet.Pr[Edge[i].St] = DSet.Pr[Fn]
          then Connect(DSet.Pr[Edge[i].Fn], 1)
          else
          If DSet.Pr[Edge[i].Fn] = DSet.Pr[Fn]
            then Connect(DSet.Pr[Edge[i].St], 1)
            else ConnectMiddle(DSet.Pr[Edge[i].St], DSet.Pr[Edge[i].Fn]);

    Result:= min(Result, Edge[i].W+Heap.Key[1]);
  end;
end;

Procedure Solve;
begin
  Sort(1, E);
  MakeEdgeList;
  FindResult;
end;

Procedure WriteData;
begin
  Assign(Output, 'output.txt');
  ReWrite(Output);
  WriteLn(Result);
  Close(Output);
end;

begin
  Infinity:= Int64(1000000)*Int64(1000000);
  InputData;
  Solve;
  WriteData;
end.