{$A+,B-,D+,E-,F-,G+,I+,L+,N-,O-,P-,Q+,R+,S+,T-,V+,X+,Y+}
{$M 16384,0,655360}
program macro;
const MaxM = 1000; MaxN = 1000; TotCells = 1000; MaxTSC = 10000000;
type Cell = integer;
     OpCode = (_LOAD, _STORE, _READ, _WRITE, _ADD, _SUB, _MULT, _DIV, _HALT,
               _JUMP, _JGTZ, _JZERO, _ERROR);
     ArgType = (_IMM, _INDR, _INDR2, _IP, _NONE);
     Op = record oc : OpCode; t : ArgType; a : Cell end;
     PCell = ^Cell;
type TOpcStrArr = array [OpCode] of string[7];
     TPossArgArr = array [OpCode] of byte;
const OpcStrArr : TOpcStrArr = (
   'LOAD', 'STORE',  'READ', 'WRITE',   'ADD',   'SUB',  'MULT',   'DIV',
   'HALT',  'JUMP',  'JGTZ', 'JZERO',   '???');
   PossArgArr : TPossArgArr = (7, 6, 6, 7, 7, 7, 7, 7, 0, 8, 8, 8, 0);
   DoUpCase = true;
var
  M, N, IP, NextIP  : integer;
  TSC       : longint;
  Prog      : array [0..MaxM] of Op;
  Mem       : array [0..TotCells-1] of Cell;
  MemF      : array [0..TotCells-1] of boolean;

procedure error (var S : String; T : String);
begin dec(S[0]); writeln ('**error**: in "',S,'": ', T); runerror (239) end;

procedure parseline (var O : Op; S : String);
var S1, S2 : string; P : integer; oc, oci : Opcode; k : integer;
begin
  S1 := '';  S2 := '';  S := S + #0;  P := 1;
  while S[P] in [' ',#9] do inc (P);
  while S[P] in ['A'..'Z','a'..'z'] do begin
    if DoUpcase then S[P] := upcase (S[P]);
    S1 := S1 + S[P];  inc (P) end;
  if S1 = '' then error (S, 'instruction code expected');
  oc := _ERROR;
  for oci := _LOAD to _JZERO do
    if S1 = OpcStrArr[oci] then begin oc:=oci; break end;
  if oc = _ERROR then error (S, 'invalid instruction');
  O.oc := oc;  O.t := _NONE;
  if not (S[P] in [' ',#9,#0]) then error (S, 'spaces expected');
  while S[P] in [' ',#9] do inc (P);
  if S[P] <> #0 then begin
    if S[P] = '=' then begin O.t := _IMM; inc (P) end
    else if S[P] = '*' then begin O.t := _INDR2; inc (P) end
    else O.t := _INDR;
    if not (S[P] in ['-','0'..'9']) then error (S, 'number expected');
    S2 := S[P]; inc (P);
    while S[P] in ['0'..'9'] do begin S2:=S2+S[P]; inc(P) end;
    val (S2, O.a, k);
    if k <> 0 then error (S, 'invalid numeric constant')
  end;
  while S[P] in [' ',#9] do inc (P);
  if S[P] <> #0 then error (S, 'extra characters on line');
  k := PossArgArr[oc];
  if (k = 0) xor (O.t = _NONE) then error (S, 'no or extra arguments');
  if k = 8 then begin
    if O.t <> _INDR then error (S, 'label expected');
    O.t := _IP;
    if (O.a < 0) or (O.a >= M) then error (S, 'invalid target')
  end else if (O.t <> _NONE) and not odd (k shr ord(O.t)) then
    error (S, 'invalid arguments');
  if (O.t in [_INDR, _INDR2]) and ((O.a < 0) or (O.a >= TotCells)) then
    error (S, 'invalid address');
end;

function c (x : Cell) : Cell;
begin
  if (x < 0) or (x >= TotCells) then runerror (239);
  if not MemF[x] then
    runerror (239);
  c := Mem[x]
end;

function v (var O : Op) : Cell;
begin
  case O.t of
  _NONE: runerror (239);
  _IP:   runerror (239);
  _IMM:  v := O.a;
  _INDR: v := c(O.a);
  _INDR2: v := c(c(O.a))
  end
end;

function p (var O : Op) : Cell;
begin
  case O.t of
  _NONE, _IP, _IMM:  runerror (239);
  _INDR:  p := O.a;
  _INDR2: p := c(O.a)
  end
end;

procedure mstore (x, a : Cell);
begin Mem[x] := a; MemF[x] := true end;

var i : integer; S : string; x : Cell;
begin
  assign (input, 'ram.in'); reset (input);
  assign (output, 'ram.out'); rewrite (output);
  readln (M, N);
  if (M <= 0) or (M > MaxM) or (N <= 0) or (N > MaxN) then runerror (239);
  for i := 0 to M - 1 do begin
    readln (S);
    parseline (Prog[i], S)
  end;
  IP := 0;  TSC := 0;
  repeat
    inc (TSC);  NextIP := succ(IP);
    case Prog[IP].oc of
    _LOAD:  mstore (0, v(Prog[IP]));
    _STORE: mstore (p(Prog[IP]), c(0));
    _READ:  begin
              if N <= 0 then runerror (239);
              read (x);  dec(N);
              mstore (p(Prog[IP]), x)
            end;
    _WRITE: writeln (v(Prog[IP]));
    _ADD:   mstore (0, c(0) + v(Prog[IP]));
    _SUB:   mstore (0, c(0) - v(Prog[IP]));
    _MULT:  mstore (0, c(0) * v(Prog[IP]));
    _DIV:   mstore (0, c(0) div v(Prog[IP]));
    _HALT:  break;
    _JUMP:  NextIP := Prog[IP].a;
    _JGTZ:  if c(0) > 0 then NextIP := Prog[IP].a;
    _JZERO: if c(0) = 0 then NextIP := Prog[IP].a;
    else runerror (239)
    end;
    IP := NextIP;
    if (IP < 0) or (IP >= M) then runerror (239);
    if TSC >= MaxTSC then runerror (239);
  until false
end.
