#include <fstream>

typedef long double Ty;

class vector2d{
public:
	Ty x;
	Ty y;
	vector2d(Ty _x,Ty _y){x=_x;y=_y;};
	vector2d(){x=y=0;};
	vector2d(const vector2d &a){
		x=a.x;
		y=a.y;
	};
};

//input: v1(x1,y1),v2(x2,y2)
//out: v((v1,v2),[v1,v2])

inline
    vector2d& operator*=(
	vector2d& _X,
	const vector2d& _Y)
{
	Ty _W = _X.x * _Y.x + _X.y * _Y.y;
	_X.y=_X.x * _Y.y - _X.y * _Y.x;
	_X.x=_W;
	return (_X);
}

inline
    vector2d& operator*=(
	vector2d& _X,
	Ty _Y)
{
	_X.x*=_Y;
	_X.y*=_Y;
	return (_X);
}

inline
    vector2d& operator/=(
	vector2d& _X,
	Ty _Y)
{
	_X.x/=_Y;
	_X.y/=_Y;
	return (_X);
}

inline
    vector2d& operator+=(
	vector2d& _X,
	const vector2d& _Y)
{
	_X.x+=_Y.x;
	_X.y+=_Y.y;
	return (_X);
}

inline
    vector2d& operator-=(
	vector2d& _X,
	const vector2d& _Y)
{
	_X.x-=_Y.x;
	_X.y-=_Y.y;
	return (_X);
}

inline
	vector2d operator+(const vector2d& _L,
		const vector2d& _R)
	{vector2d _W(_L);
	return (_W += _R);
}

inline
	vector2d operator-(const vector2d& _L,
		const vector2d& _R)
	{vector2d _W(_L);
	return (_W -= _R);
}

inline
	vector2d operator*(const vector2d& _L,
		const vector2d& _R)
	{vector2d _W(_L);
	return (_W *= _R);
}

inline
	vector2d operator*(const vector2d& _L,
		Ty _R)
	{vector2d _W(_L);
	return (_W *= _R);
}

inline
	vector2d operator/(const vector2d& _L,
		Ty _R)
	{vector2d _W(_L);
	return (_W /= _R);
}

using namespace std;

ifstream I("pipe.in");
ofstream O("pipe.out");

const long double MININF=-1000000;

int n;
vector2d P[2000];

long double maxx=MININF;

void in(){
	I>>n;
	for(int i=0;i<n;i++) I>>P[i].x>>P[i].y;
}

//find peres line(v1,v3) with line(v2,v4)
vector2d peres(vector2d v1,vector2d v3,vector2d v2,vector2d v4){
	vector2d R1=v3-v1;
	vector2d R2=v4-v2;
	return v1+R1*(vector2d(v2-v1)*R2).y/(R1*R2).y;
}

void sol(){
	vector2d light((P[0].x+P[1].x)/2,(P[0].y+P[1].y)/2-0.5);
	vector2d uplight=P[1]-light;
	vector2d downlight=uplight-vector2d(0,1);
	for(int i=2;i<n;i++){
		vector2d newuplight=P[i]-light;
		vector2d newdownlight=newuplight-vector2d(0,1);
		if((uplight*newuplight).y<0){
			uplight=newuplight;
			if((uplight*downlight).y>0){
				//trace downlight
				//find peres line(light,light+downlight) with line(P[i-1],P[i])
				maxx=peres(light,light+downlight,P[i-1],P[i]).x;
			}
		}
		if((downlight*newdownlight).y>0){
			downlight=newdownlight;
			if((downlight*uplight).y<0){
				//trace uplight
				//find peres line(light,light+uplight) with line(P[i-1]-(0,1),P[i]-(0,1))
				maxx=peres(light,light+uplight,P[i-1]-vector2d(0,1),P[i]-vector2d(0,1)).x;
			}
		}
	}
}

void out(){
	O.precision(2);
	if(maxx==MININF) O<<"DELO TRUBA";
	else O<<fixed<<maxx;
}

int main(){
	in();
	sol();
	out();
	return 0;
}
