const
     FileIn='customs.in';
     FileOut='customs.out';
     MaxN=10000;
     MaxTokens=3;
type
    PEdge=^TEdge;
    TEdge=record
                Destination: LongInt;
                Price: LongInt;
                Next: PEdge;
          end;
    TNode=record
                First, Last: PEdge;
          end;
    TMaxPrice=record
                    Summary: Int64;
                    Tokens: array [1..MaxTokens] of LongInt;
              end;
    PTree=^TTree;
    TTree=record
                X: LongInt;
                Y: Int64;
                L, R: PTree;
          end;

procedure Split (T: PTree; X: LongInt; var L, R: PTree);
begin
     if not Assigned (T)
        then begin
             L:=nil;
             R:=nil;
             Exit;
        end
        else if X>T^.X
                then begin
                     Split (T^.R, X, T^.R, R);
                     L:=T;
                end
                else begin
                     Split (T^.L, X, L, T^.L);
                     R:=T;
                end;
end;

function Merge (L, R: PTree): PTree;
begin
     if not Assigned (L)
        then Merge:=R
        else if not Assigned (R)
                then Merge:=L
                else if L^.Y<R^.Y
                        then begin
                             L^.R:=Merge (L^.R, R);
                             Merge:=L;
                        end
                        else begin
                             R^.L:=Merge (L, R^.L);
                             Merge:=R;
                        end;
end;

procedure Insert (var T: PTree; X: LongInt; Y: Int64);
var
   T1: PTree;
begin
     if (not Assigned (T)) or (Y<T^.Y)
        then begin
             New (T1);
             Split (T, X, T1^.L, T1^.R);
             T1^.X:=X;
             T1^.Y:=Y;
             T:=T1;
        end
        else if X<T^.X
                then Insert (T^.L, X, Y)
                else Insert (T^.R, X, Y);
end;

procedure Delete (var T: PTree; X: LongInt);
var
   T1: PTree;
begin
     if Assigned (T)
        then if X<T^.X
                then Delete (T^.L, X)
                else if X>T^.X
                        then Delete (T^.R, X)
                        else begin
                             T1:=T;
                             T:=Merge (T^.L, T^.R);
                             Dispose (T1);
                        end;
end;

var
   N, M: LongInt;
   Nodes: array [1..MaxN] of TNode;
   A, B: LongInt;
   States: array [1..MaxN] of LongInt;
   Distances: array [1..MaxN] of TMaxPrice;
   Answer: Int64;

procedure Add (aNode, aDestination, aPrice: LongInt);
begin
     with Nodes [aNode]
          do begin
             if Assigned (Last)
                then begin
                     New (Last^.Next);
                     Last:=Last^.Next;
                end
                else begin
                     New (Last);
                     First:=Last;
                end;
             Last^.Destination:=aDestination;
             Last^.Price:=aPrice;
             Last^.Next:=nil;
          end;
end;

procedure ReadData;
var
   F: Text;
   NEdge: LongInt;
   X, Y, Z: LongInt;
begin
     FillChar (Nodes, SizeOf (Nodes), 0);

     Assign (F, FileIn);
     Reset (F);
     Readln (F, N, M);
     for NEdge:=1 to M
         do begin
            Readln (F, X, Y, Z);
            Add (X, Y, Z);
            Add (Y, X, Z);
         end;
     Readln (F, A, B);
     Close (F);
end;

procedure WriteData;
var
   F: Text;
begin
     Assign (F, FileOut);
     Rewrite (F);
     Writeln (F, Answer);
     Close (F);
end;

procedure CalcNewMaxPrice (var aMaxPrice: TMaxPrice; aPrice: LongInt);
var
   Index, MinIndex: LongInt;
begin
     with aMaxPrice
          do begin
             MinIndex:=Low (Tokens);
             for Index:=MinIndex+1 to High (Tokens)
                 do if Tokens [Index]<Tokens [MinIndex]
                       then MinIndex:=Index;
             if Tokens [MinIndex]<aPrice
                then begin
                     Inc (Summary, aPrice-Tokens [MinIndex]);
                     Tokens [MinIndex]:=aPrice;
                end;
          end;
end;

procedure Dijkstra;
var
   Root: PTree;
   BestNode: LongInt;
   Edge: PEdge;
   NewPrice: TMaxPrice;
begin
     FillChar (States, SizeOf (States), 0);
     States [A]:=1;
     FillChar (Distances [A], SizeOf (Distances [A]), 0);
     Root:=nil;
     Insert (Root, A, Distances [A].Summary);

     repeat
           BestNode:=Root^.X;
           States [BestNode]:=2;
           Delete (Root, BestNode);

           Edge:=Nodes [BestNode].First;
           while Assigned (Edge)
                 do begin
                    NewPrice:=Distances [BestNode];
                    CalcNewMaxPrice (NewPrice, Edge^.Price);
                    case States [Edge^.Destination] of
                         0: begin
                                 States [Edge^.Destination]:=1;
                                 Distances [Edge^.Destination]:=NewPrice;
                                 Insert (Root, Edge^.Destination, NewPrice.Summary);
                            end;
                         1: if NewPrice.Summary<Distances [Edge^.Destination].Summary
                               then begin
                                    Distances [Edge^.Destination]:=NewPrice;
                                    Delete (Root, Edge^.Destination);
                                    Insert (Root, Edge^.Destination, NewPrice.Summary);
                               end;
                    end;
                    Edge:=Edge^.Next;
                 end;
     until not Assigned (Root);
end;

procedure Solve;
begin
     Dijkstra;
     Answer:=Distances [B].Summary;
end;

begin
     ReadData;
     Solve;
     WriteData;
end.
