const
     FileIn='quirks.in';
     FileOut='quirks.out';
     MaxN=50000;
     MaxM=50000;
type
    PEdge=^TEdge;
    TEdge=record
                Destination: LongInt;
                Next: PEdge;
          end;
    TNode=record
                First, Last: PEdge;
          end;
    TInputEdge=record
                     Source, Destination: LongInt;
                     Key: LongInt;
               end;
var
   FIn, FOut: Text;
   T: LongInt;
   N, M: LongInt;
   Nodes: array [1..MaxN] of TNode;
   Edges: array [1..MaxM] of TInputEdge;
   Answer: Boolean;

procedure ReadData;
var
   NEdge: LongInt;
   A, B: LongInt;
begin
     Read (FIn, N, M);
     for NEdge:=1 to M
         do Read (FIn, Edges [NEdge].Source, Edges [NEdge].Destination);
end;

procedure WriteData;
begin
     if Answer
        then Writeln (FOut, 'YES')
        else Writeln (FOut, 'NO');
end;

procedure Swap (var aEdge1, aEdge2: TInputEdge);
var
   TemporaryEdge: TInputEdge;
begin
     TemporaryEdge:=aEdge1;
     aEdge1:=aEdge2;
     aEdge2:=TemporaryEdge;
end;

procedure QuickSort (aLeft, aRight: LongInt);
var
   i, j: LongInt;
   MiddleKey: LongInt;
begin
     i:=aLeft;
     j:=aRight;
     MiddleKey:=Edges [(i+j) shr 1].Key;
     repeat
           while Edges [i].Key<MiddleKey
                 do Inc (i);
           while MiddleKey<Edges [j].Key
                 do Dec (j);
           if i<=j
              then begin
                   Swap (Edges [i], Edges [j]);
                   Inc (i);
                   Dec (j);
              end;
     until i>j;
     if aLeft<j
        then QuickSort (aLeft, j);
     if i<aRight
        then QuickSort (i, aRight);
end;

procedure Add (aNode, aDestination: LongInt);
begin
     with Nodes [aNode]
          do begin
             if Assigned (Last)
                then begin
                     New (Last^.Next);
                     Last:=Last^.Next;
                end
                else begin
                     New (Last);
                     First:=Last;
                end;
             Last^.Destination:=aDestination;
             Last^.Next:=nil;
          end;
end;

var
   States: array [1..MaxN] of LongInt;

procedure DFS (aNode: LongInt);
var
   Edge: PEdge;
begin
     States [aNode]:=1;
     Edge:=Nodes [aNode].First;
     while Assigned (Edge)
           do begin
              case States [Edge^.Destination] of
                   0: DFS (Edge^.Destination); // Node not visited
                   1: ; // Cycle found. Not interesting
                   2: Answer:=false; // We try to visit node visited earlier => that can be reached by two ways from root :)
              end;
              Edge:=Edge^.Next;
           end;
     States [aNode]:=2;
end;

procedure SolveOne;
var
   Node, MegaNode: LongInt;
begin
     for Node:=1 to M
         do Edges [Node].Key:=Edges [Node].Source*N+Edges [Node].Destination;
     QuickSort (1, M);
     FillChar (Nodes, SizeOf (Nodes), 0);
     Add (Edges [1].Source, Edges [1].Destination);
     for Node:=2 to M
         do if Edges [Node-1].Key<>Edges [Node].Key
               then Add (Edges [Node].Source, Edges [Node].Destination);

     FillChar (States, SizeOf (States), 0);
     for Node:=1 to N
         do case States [Node] of
                 0: begin // Was not reached from other nodes => they can't be meganodes
                         DFS (Node);
                         MegaNode:=Node;
                    end;
            end;
     FillChar (States, SizeOf (States), 0);
     Answer:=true;
     DFS (MegaNode);
     if Answer
        then for Node:=1 to N
                 do if States [Node]=0
                       then begin
                            Answer:=false;
                            Break;
                       end;
end;

procedure Solve;
var
   I: LongInt;
begin
     Assign (FIn, FileIn);
     Reset (FIn);
     Assign (FOut, FileOut);
     Rewrite (FOut);
     Read (FIn, T);
     for I:=1 to T
         do begin
            ReadData;
            SolveOne;
            WriteData;
         end;
     Close (FIn);
     Close (FOut);
end;

begin
     Solve;
end.
