uses SysUtils;

type
    PTree=^TTree;
    TTree=record
                X: Word;
                Y: LongInt;
                L, R: PTree;
          end;

var
   Trees: array [$0000..$ffff] of PTree;

procedure Split (T: PTree; X: Word; var L, R: PTree);
begin
     if not Assigned (T)
        then begin
             L:=nil;
             R:=nil;
             Exit;
        end
        else if X>T^.X
                then begin
                     Split (T^.R, X, T^.R, R);
                     L:=T;
                end
                else begin
                     Split (T^.L, X, L, T^.L);
                     R:=T;
                end;
end;

function Merge (L, R: PTree): PTree;
begin
     if not Assigned (L)
        then Merge:=R
        else if not Assigned (R)
                then Merge:=L
                else if L^.Y<R^.Y
                        then begin
                             L^.R:=Merge (L^.R, R);
                             Merge:=L;
                        end
                        else begin
                             R^.L:=Merge (L, R^.L);
                             Merge:=R;
                        end;
end;

procedure Insert (var T: PTree; X: Word; Y: LongInt);
begin
     if (not Assigned (T)) or (Y<T^.Y)
        then begin
             Split (T, X, Trees [X]^.L, Trees [X]^.R);
             Trees [X]^.Y:=Y;
             T:=Trees [X];
        end
        else if X<T^.X
                then Insert (T^.L, X, Y)
                else Insert (T^.R, X, Y);
end;

procedure Delete (var T: PTree; X: Word);
begin
     if Assigned (T)
        then if X<T^.X
                then Delete (T^.L, X)
                else if X>T^.X
                        then Delete (T^.R, X)
                        else T:=Merge (T^.L, T^.R);
end;

const
     FileIn='2instr.in';
     FileOut='2instr.out';
     MaxAnswerLength=$10000;
var
   Image: array [1..3*1024*1024] of Char;
   ImageSize: LongInt;
   ImageIndex: LongInt;

   HexTable: array [Char] of Byte;

   Start, Finish: LongInt;
   Memory: array [$0000..$ffff] of Byte;

   Possible: Boolean;
   AnswerLength: LongInt;
   Answer: array [1..MaxAnswerLength] of LongInt;

procedure InitHexTable;
begin
     HexTable ['0']:=0;
     HexTable ['1']:=1;
     HexTable ['2']:=2;
     HexTable ['3']:=3;
     HexTable ['4']:=4;
     HexTable ['5']:=5;
     HexTable ['6']:=6;
     HexTable ['7']:=7;
     HexTable ['8']:=8;
     HexTable ['9']:=9;
     HexTable ['A']:=10;
     HexTable ['B']:=11;
     HexTable ['C']:=12;
     HexTable ['D']:=13;
     HexTable ['E']:=14;
     HexTable ['F']:=15;
     HexTable ['a']:=10;
     HexTable ['b']:=11;
     HexTable ['c']:=12;
     HexTable ['d']:=13;
     HexTable ['e']:=14;
     HexTable ['f']:=15;
end;

function HexToInt (aHexString: string): LongInt;
var
   Index: LongInt;
   Int: LongInt;
begin
     Int:=0;
     for Index:=1 to Length (aHexString)
         do Int:=(Int shl 4) or HexTable [aHexString [Index]];
     HexToInt:=Int;
end;

function ReadHex: string;
var
   Hex: string;
begin
     repeat
           Inc (ImageIndex);
     until Image [ImageIndex] in ['0'..'9', 'A'..'F', 'a'..'f'];
     Hex:='';
     while (Image [ImageIndex] in ['0'..'9', 'A'..'F', 'a'..'f']) and (ImageIndex<=ImageSize)
           do begin
              Hex:=Hex+Image [ImageIndex];
              Inc (ImageIndex);
           end;
     ReadHex:=Hex;
end;

procedure ReadData;
var
   F: file of Char;
   Address: LongInt;
begin
     Assign (F, FileIn);
     Reset (F);
     ImageSize:=FileSize (F);
     BlockRead (F, Image, ImageSize);
     Close (F);

     InitHexTable;
     ImageIndex:=0;

     Start:=HexToInt (ReadHex);
     Finish:=HexToInt (ReadHex);
     for Address:=Low (Memory) to High (Memory)
         do Memory [Address]:=HexToInt (ReadHex);
end;

var
   Distances: array [$0000..$ffff] of LongInt;

procedure WriteData;
var
   FChar: file of Char;
   BytesOut: LongInt;

procedure Out (const aString: string);
var
   NChar: LongInt;
begin
     for NChar:=1 to Length (aString)
         do begin
            Inc (ImageIndex);
            Image [ImageIndex]:=aString [NChar];
         end;
end;

procedure OutByte (aByteString: string);
begin
     Out (aByteString);
     Inc (BytesOut);
     if BytesOut and 15=0
        then Out (#13#10)
        else if BytesOut and 7=0
                then Out (#32#32)
                else Out (#32);
end;

var
   FText: Text;
   Index: LongInt;
begin
     if Possible
        then begin
             ImageIndex:=0;
             BytesOut:=0;

             Out (IntToStr (Distances [Finish])+#13#10);

             for Index:=AnswerLength downto 1
                 do case Answer [Index] of
                         1: OutByte ('5C');
                         2: begin
                                 OutByte ('0F');
                                 OutByte ('CC');
                            end;
                    end;

             while not (Image [ImageIndex] in ['0'..'9', 'A'..'F'])
                   do Dec (ImageIndex);
             OutByte (#13#10);
             ImageSize:=ImageIndex;

             Assign (FChar, FileOut);
             Rewrite (FChar);
             BlockWrite (FChar, Image, ImageSize);
             Close (FChar);
        end
        else begin
             Assign (FText, FileOut);
             Rewrite (FText);
             Writeln (FText, 'IMPOSSIBLE');
             Close (FText);
        end;
end;

function Pop (aSP: Word): Word;
begin
//     Writeln ('Pop: ', aSP, ' -> ', Memory [aSP]+(Memory [(aSP+1) and $ffff] shl 8));
     Pop:=Memory [aSP]+(Memory [(aSP+1) and $ffff] shl 8);
end;

function BSwap (aSP: Word): Word;
begin
//     Writeln ('BSwap: ', aSP, ' -> ', (Lo (aSP) shl 8)+Hi (aSP));
     BSwap:=(Lo (aSP) shl 8)+Hi (aSP);
end;


var
   States: array [$0000..$ffff] of Byte;
   From: array [$0000..$ffff] of Word;
   Root: PTree;

procedure Relax (aX, aFrom: Word; aY: LongInt);
begin
     case States [aX] of
          0: begin
                  States [aX]:=1;
                  Distances [aX]:=aY;
                  Insert (Root, aX, aY);
                  From [aX]:=aFrom;
             end;
          1: if aY<Distances [aX]
                then begin
                     Delete (Root, aX);
                     Distances [aX]:=aY;
                     Insert (Root, aX, aY);
                     From [aX]:=aFrom;
                end;
     end;
end;

procedure Dijkstra;
var
   Node: Word;
begin
     FillChar (States, SizeOf (States), 0);

     Root:=nil;

     States [Start]:=1;
     Distances [Start]:=0;

     Insert (Root, Start, Distances [Start]);

     repeat
           Node:=Root^.X;
           States [Node]:=2;
           if Node=Finish
              then Break;
           Delete (Root, Root^.X);

           Relax (BSwap (Node), Node, Distances [Node]+2); // \ Do not change order!!!!
           Relax (Pop (Node), Node, Distances [Node]+1);   // /
     until not Assigned (Root);
end;

procedure Solve;
var
   Node: Word;
begin
     for Node:=Low (Trees) to High (Trees)
         do begin
            New (Trees [Node]);
            Trees [Node]^.X:=Node;
         end;
     Dijkstra;
     Possible:=States [Finish]=2;
     if Possible
        then begin
             AnswerLength:=0;
             Node:=Finish;
             while Node<>Start
                   do begin
                      Inc (AnswerLength);
                      Answer [AnswerLength]:=Distances [Node]-Distances [From [Node]];
                      Node:=From [Node];
                   end;
        end;
end;

begin
     ReadData;
     Solve;
     WriteData;
end.
