uses Math;
type
    PTree=^TTree;
    TTree=record
                X: Integer;
                Y: Extended;
                L, R: PTree;
          end;

procedure Split (T: PTree; X: Integer; var L, R: PTree);
begin
     if not Assigned (T)
        then begin
             L:=nil;
             R:=nil;
             Exit;
        end
        else if X>T^.X
                then begin
                     Split (T^.R, X, T^.R, R);
                     L:=T;
                end
                else begin
                     Split (T^.L, X, L, T^.L);
                     R:=T;
                end;
end;

function Merge (L, R: PTree): PTree;
begin
     if not Assigned (L)
        then Merge:=R
        else if not Assigned (R)
                then Merge:=L
                else if L^.Y<R^.Y
                        then begin
                             L^.R:=Merge (L^.R, R);
                             Merge:=L;
                        end
                        else begin
                             R^.L:=Merge (L, R^.L);
                             Merge:=R;
                        end;
end;

procedure Insert (var T: PTree; X: Integer; Y: Extended);
var
   T1: PTree;
begin
     if (not Assigned (T)) or (Y<T^.Y)
        then begin
             New (T1);
             Split (T, X, T1^.L, T1^.R);
             T1^.X:=X;
             T1^.Y:=Y;
             T:=T1;
        end
        else if X<T^.X
                then Insert (T^.L, X, Y)
                else Insert (T^.R, X, Y);
end;

procedure Delete (var T: PTree; X: Integer);
var
   T1: PTree;
begin
     if Assigned (T)
        then if X<T^.X
                then Delete (T^.L, X)
                else if X>T^.X
                        then Delete (T^.R, X)
                        else begin
                             T1:=T;
                             T:=Merge (T^.L, T^.R);
                             Dispose (T1);
                        end;
end;

const
     FileIn='polygon.in';
     FileOut='polygon.out';
     MaxN=300;
type
    TPoint=record
                 X, Y: Extended;
           end;
var
   N: Integer;
   Points: array [1..MaxN] of TPoint;
   M: Integer;

procedure ReadData;
var
   F: Text;
   NPoint: LongInt;
begin
     Assign (F, FileIn);
     Reset (F);
     Readln (F, N);
     for NPoint:=1 to N
         do Read (F, Points [NPoint].X, Points [NPoint].Y);
     Close (F);
end;

procedure WriteData;
var
   F: Text;
begin
     Assign (F, FileOut);
     Rewrite (F);
     Writeln (F, M);
     Close (F);
end;

const
     Eps=1e-7;
type
    TStackItem=record
                     Point: Integer;
                     Tree: PTree;
                     SummaryAngle: Extended;
               end;
var
   PifagorNumber: Extended;
   Stack: array [1..MaxN*MaxN] of TStackItem;
   Top: LongInt;
   AX, AY, BX, BY, TreeY: Extended;
   InStack: array [1..MaxN] of Boolean;
   BestTop: array [1..MaxN, 1..MaxN] of LongInt;

procedure Debug;
var
   NItem: LongInt;
begin
     for NItem:=1 to Top
         do Write (Stack [NItem].Point, #32);
     Writeln;
end;

procedure DFS;
var
   Point1, Point2, Point3: LongInt;
   Vector, Scalar: Extended;
   Angle: Extended;
begin
     Inc (Top);
     AX:=Points [Stack [Top-1].Point].X-Points [Stack [Top-2].Point].X;
     AY:=Points [Stack [Top-1].Point].Y-Points [Stack [Top-2].Point].Y;

     for Point1:=1 to N
         do begin
            BX:=Points [Point1].X-Points [Stack [Top-1].Point].X;
            BY:=Points [Point1].Y-Points [Stack [Top-1].Point].Y;
            Vector:=AX*BY-AY*BX;
            if Vector>0
               then Insert (Stack [Top].Tree, Point1, Vector);
         end;

     while Assigned (Stack [Top].Tree)
           do begin
              Stack [Top].Point:=Stack [Top].Tree^.X;
              Delete (Stack [Top].Tree, Stack [Top].Tree^.X);

              Point1:=Stack [Top-2].Point;
              Point2:=Stack [Top-1].Point;
              Point3:=Stack [Top].Point;
              AX:=Points [Point2].X-Points [Point1].X;
              AY:=Points [Point2].Y-Points [Point1].Y;
              BX:=Points [Point3].X-Points [Point2].X;
              BY:=Points [Point3].Y-Points [Point2].Y;
              Vector:=AX*BY-AY*BX;
              Scalar:=AX*BX+AY*BY;
              Angle:=arctan2 (Vector, Scalar); // Manual is wrong!
//              Writeln (Round (Angle*180/Pi));
              Stack [Top].SummaryAngle:=Stack [Top-1].SummaryAngle+Angle;
              if Stack [Top].SummaryAngle>PifagorNumber*2 // We are doing 2nd circle
                 then Continue;

              if InStack [Stack [Top].Point]
                 then begin
                      if Stack [Top].Point=Stack [1].Point
                         then if M<Top-1
                                 then begin
                                      M:=Top-1;
//                                      Write ('Accepted: '); Debug;
                                 end;
                 end
                 else if Top>BestTop [Stack [Top-1].Point, Stack [Top].Point]
                         then begin
                              BestTop [Stack [Top-1].Point, Stack [Top].Point]:=Top;
                              InStack [Stack [Top].Point]:=true;
                              DFS;
                              InStack [Stack [Top].Point]:=false;
                         end;
           end;
     Dec (Top);
end;

procedure Solve;
var
   Point1, Point2: Integer;
begin
     M:=0;

     Stack [1].Tree:=nil;
     Stack [1].SummaryAngle:=0;

     Stack [2].Tree:=nil;
     for Point1:=1 to N
         do Insert (Stack [2].Tree, Point1, 1);
     Stack [2].SummaryAngle:=0;

     Top:=2;

//     FillChar (BestTop, SizeOf (BestTop), 0);

     for Point1:=1 to N
         do begin
            Stack [1].Point:=Point1;
            for Point2:=1 to N
                do if Point1<>Point2
                      then begin
                           Stack [2].Point:=Point2;
                           FillChar (InStack, SizeOf (InStack), false);
                           InStack [Point1]:=true;
                           InStack [Point2]:=true;
                           FillChar (BestTop, SizeOf (BestTop), 0);
                           BestTop [Point1, Point2]:=Top;
                           DFS;
                      end;
         end;
end;

begin
     PifagorNumber:=Pi;
     ReadData;
     Solve;
     WriteData;
end.
