const
     FileIn='elevator.in';
     FileOut='elevator.out';
     MaxN=1000;
type
    TDirection=(dUp, dDown);

    PTree=^TTree;
    TTree=record
                X, Y: LongInt;
                L, R: PTree;
          end;
var
   C, N, K: LongInt;
   Trees: array [1..MaxN] of PTree;
   Answer: LongInt;

procedure Split (T: PTree; X: LongInt; var L, R: PTree);
begin
     if not Assigned (T)
        then begin
             L:=nil;
             R:=nil;
             Exit;
        end
        else if X>T^.X
                then begin
                     Split (T^.R, X, T^.R, R);
                     L:=T;
                end
                else begin
                     Split (T^.L, X, L, T^.L);
                     R:=T;
                end;
end;

function Merge (L, R: PTree): PTree;
begin
     if not Assigned (L)
        then Merge:=R
        else if not Assigned (R)
                then Merge:=L
                else if L^.Y>R^.Y
                        then begin
                             L^.R:=Merge (L^.R, R);
                             Merge:=L;
                        end
                        else begin
                             R^.L:=Merge (L, R^.L);
                             Merge:=R;
                        end;
end;

procedure Insert (var T: PTree; X, Y: LongInt);
var
   T1: PTree;
begin
     if (not Assigned (T)) or (Y>T^.Y)
        then begin
             New (T1);
             Split (T, X, T1^.L, T1^.R);
             T1^.X:=X;
             T1^.Y:=Y;
             T:=T1;
        end
        else if X<T^.X
                then Insert (T^.L, X, Y)
                else Insert (T^.R, X, Y); // There must be no duplicates!!!
end;

function Delete (var T: PTree; X: LongInt): Boolean;
var
   T1: PTree;
begin
     if Assigned (T)
        then if X<T^.X
                then Delete:=Delete (T^.L, X)
                else if X>T^.X
                        then Delete:=Delete (T^.R, X)
                        else begin
                             T1:=T;
                             T:=Merge (T^.L, T^.R);
                             Dispose (T1);
                             Delete:=true;
                        end
        else Delete:=false;
end;

procedure ReadData;
var
   F: Text;
   NItem: LongInt;
   Source, Destination: LongInt;
begin
     Assign (F, FileIn);
     Reset (F);
     Readln (F, N, C, K);
     for NItem:=1 to K
         do begin
            Read (F, Source, Destination);
            Insert (Trees [Source], Destination, Random (MaxLongInt));
         end;
     Close (F);
end;

procedure WriteData;
var
   F: Text;
begin
     Assign (F, FileOut);
     Rewrite (F);
     Writeln (F, Answer*5);
     Close (F);
end;

function Max (aA, aB: LongInt): LongInt;
begin
     if aA>aB
        then Max:=aA
        else Max:=aB;
end;

function GetMaxDestination (aTree: PTree): LongInt;
var
   Tree: PTree;
   MaxDestination: LongInt;
begin
     MaxDestination:=0;
     Tree:=aTree;
     while Assigned (Tree)
           do begin
              if Tree^.X>MaxDestination
                 then MaxDestination:=Tree^.X;
              Tree:=Tree^.R;
           end;
     GetMaxDestination:=MaxDestination;
end;

function GetMinDestination (aTree: PTree): LongInt;
var
   Tree: PTree;
   MinDestination: LongInt;
begin
     MinDestination:=N+1;
     Tree:=aTree;
     while Assigned (Tree)
           do begin
              if Tree^.X<MinDestination
                 then MinDestination:=Tree^.X;
              Tree:=Tree^.L;
           end;
     GetMinDestination:=MinDestination;
end;

function SomebodyLowerWantsUp (aFloor: LongInt): Boolean;
var
   Floor: LongInt;
begin
     for Floor:=aFloor downto 1
         do if GetMaxDestination (Trees [Floor])>Floor
               then begin
                    SomebodyLowerWantsUp:=true;
                    Break;
               end;
     SomebodyLowerWantsUp:=false;
end;

function SomebodyHigherWantsDown (aFloor: LongInt): Boolean;
var
   Floor: LongInt;
begin
     for Floor:=aFloor downto 1
         do if GetMinDestination (Trees [Floor])<Floor
               then begin
                    SomebodyHigherWantsDown:=true;
                    Break;
               end;
     SomebodyHigherWantsDown:=false;
end;

procedure Walk (aTree: PTree);
begin
     if Assigned (aTree)
        then begin
             Write (aTree^.X, #32);
             Walk (aTree^.L);
             Walk (aTree^.R);
        end;
end;

procedure Solve;
var
   Elevator: PTree;
   Floor: LongInt;
   Direction, OldDirection: TDirection;
   Destination, NearestDestination: LongInt;
   CountInside: LongInt;
   Changed: Boolean;

procedure Debug;
var
   NFloor: LongInt;
begin
     Exit;
     Writeln ('----------------------');
     for NFloor:=N downto 1
         do begin
            Write (NFloor, ':');
            Walk (Trees [NFloor]);
            Writeln;
         end;
     Write ('Elevator at ', Floor,': ');
     Walk (Elevator);
     Writeln;
     Writeln (K, ' people left!');
     Readln;
end;

begin
     if C>=K
        then begin
             Destination:=0;
             for Floor:=1 to N
                 do Destination:=Max (Destination, GetMaxDestination (Trees [Floor]));
             Answer:=(Destination-1)*2;
             Exit;
        end;

     Elevator:=nil;
     Floor:=1;
     Direction:=dUp;
     CountInside:=0;
     repeat
           Debug;
           OldDirection:=Direction;
           //   ਥ堫 - 
           while Delete (Elevator, Floor)
                 do begin
                    Dec (CountInside);
                    Dec (K);
                 end;
           // ,   ,   , - 
           if Direction=dUp
              then repeat
                         Destination:=GetMinDestination (Elevator);
                         if Destination<Floor
                            then begin
                                 Delete (Elevator, Destination);
                                 Dec (CountInside);
                                 Insert (Trees [Floor], Destination, Random (MaxLongInt));
                            end;
                   until Destination>=Floor;
{
           // ,   ,   , - 
           if Direction=dDown
              then repeat
                         Destination:=GetMaxDestination (Elevator);
                         if Destination>Floor
                            then begin
                                 Delete (Elevator, Destination);
                                 Dec (CountInside);
                                 Insert (Trees [Floor], Destination, Random (MaxLongInt));
                            end;
                   until Destination<=Floor;
}
           // ᫨   ,  ࠥ 稪
           // ᫨  , ஡㥬 모 ⮣,   
           if Direction=dDown
              then repeat
                         Changed:=false;
                         Destination:=GetMinDestination (Trees [Floor]);
                         if Destination<Floor
                            then begin
                                 if CountInside=C
                                    then begin
                                         NearestDestination:=GetMaxDestination (Elevator);
                                         if NearestDestination<Destination
                                            then begin
                                                 Delete (Elevator, NearestDestination);
                                                 Dec (CountInside);
                                                 Insert (Trees [Floor], NearestDestination, Random (MaxLongInt));
                                            end;
                                    end;
                                 if CountInside<C
                                    then begin
                                         Delete (Trees [Floor], Destination);
                                         Insert (Elevator, Destination, Random (MaxLongInt));
                                         Inc (CountInside);
                                         Changed:=true;
                                    end;
                            end;
                   until not Changed;
{           if Direction=dUp
              then} repeat
                         Changed:=false;
                         Destination:=GetMaxDestination (Trees [Floor]);
                         if Destination>Floor
                            then begin
                                 if CountInside=C
                                    then begin
                                         NearestDestination:=GetMinDestination (Elevator);
                                         if NearestDestination<Destination
                                            then begin
                                                 Delete (Elevator, NearestDestination);
                                                 Dec (CountInside);
                                                 Insert (Trees [Floor], NearestDestination, Random (MaxLongInt));
                                            end;
                                    end;
                                 if CountInside<C
                                    then begin
                                         Delete (Trees [Floor], Destination);
                                         Insert (Elevator, Destination, Random (MaxLongInt));
                                         Inc (CountInside);
                                         Changed:=true;
                                    end;
                            end;
                   until not Changed;

           if (not SomebodyHigherWantsDown (Floor)) and (GetMaxDestination (Elevator)<Floor)
              then Direction:=dDown;
           // ᫨   ,  ᥬ    ,   
           if (Direction=dDown) and (GetMinDestination (Elevator)>Floor) and (CountInside=C)
              then Direction:=dUp;
           // ᫨      ,    ,   ,  
           if (GetMaxDestination (Elevator)>Floor) and not SomebodyLowerWantsUp (Floor)
              then Direction:=dUp;

           Debug;

           if (Direction=dDown) and (Floor=1)
              then Direction:=dUp;
           if (Direction=dUp) and (Floor=N)
              then Direction:=dDown;

           if OldDirection=Direction
              then begin
                   if Direction=dUp
                      then Inc (Floor);
                   if Direction=dDown
                      then Dec (Floor);
                   Inc (Answer);
              end;
     until K=0;
     Answer:=Answer+Floor-1;
end;

begin
     ReadData;
     Solve;
     WriteData;
end.
