#include <stdio.h>
#include <stdlib.h>
#include <string.h>

struct TEdge {
  int from,to;
  TEdge*next;
};
class TGraph {
  private:
    int n_verts,n_edges,root;
    TEdge*edges_cont_0,*edges_cont_1,**edges,**edges_rev;
    char*marks; int*levers_up,*levers_down;
    int*stk_vert; TEdge**stk_edge; int*stk_lev; int stk_pnt;
    int*seq; int seq_len,seq_pos;
  protected:
    int f_seq,f_test,f_failed;
    void reset(void);
    void search(int);
  public:
    TGraph(void);
    ~TGraph();
    void Create(void);
    void Delete(void);
    void scan(void);
    int checkroot(void);
    int checksing(void);
};

TGraph graph;
int f_ok;

int main(void) {
  #ifndef OFFLINE
  freopen("quirks.in","rt",stdin);
  freopen("quirks.out","wt",stdout);
  #endif
  int n_tests,i_test;
  scanf("%d",&n_tests);
  for (i_test=0; i_test<n_tests; i_test++) {
    graph.scan();
    f_ok=0;
    if (graph.checkroot()) if (graph.checksing()) f_ok=1;
    printf("%s\n",f_ok?"YES":"NO");
  }
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


void TGraph::reset(void) {
  memset(marks,0,sizeof(char)*n_verts);
  if (f_seq) seq_len=0;
  if (f_test) {
    memset(levers_up,0,sizeof(int)*n_verts);
    memset(levers_down,0,sizeof(int)*n_verts);
    f_failed=0;
  }
}
void TGraph::search(int cur) {
  int to,lev; TEdge*edge;
  stk_pnt=0; *stk_vert=cur; *stk_edge=edges[cur]; if (f_test) *stk_lev=0;
  marks[cur]=1;
  while (stk_pnt>=0) {
    cur=stk_vert[stk_pnt]; edge=stk_edge[stk_pnt];
    if (f_test) lev=stk_lev[stk_pnt];
    if (!edge) {
      if (f_seq) seq[seq_len++]=cur;
      stk_pnt--;
      if (f_test) {
        marks[cur]=-1;
        lev-=levers_down[cur]; lev+=levers_up[cur];
        if (lev>1) f_failed|=2;
        if (stk_pnt>=0) stk_lev[stk_pnt]+=lev;
      } continue;
    }
    stk_edge[stk_pnt]=edge->next;
    to=edge->to;
    if (marks[to]) {
      if (f_test) {
        if (marks[to]<0) f_failed|=1;
        else { levers_up[cur]++; levers_down[to]++; }
      } continue;
    }
    stk_pnt++;
    stk_vert[stk_pnt]=to;
    stk_edge[stk_pnt]=edges[to];
    if (f_test) stk_lev[stk_pnt]=0;
    marks[to]=1;
  }
}

int TGraph::checkroot(void) {
  int vert;
  f_seq++;
  reset();
  for (vert=0; vert<n_verts; vert++) if (!marks[vert]) search(vert);
  f_seq--;
  root=seq[seq_len-1];
  #ifdef DEBUG
  printf("%d ",root+1);
  #endif
  reset();
  search(root);
  for (vert=0; vert<n_verts; vert++) if (!marks[vert]) break;
  return(vert>=n_verts);
}
int TGraph::checksing(void) {
  f_test++;
  reset();
  search(root);
  f_test--;
  #ifdef DEBUG
  printf("%d ",f_failed);
  #endif
  return(!f_failed);
}

void TGraph::scan(void) {
  Delete();
  scanf("%d%d",&n_verts,&n_edges);
  Create();
  int i_edge,v,w;
  memset(edges,0,sizeof(TEdge*)*n_verts);
  memset(edges_rev,0,sizeof(TEdge*)*n_verts);
  for (i_edge=0; i_edge<n_edges; i_edge++) {
    scanf("%d%d",&v,&w); v--; w--;
    edges_cont_0[i_edge].from=v;
    edges_cont_0[i_edge].to=w;
    edges_cont_0[i_edge].next=edges[v];
    edges[v]=&edges_cont_0[i_edge];
    edges_cont_1[i_edge].from=w;
    edges_cont_1[i_edge].to=v;
    edges_cont_1[i_edge].next=edges_rev[w];
    edges_rev[w]=&edges_cont_1[i_edge];
  }
}

TGraph::TGraph(void) {
  f_seq=0; f_test=0; f_failed=0;
  n_verts=0; n_edges=0;
  Create();
}
TGraph::~TGraph() {
  Delete();
}
void TGraph::Create(void) {
  edges_cont_0=new TEdge[n_edges]; edges_cont_1=new TEdge[n_edges];
  edges=new TEdge*[n_verts]; edges_rev=new TEdge*[n_verts];
  marks=new char[n_verts];
  levers_up=new int[n_verts]; levers_down=new int[n_verts];
  stk_vert=new int[n_verts]; stk_edge=new TEdge*[n_verts];
  stk_lev=new int[n_verts];
  seq=new int[n_verts];
}
void TGraph::Delete(void) {
  delete[]edges_cont_0; delete[]edges_cont_1;
  delete[]edges; delete[]edges_rev;
  delete[]marks; delete[]levers_up; delete[]levers_down;
  delete[]stk_vert; delete[]stk_edge; delete[]stk_lev;
  delete[]seq;
}


