#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int scanbit(void);
long scanbits(int);
int scandata(unsigned char*,int);

class THuffman {
  private:
    int n_syms;
    int*lens;
    long*codes;
  protected:
    int findsymmaxlen(void);
  public:
    THuffman(int);
    ~THuffman();
    void reset(void);
    void setlen(int,int);
    void build(void);
    int operator[](long) const;
};

int scansym(const THuffman&);

union THeader {
  unsigned char data[8];
  struct {
    char sign[4];
    long len;
  };
};

THeader header;
THuffman table(24),basic(288),sup(32);
long*levs; int*strobes;
char*str;

int main(void) {
  #ifndef OFFLINE
  freopen("kar.in","rt",stdin);
  freopen("kar.out","wt",stdout);
  #endif
  scandata(header.data,8);
  { int i_sym;
    for (i_sym=0; i_sym<24; i_sym++) table.setlen(i_sym,scanbits(4));
    table.build();
    #ifdef DEBUG
    printf("\n");
    #endif
    for (i_sym=0; i_sym<288; i_sym++) basic.setlen(i_sym,scansym(table));
    basic.build();
    #ifdef DEBUG
    printf("\n");
    #endif
    for (i_sym=0; i_sym<32; i_sym++) sup.setlen(i_sym,scansym(table));
    sup.build();
    #ifdef DEBUG
    printf("\n");
    #endif
  }
  long pos,sub_pos,sub_len; int sym;
  levs=new long[32]; strobes=new int[32];
  *levs=1L; *strobes=0;
  for (sym=1; sym<32; sym+=2) levs[sym]=1L<<((sym+1)>>1);
  for (sym=2; sym<32; sym+=2) levs[sym]=(1L<<((sym>>1)))+(1L<<((sym>>1)-1));
  for (sym=1; sym<32; sym++) strobes[sym]=(sym-1)>>1;
  str=new char[header.len+2];
  for (pos=0; pos<header.len; ) {
    sym=scansym(basic);
    if (sym<256) {
      str[pos++]=(char)sym;
    } else {
      sym-=256;
      sub_pos=levs[sym]|scanbits(strobes[sym]);
      sym=scansym(sup);
      sub_len=levs[sym]|scanbits(strobes[sym]);
      for (sub_pos=pos-sub_pos; sub_len>0; sub_pos++,sub_len--)
        str[pos++]=str[sub_pos];
    }
  } str[pos]=0;
  #ifdef DEBUG
  printf("\n");
  #endif
  for (pos=0; pos<header.len; pos++)
    printf("%02X",(unsigned int)((unsigned char)str[pos]));
  printf("\n");
  #ifdef DEBUG
  printf("%s\n",str);
  #endif
  delete[]str;
  delete[]levs; delete[]strobes;
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


int scansym(const THuffman&huff) {
  long code=1; int sym=-1;
  while (sym<0) {
    code=(code<<1)|((long)scanbit());
    sym=huff[code];
  }
  #ifdef DEBUG
  //if (sym) printf("(%d) ",sym); else
  printf(" ");
  #endif
  return(sym);
}


int THuffman::operator[](long code) const {
  int i_sym;
  for (i_sym=0; i_sym<n_syms; i_sym++) if (codes[i_sym]==code) break;
  return(i_sym<n_syms?i_sym:-1);
}

int THuffman::findsymmaxlen(void) {
  int i_sym,i_sym_to;
  for (i_sym=0; i_sym<n_syms; i_sym++)
   if (lens[i_sym]>0) if (codes[i_sym]<0)
    break;
  for (i_sym_to=i_sym; i_sym_to<n_syms; i_sym_to++)
   if (lens[i_sym_to]>0) if (codes[i_sym_to]<0)
    if (lens[i_sym]<lens[i_sym_to]) i_sym=i_sym_to;
  return(i_sym<n_syms?i_sym:-1);
}
void THuffman::build(void) {
  int i_sym; int len; long code;
  memset(codes,-1,sizeof(long)*n_syms);
  i_sym=findsymmaxlen();
  if (i_sym<0) return;
  len=lens[i_sym];
  codes[i_sym]=code=1L<<len;
  for (i_sym=findsymmaxlen(); i_sym>=0; i_sym=findsymmaxlen()) {
    for (; len>lens[i_sym]; len--) code>>=1;
    codes[i_sym]=++code;
  }
}

void THuffman::reset(void) {
  memset(lens,0,sizeof(int)*n_syms);
  memset(codes,-1,sizeof(long)*n_syms);
}
void THuffman::setlen(int i_sym,int len) {
  lens[i_sym]=len;
}

THuffman::THuffman(int n_syms_) {
  n_syms=n_syms_;
  lens=new int[n_syms]; codes=new long[n_syms];
}
THuffman::~THuffman() {
  delete[]lens; delete[]codes;
}


int scanbit(void) {
  static unsigned int byte=0,bit=0;
  static int len=0;
  if (len<=0) { byte=0; scanf("%X",&byte); len=8; }
  len--; bit=byte>>len; byte^=bit<<len;
  #ifdef DEBUG
  printf("%X",bit);
  #endif
  return((int)bit);
}
long scanbits(int len) {
  long data=0;
  int pos;
  for (pos=0; pos<len; pos++) data=(data<<1)|((long)scanbit());
  #ifdef DEBUG
  printf(" ");
  #endif
  return(data);
}
int scandata(unsigned char*data,int len) {
  int pos;
  unsigned int z;
  for (pos=0; pos<len; pos++) {
    if (scanf("%X",&z)<1) break;
    data[pos]=(unsigned char)z;
  }
  return(pos);
}


