#include <stdio.h>
#include <stdlib.h>
#include <string.h>

class TPolynom {
  private:
    int deg,*coeffs;
  protected:
    void clear(void);
  public:
    TPolynom(int);
    ~TPolynom();
    void print(void) const;
    TPolynom& operator=(int);
    TPolynom& operator=(const TPolynom&);
    TPolynom& operator*=(int);
    TPolynom& operator%=(int);
    TPolynom& operator+=(const TPolynom&);
    TPolynom& cool(const TPolynom&,int);
};

class TGraph {
  private:
    int n_verts,n_cells,c_colors;
    char*mtrx_cont,**mtrx;
    int*lists_cont,**lists,**ps_lists_cont,***ps_lists;
    int*colors;
    int*marks_cont,**marks;
    TPolynom*pols;
    int vert;
  protected:
    void rec(void);
    void rec_end(void);
    void call(void);
  public:
    TGraph(void);
    ~TGraph();
    void Create(void);
    void Delete(void);
    void scan(void);
    void printpol(void);
    void calcpol(void);
};

TGraph graph;

int main(void) {
  #ifndef OFFLINE
  freopen("chrom.in","rt",stdin);
  freopen("chrom.out","wt",stdout);
  #endif
  graph.scan();
  graph.calcpol();
  graph.printpol();
  #ifndef OFFLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


void TGraph::rec(void) {
  pols[vert]=pols[vert-1];
  for (colors[vert]=0; colors[vert]<c_colors; colors[vert]++)
    if (!marks[vert][colors[vert]]) call();
  pols[vert]%=c_colors++; call(); c_colors--;
}
void TGraph::rec_end(void) {
  int color,c_colls;
  c_colls=0;
  for (color=0; color<c_colors; color++) if (!marks[vert][color]) c_colls++;
  //pols[vert]=pols[vert-1]; pols[vert]*=c_colls; pols[n_verts]+=pols[vert];
  //pols[vert]=pols[vert-1]; pols[vert]%=c_colors; pols[n_verts]+=pols[vert];
  pols[n_verts].cool(pols[vert-1],c_colls-c_colors);
}
void TGraph::call(void) {
  int*p_list;
  for (p_list=ps_lists[vert][vert+1]; *p_list>=0; p_list++)
    marks[*p_list][colors[vert]]++;
  vert++;
  if (vert+1<n_verts) rec(); else rec_end();
  vert--;
  for (p_list=ps_lists[vert][vert+1]; *p_list>=0; p_list++)
    marks[*p_list][colors[vert]]--;
}

void TGraph::calcpol(void) {
  memset(colors,-1,sizeof(int)*n_verts); c_colors=0;
  memset(marks_cont,0,sizeof(int)*n_cells);
  (*pols=1)%=colors[c_colors++]=0;
  if (n_verts>1) {
    pols[n_verts]=0;
    vert=0; call();
  } else pols[n_verts]=*pols;
}

void TGraph::scan(void) {
  Delete();
  scanf("%d",&n_verts);
  n_cells=n_verts*n_verts;
  Create();
  int n_edges,i_edge,v,w;
  memset(mtrx_cont,0,sizeof(char)*n_cells);
  scanf("%d",&n_edges);
  for (i_edge=0; i_edge<n_edges; i_edge++) {
    scanf("%d%d",&v,&w); v--; w--;
    mtrx[v][w]=1; mtrx[w][v]=1;
  }
  memset(lists_cont,-1,sizeof(int)*n_cells);
  for (v=0; v<n_verts; v++) {
    i_edge=0;
    for (w=0; w<n_verts; w++) {
      ps_lists[v][w]=&lists[v][i_edge];
      if ((w!=v)&&mtrx[v][w]) lists[v][i_edge++]=w;
    }
  }
}
void TGraph::printpol(void) {
  pols[n_verts].print();
}

TGraph::TGraph(void) {
  n_verts=0; n_cells=0;
  Create();
}
TGraph::~TGraph() {
  Delete();
}
void TGraph::Create(void) {
  int x,y;
  mtrx_cont=new char[n_cells]; mtrx=new char*[n_verts];
  lists_cont=new int[n_cells]; lists=new int*[n_verts];
  ps_lists_cont=new int*[n_cells]; ps_lists=new int**[n_verts];
  colors=new int[n_verts];
  marks_cont=new int[n_cells]; marks=new int*[n_verts];
  for (x=0,y=0; x<n_verts; x++,y+=n_verts) {
    mtrx[x]=&mtrx_cont[y];
    lists[x]=&lists_cont[y];
    ps_lists[x]=&ps_lists_cont[y];
    marks[x]=&marks_cont[y];
  }
  pols=new TPolynom[n_verts+1](n_verts);
}
void TGraph::Delete(void) {
  delete[]mtrx_cont; delete[]mtrx;
  delete[]marks_cont; delete[]marks;
  delete[]colors;
  delete[]pols;
}


TPolynom& TPolynom::operator=(int loose) {
  clear();
  *coeffs=loose;
  return(*this);
}
TPolynom& TPolynom::operator=(const TPolynom&arg) {
  //clear();
  //memcpy(coeffs,arg.coeffs,sizeof(int)*((arg.deg<=deg?arg.deg:deg)+1));
  memcpy(coeffs,arg.coeffs,sizeof(int)*(deg+1));
  return(*this);
}
TPolynom& TPolynom::operator*=(int mult) {
  int idx;
  for (idx=0; idx<=deg; idx++) coeffs[idx]*=mult;
  return(*this);
}
TPolynom& TPolynom::operator%=(int root) {
  int idx;
  for (idx=deg; idx>0; idx--) coeffs[idx]=coeffs[idx-1]-root*coeffs[idx];
  coeffs[idx]=-root*coeffs[idx];
  return(*this);
}
TPolynom& TPolynom::operator+=(const TPolynom&arg) {
  int idx;
  for (idx=0; (idx<=deg)&&(idx<=arg.deg); idx++)
    coeffs[idx]+=arg.coeffs[idx];
  return(*this);
}
TPolynom& TPolynom::cool(const TPolynom&arg,int mult_minus_root) {
  int idx;
  for (idx=deg; idx>0; idx--)
    coeffs[idx]+=arg.coeffs[idx-1]+mult_minus_root*arg.coeffs[idx];
  coeffs[idx]+=mult_minus_root*arg.coeffs[idx];
  return(*this);
}

void TPolynom::clear(void) {
  memset(coeffs,0,sizeof(int)*(deg+1));
}

void TPolynom::print(void) const {
  int idx;
  printf("%d",deg);
  for (idx=0; idx<=deg; idx++) printf(" %d",coeffs[idx]);
  printf("\n");
}

TPolynom::TPolynom(int deg_) {
  deg=deg_;
  coeffs=new int[deg+1];
}
TPolynom::~TPolynom() {
  delete[]coeffs;
}


