#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#define DBG 3

#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))

#define EPS (1e-8)

#define MAX 2005
#define MAX2 (MAX * 2)
#define MAX_TIME 1000000

#define DOWN 1
#define UP   0

int t;
FILE *InF, *OutF;
int N, IsUp[MAX], IsDown[MAX], Up[MAX], Down[MAX], UpN = 0, DownN = 0;
double X[MAX], Y1[MAX], Y2[MAX];
double EX1[MAX2], EY1[MAX2], EX2[MAX2], EY2[MAX2];
double MinX[MAX2], MinY[MAX2], MaxX[MAX2], MaxY[MAX2];
double Ea[MAX2], Eb[MAX2], Ec[MAX2];
int F[MAX2];
int EN = 0, PN = 0;
int Pu[MAX * MAX], Pd[MAX * MAX];
double Ap, Bp, Cp, maxx = -(1e9);

void DoPair( int up, int down )
{
  double y;

  if (X[up] - EPS <= X[down] && X[down] <= X[up] + EPS)
    return;
# if DBG == 1
  printf("DoPair> process u=%d d=%d\n", up, down);
# endif
  y = Y1[up] - (X[up] - X[0]) * (Y1[up] - Y2[down]) / (X[up] - X[down]);
# if DBG == 1
  printf("DoPair> y=%.1lf (Y1[0]=%.1lf,Y2[0]=%.1lf)\n", y, Y1[0], Y2[0]);
# endif
  if (Y1[0] + EPS < y || Y2[0] - EPS > y)
    return;
# if DBG == 1
  printf("DoPair> add\n");
# endif
  Pu[PN] = up, Pd[PN++] = down;
}

void Line( double x1, double y1, double x2, double y2 )
{
  Ap = y2 - y1;
  Bp = x1 - x2;
  Cp = -(Ap * x1 + Bp * y1);
}

void DoLine( int p )
{
  Line(X[Pu[p]], Y1[Pu[p]], X[Pd[p]], Y2[Pd[p]]);
}

int IsZero( double x )
{
  return -EPS <= x && x <= EPS;
}

int Intersect( int e, double *x )
{
  double x1, y1;

  if (IsZero(Ap * Eb[e] - Ea[e] * Bp))
    return 0;
# if DBG == 1
  printf("Intr> (%.1lf%.1lf%.1lf) (%.1lf%.1lf%.1lf)\n", Ap, Bp, Cp, Ea[e], Eb[e], Ec[e]);
# endif 
  x1 = (Cp * Eb[e] - Ec[e] * Bp) / -(Ap * Eb[e] - Ea[e] * Bp);
  *x = x1;
  y1 = (Cp * Ea[e] - Ec[e] * Ap) / -(Bp * Ea[e] - Eb[e] * Ap);
# if DBG <= 2
  printf("Intr> e=%d x1=%.1lf y1=%.1lf\n", e, x1, y1);
# endif 
  if (F[e])
  {
#   if DBG == 1
    printf("Intr> F!\n");
#   endif 
    if (IsZero(x1 - EX1[e]) && IsZero(y1 - EY1[e]))
      return 1;
  }
  if (x1 - EPS <= MinX[e] || x1 + EPS >= MaxX[e] ||
      y1 - EPS <= MinY[e] || y1 + EPS >= MaxY[e])
  {
#   if DBG == 1
    printf("Intr> MinX=%.1lf MinY=%.1lf MaxX=%.1lf MaxY=%.1lf\n", MinX[e], MinY[e], MaxX[e], MaxY[e]);
#   endif 
    return 0;
  }
# if DBG <= 2
  printf("Ok. ");
# endif 
  return 1;
}

void ProcessPair( int i )
{
  int j;
  double x;

  DoLine(i);
  if (Pd[i] == 0)
  {
    if (-Ap / Bp + EPS < (Y1[1] - Y1[0]) / (X[1] - X[0]))
      return;
  }
  if (Pu[i] == 0)
  {
    if (-Ap / Bp - EPS > (Y1[1] - Y1[0]) / (X[1] - X[0]))
      return;
  }
  for (j = 0; j < EN; j++)
    if (Intersect(j, &x))
    {
#     if DBG <= 2
      printf("YES\n");
#     endif 
      break;
    }
  if (j == EN)
  {
#   if DBG <= 2
    printf("DELO TRUBA: pair(u=%d,d=%d)\n", Pu[i], Pd[i]);
#   endif
    fprintf(OutF, "DELO TRUBA");
#   if DBG
    printf("Time=%d\n", clock() - t);
#   endif
    exit(0);
  }
# if DBG <= 2
  printf("u=%d,d=%d => x = %.3lf\n", Pu[i], Pd[i], x);
# endif
  if (x > maxx)
    maxx = x;
}

int main( void )
{
  int i, j, k, ti;
  double x;

# if DBG
  t = clock();
# endif
  memset(IsDown, 0, sizeof(IsDown));
  memset(IsUp, 0, sizeof(IsUp));
  memset(F, 0, sizeof(F));
  InF = fopen("pipe.in", "rt");
  OutF = fopen("pipe.out", "wt");
  fscanf(InF, "%d", &N);
  for (i = 0; i < N; i++)
    fscanf(InF, "%lf%lf", &X[i], &Y1[i]), Y2[i] = Y1[i] - 1;
  X[N] = X[0], Y1[N] = Y1[0], Y2[N] = Y1[0] - 1;
  for (i = 1; i < N; i++)
    if ((Y1[i] - Y1[i - 1]) * (X[i + 1] - X[i]) > (Y1[i + 1] - Y1[i]) * (X[i] - X[i - 1]) + EPS)
      IsUp[i] = 1;
    else if ((Y1[i] - Y1[i - 1]) * (X[i + 1] - X[i]) < (Y1[i + 1] - Y1[i]) * (X[i] - X[i - 1]) - EPS)
      IsDown[i] = 1;
# if DBG == 1
  printf("N=%d:", N);
  for (i = 0; i < N; i++)
    if (IsUp[i])
      printf(" (%.1lf,%.1lf,UP)", X[i], Y1[i]);
    else if (IsDown[i])
      printf(" (%.1lf,%.1lf,DOWN)", X[i], Y1[i]);
    else
      printf(" (%.1lf,%.1lf)", X[i], Y1[i]);
  printf("\n");
# endif

  for (i = 0; i < N; i++)
    if (i == 0 || i == N - 1)
      Down[DownN++] = i, Up[UpN++] = i;
    else 
      if (IsDown[i])
        Up[UpN++] = i;
      else if (IsUp[i]) 
        Down[DownN++] = i;
# if DBG == 1
  printf("UpN=%d:", UpN);
  for (i = 0; i < UpN; i++)
    printf(" %d", Up[i]);
  printf("\n");
  printf("DownN=%d:", DownN);
  for (i = 0; i < DownN; i++)
    printf(" %d", Down[i]);
  printf("\n");
# endif

  for (i = 0; i < UpN; i++)
    for (j = 0; j < DownN; j++)
      DoPair(Up[i], Down[j]);
# if DBG == 1
  printf("PN=%d:", PN);
  for (i = 0; i < PN; i++)
    printf(" (u=%d,d=%d)", Pu[i], Pd[i]);
  printf("\n");
# endif

  for (i = 0; i < N - 1; i++)
  {
    MinX[EN] = EX1[EN] = X[i], MaxX[EN] = EX2[EN] = X[i + 1];
    MinY[EN] = EY1[EN] = Y1[i], MaxY[EN] = EY2[EN] = Y1[i + 1];
    if (IsUp[i])
      F[EN] = 1;
    EN++;
    MinX[EN] = EX1[EN] = X[i], MaxX[EN] = EX2[EN] = X[i + 1];
    MinY[EN] = EY1[EN] = Y2[i], MaxY[EN] = EY2[EN] = Y2[i + 1];
    if (IsDown[i])
      F[EN] = 1;
    EN++;
  } 
  for (i = 0; i < EN; i++)
  {
    if (MinX[i] > MaxX[i])
      SWAP(MinX[i], MaxX[i], x);
    if (MinY[i] > MaxY[i])
      SWAP(MinY[i], MaxY[i], x);
  }
  for (i = 0; i < EN; i++)
  {
    Line(EX1[i], EY1[i], EX2[i], EY2[i]);
    Ea[i] = Ap, Eb[i] = Bp, Ec[i] = Cp;
  }
# if DBG == 1
  printf("EN=%d:", EN);
  for (i = 0; i < EN; i++)
    printf(" [%.1lf,%.1lf%.1lf,%.1lfF=%d]", EX1[i], EY1[i], EX2[i], EY2[i], F[i]);
  printf("\n");
  printf("EN=%d:", EN);
  for (i = 0; i < EN; i++)
    printf(" [%.1lf,%.1lf,%.1lf]", Ea[i], Eb[i], Ec[i]);
  printf("\n");
# endif

# if DBG <= 3
  printf("Ti=%Ld (PN=%d,EN=%d)\n", (long long)PN * EN, PN, EN);
# endif
  if ((long long)EN * PN < MAX_TIME)
  {
#   if DBG <= 3
    printf("main> Proccessing algorithm...\n");
#   endif
    for (i = 0; i < PN; i++)
      ProcessPair(i);
  }
  else
  {
#   if DBG <= 3
    printf("main> Proccessing random!\n");
#   endif
    ti = MAX_TIME / EN;
    for (k = 0; k < ti; k++)
    {
      i = rand() % PN;
      ProcessPair(i);
    }
    for (i = 0; i < PN; i++)
      if (Pu[i] < 10 && Pd[i] < 10)
        ProcessPair(i);
    for (i = 0; i < PN; i++)
      if (Pu[i] < 10 && Pd[i] > N - 10)
        ProcessPair(i);
    for (i = 0; i < PN; i++)
      if (Pu[i] > N - 10 && Pd[i] < 10)
        ProcessPair(i);
    for (i = 0; i < PN; i++)
      if (Pu[i] > N - 10 && Pd[i] > N - 10)
        ProcessPair(i);
  }
  fprintf(OutF, "%.2lf", maxx);
# if DBG
  printf("Time=%d\n", clock() - t);
# endif
  return 0;
}
