#include <stdio.h>
#include <string.h>

#define DBG 0
#define RES 1

#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))

#define MAX_LEN 3000000
#define MAX_T 100000

typedef struct
{
  int l, c[32];
} code;

typedef struct tagTREE TREE;
struct tagTREE
{
  /* Less = 0, More = 1 */
  TREE *Less, *More;
  int Key;
};

int Bit[MAX_LEN], N = 0, Pos;
int Len = 0, OutLen = 0;
int A[33];
int S[MAX_LEN];

int L0[24], P0[24];
code C0[24];
TREE *T0;

int L1[288], P1[288];
code C1[288];
TREE *T1;

int L2[32], P2[32];
code C2[32];
TREE *T2;

TREE *NewT( int Key )
{
  static TREE Addr[MAX_T];
  static int APos = 0;

  Addr[APos].Key = Key;
  Addr[APos].Less = NULL;
  Addr[APos].More = NULL;
  return &Addr[APos++];
}

int GetNum( char hex )
{
  if ('0' <= hex && hex <= '9')
    return hex - '0';
  if ('a' <= hex && hex <= 'f')
    return hex - 'a' + 10;
  else
    return hex - 'A' + 10;
}

void GetCodes( int N, int *L, int *P, code *C )
{
  int i, j, tmp;

  for (i = 0; i < N; i++)
    P[i] = i;
  for (i = 0; i < N; i++)
    for (j = 1; j < N; j++)
      if (L[j - 1] < L[j])
      {
        SWAP(L[j - 1], L[j], tmp);
        SWAP(P[j - 1], P[j], tmp);
      }
  memset(C, 0, sizeof(code) * N);
  for (i = 0; i < N; i++)
    C[P[i]].l = L[i];
  for (i = 1; i < 24 && L[i] > 0; i++)
  {
    for (j = 0; j < L[i]; j++)
      C[P[i]].c[j] = C[P[i - 1]].c[j];
    for (j = L[i] - 1; C[P[i]].c[j] == 1; j--)
      C[P[i]].c[j] = 0;
    C[P[i]].c[j] = 1;
  }
}

void BuildTree( int N, code *C, TREE **T )
{
  TREE **P;
  int i, j;

  *T = NewT(0);
  for (i = 0; i < N; i++)
  {
    P = T;
    for (j = 0; j < C[i].l; j++)
    {
      if ((*P)->Less == NULL)
      {
        (*P)->Less = NewT(0);
        (*P)->More = NewT(0);
      }
      if (C[i].c[j] == 0)
        P = &(*P)->Less;
      else
        P = &(*P)->More;
    }
    (*P)->Key = i;
  }
}

int ReadSymbol( TREE *T )
{
  while (T->Less)
    if (Bit[Pos++])
      T = T->More;
    else
      T = T->Less;
  return T->Key;
}

int Log2( int a )
{
  int res = 0;

  while (a >= 2)
    res++, a >>= 1;
  return res;
}

int main( void )
{
  int c, i, j, k, x, l;

  freopen("kar.in", "rt", stdin);
  freopen("kar.out", "wt", stdout);
  /* Read bit sequence */
  while (1)
  {
    c = getc(stdin);
    while (c == 32 || c == 10 || c == 13 || c == 8 || c == 9)
      c = getc(stdin);
    if (c == -1)
      break;
    c = (GetNum(c) << 4) + GetNum(getc(stdin));
    for (i = 7; i >= 0; i--)
      Bit[N++] = (c >> i) & 1;
  }
  /* Signature */
  Pos = 32;
  /* Read length of the original string */
  for (i = 3; i >= 0; i--)
    for (j = (i << 3); j < (i << 3) + 8; j++)
      Len <<= 1, Len += Bit[Pos + j];
  Pos += 32;
  /* Read lengths of codes for the tree of lengths */
  memset(L0, 0, sizeof(L0));
  for (i = 0; i < 24; i++)
    for (j = 0; j < 4; j++)
      L0[i] <<= 1, L0[i] += Bit[Pos++];
  /* Decode codes for the tree of lengths */
  GetCodes(24, L0, P0, C0);
  /* Build tree of codes of lengths */
  BuildTree(24, C0, &T0);
  /* Reading lengths */
  for (i = 0; i < 288; i++)
    L1[i] = ReadSymbol(T0);
  for (i = 0; i < 32; i++)
    L2[i] = ReadSymbol(T0);
  /* Decode codes of all symbols */
  GetCodes(288, L1, P1, C1);
  GetCodes(32, L2, P2, C2);
  /* Build tree of codes of all symbols */
  BuildTree(288, C1, &T1);
  BuildTree(32, C2, &T2);
  /* Preparing array A */
  A[0] = 1, A[1] = 2;
  for (i = 2; i < 33; i++)
    if (i & 1)
      k = i / 2, A[i] = (1 << (k + 1));
    else
      k = i / 2, A[i] = (1 << (k - 1)) + (1 << k);
  /* Reading string */
  while (OutLen < Len && Pos < N)
  {
    c = ReadSymbol(T1);
    if (c >= 256)
    {
      c -= 256;
      k = Log2(A[c + 1] - A[c]);
      for (x = 0, i = 0; i < k; i++)
        x <<= 1, x += Bit[Pos++];
      x += A[c];
      c = ReadSymbol(T2);
      k = Log2(A[c + 1] - A[c]);
      for (l = 0, i = 0; i < k; i++)
        l <<= 1, l += Bit[Pos++];
      l += A[c];
#     if DBG == 2
      printf("(%d,%d)", x, l);
#     endif
      /* LZSS Decoding */
      for (i = 0; i < l; i++)
        S[OutLen + i] = S[OutLen - x + i];
      OutLen += l;
    }
    else
    {
#     if DBG == 2
      printf("%02X", c);
#     endif
      /* LZSS Decoding */
      S[OutLen] = c;
      OutLen++;
    }
# if DBG == 1
  for (i = 0; i < Len; i++)
    printf("%c", S[i]);
# endif
  }
# if RES
  for (i = 0; i < Len; i++)
    printf("%02X", S[i]);
# endif
  return 0;
}
