#include <stdio.h>
#include <string.h>

#define DBG 0

#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))
#define ABS(A) ((A) > 0 ? (A) : -(A))

#define EPS (1e-8)

#define MAX 12
#define MAX_NUM 9

int VN, EN, Is[MAX][MAX], C[MAX][MAX], P[MAX];
int U[MAX], Num;
int N;
double A[MAX_NUM][MAX_NUM], B[MAX_NUM];
double X[MAX_NUM];

int main( void )
{
  FILE *InF, *OutF;
  int i, j, k, a, b, sum;
  double tmp;

  memset(P, 0, sizeof(P));
  memset(Is, 0, sizeof(Is));
  InF = fopen("chrom.in", "rt");
  OutF = fopen("chrom.out", "wt");
  /* Reading input data */
  fscanf(InF, "%d%d", &VN, &EN);
  for (i = 0; i < EN; i++)
  {
    fscanf(InF, "%d%d", &a, &b), a--, b--;
    if (!Is[a][b])
    {
      Is[a][b] = Is[b][a] = 1;
      C[a][P[a]++] = b;
      C[b][P[b]++] = a;
    }
  }
  /* Calculating coefficents for Gauss's matrix */
  N = MAX_NUM;
  memset(B, 0, sizeof(B));
  A[0][0] = A[1][0] = 1;
  for (i = 2; i < N; i++)
  {
    Num = i;
    sum = 0;
    memset(U, 0, sizeof(U));
    while (!U[VN])
    {
      for (j = 0; j < VN; j++)
      {
        for (k = 0; k < P[j]; k++)
          if (U[j] == U[C[j][k]])
            break;
        if (k < P[j])
          break;
      }
      if (j == VN)
        sum++;
      U[0]++;
      for (j = 0; U[j] >= Num; j++)
        U[j] = 0, U[j + 1]++;
    }
    B[i] = sum;
  }
#if DBG
  for (i = 0; i < N; i++)
    printf("%.1lf ", B[i]);
  printf("\n");
#endif
  for (i = 0; i < N; i++)
  {
    A[i][0] = 1;
    for (j = 1; j < N; j++)
      A[i][j] = A[i][j - 1] * i;
  }
  /* Gauss's algorithm */
  for (i = 0; i < N; i++)
  {
    for (j = i; j < N; j++)
      if (ABS(A[j][i]) > EPS)
        break;
    for (k = i; k < N; k++)
      SWAP(A[i][k], A[j][k], tmp);
    SWAP(B[i], B[j], tmp);
    for (j = i + 1; j < N; j++)
    {
      tmp = A[j][i] / A[i][i];
      for (k = i; k < N; k++)
        A[j][k] -= A[i][k] * tmp;
      B[j] -= B[i] * tmp;
    }
  }
  for (i = N - 1; i >= 0; i--)
  {
    X[i] = B[i];
    for (j = N - 1; j > i; j--)
      X[i] -= A[i][j] * X[j];
    X[i] /= A[i][i];
  }
  while (ABS(X[N - 1]) <= EPS)
    N--;
  fprintf(OutF, "%d ", N - 1);
  for (i = 0; i < N; i++)
    fprintf(OutF, "%.0lf ", X[i]);
  return 0;
}
