{$I-,Q-,R-,S-}
{$D-}

type
  Integer = Longint;

const
  MAXM = 32768;
  S2X16 = 1 shl 16;

  CmdStrings: array[0..6] of Char = ('A', 'S', 'M', 'D', 'O', 'R', 'W');

  DIV_BY_ZERO = 'DIVISION BY ZERO';
  RUN_TIME = 'RUN-TIME ERROR';
  SUCCESSFUL = 'SUCCESSFUL TERMINATION';

type
  TArgType = (_const, _link);

  TArg = record
    t: TArgType;
    k: Integer;
  end;

  TCmd = (_add, _sub, _mul, _div, _mod, _read, _write);

  TOper = record
    Cmd: TCmd;
    Arg: TArg;
  end;

var
  Memory: array[0..MAXM] of Integer;
  NNew: array[0..MAXM] of Boolean;

procedure Init();
begin
  Assign(Input, 'indirect.in');
  Reset(Input);
  Assign(Output, 'indirect.out');
  Rewrite(Output);
end;

function ReadCmd(): TCmd;
var
  Ch: Char;
  i: Integer;
begin
  Read(Ch);
  for i := 0 to High(CmdStrings) do
    if Ch = CmdStrings[i] then
    begin
      ReadCmd := TCmd(i);
      Exit;
    end;
end;

function ReadArg(): TArg;
var
  Res: TArg;
  Ch: Char;
  Otr: Boolean;
begin
  Read(Ch);
  if Ch = '*' then Res.t := _link else
    Res.t := _const;

  Res.k := 0;

  Otr := False;
  Read(Ch);
  if Ch = '-' then
  begin
    Otr := True;
    Read(Ch);
  end;

  while (Ch in ['0'..'9']) do
  begin
    Res.k := Res.k * 10 + Ord(Ch) - 48;
    Read(Ch);
  end;

  if Otr then Res.k := -Res.k;

  ReadArg := Res;
end;

function ReadOper(): TOper;
var
  Res: TOper;
begin
  Res.Cmd := ReadCmd();
  Res.Arg := ReadArg();
  ReadOper := Res;
  Readln;
end;

procedure Dump();
var
  i: Integer;
begin
  for i := 0 to MAXM do Writeln(Memory[i]);
end;

procedure Done();
begin
  Close(Input);
  Close(Output);
end;

procedure RunTime();
begin
  Writeln(RUN_TIME);

  Dump();

  Done();
  Halt;
end;

procedure DivZero();
begin
  Writeln(DIV_BY_ZERO);

  Dump();

  Done();
  Halt;
end;

procedure SuccessfulTerm();
begin
  Writeln(SUCCESSFUL);

  Dump();

  Done();
  Halt;
end;

function Get(const k: Integer): Integer;
begin
  if Memory[k] >= 0 then
  begin
    Get := Memory[k];
    Exit;
  end;

  if NNew[k] then RunTime();
  NNew[k] := True;
  Get := Get(Abs(Memory[k]));
end;

function GetK(const k: Integer): Integer;
begin
  if Memory[k] >= 0 then
  begin
    GetK := k;
    Exit;
  end;

  if NNew[k] then RunTime();
  NNew[k] := True;
  GetK := GetK(Abs(Memory[k]));
end;

function GetValue(const Arg: TArg): Integer;
begin
  if Arg.t = _const then
  begin
    GetValue := Arg.k;
    Exit;
  end;

  Fillchar(NNew, Sizeof(NNew), 0);
  GetValue := Get(Arg.k);
end;

function GetSlot(const k: Integer): Integer;
begin
  Fillchar(NNew, Sizeof(NNew), 0);
  GetSlot := GetK(k);
end;

procedure OnOver(var k: Integer);
begin
  k := k mod S2X16;
  if k > 32767 then k := -32768 + k - 32767 - 1 else
    if k < -32768 then k := 32767 + k + 32768 + 1;
end;

procedure Solve();
var
  Oper: TOper;
  Arg: TArg;
  Tmp: Integer;
begin
  while not Eof do
  begin
    Oper := ReadOper();
    Arg := Oper.Arg;

    case Oper.Cmd of
      _add:
      begin
        Inc(Memory[0], GetValue(Arg));
        OnOver(Memory[0]);
      end;

      _sub:
      begin
        Dec(Memory[0], GetValue(Arg));
        OnOver(Memory[0]);
      end;

      _mul:
      begin
        Memory[0] := Memory[0] * GetValue(Arg);
        OnOver(Memory[0]);
      end;

      _div:
      begin
        Tmp := GetValue(Arg);
        if Tmp = 0 then DivZero();
        Memory[0] := Memory[0] div Tmp;
      end;

      _mod:
      begin
        Tmp := GetValue(Arg);
        if Tmp = 0 then DivZero();
        Memory[0] := Memory[0] mod Tmp;
      end;

      _read:
      begin
        Memory[0] := GetValue(Arg);
      end;

      _write:
      begin
        Memory[GetSlot(Arg.k)] := Memory[0];
      end;
    end;
  end;
end;

begin
  Init();
  Solve();
  SuccessfulTerm();
end.
