{$I-,Q-,R-,S-}
{$D-}

type
  Integer = Longint;

const
  INFINITE = 100000000;

  Hex = ['0'..'9', 'A'..'F'];

  S_POP = '2';
  S_SWAP = '11';

  S16X3 = 4096;
  S16X2 = 256;
  S16X1 = 16;

  B11 = '0F';
  B12 = 'CC';
  B2 = '5C';

type
  TByte = array[1..2] of Char;
  TAddr = array[1..2] of TByte;
  TAnswer = AnsiString;

var
  ks, kf: TAddr;
  ToDec: array['0'..'F'] of Integer;
  Memory: array[0..15, 0..15, 0..15, 0..15] of TByte;
  Lens: array[0..15, 0..15, 0..15, 0..15] of Integer;
  CurStr: TAnswer;
  Answer: TAnswer;

function ReadByte(): TByte;
var
  Res: TByte;
  Ch: Char;
begin
  Read(Ch);
  while not (Ch in Hex) do Read(Ch);

  Res[1] := Ch;
  Read(Ch);
  Res[2] := Ch;

  ReadByte := Res;
end;

function ReadAddr(): TAddr;
var
  Res: TAddr;
begin
  Res[1] := ReadByte();
  Res[2] := ReadByte();
  ReadAddr := Res;
end;

procedure Init();
var
  i, j, t, h: Integer;
  g: Char;
begin
  Assign(Input, '2instr.in');
  Reset(Input);
  Assign(Output, '2instr.out');
  Rewrite(Output);

  ks := ReadAddr();
  kf := ReadAddr();

  for i := 0 to 15 do
    for j := 0 to 15 do
      for t := 0 to 15 do
        for h := 0 to 15 do
        begin
          Memory[i, j, t, h] := ReadByte();
          Lens[i, j, t, h] := INFINITE;
        end;

  for g := '0' to '9' do
    ToDec[g] := Ord(g) - 48;

  for g := 'A' to 'F' do
    ToDec[g] := Ord(g) - Ord('A') + 10;
end;

procedure MutLens(const a: TAddr; const Len: Integer);
begin
  Lens[ToDec[a[1][1]], ToDec[a[1][2]], ToDec[a[2][1]], ToDec[a[2][2]]] := Len;
end;

function GetLens(const a: TAddr): Integer;
begin
  GetLens := Lens[ToDec[a[1][1]], ToDec[a[1][2]], ToDec[a[2][1]], ToDec[a[2][2]]];
end;

function EqByte(const b1, b2: TByte): Boolean;
begin
  EqByte := (b1[1] = b2[1]) and (b1[2] = b2[2]);
end;

function EqAddr(const k1, k2: TAddr): Boolean;
begin
  EqAddr := EqByte(k1[1], k2[1]) and EqByte(k1[2], k2[2]);
end;

function BSwap(const k: TAddr): TAddr;
var
  Res: TAddr;
begin
  Res[1] := k[2];
  Res[2] := k[1];
  BSwap := Res;
end;

function AddrToDec(const k: TAddr): Integer;
begin
  AddrToDec := ToDec[k[1][1]] * S16X3 + ToDec[k[1][2]] * S16X2
    + ToDec[k[2][1]] * S16X1 + ToDec[k[2][2]];
end;

function DecToByte(k: Integer): TByte;
begin
  DecToByte := Memory[k div S16X3, (k mod S16X3) div S16X2,
    (k mod S16X2) div S16X1, k mod S16X1];
end;

function Pop(const k: TAddr): TAddr;
var
  Res: TAddr;
  h: Integer;
begin
  h := AddrToDec(k);
  Res[1] := DecToByte(h + 1);
  Res[2] := DecToByte(h);
  Pop := Res;
end;

procedure ApplyStr();
var
  i: Integer;
begin
  if (Length(CurStr) < Length(Answer)) or (Length(Answer) = 0) then
  begin
    Answer := CurStr;
    Exit;
  end;

  if Length(Answer) < Length(CurStr) then Exit;

  for i := 1 to Length(Answer) do
    if CurStr[i] < Answer[i] then
    begin
      Answer := CurStr;
      Exit;
    end;
end;

procedure Dfs(const k: TAddr);
var
  k2: TAddr;
  l: Integer;
begin
  MutLens(k, Length(CurStr));

  if EqAddr(k, kf) then
  begin
    ApplyStr();
    Exit;
  end;

  k2 := BSwap(k);
  if GetLens(k2) >= Length(CurStr) + Length(S_SWAP) then
  begin
    l := Length(CurStr);
    CurStr := CurStr + S_SWAP;
    Dfs(k2);
    SetLength(CurStr, l);
  end;

  k2 := Pop(k);
  if GetLens(k2) >= Length(CurStr) + Length(S_POP) then
  begin
    l := Length(CurStr);
    CurStr := CurStr + S_POP;
    Dfs(k2);
    SetLength(CurStr, l);
  end;
end;

procedure Solve();
var
  CoolAnswer: TAnswer;
  OnBlock, OnLine: Integer;
  First: Boolean;
  i: Integer;
begin
  Dfs(ks);

  if Length(Answer) = 0 then
  begin
    Writeln('IMPOSSIBLE');
    Exit;
  end;

  Writeln(Length(Answer));

  i := 1;
  OnBlock := 0;
  OnLine := 0;
  First := True;
  while i <= Length(Answer) do
  begin
    if OnBlock = 8 then
    begin
      OnBlock := 0;
      Write(' ');
    end;
    if OnLine = 16 then
    begin
      Writeln;
      OnLine := 0;
    end;

    if Answer[i] = '1' then
    begin
      if First then
      begin
        Write(B11);
        First := False;
      end else
      begin
        Write(B12);
        First := True;
      end;
    end else
    begin
      Write(B2);
      First := True;
    end;

    if (OnLine < 16) and (i < Length(Answer)) then Write(' ');
    Inc(OnBlock);
    Inc(OnLine);
    Inc(i);
  end;
  if OnLine > 0 then Writeln;
end;

procedure Done();
begin
  Close(Input);
  Close(Output);
end;

begin
  Init();
  Solve();
  Done();
end.
