{$I-,Q-,R-,S-}
{$D-}

type
  Integer = Longint;

const
  MAXN = 1005;
  MAXM = 1005;
  MAXR = 1005;

  CmdStrings: array[0..11] of String = ('LOAD', 'STORE', 'ADD', 'SUB', 'MULT',
    'DIV', 'READ', 'WRITE', 'JUMP', 'JGTZ', 'JZERO', 'HALT');

type
  TCommand = (_load, _store, _add, _sub, _mult, _div, _read, _write, _jump,
              _jgtz, _jzero, _halt);

  TVType = (_const, _addr, _link);

  TVf = record
    t: TVType;
    k: Integer;
  end;

  TOper = record
    Cmd: TCommand;
    v: TVf;
  end;

var
  n, m: Integer;
  Numbers: array[0..MAXN] of Integer;
  Prog: array[0..MAXM] of TOper;
  Cur: Integer;
  Reg: array[0..MAXR] of Integer;

function ReadCmd(): TCommand;
var
  Str: String;
  Ch: Char;
  i: Integer;
begin
  Read(Ch);
  Str := '';
  while not (Ch in [' ', #13, #10]) do
  begin
    Str := Str + Ch;
    Read(Ch);
  end;

  for i := 0 to High(CmdStrings) do
    if (Str = CmdStrings[i]) then
    begin
      ReadCmd := TCommand(i);
      Exit;
    end;
end;

function ReadV(): TVf;
var
  Ch: Char;
  Res: TVf;
  Otr: Boolean;
begin
  Read(Ch);
  while not (Ch in ['0'..'9', '=', '*', '-']) do Read(Ch);

  case Ch of
    '=':
    begin
      Res.t := _const;
      Read(Ch);
    end;
    '*':
    begin
      Res.t := _link;
      Read(Ch);
    end;
    else Res.t := _addr;
  end;

  Res.k := 0;

  Otr := False;
  if Ch = '-' then
  begin
    Otr := True;
    Read(Ch);
  end;

  while (Ch in ['0'..'9']) do
  begin
    Res.k := Res.k * 10 + Ord(Ch) - 48;
    Read(Ch);
  end;

  if Otr then Res.k := -Res.k;
  ReadV := Res;
end;

procedure ReadProgram();
var
  i: Integer;
begin
  for i := 0 to m - 1 do
  begin
    Prog[i].Cmd := ReadCmd();
    if (Prog[i].Cmd <> _halt) then
      Prog[i].v := ReadV();
    Readln;
  end;

  Cur := 0;
end;

procedure Init();
var
  i: Integer;
begin
  Assign(Input, 'ram.in');
  Reset(Input);
  Assign(Output, 'ram.out');
  Rewrite(Output);

  Readln(m, n);

  ReadProgram();

  for i := 1 to n do Read(Numbers[i]);
  Numbers[0] := 0;
end;

function GetVNum(const v: TVf): Integer;
var
  Res: Integer;
begin
  Res := 0;

  case v.t of
    _const: Res := v.k;
    _addr: Res := Reg[v.k];
    _link: Res := Reg[Reg[v.k]];
  end;

  GetVNum := Res;
end;

procedure Solve();
var
  v: TVf;
  Next: Integer;
begin
  while True do
  begin
    Next := Cur + 1;
    v := Prog[Cur].v;
    case Prog[Cur].Cmd of
      _load:
      begin
        Reg[0] := GetVNum(v);
      end;

      _store:
      begin
        if v.t = _addr then Reg[v.k] := Reg[0] else
          Reg[Reg[v.k]] := Reg[0];
      end;

      _add:
      begin
        Inc(Reg[0], GetVNum(v));
      end;

      _sub:
      begin
        Dec(Reg[0], GetVNum(v));
      end;

      _mult:
      begin
        Reg[0] := Reg[0] * GetVNum(v);
      end;

      _div:
      begin
        Reg[0] := Reg[0] div GetVNum(v);
      end;

      _read:
      begin
        Inc(Numbers[0]);
        if v.t = _addr then Reg[v.k] := Numbers[Numbers[0]] else
          Reg[Reg[v.k]] := Numbers[Numbers[0]];
      end;

      _write:
      begin
        Writeln(GetVNum(v));
      end;

      _jump:
      begin
        Next := v.k;
      end;

      _jgtz:
      begin
        if Reg[0] > 0 then Next := v.k;
      end;

      _jzero:
      begin
        if Reg[0] = 0 then Next := v.k;
      end;

      _halt:
      begin
        Exit;
      end;
    end;

    Cur := Next;
  end;
end;

procedure Done();
begin
  Close(Input);
  Close(Output);
end;

begin
  Init();
  Solve();
  Done();
end.

