{$I-,Q-,R-,S-}
{$D-}

const
  MAXN = 2005;
  EPS = 1E-7;
  STEP = 0.005;
  INFINITE = 1E15;

type
  Integer = Longint;

  TPoint = record
    x, y: Extended;
  end;

  TLine = record
    a, b, c: Extended;
  end;

var
  n: Integer;
  Up: array[1..MAXN] of TPoint;
  Down: array[1..MAXN] of TPoint;
  Answer: Extended;

procedure ReadPoint(var p: TPoint);
begin
  Read(p.x, p.y);
end;

procedure Init();
var
  i: Integer;
begin
  Assign(Input, 'pipe.in');
  Reset(Input);
  Assign(Output, 'pipe.out');
  Rewrite(Output);

  Read(n);
  for i := 1 to n do
  begin
    ReadPoint(Up[i]);
    Down[i] := Up[i];
    Down[i].y := Down[i].y - 1;
  end;

  Answer := -INFINITE;
end;

function Eq(const a, b: Extended): Boolean;
begin
  Eq := Abs(a - b) <= EPS;
end;

function EqPoint(const p1, p2: TPoint): Boolean;
begin
  EqPoint := Eq(p1.x, p2.x) and Eq(p1.y, p2.y);
end;

function Vp(const x1, y1, x2, y2: Extended): Extended;
begin
  Vp := x1*y2 - x2*y1;
end;

function Sp(const x1, y1, x2, y2: Extended): Extended;
begin
  Sp := x1*x2 + y1*y2;
end;

function ToLine(const p1, p2: TPoint): TLine;
var
  Res: TLine;
begin
  Res.a := p2.y - p1.y;
  Res.b := p1.x - p2.x;
  Res.c := p2.x * p1.y - p1.x * p2.y;
  ToLine := Res;
end;

function LineInter(const l1, l2: TLine): TPoint;
var
  Res: TPoint;
begin
  Res.x := (l2.b*l1.c - l1.b*l2.c) / (l2.a*l1.b - l1.a*l2.b);
  Res.y := (l1.c*l2.a - l2.c*l1.a) / (l2.b*l1.a - l1.b*l2.a);
  LineInter := Res;
end;

function Cool(const p1, p2, pk: TPoint; const Vert: Boolean): Boolean;
begin
  if Vert then
  begin
    Cool := (pk.y <= p1.y) and (pk.y <= p2.y);
  end else
  begin
    Cool := (pk.y >= p1.y) and (pk.y >= p2.y);
  end;
end;

function Intersect(const p1, p2, p3, p4: TPoint; var ResX: Extended; const Vert: Boolean): Boolean;
var
  l1, l2: TLine;
  p, pk: TPoint;
  Tmp: Extended;
  v: TPoint;
begin
  if Eq(Vp(p2.x - p1.x, p2.y - p1.y, p4.x - p3.x, p4.y - p3.y), 0) then
  begin
    Intersect := False;
    Exit;
  end;

  l1 := ToLine(p1, p2);
  l2 := ToLine(p3, p4);

  p := LineInter(l1, l2);

  Tmp := Sp(p3.x - p.x, p3.y - p.y, p4.x - p.x, p4.y - p.y);
  if Eq(Tmp, 0) then
  begin
    v.x := p.x - p1.x;
    v.y := p.y - p1.y;
    pk.x := p.x + v.x;
    pk.y := p.y + v.y;
    if Cool(p3, p4, pk, Vert) then Intersect := False else
    begin
      Intersect := True;
      ResX := p.x;
    end;
  end else
    if Tmp < 0 then
    begin
      Intersect := True;
      ResX := p.x;
    end else
      Intersect := False;
end;

procedure Done();
begin
  Close(Input);
  Close(Output);
end;

procedure Check(const p1, p2: TPoint);
var
  i: Integer;
  MinX, Tmp: Extended;
  Already: Boolean;
begin
  Already := False;
  MinX := 0;
  for i := 1 to n - 1 do
  begin
    if Already then Break;
    if Intersect(p1, p2, Up[i], Up[i + 1], Tmp, True) then
      if (Tmp < MinX) or (not Already) then
      begin
        Already := True;
        MinX := Tmp;
      end;

    if Intersect(p1, p2, Down[i], Down[i + 1], Tmp, False) then
      if (Tmp < MinX) or (not Already) then
      begin
        Already := True;
        MinX := Tmp;
      end;
  end;

  if not Already then
  begin
    Writeln('DELO TRUBA');
    Done();
    Halt;
  end else
    if MinX > Answer then Answer := MinX;
end;

procedure Solve();
var
  p1: TPoint;
  i: Integer;
begin
  p1 := Up[1];
  while p1.y >= Up[1].y - 1 do
  begin
    for i := 1 to n do
    begin
      if not Eq(Up[i].x, p1.x) then
        Check(p1, Up[i]);

      if not Eq(Down[i].x, p1.x) then
        Check(p1, Down[i]);
    end;

    p1.y := p1.y - STEP;
  end;

  Writeln(Answer:0:2);
end;

begin
  Init();
  Solve();
  Done();
end.

