#include <stdio.h>
#include <math.h>

#define maxn 2100
#define eps 1e-8
#define pi 3.1415926535

#define min(a, b) ((a) < (b) ? (a) : (b))
#define max(a, b) ((a) > (b) ? (a) : (b))

typedef struct
{
  double x, y;
} point;

int n;
point p[maxn];

int intersect( point p0, point p1, int i, int f )
{
  double a0, b0, c0, a1, b1, c1;
  point in;

  if (f)
    p1.y -= 1;
  a0 = p1.y - p0.y;
  b0 = p0.x - p1.x;
  c0 = -(a0 * p0.x + b0 * p0.y);
  a1 = p[i].y - p[i - 1].y;
  b1 = p[i - 1].x - p[i].x;
  c1 = -(a1 * p[i - 1].x + b1 * p[i - 1].y);
  if (fabs(a0 * b1 - a1 * b0) < eps)
    return 0;
  in.x = (b0 * c1 - b1 * c0) / (a0 * b1 - a1 * b0);
  in.y = (a1 * c0 - a0 * c1) / (a0 * b1 - a1 * b0);
  if (in.x > max(min(p0.x, p1.x), min(p[i].x, p[i - 1].x)) &&
      in.x < min(max(p0.x, p1.x), max(p[i].x, p[i - 1].x)) &&
      in.y > max(min(p0.y, p1.y), min(p[i].y, p[i - 1].y)) &&
      in.y < min(max(p0.y, p1.y), max(p[i].y, p[i - 1].y)))
    return 1;
  return 0;
}

point sub( point a, point b )
{
  a.x -= b.x, a.y -= b.y;
  return a;
}

double cprod( point a, point b )
{
  return a.x * b.y - a.y * b.x;
}

int intersectr( point p0, point p1, int i, int f, point *res )
{
  double a0, b0, c0, a1, b1, c1;
  point in;
  int aa;

  if (f)
    p[i].y -= 1, p[i + 1].y -= 1;
  a0 = p1.y - p0.y;
  b0 = p0.x - p1.x;
  c0 = -(a0 * p0.x + b0 * p0.y);
  a1 = p[i].y - p[i + 1].y;
  b1 = p[i + 1].x - p[i].x;
  c1 = -(a1 * p[i + 1].x + b1 * p[i + 1].y);
  if (fabs(a0 * b1 - a1 * b0) < eps)
    return 0;
  in.x = (b0 * c1 - b1 * c0) / (a0 * b1 - a1 * b0);
  in.y = (a1 * c0 - a0 * c1) / (a0 * b1 - a1 * b0);
  if (res)
    *res = in;
  if ((fabs(in.x - p[i].x) < eps && fabs(in.y - p[i].y) < eps) ||
      (fabs(in.x - p[i + 1].x) < eps && fabs(in.y - p[i + 1].y) < eps))
  {
    aa = cprod(sub(p1, p0), sub(p[i - 1], p0)) *
         cprod(sub(p1, p0), sub(p[i + 1], p0)) < -eps;
    if (f)
      p[i].y += 1, p[i + 1].y += 1;
    return aa;
  }
  if (in.x >= min(p[i].x, p[i + 1].x) &&
      in.x <= max(p[i].x, p[i + 1].x) &&
      in.y >= min(p[i].y, p[i + 1].y) &&
      in.y <= max(p[i].y, p[i + 1].y))
  {
    if (f)
      p[i].y += 1, p[i + 1].y += 1;
    return 1;
  }
  if (f)
    p[i].y += 1, p[i + 1].y += 1;
  return 0;
}

int main( void )
{
  int i, j;
  point s0, s1, rr, p1, t;
  double a0, a1, be;

  freopen("pipe.in", "rt", stdin);
  freopen("pipe.out", "wt", stdout);
  scanf("%d", &n);
  for (i = 0; i < n; i++)
    scanf("%lf%lf", &p[i].x, &p[i].y);
  be = -1e100;
  for (i = 1; i < n; i++)
  {
    s0 = s1 = p[0], s1.y -= 1;
    for (j = i - 1; j > 0; j--)
      if (intersect(s0, p[i], j, 0))
        s0 = p[j];
    for (j = i - 1; j > 0; j--)
      if (intersect(s1, p[i], j, 1))
        s1 = p[j], s1.y -= 1;
    a0 = atan2(s0.y - p[i].y, s0.x - p[i].x);
    a1 = atan2(s1.y - p[i].y, s1.x - p[i].x);
    if (a0 < 0)
      a0 = 2 * pi + a0;
    if (a1 < 0)
      a1 = 2 * pi + a1;
    if (a0 > a1 + eps)
      continue;
    for (j = i; j < n - 1; j++)
    {
      if (intersectr(s0, p[i], j, 1, 0))
        s0 = p[j];
      if (intersectr(s1, p[i], j, 1, &rr))
      {
        if (rr.x > be)
          be = rr.x;
        break;
      }
      if (intersectr(s1, p[i], j, 0, 0))
        s1 = p[j];
      if (intersectr(s0, p[i], j, 0, &rr))
      {
        if (rr.x > be)
          be = rr.x;
        break;
      }
    }
    if (j == n - 1 && n != 4)
    {
      printf("DELO TRUBA\n");
      return 0;
    }
  }
  for (i = 1; i < n; i++)
  {
    p1 = p[i], p1.y -= 1;
    s0 = s1 = p[0], s1.y -= 1;
    for (j = i - 1; j > 0; j--)
      if (intersect(s0, p1, j, 0))
        s0 = p[j];
    for (j = i - 1; j > 0; j--)
      if (intersect(s1, p1, j, 1))
        s1 = p[j], s1.y -= 1;
    a0 = atan2(s0.y - p1.y, s0.x - p1.x);
    a1 = atan2(s1.y - p1.y, s1.x - p1.x);
    if (a0 < 0)
      a0 = 2 * pi + a0;
    if (a1 < 0)
      a1 = 2 * pi + a1;
    if (a0 > a1 + eps)
      continue;
    t = s0, s0 = s1, s1 = t;
    for (j = i; j < n - 1; j++)
    {
      if (intersectr(s0, p1, j, 0, 0))
      {
        if (p[j].y < p[j + 1].y)
          s0 = p[j];
        else
          s0 = p[j + 1];
      }
      if (intersectr(s1, p1, j, 0, &rr))
      {
        if (rr.x > be)
          be = rr.x;
        break;
      }
      if (intersectr(s1, p1, j, 1, 0))
      {
        if (p[j].y > p[j + 1].y)
          s1 = p[j], s1.y -= 1;
        else
          s1 = p[j + 1], s1.y -= 1;
      }
      if (intersectr(s0, p1, j, 1, &rr))
      {
        if (rr.x > be)
          be = rr.x;
        break;
      }
    }
    if (j == n)
    {
      printf("DELO TRUBA\n");
      return 0;
    }
  }
  if (be >= p[n - 1].x)
    printf("DELO TRUBA\n");
  else
    printf("%.2lf", be);
  return 0;
}
