#define _CRT_SECURE_NO_DEPRECATE

/* ********** */

//#define DEBUG

#define WITH_SORT
//#define BAD_BOR

//#define NCYCLEUP
//#define NCYCLEDOWN
//#define NCYCLEALT

#define MAKEGRAPH_N2
//#define MAKEGRAPH_N3
//#define MAKEGRAPH_N4

//#define DIJKSTRA
#define FORDBELLMAN

/* ********** */

#include <iostream>
#include <string>
#include <utility>
#include <algorithm>
#include <vector>
#include <math.h>
#include <cassert>

using namespace std;

#define all(v) v.begin(), v.end()
#define pb push_back
#define mp make_pair

#define VS vector<string>
#define VI vector<int>

#define next(i) (i + 1) % n
#define prev(i) (i - 1 + n) % n

#define NMAX 1000
#define LMAX 2000
#define INF int(1E+9)

#define forn(i, n) for (int i = 0; i < (int)(n); ++i)

VS words;

struct vertex
{
    int next[26];
    VI whois;
    int par;
    vertex()
    {
        memset(next, 255, sizeof(next));
        par = -1;
    }
};

vector<vertex> bor;
int len[NMAX][NMAX];
int inv[NMAX];

int g[NMAX][NMAX];
int prefix[NMAX][NMAX];

void make_bad_bor(VS &a)
{
    bor.pb(vertex());
    bor[0].par = -1;
    forn (i, a.size())
    {
        int ptr = 0;
        forn (j, a[i].length())
        {
            if (bor[ptr].next[a[i][j] - 'a'] == -1)
            {
                bor.pb(vertex());
                bor[bor.size() - 1].par = ptr;
                bor[ptr].next[a[i][j] - 'a'] = bor.size() - 1;
            }
            bor[ptr].whois.pb(i);
            ptr = bor[ptr].next[a[i][j] - 'a'];
        }
        bor[ptr].whois.pb(i);
        inv[i] = ptr;
    }
}

void calc_prefixes(VS &a)
{
    forn (i, a.size())
    {
        int h = a[i].length();
        for (int ptr = inv[i]; ptr != -1; ptr = bor[ptr].par)
        {
            forn (j, bor[ptr].whois.size())
                len[i][bor[ptr].whois[j]] = max(len[i][bor[ptr].whois[j]], h);
            --h;
        }
    }


#ifdef DEBUG
    int n = a.size();
    forn (i, n)
    {
        forn (j, n) cerr << len[i][j] << " ";
        cerr << endl;
    }

    cerr << endl << endl << endl;
#endif

}

void calc_prefixes_sort(VS &words)
{
    int n = words.size();
    vector<pair<string, int> > s(n);
    forn (i, n)
        s[i] = mp(words[i], i);
    sort(all(s));
    VI near(n);
    forn (i, n - 1)
    {
        int ptr = 0;
        while (ptr < s[i].first.length() && ptr < s[i + 1].first.length() && s[i].first[ptr] == s[i + 1].first[ptr]) ++ptr;
        near[i] = ptr;
    }
    forn (i, n)
    {
        int mn = s[i].first.length();
        int pi = s[i].second;
        for (int j = i; j < n; ++j)
        {
            int pj = s[j].second;           
            len[pi][pj] = len[pj][pi] = mn;
            if (j < n - 1)  mn = min(mn, near[j]);
        }
    }
}

void build_prefixes(VS &words)
{
    memset(len, 0, sizeof(len));
    #ifdef BAD_BOR
        make_bad_bor(words);                        
        calc_prefixes(words);       
    #endif
    #ifdef WITH_SORT
        calc_prefixes_sort(words);
    #endif
}

void make_graph(VS &a)
{
    int n = a.size();
    memset(prefix, 255, sizeof(prefix));
    forn (i, n)
        forn (j, n) 
            g[i][j] = (i == j ? 0 : INF);
    forn (i, n) 
    {
#ifndef NCYCLEDOWN
        g[i][next(i)] = 1;
#endif
#ifndef NCYCLEUP
        g[i][prev(i)] = 1;
#endif
    }
    forn (j, n)
    {
        int i = j;
        int mx = -INF;
#ifndef NCYCLEALT
        forn (t, n)
#endif
#ifdef NCYCLEALT
        forn (t, j)
#endif      
        {
            i = prev(i);
            mx = max(mx, len[i][j]);
            if (mx < (int)words[j].length()) 
                if (g[i][j] > mx + 2)
                {
                    g[i][j] = mx + 2;
                    prefix[i][j] = mx + 1;
                }
        }
    }

#ifdef DEBUG
    forn (i, n)
    {
        forn (j, n) cerr << g[i][j] << " ";
        cerr << endl;
    }
#endif

}

int dist[NMAX];
int par[NMAX];

void outway(int s, int t, int n, VS &words)
{
    printf("%d\n", dist[t]);
    VS cmd;
    for (int v = t; v != s; v = par[v])
    {
        int a = par[v];
        int b = v;
        if (next(a) == b)
            cmd.pb("down");
        else
        if (prev(a) == b)
            cmd.pb("up");
        else
        {
            for (int i = prefix[a][b] - 1; i >= 0; --i)
                cmd.pb(string(1, words[b][i]));
            cmd.pb("Alt");
        }
    }
    reverse(all(cmd));
    forn (i, cmd.size()) printf("%s\n", cmd[i].c_str());
}

void dijkstra(int s, int t, int n, VS &a)
{
    forn (i, n) dist[i] = INF;
    bool used[NMAX];
    memset(used, false, sizeof(used));
    forn (i, n) dist[i] = INF;
    memset(par, 255, sizeof(par));
    dist[s] = 0;
    while (!used[t])
    {
        int mn = INF;
        int v = -1;
        forn (i, n)
            if (!used[i] && dist[i] < mn)
                mn = dist[i], v = i;
        if (v == -1) break;
        used[v] = true;
        forn (i, n)
            if (dist[i] > dist[v] + g[v][i]) 
            {
                dist[i] = dist[v] + g[v][i];
                par[i] = v;
            }
    }
    outway(s, t, n, a);
}

VI ra, rb;

void ford_bellman(int s, int t, int n, VS &a)
{
    forn (i, n)
        forn (j, n)
            if (g[i][j] < INF)
            {
                ra.pb(i);
                rb.pb(j);
            }
    forn (i, n) dist[i] = INF;
    memset(par, 255, sizeof(par));
    dist[s] = 0;
    bool updated = true;
    while (updated)
    {
        updated = false;
        forn (i, ra.size())
            if (dist[rb[i]] > dist[ra[i]] + g[ra[i]][rb[i]])
            {
                dist[rb[i]] = dist[ra[i]] + g[ra[i]][rb[i]];
                par[rb[i]] = ra[i];
                updated = true;
            }
    }
    outway(s, t, n, a);
}

void search_way(int s, int t, int n, VS &a)
{
    #ifdef DIJKSTRA
        dijkstra(s, t, n, a);
    #endif
    #ifdef FORDBELLMAN
        ford_bellman(s, t, n, a);
    #endif
}

void read_data()
{
    int n;
    assert(scanf("%d", &n) == 1);
    words.resize(n);
    string tmp;
    getline(cin, tmp);
    char buf[LMAX];
    forn (i, n)
    {
        scanf("%s", buf);       
        getline(cin, tmp);
        words[i] = buf;
    }
}

int lcp(string &a, string &b)
{
    int ptr = 0;
    while (ptr < a.length() && ptr < b.length() && a[ptr] == b[ptr]) ++ptr;
    return ptr;
}

void make_graph_N4(VS &words)
{
    int n = words.size();
    forn (i, n)
        forn (j, n) 
            g[i][j] = (i == j ? 0 : INF);
    forn (i, n) 
    {
#ifndef NCYCLEDOWN
        g[i][next(i)] = 1;
#endif
#ifndef NCYCLEUP
        g[i][prev(i)] = 1;
#endif
    }

    forn (i, n)
        for (int j = next(i); j != i; j = next(j))
        {
            int mx = -INF;
            for (int t = i; t != j; t = next(t))
                mx = max(mx, lcp(words[t], words[j]));
            if (mx < (int)words[j].length()) 
                if (g[i][j] > mx + 2)
                {
                    g[i][j] = mx + 2;
                    prefix[i][j] = mx + 1;
                }
        }
}

void make_graph_N3(VS &words)
{
    int n = words.size();

    forn (i, n)
        forn (j, n) len[i][j] = lcp(words[i], words[j]);

    forn (i, n)
        forn (j, n) 
            g[i][j] = (i == j ? 0 : INF);
    forn (i, n) 
    {
#ifndef NCYCLEDOWN
        g[i][next(i)] = 1;
#endif
#ifndef NCYCLEUP
        g[i][prev(i)] = 1;
#endif
    }

    forn (i, n)
        for (int j = next(i); j != i; j = next(j))
        {
            int mx = -INF;
            for (int t = i; t != j; t = next(t))
                mx = max(mx, len[t][j]);
            if (mx < (int)words[j].length()) 
                if (g[i][j] > mx + 2)
                {
                    g[i][j] = mx + 2;
                    prefix[i][j] = mx + 1;
                }
        }
}


void solve()
{
#ifdef MAKEGRAPH_N2
    build_prefixes(words);
    make_graph(words);
#endif
#ifdef MAKEGRAPH_N3
    make_graph_N3(words);
#endif
#ifdef MAKEGRAPH_N4
    make_graph_N4(words);
#endif
    int k;
    scanf("%d", &k);
    int s, t;
    s = 1;
    forn (i, k) 
    {
        scanf("%d", &t);
        search_way(s - 1, t - 1, words.size(), words);
        s = t;
    }
}

int main()
{
    freopen("fur.in", "rt", stdin);
    freopen("fur.out", "wt", stdout);
    read_data();
    solve();
    return 0;
}