#include <stdio.h>
#include <memory.h>
#include <string.h>

#define MAX_FILE_COUNT  1024
#define MAX_FILE_LEN    2048
#define MAXCOMMAND      60000

#define FALSE           0
#define TRUE            1

typedef struct
{
  char cmd;
  char ch;
  long parent;
  long index;
  int alt;
  int alt_len;
  long cmd_len;
  char curname[MAX_FILE_LEN];
} cmd_entry_t;

char files[MAX_FILE_COUNT][MAX_FILE_LEN];
long file_count;
long index;
cmd_entry_t queue[MAXCOMMAND];
long uk, last;

void read_file_name (long uk)
{
  char token;
  long len;
  token=getchar ();
  while (token<=32 || token >=127) token=getchar ();
  len=0;
  while (token>32 && token <127)
    {
      files[uk][len++]=token;
      token=getchar ();
    }
  files[uk][len]=0;
}

void add_up (long parent)
{
  long nindex=queue[parent].index-1;
  if (nindex<0) nindex=file_count-1;
  if (queue[parent].cmd=='D') return;
  queue[last].cmd='U';
  queue[last].index=nindex;
  queue[last].parent=parent;
  queue[last].alt=FALSE;
  queue[last].alt_len=0;
  queue[last].cmd_len=queue[parent].cmd_len+1;
  last++;
}

void add_down (long parent)
{
  long nindex=queue[parent].index+1;
  if (nindex>=file_count) nindex=0;
  if (queue[parent].cmd=='U') return;
  queue[last].cmd='D';
  queue[last].index=nindex;
  queue[last].parent=parent;
  queue[last].alt=FALSE;
  queue[last].alt_len=0;
  queue[last].cmd_len=queue[parent].cmd_len+1;
  last++;
}

void add_alt (long parent)
{
  queue[last].cmd='A';
  queue[last].index=index;
  queue[last].parent=parent;
  queue[last].alt=TRUE;
  queue[last].alt_len=0;
  queue[last].cmd_len=queue[parent].cmd_len+1;
  last++;
}

long get_alt_file (long cur, char name[MAX_FILE_LEN], long len)
{
  long i, uk;
  uk=cur;
  for (i=0; i<file_count; i++)
    {
      if (!strncmp (files[uk], name, len)) return uk;
      uk++;
      if (uk>=file_count) uk=0;
    }
  return -1;
}

void add_alt_letter (long parent, long count)
{
  long i, len, nindex;
  char file[MAX_FILE_LEN];
  len=queue[parent].alt_len;
  strncpy (file, queue[parent].curname, len);
  for (i=0; i<file_count; i++)
    {
      file[len]=files[i][len];
      nindex=get_alt_file (queue[parent].index, file, len+1);
      if (nindex>=0)
        {
          queue[last].alt=TRUE;
          queue[last].alt_len=len+1;
          queue[last].ch=files[i][len];
          queue[last].cmd=' ';
          memcpy (queue[last].curname, file, sizeof (file));
          queue[last].index=nindex;
          queue[last].parent=parent;
          queue[last].cmd_len=queue[parent].cmd_len+1;
          last++;
        }
    }
}

void print (long uk)
{
  if (uk==0) return;
  print (queue[uk].parent);
  if (queue[uk].alt)
    {
      if (queue[uk].cmd=='A') printf ("Alt\n"); else
        printf ("%c\n", queue[uk].ch);
    } else
    {
      if (queue[uk].cmd=='U') printf ("Up\n");
      if (queue[uk].cmd=='D') printf ("Down\n");
      if (queue[uk].cmd=='A') printf ("Alt\n");
    }
}

void find_optimal_cmd (long dest)
{
  cmd_entry_t cur;
  uk=0; last=0;
  if (dest==index)
  {
    printf ("0\n");
    return;
  }
  queue[last].cmd=' ';
  queue[last].index=index;
  queue[last].parent=-1;
  queue[last].cmd_len=0;
  last++;
  add_up (0);
  add_down (0);
  add_alt (0);

  while (uk<last)
    {
      cur=queue[uk];
      if (cur.index==dest && uk!=0)
        {
          printf ("%ld\n", cur.cmd_len);
          print (uk);
          return;
        }
      if (!cur.alt)
        add_alt (uk); else
        {
          add_alt_letter (uk, cur.alt_len+1);
        }
      add_up (uk);
      add_down (uk);
      uk++;
    }

}

int main (int argc, char **argv)
{
  long i, n, dest;
  freopen ("fur.in", "r", stdin);
  freopen ("fur.out", "w", stdout);

  // Read data from disk
  scanf ("%ld", &file_count);
  for (i=0; i<file_count; i++)
    read_file_name (i);

  scanf ("%ld", &n);
  index=0;
  for (i=0; i<n; i++)
    {
      scanf ("%ld", &dest);
      dest--;
      find_optimal_cmd (dest);
      index=dest;
    }

  return 0;
}
