#include <iostream>
#include <cstring>
#include <algorithm>

#define inf 1000000
#define INF KEY(inf)

using namespace std;

char s[1010][2010];

struct KEY{
	int x;
	bool friend operator<(KEY x, KEY y){
		return y.x==inf||(x.x!=inf&&strcmp(s[x.x], s[y.x])==-1);
	}
	bool friend operator==(KEY x, KEY y){
		return x.x==y.x;
	}
	KEY(int X){x=X;}
	KEY(){x=inf;}
};

struct tree;

tree* nul;

struct tree{
	KEY k;
	tree *l, *r, *p;
	tree(){l=r=p=nul;}
	tree(tree* L, tree* R, tree* P, KEY key){l=L;r=R;p=P;k=key;}
	void destroy(){
		if (this==nul) return;
		l->destroy();
		r->destroy();
		delete this;
	}
};

void rot(tree* &T, tree* x){
	tree* y=x->p;
	x->p=y->p;
	y->p=x;
	if (x->p==nul) T=x;
	else if (y==x->p->l) x->p->l=x; else x->p->r=x;
	if (x==y->l){
		y->l=x->r;
		if (y->l!=nul) y->l->p=y;
		x->r=y;
	} else {
		y->r=x->l;
		if (y->r!=nul) y->r->p=y;
		x->l=y;
	}
}

void splay(tree* &T, tree* x){
	while (x->p!=nul){
		if (x->p->p==nul) rot(T, x);
		else if ((x==x->p->l&&x->p==x->p->p->l)||(x==x->p->r&&x->p==x->p->p->r)) {rot(T, x->p); rot(T, x);}
		else {rot(T, x); rot(T, x);}
	}
}

tree* access(tree* &T, KEY key){
	tree *x=T, *y=nul;
	while (x!=nul){
		y=x;
		if (x->k==key) {splay(T, x); return x;}
		if (key<x->k) x=x->l; else x=x->r;
	}
	splay(T, y);
	return nul;
}

void split(tree* T, KEY key, tree* &T1, tree* &T2){
	access(T, key);
	if (key<T->k){
		T1=T->l;
		if (T1!=nul) T1->p=nul;
		T->l=nul;
		T2=T;
	} else {
		T2=T->r;
		if (T2!=nul) T2->p=nul;
		T->r=nul;
		T1=T;
	}
}

tree* insert(tree* &T, KEY key){
	tree *T1, *T2;
	split(T, key, T1, T2);
	T=new tree(T1, T2, nul, key);
	if (T1!=nul) T1->p=T;
	if (T2!=nul) T2->p=T;
	return T;
}

void getnext(tree* &T){
	tree* x=T;
	x=x->r;
	while (x->l!=nul) x=x->l;
	splay(T, x);
}

void getprev(tree* &T){
	tree* x=T;
	x=x->l;
	while (x->r!=nul) x=x->r;
	splay(T, x);
}

tree *q;
int d[1010][1010], n, i, dist[1010], p[1010], path[1010], pathlen, k, x, y;

inline int fix(int x){
	return (n+(x%n))%n;
}

inline int common(int x, int y){
	int i;
	for (i=0; s[x][i]&&s[y][i]&&s[x][i]==s[y][i]; i++);
	return i;
}

void makegraph(){
	int i, j, lcp, t;
	for (i=0; i<n; i++){
		q->destroy();
		q=nul;
		insert(q, KEY(i));
		for (j=1; j<n-1; j++){
			lcp=-1;
			insert(q, KEY(fix(i+j)));
			if (q->l!=nul){
				getprev(q);
				t=common(fix(i+j), q->k.x);
				if (t>lcp) lcp=t;
			}
			access(q, KEY(fix(i+j)));
			if (q->r!=nul){
				getnext(q);
				t=common(fix(i+j), q->k.x);
				if (t>lcp) lcp=t;
			}
			if (lcp==-1||s[fix(i+j)][lcp]==0) d[i][fix(i+j)]=inf; else d[i][fix(i+j)]=lcp+2;
		}
	}
	for (i=0; i<n; i++)
		d[i][fix(i-1)]=d[i][fix(i+1)]=1;
}

void dijkstra(int x){
	char col[1000];
	int i, j, min;
	for (i=0; i<n; i++){
		dist[i]=inf;
		col[i]=0;
	}
	dist[x]=0;
	p[x]=-1;
	for (j=0; j<n; j++){
		min=-1;
		for (i=0; i<n; i++) if (col[i]==0&&(min==-1||dist[i]<dist[min])) min=i;
		col[min]=1;
		for (i=0; i<n; i++)
			if (dist[i]>dist[min]+d[min][i]){
				dist[i]=dist[min]+d[min][i];
				p[i]=min;
			}
	}
}

void makepath(int x){
	pathlen=0;
	while (p[x]!=-1){
		path[pathlen++]=x;
		x=p[x];
	}
	path[pathlen++]=x;
	reverse(&path[0], &path[pathlen]);
}

void printedge(int x, int y){
	int i, n;
	if (fix(x+1)==y) printf("down\n");
	else if (fix(x-1)==y) printf("up\n");
	else {
		printf("Alt\n");
		n=common(x, y)+1;
		for (i=0; i<n; i++)
			printf("%c\n", s[y][i]);
	}
}

void printpath(){
	int i;
	for (i=0; i<pathlen-1; i++){
		printedge(path[i], path[i+1]);
	}
}

int main(){
	freopen("fur.in", "rt", stdin);
	freopen("fur.out", "wt", stdout);
	nul=new tree();
	nul->l=nul->r=nul->p=nul;
	q=nul;
	scanf("%d", &n);
	char tmp[2020];
	for (i=0; i<n; i++)
		scanf("%s", s[i]);
	makegraph();
	scanf("%d", &k);
	x=0;
	for (i=0; i<k; i++){
		scanf("%d", &y);
		y--;
		dijkstra(x);
		makepath(y);
		printf("%d\n", dist[y]);
		printpath();
		x=y;
	}
	return 0;
}