#include <cstdio>
#include <vector>
#include <stack>
#include <string>
#include <iostream>
#include <algorithm>

using namespace std;

const int INF = 1 << 20;

enum MoveType
{
	UP = 0, 
	DOWN = 1,
	ALT = 2,
	NONE = 3
};

struct Move
{
	MoveType type;
	int keys;
	string altWord;
};

vector<string> words;
vector<vector<Move> > W;
vector<bool> visited;
vector<int> dist;
vector<int> parent;
int cnt = 0;

inline int UpDist(int i, int j)
{
	if ( j <= i )
		return i - j;
	else
		return i + words.size() - j;
}

inline int DownDist(int i, int j)
{
	if ( i <= j )
		return j - i;
	else
		return j + words.size() - i;
}

string AltDist(int first, int second)
{
	for ( int i = 1; i < words[second].length(); ++i )
	{
		string newStr = words[second].substr(0, i);
		bool flag = true;
		for ( int j = first; j != second; j = (j + 1) % words.size() )
			if ( words[j].substr(0, i).compare(newStr) == 0 )
			{
				flag = false;
				break;
			}
			if ( flag )
				return newStr;
	}
	return "";
}

inline int minInd(int *arr)
{
	int minInd = arr[0] < arr[1] ? 0 : 1;
	if ( arr[2] < arr[minInd] )
		minInd = 2;
	return minInd;
}

void computeCosts()
{
	for ( int i = 0; i < cnt; ++i )
		for ( int j = 0; j < cnt; ++j )
		{
			if ( i == j )
				W[i][j].type = NONE;
			else
			{
				int costs[3];
				costs[0] = UpDist(i, j);
				costs[1] = DownDist(i, j);
				string str = AltDist(i, j);
				costs[2] = str.length() == 0 ? INF : str.length() + 1;
				int min = minInd(costs);
				if ( min == 0 )
				{
					W[i][j].type = UP;
					W[i][j].keys = costs[0];
				}
				else if ( min == 1 )
				{
					W[i][j].type = DOWN;
					W[i][j].keys = costs[1];
				}
				else
				{
					W[i][j].type = ALT;
					W[i][j].altWord = str;
				}
			}
		}
}

void printPath(int ver)
{
	stack<Move> st;
	int S = ver;
	while ( parent[ver] != -1 )
	{
		st.push(W[parent[ver]][ver]);
		ver = parent[ver];
	}
	printf("%d\n", dist[S]);
	while ( !st.empty() )
	{
		Move m = st.top(); st.pop();
		switch ( m.type )
		{
		case UP:
			for ( int i = 0; i < m.keys; ++i )
				puts("up");
			break;
		case DOWN:
			for ( int i = 0; i < m.keys; ++i )
				puts("down");
			break;
		case ALT:
			puts("Alt");
			for ( int i = 0; i < m.altWord.length(); ++i )
				printf("%c\n", m.altWord[i]);
			break;
		}
	}
}

int getEdgeCost(int i, int j)
{
	if ( W[i][j].type == UP || W[i][j].type == DOWN )
		return W[i][j].keys;
	else if (  W[i][j].type == ALT )
		return W[i][j].altWord.length() + 1;
	else
		return 0;
}

int getMin()
{
	int mInd = -1;
	for ( int i = 0; i < cnt; ++i )
		if ( !visited[i] )
			if ( mInd == -1 || dist[i] < dist[mInd] )
				mInd = i;
	return mInd;
}

void dijkstra(int start)
{
	for ( int i = 0; i < cnt; ++i )
	{
		visited[i] = false;
		dist[i] = INF;
		parent[i] = -1;
	}
	dist[start] = 0;
	for ( int i = 0; i < cnt; ++i )
	{
		int mInd = getMin();
		for ( int j = 0; j < cnt; ++j )
		{
			int newDist = dist[mInd] + getEdgeCost(mInd, j);
			if ( newDist < dist[j] )
			{
				dist[j] = newDist;
				parent[j] = mInd;
			}
		}
	}
}

int main()
{
	freopen("fur.in", "r", stdin);
	freopen("fur.out", "w", stdout);

	string dummy;
	cin >> cnt;
	getline(cin, dummy);

	words.resize(cnt);
	visited.resize(cnt);
	W.resize(cnt);
	dist.resize(cnt);
	parent.resize(cnt);
	for ( int i = 0; i < W.size(); ++i )
		W[i].resize(cnt);

	for ( int i = 0; i < cnt; ++i )
		getline(cin, words[i]);
	//getline(cin, dummy);

	computeCosts();
	int moveCnt = 0;
	cin >> moveCnt;
	int curFile = 0, newFile = 0;
	for ( int i = 0; i < moveCnt; ++i )
	{
		cin >> newFile;
		--newFile;
		dijkstra(curFile);
		printPath(newFile);
		curFile = newFile;
	}
	return 0;
}