/**************************************/
/*   57, Moscow                       */
/**************************************/

#include <fstream>
using namespace std;

struct snode
{
   snode* parent;
   int stri, lchr;
   snode* kids [26];
   int rmqid;

   void init ()
   {
      parent = NULL;
      for ( int i = 0; i < 26; i++ )
         kids [i] = NULL;
      stri = -1;
      lchr = 0;
   }
};

char fnames [1024][2006];
int flen [1024];
snode* head [1024];
int n;

snode snodes_alloc [2057];
int last_snode_alloc = 0;
inline snode* new_snode ()
{
   snodes_alloc [last_snode_alloc].init ();
   return & ( snodes_alloc [last_snode_alloc++] );
}

snode* add_name ( snode* root, int i )
{
   if ( root == NULL )
   {
      root = new_snode ();
      root->kids [fnames [i][0]] = new_snode ();
      snode* kid = root->kids [fnames [i][0]];
      kid->parent = root;
      kid->stri = i;
      kid->lchr = flen [i];
      head [i] = kid;
      return root;
   }
   snode* last = root;
   while ( true )
   {
      if ( last->lchr >= flen [i] )
      {
         head [i] = last;
         return root;
      }
      snode* next = last->kids [fnames [i][last->lchr]];
      if ( next == NULL )
      {
         next = new_snode ();
         last->kids [fnames [i][last->lchr]] = next;
         next->parent = last;
         next->stri = i;
         next->lchr = flen [i];
         head [i] = next;
         return root;
      }
      for ( int j = last->lchr; j < next->lchr; j++ )
      {
         if ( fnames [i][j] != fnames [next->stri][j] )
         {
            // split
            snode* split = new_snode ();
            split->parent = last;
            last->kids [fnames [i][last->lchr]] = split;
            split->stri = next->stri;
            split->lchr = j;
            split->kids [fnames [next->stri][j]] = next;
            next->parent = split;
            if ( j == flen [i] )
            {
               head [i] = split;
               return root;
            }
            snode* ns = new_snode ();
            split->kids [fnames [i][j]] = ns;
            ns->parent = split;
            ns->stri = i;
            ns->lchr = flen [i];
            head [i] = ns;
            return root;
         }
      }
      last = next;
   }
   return root;
}
int tree_rmq [2057];
snode* tree_lnk [2057];
int rmq_size = 0;
int rmq_vals [2057][2057];
void build_rmq ( snode* node, int d )
{
   int nk = 0;
   for ( int i = 0; i < 26; i++ )
   {
      if ( node->kids [i] != NULL )
      {
         if ( nk != 0 )
         {
            node->rmqid = rmq_size;
            tree_lnk [rmq_size] = node;
            tree_rmq [rmq_size++] = d;
         }
         nk++;
         build_rmq ( node->kids [i], d+1 );
      }
   }
   if ( nk < 2 )
   {
      node->rmqid = rmq_size;
      tree_lnk [rmq_size] = node;
      tree_rmq [rmq_size++] = d;
   }
}
void make_rmq ( snode* root )
{
   build_rmq ( root, 0 );
   for ( int i = 0; i < rmq_size; i++ )
   {
      rmq_vals [i][i] = i;
      for ( int j = i+1; j < rmq_size; j++ )
      {
         if ( tree_rmq [j] < tree_rmq [rmq_vals [i][j-1]] )
            rmq_vals [i][j] = j;
         else
            rmq_vals [i][j] = rmq_vals [i][j-1];
      }
   }
}

int max_match ( int i, int j )
{
   snode* inode = head [i];
   snode* jnode = head [j];
   int irmq = inode->rmqid;
   int jrmq = jnode->rmqid;
   int mrmq;
   if ( irmq < jrmq )
      mrmq = rmq_vals [irmq][jrmq];
   else
      mrmq = rmq_vals [jrmq][irmq];
   return tree_lnk [mrmq]->lchr;
}

int mprint [1024][1024];
void fill_mprint ()
{
   for ( int i = 0; i < n; i++ )
   {
      int lj = i;
      mprint [i][i] = 0;
      for ( int j = i-1; j != i; j-- )
      {
         if ( j < 0 )
            j += n;
         if ( i == j )
            break;
         int mm = max_match ( i, j ) + 1;
         if ( mprint [lj][i] < mm )
            mprint [j][i] = mm;
         else
            mprint [j][i] = mprint [lj][i];
         lj = j;
      }
   }
}

int udlen ( int i, int j )
{
   if ( j < i )
   {
      int k = i - j;
      if ( n - k < k )
         return n - k;
      else
         return k;
   }
   else
   {
      int k = j - i;
      if ( n - k < k )
         return n - k;
      else
         return k;
   }
}
inline int altlen ( int i, int j )
{
   return 1 + mprint [i][j];
}

int dmat [1024][1024];
void build_graph ()
{
   for ( int i = 0; i < n; i++ )
   {
      for ( int j = 0; j < n; j++ )
      {
         if ( j != i )
         {
            int sway = udlen ( i, j );
            int away = altlen ( i, j );
            int mway = ( sway < away ? sway : away );
            dmat [i][j] = mway;
         }
      }
   }
}

bool visited [1024];
int from [1024];

#define INF    1000000000
class pqueue
{
   int elems [2057];
   int tnmo;
   int rn;
public:

   void init ()
   {
      rn = 2;
      while ( rn < n )
         rn *= 2;
      tnmo = rn * 2 - 1;
      for ( int i = 0; i < rn-1; i++ )
         elems [i] = 0;
      for ( int i = 0; i < rn; i++ )
         elems [i+rn-1] = INF;
   }
   int get_el ( int i )
   {
      return elems [i+rn-1];
   }
   void set_el ( int i, int v );
   int get_min ()
   {
      return elems [0];
   }
} queue;

void pqueue::set_el ( int i, int v )
{
   elems [i+rn-1] = v;
   int last = i+rn-1;
   while ( last > 0 )
   {
      int j = ( last-1 ) >> 1;
      int k;
      if ( last & 1 )
         k = last + 1;
      else
         k = last - 1;
      if ( last >= rn-1 )
      {
         if ( elems [last] > elems [k] )
            elems [j] = k - rn + 1;
         else
            elems [j] = last - rn + 1;
      }
      else
      {
         if ( elems [elems [last]+rn-1] > elems [elems [k]+rn-1] )
            elems [j] = elems [k];
         else
            elems [j] = elems [last];
      }
      last = j;
   }
}

int dijkstra ( int a, int b )
{
   for ( int i = 0; i < n; i++ )
   {
      visited [i] = false;
      from [i] = -1;
   }
   //visited [a] = true;
   queue.init ();
   queue.set_el ( a, 0 );
   int valb = INF;
   int nvis = 0;
   
   while ( nvis < n )
   {
      int i = queue.get_min ();
      visited [i] = true;
      if ( i == b )
         return queue.get_el ( b );
      int dist = queue.get_el ( i );
      queue.set_el ( i, INF );
      for ( int j = 0; j < n; j++ )
      {
         if ( !visited [j] && queue.get_el ( j ) > dist + dmat [i][j] )
         {
            queue.set_el ( j, dist + dmat [i][j] );
            from [j] = i;
         }
      }
   }
   return queue.get_el ( b );
}

enum { cmdUp, cmdDown, cmdAlt };
struct command
{
   int type;
   int si, sn;
};
command cmds [1024];
int ncmds;

int main ()
{
   ifstream fin ( "fur.in" );
   ofstream fout ( "fur.out" );

   snode* troot = NULL;

   // input ///////
   fin >> n;
   for ( int i = 0; i < n; i++ )
   {
      fin >> fnames [i];
      flen [i] = (int) strlen ( fnames [i] );
      for ( int j = 0; j <= flen [i]; j++ )
         fnames [i][j] -= 'a';
      troot = add_name ( troot, i );
   }
   make_rmq ( troot );
   fill_mprint ();
   build_graph ();
   ////////////////

   int k;
   fin >> k;

   int last = 0;
   for ( int i = 0; i < k; i++ )
   {
      int next;
      fin >> next;
      next--;
      // output //
      fout << dijkstra ( last, next ) << endl;
      ncmds = 0;
      int cur = next;
      while ( cur != last )
      {
         int pr = from [cur];
         int len = dmat [pr][cur];
         int lenm = mprint [pr][cur];
         if ( len == lenm + 1 )
         {
            cmds [ncmds].type = cmdAlt;
            cmds [ncmds].si = cur;
            cmds [ncmds++].sn = lenm;
         }
         else
         {
            if ( pr < cur )
            {
               int k = cur - pr;
               if ( n - k > k )
               {
                  cmds [ncmds].type = cmdDown;
                  cmds [ncmds++].sn = k;
               }
               else
               {
                  cmds [ncmds].type = cmdUp;
                  cmds [ncmds++].sn = n - k;
               }
            }
            else
            {
               int k = pr - cur;
               if ( n - k > k )
               {
                  cmds [ncmds].type = cmdUp;
                  cmds [ncmds++].sn = k;
               }
               else
               {
                  cmds [ncmds].type = cmdDown;
                  cmds [ncmds++].sn = n - k;
               }
            }
         }
         cur = pr;
      }
      for ( int a = ncmds-1; a >= 0; a-- )
      {
         switch ( cmds [a].type )
         {
         case cmdUp:
            for ( int b = 0; b < cmds [a].sn; b++ )
               fout << "up\n";
            break;
         case cmdDown:
            for ( int b = 0; b < cmds [a].sn; b++ )
               fout << "down\n";
            break;
         case cmdAlt:
            fout << "Alt\n";
            for ( int b = 0; b < cmds [a].sn; b++ )
               fout << (char) ( fnames [cmds [a].si][b] + 'a' ) << "\n";
            break;
         }
      }
      ////////////
      last = next;
   }
   
   return 0;
}