import java.util.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;

/**
 * Fast solution of the problem "Buses"
 *
 * @author Pavel Mavrin
 */
public class buses_pma_fast {

    private static final int DAY_LENGTH = 24 * 60;
    private static final int DAY_NUMBER = 2;

    public static void main(String[] args) throws FileNotFoundException {
        Scanner scanner = new Scanner(new File("buses.in"));
        PrintWriter writer = new PrintWriter("buses.out");

        int m = scanner.nextInt();
        int n = scanner.nextInt();

        Route[] routes = new Route[n];
        for (int i = 0; i < n; i++) {
            routes[i] = new Route(
                    scanner.nextInt(),
                    parseTime(scanner.next()),
                    scanner.nextInt(),
                    parseTime(scanner.next())
            );
        }

        List<Bus> buses = new ArrayList<Bus>();
        boolean inf = false;

        Map<Integer, Set<Bus>> arrivials = new HashMap<Integer, Set<Bus>>();
        Map<Integer, Set<Bus>> positions = new HashMap<Integer, Set<Bus>>();
        Map<Integer, Set<Route>> routeStarts = new HashMap<Integer, Set<Route>>();
        for (Route route : routes) {
            add(routeStarts, route.departureTime, route);
        }

        for (int dayNumber = 0; dayNumber <= DAY_NUMBER; dayNumber++) {
            for (int time = 0; time < DAY_LENGTH; time++) {

                Set<Bus> arrive = getAll(arrivials, time);
                for (Bus bus : arrive) {
                    bus.state = Bus.STATE_WAITING;
                    add(positions, bus.route.destination, bus);
                }
                if (arrive.size() > 0) {
                    arrivials.remove(time);
                }

                Set<Route> start = getAll(routeStarts, time);
                for (Route route : start) {
                    Set<Bus> here = getAll(positions, route.source);
                    Bus bus;
                    if (here.size() > 0) {
                        bus = here.iterator().next();
                        here.remove(bus);
                    } else {
                        bus = new Bus();
                        buses.add(bus);
                        if (dayNumber == DAY_NUMBER) {
                            inf = true;
                        }
                    }
                    bus.state = Bus.STATE_MOVING;
                    bus.route = route;
                    add(arrivials, route.arrivialTime, bus);
                }
            }
        }
        if (inf) {
            writer.println(-1);
        } else {
            writer.println(buses.size());
        }
        writer.close();
    }

    private static <K, V> Set<V> getAll(Map<K, Set<V>> map, K key) {
        Set<V> result = map.get(key);
        return result != null ? result : Collections.EMPTY_SET;
    }

    private static <K, V> void add(Map<K, Set<V>> map, K key, V value) {
        Set<V> set = map.get(key);
        if (set == null) {
            set = new HashSet<V>();
            map.put(key, set);
        }
        set.add(value);
    }

    private static int parseTime(String s) {
        int h = Integer.parseInt(s.substring(0, 2));
        int m = Integer.parseInt(s.substring(3, 5));
        return h * 60 + m;
    }

    /**
     * Represents a route for a bus.
     */
    private static final class Route {
        protected final int source;
        protected final int departureTime;
        protected final int destination;
        protected final int arrivialTime;

        public Route(int source, int departureTime, int destination, int arrivialTime) {
            this.source = source;
            this.departureTime = departureTime;
            this.destination = destination;
            this.arrivialTime = arrivialTime;
        }
    }

    /**
     * Represents a bus.
     */
    private static final class Bus {
        protected static final int STATE_MOVING = 0;
        protected static final int STATE_WAITING = 1;

        protected int state;
        protected Route route;
    }
}
