import java.util.Scanner;
import java.util.List;
import java.util.ArrayList;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;

/**
 * Slow solution of the problem "Buses"
 *
 * @author Pavel Mavrin
 */
public class buses_pma_slow {

    private static final int DAY_LENGTH = 24 * 60;
    private static final int DAY_NUMBER = 2;

    public static void main(String[] args) throws FileNotFoundException {
        Scanner scanner = new Scanner(new File("buses.in"));
        PrintWriter writer = new PrintWriter("buses.out");

        int m = scanner.nextInt();
        int n = scanner.nextInt();

        Route[] routes = new Route[n];
        for (int i = 0; i < n; i++) {
            routes[i] = new Route(
                    scanner.nextInt(),
                    parseTime(scanner.next()),
                    scanner.nextInt(),
                    parseTime(scanner.next())
            );
        }
        for (int i = 0; i < n; i++) {
            if (routes[i].departureTime == routes[i].arrivialTime) {
                System.out.println(i);
                System.exit(1);
            }
        }        

        List<Bus> buses = new ArrayList<Bus>();
        boolean inf = false;
        for (int dayNumber = 0; dayNumber <= DAY_NUMBER; dayNumber++) {
            for (int time = 0; time < DAY_LENGTH; time++) {

                for (Bus bus : buses) {
                    if (bus.state == Bus.STATE_MOVING && bus.route.arrivialTime == time) {
                        bus.state = Bus.STATE_WAITING;
                    }
                }

                for (Route route : routes) {
                    if (route.departureTime == time) {

                        Bus bus = null;
                        for (Bus b : buses) {
                            if (b.state == Bus.STATE_WAITING && b.route.destination == route.source) {
                                bus = b;
                                break;
                            }
                        }
                        if (bus == null) {
                            bus = new Bus();
                            buses.add(bus);
                            if (dayNumber == DAY_NUMBER) {
                                inf = true;
                            }
                        }
                        bus.state = Bus.STATE_MOVING;
                        bus.route = route;
                    }
                }
            }
        }
        if (inf) {
            writer.println(-1);
        } else {
            writer.println(buses.size());
        }
        writer.close();
    }

    private static int parseTime(String s) {
        int h = Integer.parseInt(s.substring(0, 2));
        int m = Integer.parseInt(s.substring(3, 5));
        return h * 60 + m;
    }

    /**
     * Represents a route for a bus.
     */
    private static final class Route {
        protected final int source;
        protected final int departureTime;
        protected final int destination;
        protected final int arrivialTime;

        public Route(int source, int departureTime, int destination, int arrivialTime) {
            this.source = source;
            this.departureTime = departureTime;
            this.destination = destination;
            this.arrivialTime = arrivialTime;
        }
    }

    /**
     * Represents a bus.
     */
    private static final class Bus {
        protected static final int STATE_MOVING = 0;
        protected static final int STATE_WAITING = 1;

        protected int state;
        protected Route route;
    }
}
