#include <stdio.h>
#include <vector>
#pragma warning (disable: 4018 4267)

//#define DEBUG
using namespace std;

class Time;
class Route;
class City;

vector<City> cities;

class Time
{
public:
	int h;
	int m;

	operator int ()
	{
		return h*60+m;
	}

	friend Time operator + (Time t1, Time t2)
	{
		return Time((int)t1+(int)t2);
	}

	friend Time operator - (Time t1, Time t2)
	{
		return Time((int)t1-(int)t2);
	}

	static Time Duration(Time t1, Time t2)
	{
		if (t1 > t2)
			t2 = t2+Time(24, 0);

		return t2-t1;
	}

	void Print()
	{
		printf("%02d:%02d", h, m);
	}

	Time()
	{
		h = 0; 
		m = 0;
	}

	Time(int t)
	{
		h = t/60;
		m = t%60;
	}

	Time(int h, int m)
	{
		this->h = h;
		this->m = m;
	}
};

class Route
{
public:
	//   

	Time duration;
	int id;
	int n1, n2;
	Time t1, t2;

	friend bool operator == (Route r1, Route r2)
	{
		return (r1.id == r2.id);
	}

	friend Route operator+(Route r1, Route r2)
	{
		Route r(r1.n1, r1.t1, r2.n2, r2.t2);

		r.duration = r1.duration+r2.duration+Time::Duration(r1.t2, r2.t1);

		return r;
	}

	void Print()
	{
		printf("%d -> %d ", n1+1, n2+1);
		t1.Print();
		printf(" ");
		t2.Print();
		printf(" ");
		duration.Print();
		printf("\n");
	}

	Route(int n1, Time t1, int n2, Time t2)
	{
		duration = Time::Duration(t1, t2);
		this->n1 = n1;
		this->n2 = n2;
		this->t1 = t1;
		this->t2 = t2;
		id = -1;
	}
};

class City
{
public:
	vector<Route> r1;
	vector<Route> r2;

	bool IsReady()
	{
		int ans = 0;

		for (int i = 0; i < r1.size(); i++)
			if (r1[i].n1 != r1[i].n2)
				ans++;

		for (int i = 0; i < r2.size(); i++)
			if (r2[i].n1 != r2[i].n2)
				ans++;

		ans = (r1.size()+r2.size()+ans)/2;

		if (ans <= 1)
			return true;
		else
			return false;
	}
};

void AddRoute(Route r)
{
	static int id = 0;
	r.id = id;
	id++;

	City &c1 = cities[r.n1];
	City &c2 = cities[r.n2];

	c1.r2.push_back(r);
	c2.r1.push_back(r);
}

void Remove(Route r, vector<Route> &arr)
{
	for (int i = 0; i < arr.size(); i++)
		if (arr[i] == r)
		{
			arr.erase(arr.begin()+i);
				break;
		}
}

void RemoveRoute(Route &r)
{
	City &c1 = cities[r.n1];
	City &c2 = cities[r.n2];

	Remove(r, c1.r2);
	Remove(r, c2.r1);

	r.id = -1;
}

void GetRoutes1(City &c, int &i1, int &i2)
{
	i1 = rand()%c.r1.size();
	i2 = rand()%c.r2.size();
}

void GetRoutes2(City &c, int &j1, int &j2)
{
	bool init = false;

	for (int i1 = 0; i1 < c.r1.size(); i1++)
		for (int i2 = 0; i2 < c.r2.size(); i2++)
		{
			Route &ri1 = c.r1[i1];
			Route &ri2 = c.r2[i2];

			if (ri1 == ri2)
				continue;

			if (!init)
			{
				j1 = i1;
				j2 = i2;
				init = true;
			}

			Route &rj1 = c.r1[j1];
			Route &rj2 = c.r2[j2];

			if (Time::Duration(ri1.t2, ri2.t1) < Time::Duration(rj1.t2, rj2.t1))
			{
				j1 = i1;
				j2 = i2;
			}
		}
}

int Solve1()
{
	for (int i = 0; i < cities.size(); i++)
	{
		City &c = cities[i];
		if (c.r1.size() != c.r2.size())
			return -1;
	}

	int res = 0;

	for (int i = 0; i < cities.size(); i++)
	{
		City &c = cities[i];

		while (!c.IsReady())
		{
			int i1, i2;
			GetRoutes1(c, i1, i2);

			Route r1 = c.r1[i1];
			Route r2 = c.r2[i2];
			Route r = r1+r2;

#ifdef DEBUG
			r1.Print();
			r2.Print();
			r.Print();
			printf("=========\n");
#endif
			RemoveRoute(r1);
			RemoveRoute(r2);

			AddRoute(r);
		}

		if (c.r1.size() == 0)
			continue;

		Route &r = c.r1[0];
		res += r.duration/Time(24, 0)+1;

#ifdef DEBUG
		r.Print();
#endif
	}
	return res;
}

Route ReadRoute()
{
	int n1, h1, m1;
	int n2, h2, m2;

	scanf("%d%d:%d", &n1, &h1, &m1);
	scanf("%d%d:%d", &n2, &h2, &m2);

	Time t1 = Time(h1, m1);
	Time t2 = Time(h2, m2);

	return Route(n1-1, t1, n2-1, t2);
}

void ReadData()
{
	int n, m;
	scanf("%d%d", &n, &m);

	for (int i = 0; i < n; i++)
		cities.push_back(City());

	for (int i = 0; i < m; i++)
	{
		Route r = ReadRoute();
		AddRoute(r);
	}
}

void main()
{
	freopen("buses.in", "r", stdin);
#ifndef DEBUG
	freopen("buses.out", "w", stdout);
#endif

	ReadData();
	int ans = Solve1();
	printf("%d\n", ans);
}