import java.io.*;
import java.util.*;

public class poly_md_int implements Runnable {
	class Point {
		int x, y;
		
		public Point(int x, int y) {
			this.x = x;
			this.y = y;
		}
		
		@Override
		public int hashCode() {
			return x << 16 | y;
		}
		
		@Override
		public boolean equals(Object obj) {
			if (obj instanceof Point) {
				Point that = (Point) obj;
				return x == that.x && y == that.y;
			}
			return false;
		}
		
		@Override
		public String toString() {
			return x + " " + y;
		}
		
		public Point shift(int dx, int dy) {
			return new Point(x + dx, y + dy);
		}
		
		public Point shift(Point d) {
			return new Point(x + d.x, y + d.y);
		}
	}
	
	class Polymino {
		int hei, wid, size;
		HashSet<Point> cells;
		
		public Polymino(Scanner in) {
			hei = in.nextInt();
			wid = in.nextInt();
			in.nextLine();
			cells = new HashSet<Point>();
			for (int i = 0; i < hei; i++) {
				String s = in.nextLine();
				for (int j = 0; j < wid; j++) {
					if (s.charAt(j) == 'X') {
						cells.add(new Point(i, j));
					}
				}
			}
			size = cells.size();
		}
		
		public Polymino(HashSet<Point> cells, int h, int w) {
			hei = h;
			wid = w;
			this.cells = cells;
			size = cells.size();
		}
		
		public Polymino(int[] x, int[] y) {
			size = x.length;
			cells = new HashSet<Point>();
			hei = wid = 0;
			for (int i = 0; i < size; i++) {
				cells.add(new Point(x[i], y[i]));
				hei = Math.max(hei, x[i]);
				wid = Math.max(wid, y[i]);
			}
			hei++;
			wid++;
		}
		
		@Override
		public String toString() {
			char[][] c = new char[hei][wid];
			for (int i = 0; i < hei; i++)
				for (int j = 0; j < wid; j++)
					c[i][j] = '.';
			for (Point p : cells) {
				c[p.x][p.y] = 'X';
			}
			StringBuilder sb = new StringBuilder(hei * (wid + 1));
			for (int i = 0; i < hei; i++) {
				sb.append(c[i]).append("\n");
			}
			return sb.toString();
		}
		
		public Polymino turnClockwise() {
			HashSet<Point> rc = new HashSet<Point>();
			for (Point p : cells) {
				rc.add(new Point(p.y, hei - 1 - p.x));
			}
			return new Polymino(rc, wid, hei);
		}

		public Polymino turnCounterclockwise() {
			HashSet<Point> rc = new HashSet<Point>();
			for (Point p : cells) {
				rc.add(new Point(wid - 1 - p.y, p.x));
			}
			return new Polymino(rc, wid, hei);
		}

		public int countEntries(Polymino that) {
			Point thatPoint = that.cells.iterator().next();
			int entries = 0;
			mainloop:
			for (Point fromp : cells) {
				Point shift = fromp.shift(-thatPoint.x, -thatPoint.y);
				for (Point p : that.cells) {
					if (!cells.contains(p.shift(shift))) {
						continue mainloop;
					}
				}
				entries++;
			}
			return entries;
		}
		
		public int containedInRectangle(int h, int w) {
			if (h < hei || w < wid)
				return 0;
			return (h - hei + 1) * (w - wid + 1);
		}

		public int containedInL() {
			boolean[][] a = new boolean[hei + 1][wid + 1];
			for (Point p : cells) {
				a[p.x][p.y] = true;
			}
			int count = 0;
			for (int i = hei - 1; i >= 0; i--)
				for (int j = wid - 1; j >= 0; j--)
					if (a[i][j] | a[i + 1][j] | a[i][j + 1])
						a[i][j] = true;
					else
						count++;
			return count;
		}
	}
	
	Polymino poly1x1 = new Polymino(new int[]{0}, new int[]{0});
	Polymino poly2x1 = new Polymino(new int[]{0, 1}, new int[]{0, 0});
	Polymino poly1x2 = new Polymino(new int[]{0, 0}, new int[]{0, 1});
	Polymino polyL = new Polymino(new int[]{0, 0, 1}, new int[]{0, 1, 0});
	Polymino poly2x2 = new Polymino(new int[]{0, 0, 1, 1}, new int[]{0, 1, 0, 1});
	
	private Scanner in;
	private PrintWriter out;

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	int k;
	Polymino from, poly;

	private void solve() throws IOException {
		in = new Scanner(new File("poly.in"));
		out = new PrintWriter(new File("poly.out"));
		k = in.nextInt();
		poly = new Polymino(in);
		from = new Polymino(in);
		if (k <= poly.size)			
			solveSmallK();
		else
			solveBigK();
		in.close();
		out.close();
	}

	private void solveSmallK() {
		int answer = 0;
		for (int dx = 0; dx < k; dx++) {
			for (int dy = 0; dy < k; dy++) {
				answer += checkShift(dx, dy);
			}
		}
		out.println(answer);
	}

	private int checkShift(int dx, int dy) {
		HashSet<Point> temp = new HashSet<Point>();
		int xmin = Integer.MAX_VALUE;
		int xmax = Integer.MIN_VALUE;
		int ymin = Integer.MAX_VALUE;
		int ymax = Integer.MIN_VALUE;
		for (Point p : poly.cells) {
			int x = (p.x + dx) / k;
			int y = (p.y + dy) / k;
			temp.add(new Point(x, y));
			xmin = Math.min(xmin, x);
			xmax = Math.max(xmax, x);
			ymin = Math.min(ymin, y);
			ymax = Math.max(ymax, y);
		}
		HashSet<Point> compressed = new HashSet<Point>();
		for (Point p : temp) {
			compressed.add(p.shift(-xmin, -ymin));
		}
		Polymino compr = new Polymino(compressed, xmax - xmin + 1, ymax - ymin + 1);
		return from.countEntries(compr);
	}

	private void solveBigK() {
		int ans = 0;

		int in1x1 = poly.containedInRectangle(k, k);
		ans += in1x1 * from.countEntries(poly1x1);
		
		int in2x1 = poly.containedInRectangle(2 * k, k) - 2 * in1x1;
		ans += in2x1 * from.countEntries(poly2x1);
		
		int in1x2 = poly.containedInRectangle(k, 2 * k) - 2 * in1x1;
		ans += in1x2 * from.countEntries(poly1x2);
		
		int inL = 0;
		for (int angle = 0; angle < 4; angle++) {
			int inThisL = poly.containedInL();
			ans += inThisL * from.countEntries(polyL);
			inL += inThisL;
			poly = poly.turnClockwise();
			polyL = polyL.turnCounterclockwise();
		}

		int in2x2 = poly.containedInRectangle(2 * k, 2 * k) -
			inL - 2 * in2x1 - 2 * in1x2 - 4 * in1x1;
		ans += in2x2 * from.countEntries(poly2x2);
		out.println(ans);
	}

	public static void main(String[] args) {
		new poly_md_int().run();
	}
}
