import java.io.*;
import java.util.*;

public class poly_md_only_small_k implements Runnable {
	class Point {
		int x, y;
		
		public Point(int x, int y) {
			this.x = x;
			this.y = y;
		}
		
		@Override
		public int hashCode() {
			return x << 16 | y;
		}
		
		@Override
		public boolean equals(Object obj) {
			if (obj instanceof Point) {
				Point that = (Point) obj;
				return x == that.x && y == that.y;
			}
			return false;
		}
		
		@Override
		public String toString() {
			return x + " " + y;
		}
		
		public Point shift(int dx, int dy) {
			return new Point(x + dx, y + dy);
		}
		
		public Point shift(Point d) {
			return new Point(x + d.x, y + d.y);
		}
	}
	
	class Polymino {
		int hei, wid, size;
		HashSet<Point> cells;
		
		public Polymino(Scanner in) {
			hei = in.nextInt();
			wid = in.nextInt();
			in.nextLine();
			cells = new HashSet<Point>();
			for (int i = 0; i < hei; i++) {
				String s = in.nextLine();
				for (int j = 0; j < wid; j++) {
					if (s.charAt(j) == 'X') {
						cells.add(new Point(i, j));
					}
				}
			}
			size = cells.size();
		}
		
		public Polymino(HashSet<Point> cells, int h, int w) {
			hei = h;
			wid = w;
			this.cells = cells;
			size = cells.size();
		}
		
		@Override
		public String toString() {
			char[][] c = new char[hei][wid];
			for (int i = 0; i < hei; i++)
				for (int j = 0; j < wid; j++)
					c[i][j] = '.';
			for (Point p : cells) {
				c[p.x][p.y] = 'X';
			}
			StringBuilder sb = new StringBuilder(hei * (wid + 1));
			for (int i = 0; i < hei; i++) {
				sb.append(c[i]).append("\n");
			}
			return sb.toString();
		}
		
		public Polymino turn() {
			HashSet<Point> rc = new HashSet<Point>();
			for (Point p : cells) {
				rc.add(new Point(p.y, wid - p.x));
			}
			return new Polymino(rc, wid, hei);
		}

		public int countEntries(Polymino that) {
			Point thatPoint = that.cells.iterator().next();
			int entries = 0;
			mainloop:
			for (Point fromp : cells) {
				Point shift = fromp.shift(-thatPoint.x, -thatPoint.y);
				for (Point p : that.cells) {
					if (!cells.contains(p.shift(shift))) {
						continue mainloop;
					}
				}
				entries++;
			}
			return entries;
		}
	}
	
	private Scanner in;
	private PrintWriter out;

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	int k;
	Polymino from, poly;

	private void solve() throws IOException {
		in = new Scanner(new File("polymino.in"));
		out = new PrintWriter(new File("polymino.out"));
		k = in.nextInt();
		poly = new Polymino(in);
		from = new Polymino(in);
		solveSmallK();
		in.close();
		out.close();
	}

	private void solveSmallK() {
		int answer = 0;
		for (int dx = 0; dx < k; dx++) {
			for (int dy = 0; dy < k; dy++) {
				answer += checkShift(dx, dy);
			}
		}
		out.println(answer);
	}

	private int checkShift(int dx, int dy) {
		HashSet<Point> temp = new HashSet<Point>();
		int xmin = Integer.MAX_VALUE;
		int xmax = Integer.MIN_VALUE;
		int ymin = Integer.MAX_VALUE;
		int ymax = Integer.MIN_VALUE;
		for (Point p : poly.cells) {
			int x = (p.x + dx) / k;
			int y = (p.y + dy) / k;
			temp.add(new Point(x, y));
			xmin = Math.min(xmin, x);
			xmax = Math.max(xmax, x);
			ymin = Math.min(ymin, y);
			ymax = Math.max(ymax, y);
		}
		HashSet<Point> compressed = new HashSet<Point>();
		for (Point p : temp) {
			compressed.add(p.shift(-xmin, -ymin));
		}
		Polymino compr = new Polymino(compressed, xmax - xmin + 1, ymax - ymin + 1);
		return from.countEntries(compr);
	}

	public static void main(String[] args) {
		new poly_md_only_small_k().run();
	}

}
