#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <assert.h>

#define inpfile "reform.in"
#define outfile "reform.out"

const int NMAX = 45;
const double EPS = 1e-10;

struct COORD {
	double x,y;
};

struct CUT {
	int i,j,cnt;
};

struct SEGMENT {
	COORD p1,p2;
};

COORD a[NMAX];
bool b[NMAX][NMAX];
int n;

CUT cut[10*NMAX];
int cutn;
int u[10*NMAX];
int c[10*NMAX],r[10*NMAX];
bool d[10*NMAX][10*NMAX];
int cn,rn;
int sum;
int res;

COORD poly[10*NMAX][NMAX];
int polyn[10*NMAX];
int pn;

SEGMENT seg[NMAX];
int segn;

void Init()
{
	freopen(inpfile,"r",stdin);
	freopen(outfile,"w",stdout);
}

void Out()
{
	int i;
	printf("%d\n",res);
	printf("%d\n",segn);
	for (i = 1; i <= segn; i++)
		printf("%.0lf %.0lf %.0lf %.0lf\n",seg[i].p1.x,seg[i].p1.y,seg[i].p2.x,seg[i].p2.y);
	exit(0);
}

double Vc(COORD &p1, COORD &p2, COORD &p3, COORD &p4)
{
	return (p2.x - p1.x)*(p4.y - p3.y) - (p2.y - p1.y)*(p4.x - p3.x);
}

double Sc(COORD &p1, COORD &p2, COORD &p3, COORD &p4)
{
	return (p2.x - p1.x)*(p4.x - p3.x) + (p2.y - p1.y)*(p4.y - p3.y);
}

bool PointOnRay(COORD &p1, COORD &p2, COORD &q)
{
	return (fabs(Vc(p1,p2,p1,q)) < EPS) && (Sc(p1,p2,p1,q) > -EPS);
}

bool PointOnSegment(COORD &p1, COORD &p2, COORD &q)
{
	return (fabs(Vc(p1,p2,p1,q)) < EPS) && (Sc(q,p1,q,p2) < -EPS);
}

bool ClearRay(COORD *a, int n, COORD &p1, COORD &p2)
{
	int i;
	for (i = 1; i <= n; i++)
		if (PointOnRay(p1,p2,a[i])) return false;
	return true;
}

double sqr(double x)
{
	return x*x;
}

bool StrictCross(COORD &p1, COORD &p2, COORD &p3, COORD &p4)
{
	double v1,v2;
	COORD q;

	v1 = Vc(p3,p1,p3,p4);
	v2 = Vc(p1,p2,p3,p4);
	if (fabs(v2) < EPS) return false;

	q.x = p1.x - (p2.x - p1.x)*v1/v2;
	q.y = p1.y - (p2.y - p1.y)*v1/v2;
	return (Sc(p1,p2,p1,q) > -EPS) && (Sc(q,p3,q,p4) < -EPS);
}

bool InnerPoint(COORD *a, int n, COORD &p)
{
	double cs,sn;
	COORD q;
	int i,cnt;

	for (i = 1; i <= n; i++)
		if (PointOnSegment(a[i],a[i + 1],p)) return false;

	do {
		cs = (double)(rand()%1001)/(double)1000;
		sn = sqrt(1 - sqr(cs));
		if (rand()%2 == 0) cs = -cs;
		if (rand()%2 == 0) sn = -sn;
		q.x = p.x + cs;
		q.y = p.y + sn;
	} while (!ClearRay(a,n,p,q));

	cnt = 0;
	for (i = 1; i <= n; i++)
		if (StrictCross(p,q,a[i],a[i + 1])) cnt++;

	return (cnt%2 == 1);
}

bool Eq(COORD &p1, COORD &p2)
{
	return (fabs(p2.x - p1.x) < EPS) && (fabs(p2.y - p1.y) < EPS);
}

bool InnerDiagonal(COORD *a, int n, COORD &p1, COORD &p2)
{
	COORD p3,p4;
	double v1,v2;
	COORD q;
	int i;

	for (i = 1; i <= n; i++) {
		p3 = a[i];
		p4 = a[i+1];

		v1 = Vc(p3,p1,p3,p4);
		v2 = Vc(p1,p2,p3,p4);
		if (fabs(v2) < EPS) {
			if (fabs(Vc(p1,p2,p1,p3)) > EPS) continue;
			if ((Sc(p3,p1,p3,p2) < -EPS) || (Sc(p4,p1,p4,p2) < -EPS)) return false;
			if ((Eq(p1,p3) && Eq(p2,p4)) || (Eq(p2,p3) && Eq(p1,p4))) return false;
			continue;
		}

		q.x = p1.x - (p2.x - p1.x)*v1/v2;
		q.y = p1.y - (p2.y - p1.y)*v1/v2;

		if ((Sc(q,p1,q,p2) > EPS) || (Sc(q,p3,q,p4) > EPS)) continue;
		if (!Eq(p1,q) && !Eq(p2,q)) return false;
	}

	q.x = (p1.x + p2.x) / 2;
	q.y = (p1.y + p2.y) / 2;
	return InnerPoint(a,n,q);
}

bool Cross(COORD &p1, COORD &p2, COORD &p3, COORD &p4)
{
	return (Vc(p1,p2,p1,p3)*Vc(p1,p2,p1,p4) < -EPS) && (Vc(p3,p4,p3,p1)*Vc(p3,p4,p3,p2) < -EPS);
}

void Rec(int h)
{
	if (h == cutn + 1) {
		if (res >= sum) {
			res = sum;
			rn = cn;
			int i;
			for (i = 1; i <= cn; i++) r[i] = c[i];
		}
		return;
	}

	int i;
	u[h] = false;
	Rec(h + 1);

	for (i = 1; i <= cn; i++)
		if (d[c[i]][h]) return;

	u[h] = true;
	cn++;
	c[cn] = h;
	sum -= cut[h].cnt;
	Rec(h + 1);
	cn--;
	sum += cut[h].cnt;
}

void Inc(int &x, int n)
{
	if (x == n) x = 1;
	else x++;
}

void Dec(int &x, int n)
{
	if (x == 1) x = n;
	else x--;
}

int Succ(int &x, int n)
{
	if (x == n) return 1;
	else return x + 1;
}

int Pred(int &x, int n)
{
	if (x == 1) return n;
	else return x - 1;
}

void Cutter(int k)
{
	if (polyn[k] <= 3) return;

	int i,j;
	int t1,t2;

	t1 = 0; t2 = 0;

	for (i = 1; (i <= polyn[k] - 1) && !t1; i++)
		for (j = i + 1; j <= polyn[k]; j++)
			if (InnerDiagonal(poly[k],polyn[k],poly[k][i],poly[k][j])) {
				t1 = i;
				t2 = j;
				break;
			}

	assert(t1);
	segn++;
	seg[segn].p1 = poly[k][t1];
	seg[segn].p2 = poly[k][t2];

	pn++;
	polyn[pn] = t2 - t1 + 1;
	for (i = t1; i <= t2; i++)
		poly[pn][i - t1 + 1] = poly[k][i];

	poly[pn][0] = poly[pn][polyn[pn]];
	poly[pn][polyn[pn] + 1] = poly[pn][1];

	int h;
	h = 0;
	pn++;
	for (i = t2; i <= polyn[k]; i++) {
		h++;
		poly[pn][h] = poly[k][i];
	}
	for (i = 1; i <= t1; i++) {
		h++;
		poly[pn][h] = poly[k][i];
	}
	polyn[pn] = h;
	poly[pn][0] = poly[pn][polyn[pn]];
	poly[pn][polyn[pn] + 1] = poly[pn][1];

	polyn[k] = polyn[pn];
	for (i = 0; i <= h + 1; i++)
		poly[k][i] = poly[pn][i];
	pn--;

	Cutter(pn);
	Cutter(k);
}

void Solve()
{
	int i,j,k;
	int num[3];
	int cnt;

	memset(b,0,sizeof(b));
	for (i = 1; i <= n - 1; i++)
		for (j = i + 1; j <= n; j++) {
			b[i][j] = InnerDiagonal(a,n,a[i],a[j]);
			b[j][i] = b[i][j];
		}

	cutn = 0; 
	for (i = 1; i <= n - 1; i++)
		for (j = i + 1; j <= n; j++)
			if (b[i][j]) {
				cnt = 0;
				if ((fabs(Vc(a[i - 1],a[i],a[i],a[j])) < EPS) || (fabs(Vc(a[i],a[i + 1],a[i],a[j])) < EPS)) {
					cnt++; 
					num[cnt] = i;
				}
				if ((fabs(Vc(a[j - 1],a[j],a[i],a[j])) < EPS) || (fabs(Vc(a[j],a[j + 1],a[i],a[j])) < EPS)) {
					cnt++;
					num[cnt] = j;
				}

				if (cnt > 0) {
					num[2] = i + j - num[1];
					cutn++;
					cut[cutn].i = num[1];
					cut[cutn].j = num[2];
					cut[cutn].cnt = cnt;
				}
			}

	memset(d,0,sizeof(d));
	for (i = 1; i <= cutn - 1; i++)
		for (j = i + 1; j <= cutn; j++) {
			d[i][j] = Cross(a[cut[i].i],a[cut[i].j],a[cut[j].i],a[cut[j].j]);
			if (cut[i].i == cut[j].i) d[i][j] = true;
			if (cut[i].cnt == 2) {
				if (cut[i].j == cut[j].i) d[i][j] = true;
				if ((cut[j].cnt == 2) && (cut[i].j == cut[j].j)) d[i][j] = true;
			}
			if ((cut[j].cnt == 2) && (cut[i].i == cut[j].j)) d[i][j] = true;
			d[j][i] = d[i][j];
		}

	res = n - 2;
	sum = n - 2;
	memset(u,0,sizeof(u));
	cn = 0;
	Rec(1);

	int h;
	memset(polyn,0,sizeof(polyn));
	pn = 1;
	for (i = 1; i <= n; i++) {
		polyn[pn]++;
		poly[pn][polyn[pn]] = a[i];
	}

	poly[pn][0] = poly[pn][polyn[pn]];
	poly[pn][polyn[pn] + 1] = poly[pn][1];

	segn = 0;

	COORD p1,p2;
	int s,t;
	for (i = 1; i <= rn; i++) {
		p1 = a[cut[r[i]].i];
		p2 = a[cut[r[i]].j];
		segn++;
		seg[segn].p1 = p1;
		seg[segn].p2 = p2;

		for (j = 1; j <= pn; j++) {
			cnt = 0;
			for (k = 1; k <= polyn[j]; k++)
				if (Eq(poly[j][k],p1) || Eq(poly[j][k],p2)) {
					cnt++;
					assert(cnt <= 2);
					num[cnt] = k;
				}

			if (cnt >= 2) {
				s = num[1];
				t = num[2];
				if ((s % polyn[j] + 1 == t) || (t % polyn[j] + 1 == s)) continue;

				pn++;
				for (k = s; k <= t; k++)
					poly[pn][k - s + 1] = poly[j][k];
				polyn[pn] = t - s + 1;
				poly[pn][0] = poly[pn][polyn[pn]];
				poly[pn][polyn[pn] + 1] = poly[pn][1];

				h = 2;
				for (k = 3; k <= polyn[pn]; k++) {
					if (fabs(Vc(poly[pn][h - 1],poly[pn][h],poly[pn][h],poly[pn][k])) < EPS) {
						poly[pn][h] = poly[pn][k];
					} else {
						h++;
						poly[pn][h] = poly[pn][k];
					}
				}
				if (fabs(Vc(poly[pn][h - 1],poly[pn][h],poly[pn][h],poly[pn][1])) < EPS) h--;
				if (fabs(Vc(poly[pn][h],poly[pn][1],poly[pn][1],poly[pn][2])) < EPS) {
					poly[pn][1] = poly[pn][h];
					h--;
				}
				polyn[pn] = h;
				poly[pn][0] = poly[pn][polyn[pn]];
				poly[pn][polyn[pn] + 1] = poly[pn][1];

				s = num[2];
				t = num[1];

				pn++;
				h = 0;
				for (k = s; k <= polyn[j]; k++) {
					h++;
					poly[pn][h] = poly[j][k];
				}
				for (k = 1; k <= t; k++) {
					h++;
					poly[pn][h] = poly[j][k];
				}

				polyn[pn] = h;
				poly[pn][0] = poly[pn][polyn[pn]];
				poly[pn][polyn[pn] + 1] = poly[pn][1];

				h = 2;
				for (k = 3; k <= polyn[pn]; k++) {
					if (fabs(Vc(poly[pn][h - 1],poly[pn][h],poly[pn][h],poly[pn][k])) < EPS) {
						poly[pn][h] = poly[pn][k];
					} else {
						h++;
						poly[pn][h] = poly[pn][k];
					}
				}
				if (fabs(Vc(poly[pn][h - 1],poly[pn][h],poly[pn][h],poly[pn][1])) < EPS) h--;
				if (fabs(Vc(poly[pn][h],poly[pn][1],poly[pn][1],poly[pn][2])) < EPS) {
					poly[pn][1] = poly[pn][h];
					h--;
				}
				polyn[pn] = h;
				poly[pn][0] = poly[pn][polyn[pn]];
				poly[pn][polyn[pn] + 1] = poly[pn][1];

				for (k = 0; k <= polyn[pn] + 1; k++) poly[j][k] = poly[pn][k];
				polyn[j] = polyn[pn];
				pn--;
				//break;
			}
		}
	}

	for (i = 1; i <= pn; i++) Cutter(i);
}

void Inp()
{
	int i;
	scanf("%d",&n);
	for (i = 1; i <= n; i++)
		scanf("%lf %lf",&a[i].x,&a[i].y);
	a[0] = a[n]; a[n + 1] = a[1];
}

int main()
{
	srand(28374);
	Init();
	Inp();
	Solve();
	Out();
	return 0;
}
