import java.io.*;
import java.util.*;

public class reform_md implements Runnable {
    private class Segment {
        long x1, y1, x2, y2;
        
        public Segment(long x1, long y1, long x2, long y2) {
            this.x1 = x1;
            this.y1 = y1;
            this.x2 = x2;
            this.y2 = y2;
        }
        
        public int orientation(long x0, long y0) {
            long area =
                x0 * y1 - x1 * y0 +
                x1 * y2 - x2 * y1 +
                x2 * y0 - x0 * y2;
            if (area > 0)
                return 1;
            if (area < 0)
                return -1;
            return 0;
        }
        
        public boolean intersects(Segment that) {
            int o1 = orientation(that.x1, that.y1);
            int o2 = orientation(that.x2, that.y2);
            int o3 = that.orientation(x1, y1);
            int o4 = that.orientation(x2, y2);
            return o1 * o2 < 0 && o3 * o4 < 0;
        }
        
        public boolean onSameLine(Segment that) {
            return (orientation(that.x1, that.y1) == 0) &&
            (orientation(that.x2, that.y2) == 0);
        }
        
        public boolean strictlyContains(long x, long y) {
            if (orientation(x, y) != 0)
                return false;
            if (x == x1 && y == y1 || x == x2 && y == y2)
                return false;
            if ((x1 <= x && x <= x2 || x2 <= x && x <= x1) &&
                    (y1 <= y && y <= y2 || y2 <= y && y <= y1))
                return true;
            return false;
        }
        
        @Override
        public boolean equals(Object obj) {
            if (obj instanceof Segment) {
                Segment that = (Segment) obj;
                return (x1 == that.x1 && y1 == that.y1 && x2 == that.x2 && y2 == that.y2) ||
                (x1 == that.x2 && y1 == that.y2 && x2 == that.x1 && y2 == that.y1);
            }
            return false;
        }
    }
    
    private class Polygon {
        private class Diagonal {
            Segment seg;
            int type;
            int n1;
            int n2;
            
            public Diagonal(Segment seg, int type, int n1, int n2) {
                this.seg = seg;
                this.type = type;
                this.n1 = n1;
                this.n2 = n2;
            }
            
            @Override
            public boolean equals(Object obj) {
                if (obj instanceof Diagonal) {
                    Diagonal that = (Diagonal) obj;
                    return (that.n1 == n1) &&
                            (that.n2 == n2) &&
                            (that.type == type);
                }
                return false;
            }
            
            public boolean goesTogetherWith(Diagonal that) {
                if (seg.intersects(that.seg))
                    return false;
                if (n1 == that.n1 || n1 == that.n2 || 
                    n2 == that.n1 || n2 == that.n2) {
                    if (type == 2 && that.type == 2)
                        return false;
                    if (type == that.type) {
                        // type-1 and type-1 sharing an endpoint
                        int common;
                        if (n1 == that.n1 || n1 == that.n2)
                            common = n1;
                        else
                            common = n2;
                        int c1 = (common + 1) % n;
                        int c2 = (common + n - 1) % n;
                        int o1 = seg.orientation(x[c1], y[c1]);
                        int o2 = seg.orientation(x[c2], y[c2]);
                        boolean far1 = (o1 * o2 != 0);
                        int o3 = that.seg.orientation(x[c1], y[c1]);
                        int o4 = that.seg.orientation(x[c2], y[c2]);
                        boolean far2 = (o3 * o4 != 0);
                        if (far1 == far2)
                            return far1;
                        return (o1 * o2 + o3 * o4 > 0);
                    }
                    // type-2 and type-1 sharing an endpoint
                    Diagonal diag1, diag2;
                    if (type == 1) {
                        diag1 = this;
                        diag2 = that;
                    } else {
                        diag1 = that;
                        diag2 = this;
                    }
                    int common;
                    if (diag2.n1 == diag1.n1 || diag2.n1 == diag1.n2)
                        common = diag2.n1;
                    else
                        common = diag2.n2;
                    int o1 = diag2.seg.orientation(x[(common + 1) % n], y[(common + 1) % n]);
                    int o2 = diag2.seg.orientation(x[(common + n - 1) % n], y[(common + n - 1) % n]);
                    int index = diag1.n1 ^ diag1.n2 ^ common;
                    int o3 = diag2.seg.orientation(x[index], y[index]);
                    return (o1 + o2 == o3);
                }
                return true;
            }
        }
        
        private class SubPolygon {
            ArrayList<Integer> vert;
            Set<Integer> vertice;
            
            public SubPolygon() {
                vert = new ArrayList<Integer>(n);
                vertice = new HashSet<Integer>(n);
                for (int i = 0; i < n; i++) {
                    vert.add(i);
                    vertice.add(i);
                }
            }
            
            public SubPolygon(ArrayList<Integer> v) {
                vert = v;
                vertice = new HashSet<Integer>(v.size());
                for (int x : v) {
                    vertice.add(x);
                }
            }

            public void divide() {
                for (Diagonal diag : bestSet) {
                    if (vertice.contains(diag.n1) && vertice.contains(diag.n2)) {
                        bestSet.remove(diag);
                        divide(diag);
                        return;
                    }
                }
                finalSubPolygons.add(this);
            }

            private void divide(Diagonal diag) {
                int i = 0;
                int nn = vert.size();
                while (vert.get(i) != diag.n1)
                    i = (i + 1) % nn;
                ArrayList<Integer> v1 = new ArrayList<Integer>();
                ArrayList<Integer> v2 = new ArrayList<Integer>();
                while (vert.get(i) != diag.n2) {
                    v1.add(vert.get(i));
                    i = (i + 1) % nn;
                }
                v1.add(diag.n2);
                while (vert.get(i) != diag.n1) {
                    v2.add(vert.get(i));
                    i = (i + 1) % nn;
                }
                v2.add(diag.n1);
                SubPolygon sp1 = new SubPolygon(v1);
                SubPolygon sp2 = new SubPolygon(v2);
                tempSubPolygons.add(sp1);
                tempSubPolygons.add(sp2);
            }
        }
        
        private Queue<SubPolygon> tempSubPolygons;
        private ArrayList<SubPolygon> finalSubPolygons;
        
        int n;
        long[] x;
        long[] y;
        Segment[] side;
        
        public Polygon(Scanner in) {
            n = in.nextInt();
            x = new long[n];
            y = new long[n];
            for (int i = 0; i < n; i++) {
                x[i] = in.nextLong();
                y[i] = in.nextLong();
            }
            countSides();
        }

        public Polygon(long[] xx, long[] yy) {
            n = xx.length;
            x = xx;
            y = yy;
            countSides();
        }

        private void countSides() {
            side = new Segment[n];
            for (int i = 0; i < n; i++) {
                side[i] = new Segment(x[i], y[i], x[(i + 1) % n], y[(i + 1) % n]); 
            }
        }
        
        private boolean isStrictlyInside(double x, double y) {
            long xx = (long) Math.round(2 * x);
            long yy = (long) Math.round(2 * y);
            Segment segment = new Segment(xx, yy, xx + 1, yy + 100000);
            int inters = 0;
            for (Segment s : side) {
                Segment temp = new Segment(s.x1 * 2, s.y1 * 2, s.x2 * 2, s.y2 * 2);
                if (segment.intersects(temp))
                    inters++;
            }
            return (inters % 2 == 1);
        }

        public boolean isStrictlyInside(Segment seg) {
            for (int i = 0; i < n; i++) {
                if (seg.intersects(side[i]) || seg.strictlyContains(x[i], y[i]))
                    return false;
            }
            return isStrictlyInside((seg.x1 + seg.x2) / 2.0, (seg.y1 + seg.y2) / 2.0);
        }
        
        @SuppressWarnings("unchecked")
        public void triangulate() {
            cuteDiagonals = new ArrayList<Diagonal>();
            for (int i = 0; i < n; i++) {
                for (int j = i + 2; j < n; j++) {
                    if (i == 0 && j == n - 1)
                        continue;
                    Segment seg = new Segment(x[i], y[i], x[j], y[j]);
                    if (!isStrictlyInside(seg))
                        continue;
                    int type = 0;
                    if (seg.onSameLine(side[i]) || seg.onSameLine(side[(i + n - 1) % n]))
                        type++;
                    if (seg.onSameLine(side[j]) || seg.onSameLine(side[(j + n - 1) % n]))
                        type++;
                    if (type > 0)
                        cuteDiagonals.add(new Diagonal(seg, type, i, j));
                }
            }
            forbidden = new int[cuteDiagonals.size()];
            chosen = new ArrayList<Diagonal>();
            bestSet = new ArrayList<Diagonal>();
            answer = new ArrayList<Segment>();
            score = 0;
            bestScore = 0;
            goes = new boolean[cuteDiagonals.size()][cuteDiagonals.size()];
            for (int i = 0; i < cuteDiagonals.size(); i++) {
                for (int j = i + 1; j < cuteDiagonals.size(); j++) {
                    goes[i][j] = goes[j][i] =
                        cuteDiagonals.get(i).goesTogetherWith(cuteDiagonals.get(j));
                }
            }
            backtrack(0);
            for (Diagonal diag : bestSet) {
                answer.add(diag.seg);
            }
            
            tempSubPolygons = new LinkedList<SubPolygon>();
            finalSubPolygons = new ArrayList<SubPolygon>();
            SubPolygon sub = new SubPolygon();
            tempSubPolygons.add(sub);
            while (!tempSubPolygons.isEmpty())
                tempSubPolygons.poll().divide();
            
            for (SubPolygon sp : finalSubPolygons) {
                long[] xx = new long[sp.vert.size()];
                long[] yy = new long[sp.vert.size()];
                for (int i = 0; i < sp.vert.size(); i++) {
                    xx[i] = x[sp.vert.get(i)];
                    yy[i] = y[sp.vert.get(i)];
                }
                Polygon poly = new Polygon(xx, yy);
                poly.triangulateBrute();
            }
            out.println(answer.size() + 1);
            out.println(answer.size());
            for (Segment seg : answer) {
                out.println(seg.x1 + " " + seg.y1 + " " + seg.x2 + " " + seg.y2);
            }
        }

        private void normalize() {
            boolean[] degen = new boolean[n];
            int normalN = n;
            for (int i = 0; i < n; i++) {
                Segment temp = new Segment(x[(i + n - 1) % n], y[(i + n - 1) % n],
                        x[(i + 1) % n], y[(i + 1) % n]);
                if (temp.strictlyContains(x[i], y[i])) {
                    degen[i] = true;
                    normalN--;
                }
            }
            long[] xx = new long[normalN];
            long[] yy = new long[normalN];
            int j = 0;
            for (int i = 0; i < n; i++) {
                if (!degen[i]) {
                    xx[j] = x[i];
                    yy[j] = y[i];
                    j++;
                }
            }
            n = normalN;
            x = xx;
            y = yy;
            countSides();
        }

        private void triangulateBrute() {
            normalize();
//          System.err.println("Brute reform:");
//          for (int i = 0; i < n; i++) {
//              System.err.println(x[i] + " " + y[i]);
//          }
            if (n == 3)
                return;
            if (n < 3) {
                throw new Error("Degenerate Triangle!!!");
            }
            for (int i = 0; i < n; i++) {
                for (int j = i + 2; j < n; j++) {
                    if (i == 0 && j == n - 1)
                        continue;
                    Segment seg = new Segment(x[i], y[i], x[j], y[j]);
                    if (!isStrictlyInside(seg))
                        continue;
                    answer.add(seg);
                    SubPolygon sub = new SubPolygon();
                    Diagonal diag = new Diagonal(seg, -1, i, j);
                    tempSubPolygons = new LinkedList<SubPolygon>();
                    sub.divide(diag);
                    for (SubPolygon sp : tempSubPolygons) {
                        long[] xx = new long[sp.vert.size()];
                        long[] yy = new long[sp.vert.size()];
                        for (int k = 0; k < sp.vert.size(); k++) {
                            xx[k] = x[sp.vert.get(k)];
                            yy[k] = y[sp.vert.get(k)];
                        }
                        Polygon poly = new Polygon(xx, yy);
                        poly.triangulateBrute();
                    }
                    return;
                }
            }
        }

        private ArrayList<Diagonal> cuteDiagonals;
        private int[] forbidden;
        private ArrayList<Diagonal> chosen;
        private ArrayList<Diagonal> bestSet;
        private int score;
        private int bestScore;
        private boolean[][] goes;
        
        private void backtrack(int x) {
            if (x == cuteDiagonals.size()) {
                if (score > bestScore) {
                    bestScore = score;
                    bestSet = new ArrayList<Diagonal>(chosen);
                }
                return;
            }
            backtrack(x + 1);
            if (forbidden[x] > 0)
                return;
            for (int i = x + 1; i < cuteDiagonals.size(); i++) {
                if (!goes[x][i]) {
                    forbidden[i]++;
                }
            }
            Diagonal diag = cuteDiagonals.get(x);
            score += diag.type;
            chosen.add(diag);
            backtrack(x + 1);
            for (int i = x + 1; i < cuteDiagonals.size(); i++) {
                if (!goes[x][i]) {
                    forbidden[i]--;
                }
            }
            score -= diag.type;
            chosen.remove(chosen.size() - 1);
        }
        
        public void saveCuteDiagonals() throws IOException {
            PrintWriter aux = new PrintWriter(new File("reform.aux"));
            aux.println(cuteDiagonals.size());
            for (Diagonal diag : cuteDiagonals) {
                aux.println(diag.seg.x1 + " " + diag.seg.y1 + " " + diag.seg.x2 + " " + diag.seg.y2 + " ");
            }
            aux.close();
        }
    }

    private Scanner in;
    private PrintWriter out;
    private ArrayList<Segment> answer;
    
    public void run() {
        try {
            solve();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
    
    private void solve() throws Exception {
        Locale.setDefault(Locale.US);
        in = new Scanner(new File("reform.in"));
        out = new PrintWriter(new File("reform.out"));
        Polygon polygon = new Polygon(in);
        polygon.triangulate();
        polygon.saveCuteDiagonals();
        in.close();
        out.close();
    }
    
    public static void main(String[] args) {
        new Thread(new reform_md()).start();
    }
    
}
