import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.*;

public class reform_pmi_slowestest {
    static enum TurnSide {
        LEFT, RIGHT, STRAIGHT
    }

    static class Point {
        public final int id;
        public final long x;
        public final long y;

        public Point(int id, long x, long y) {
            this.id = id;
            this.x = x;
            this.y = y;
        }

        public static Point middlePoint(Point a, Point b) {
            return new Point(-1, (a.x + b.x) / 2, (a.y + b.y) / 2);
        }

        public static TurnSide getTurnSide(Point p1, Point p2, Point p3) {
            long z = (p2.x - p1.x) * (p3.y - p2.y) - (p2.y - p1.y) * (p3.x - p2.x);
            if (z > 0)
                return TurnSide.LEFT;
            else if (z < 0)
                return TurnSide.RIGHT;
            else
                return TurnSide.STRAIGHT;
        }
    }

    static class Line {
        public final long a;
        public final long b;
        public final long c;

        public Line(long a, long b, long c) {
            this.a = a;
            this.b = b;
            this.c = c;
        }

        public Line(Point a, Point b) {
            this(a.y - b.y, b.x - a.x, a.x * b.y - b.x * a.y);
        }

        public int side(Point p) {
            long z = a * p.x + b * p.y + c;
            if (z > 0)
                return 1;
            else if (z < 0)
                return -1;
            else
                return 0;
        }
    }

    static class Segment {
        public final Point a;
        public final Point b;
        public final Line line;

        public Segment(Point a, Point b) {
            this.a = a;
            this.b = b;
            line = new Line(this.a, this.b);
        }

        public static boolean intersect(Segment s1, Segment s2) {
            int s1a = s2.line.side(s1.a);
            int s1b = s2.line.side(s1.b);
            int s2a = s1.line.side(s2.a);
            int s2b = s1.line.side(s2.b);
            if (s1a * s1b == 1 || s2a * s2b == 1)
                return false;
            if (s1a * s1b == -1 || s2a * s2b == -1)
                return true;
            if (s1a != 0 || s1b != 0)
                return false;
            return Math.min(Math.max(s1.a.x, s1.b.x), Math.max(s2.a.x, s2.b.x)) > Math.max(Math.min(s2.a.x, s2.b.x), Math.min(s1.a.x, s1.b.x)) ||
                    Math.min(Math.max(s1.a.y, s1.b.y), Math.max(s2.a.y, s2.b.y)) > Math.max(Math.min(s2.a.y, s2.b.y), Math.min(s1.a.y, s1.b.y));
        }
    }

    static class Solution {
        public int answer;
        public List<Segment> answerSegments = new ArrayList<Segment>();
    }

    static class Polygon {
        static final int BIG_COORD = 30000;

        class Diagonal {
            public final int a;
            public final int b;

            public Diagonal(int a, int b) {
                this.a = a;
                this.b = b;
            }

            public Segment getSegment() {
                return new Segment(points[a], points[b]);
            }
        }

        public Point[] points;
        public Segment[] sides;

        public Polygon(ArrayList<Point> pointList) {
            int minIndex = 0;
            Point minPoint = pointList.get(0);
            for (int index = 1; index < pointList.size(); ++index) {
                Point curPoint = pointList.get(index);
                if (curPoint.x < minPoint.x || curPoint.x == minPoint.x && curPoint.y < minPoint.y) {
                    minIndex = index;
                    minPoint = curPoint;
                }
            }

            ArrayList<Point> orderedPoints = new ArrayList<Point>();
            for (int i = 0; i <= pointList.size(); ++i) {
                int index = (minIndex + i) % pointList.size();
                orderedPoints.add(pointList.get(index));
                if (orderedPoints.size() >= 3) {
                    Point p1 = orderedPoints.get(orderedPoints.size() - 3);
                    Point p2 = orderedPoints.get(orderedPoints.size() - 2);
                    Point p3 = orderedPoints.get(orderedPoints.size() - 1);
                    if (Point.getTurnSide(p1, p2, p3) == TurnSide.STRAIGHT)
                        orderedPoints.remove(orderedPoints.size() - 2);
                }
            }
            orderedPoints.remove(orderedPoints.size() - 1);

            points = orderedPoints.toArray(new Point[0]);

            sides = new Segment[points.length];
            for (int i = 0; i < sides.length; ++i)
                sides[i] = new Segment(points[i], points[(i + 1) % points.length]);
        }

        public List<Diagonal> getGoodDiagonals(int fromVertex) {
            ArrayList<Diagonal> list = new ArrayList<Diagonal>();
            for (int b = fromVertex; b < points.length; ++b)
                if (b != fromVertex)
                {
                    Segment s = new Segment(points[fromVertex], points[b]);
                    if (segmentGood(s))
                        list.add(new Diagonal(fromVertex, b));
                }

            return list;
        }

        private boolean segmentGood(Segment s) {
            for (Segment side : sides)
                if (Segment.intersect(s, side))
                    return false;

            Point middle = Point.middlePoint(s.a, s.b);
            Point outside = new Point(-1, middle.x + BIG_COORD, middle.y + BIG_COORD + 1);
            Segment toCheck = new Segment(middle, outside);
            int cnt = 0;
            for (Segment side : sides)
                if (Segment.intersect(toCheck, side))
                    ++cnt;

            return cnt % 2 != 0;
        }

        static Map<Polygon, Solution> triangulationCache = new HashMap<Polygon, Solution>();

        public Solution triangulate() throws InterruptedException {
       //     if (!triangulationCache.containsKey(this))
       //         triangulationCache.put(this, doTriangulation());
       //     return triangulationCache.get(this);
            return doTriangulation();
        }

        private Solution doTriangulation() throws InterruptedException {
            Solution solution = new Solution();

            if (points.length == 3) {
                solution.answer = points.length - 2;
                for (int i = 2; i < points.length - 1; ++i)
                    solution.answerSegments.add(new Segment(points[0], points[i]));
            } else {
                solution.answer = Integer.MAX_VALUE;
for (int i = 0; i < points.length; ++i) {
int unconvexVertex = i;
                List<Diagonal> diagonals = getGoodDiagonals(unconvexVertex);
                for (Diagonal diagonal : diagonals) {
                    ArrayList<Point> leftPart = new ArrayList<Point>();
                    for (int index = diagonal.a; true; index = (index + 1) % points.length) {
                        leftPart.add(points[index]);
                        if (index == diagonal.b)
                            break;
                    }

                    ArrayList<Point> rightPart = new ArrayList<Point>();
                    for (int index = diagonal.b; true; index = (index + 1) % points.length) {
                        rightPart.add(points[index]);
                        if (index == diagonal.a)
                            break;
                    }

                    Solution leftSolution = new Polygon(leftPart).triangulate();
                    Solution rightSolution = new Polygon(rightPart).triangulate();
                    int num = leftSolution.answer + rightSolution.answer;
                    if (num < solution.answer) {
                        solution.answer = num;
                        solution.answerSegments.clear();
                        solution.answerSegments.add(diagonal.getSegment());
                        solution.answerSegments.addAll(leftSolution.answerSegments);
                        solution.answerSegments.addAll(rightSolution.answerSegments);
                    }
                }
}
            }

            return solution;
        }

        private int getUnconvexVertex() {
            for (int i = 0; i < points.length; ++i) {
                Point p1 = points[i];
                Point p2 = points[(i + 1) % points.length];
                Point p3 = points[(i + 2) % points.length];
                if (Point.getTurnSide(p1, p2, p3) == TurnSide.RIGHT)
                    return (i + 1) % points.length;
            }
            return -1;
        }

        @Override
        public int hashCode() {
            int code = points.length;
            for (Point p : points)
                code = code * 3137 + p.hashCode();
            return code;
        }

        @Override
        public boolean equals(Object o) {
            if (!(o instanceof Polygon))
                return false;
            Polygon p = (Polygon) o;
            if (points.length != p.points.length)
                return false;
            for (int i = 0; i < points.length; ++i)
                if (points[i] != p.points[i])
                    return false;
            return true;
        }
    }

    Polygon polygon;

    public static void main(String[] args) throws Exception {
        new reform_pmi_slowestest().run();
    }

    private void run() throws FileNotFoundException, InterruptedException {
        Polygon polygon = readInput();
        Solution solution = polygon.triangulate();
        writeOutput(solution);
    }

    private void writeOutput(Solution solution) throws FileNotFoundException {
        PrintWriter writer = new PrintWriter("reform.out");

        writer.println(solution.answer);
        writer.println(solution.answerSegments.size());
        for (Segment segment : solution.answerSegments)
            writer.println(segment.a.x / 2 + " " + segment.a.y / 2 + " " +segment.b.x / 2 + " " + segment.b.y / 2);

        writer.close();
    }

    private Polygon readInput() throws FileNotFoundException {
        Scanner scanner = new Scanner(new File("reform.in"));

        int num = scanner.nextInt();
        ArrayList<Point> points = new ArrayList<Point>(num);
        for (int i = 0; i < num; ++i)
            points.add(new Point(i, 2 * scanner.nextInt(), 2 * scanner.nextInt()));

        return new Polygon(points);
    }
}
