#include <stdio.h>
#include <string.h>

#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))
#define MINI(A, B) ((A) < (B) ? (A) : (B))
#define MAXI(A, B) ((A) > (B) ? (A) : (B))

#define EPS 1e-9

#define MAX 23
#define MAXPR (1 << 20)

int N, X[MAX], Y[MAX];
int F[MAXPR], Ne[MAXPR];
int Is[MAX][MAX][MAX][MAX], Is2[MAX][MAX][MAX];
int PN = 0, P1[MAX], P2[MAX];

int IsIntr( int p1, int p2, int p3, int p4 )
{
  __int64 a1, b1, c1, a2, b2, c2;
  double xx, yy;

  if (p1 == p3 || p1 == p4 || p2 == p3 || p2 == p4)
    return 0;
  a1 = Y[p1] - Y[p2], b1 = X[p2] - X[p1], c1 = -(a1 * X[p1] + b1 * Y[p1]);
  a2 = Y[p3] - Y[p4], b2 = X[p4] - X[p3], c2 = -(a2 * X[p3] + b2 * Y[p3]);
  if (a1 * b2 == a2 * b1)
    return 0;
  xx = -(double)(c1 * b2 - c2 * b1) / (a1 * b2 - a2 * b1);
  yy = -(double)(c1 * a2 - c2 * a1) / (b1 * a2 - b2 * a1);
  return 
    MINI(X[p1], X[p2]) - EPS < xx && xx < MAXI(X[p1], X[p2]) + EPS &&
    MINI(Y[p1], Y[p2]) - EPS < yy && yy < MAXI(Y[p1], Y[p2]) + EPS &&
    MINI(X[p3], X[p4]) - EPS < xx && xx < MAXI(X[p3], X[p4]) + EPS &&
    MINI(Y[p3], Y[p4]) - EPS < yy && yy < MAXI(Y[p3], Y[p4]) + EPS;
}

int IsIn( int p1, int p2, int p3 )
{
  __int64 a, b, c;

  a = Y[p1] - Y[p2], b = X[p2] - X[p1], c = -(a * X[p1] + b * Y[p1]);
  return 
    a * X[p3] + b * Y[p3] + c == 0 && 
    MINI(X[p1], X[p2]) <= X[p3] && X[p3] <= MAXI(X[p1], X[p2]) &&
    MINI(Y[p1], Y[p2]) <= Y[p3] && Y[p3] <= MAXI(Y[p1], Y[p2]);
}

int Pr( int *A, int K, int a, int b )
{
  int pr = 0;
  while (a != b)
  {
    pr |= 1 << A[a];
    if (++a == K) a = 0;
  }
  pr |= 1 << A[a];
  return pr;
}

void dfs( int pr )
{
  int K = 0, A[MAX];
  int i, j, k, pr1, mi, ne, cmi, cne;
  int a, b, c, s1, s2, s;

  if (F[pr] != -1)
    return;
  for (i = 0; i < N; i++)
    if ((pr >> i) & 1)
      A[K++] = i;
  if (K == 3)
  {
    F[pr] = 1;
    return;
  }
  A[K] = A[0], A[K + 1] = A[1];
  for (i = 0; i < K; i++)
    if ((X[A[i + 1]] - X[A[i]]) * (Y[A[i + 2]] - Y[A[i]]) ==
        (X[A[i + 2]] - X[A[i]]) * (Y[A[i + 1]] - Y[A[i]]))
      break;
  if (i < K)
  {
    for (pr1 = 0, j = 2; j <= K; j++)
      pr1 |= 1 << A[(i + j) % K];
    dfs(pr1);
    F[pr] = F[pr1], Ne[pr] = pr1 * 2 + 1;
    return;
  }
  mi = MAX, ne = -1;
  for (k = 0; k <= 3; k++)
    for (i = 0; i < K; i++)
    {
      /* Not adjecent to k-th */
      if ((i - k + K) % K <= 1 || (i - k + K) % K >= K - 1)
        continue;
      /* Diagonal should be inside */
      s1 = s2 = 0;
      a = Y[A[i]] - Y[A[k]], b = X[A[k]] - X[A[i]];
      c = -(a * X[A[k]] + b * Y[A[k]]);
      for (j = 0; j < K; j++)
      {
        s = a * X[A[j]] + b * Y[A[j]] + c;
        if (s < 0)
          s1 = 1;
        else if (s > 0)
          s2 = 1;
      }
      if (!(s1 && s2))
        continue;
      
      /* Diagonal is not able to intersect edges */
      for (j = 0; j < K; j++)
        if (Is[A[k]][A[i]][A[j]][A[j + 1]])
          break;
      if (j < K)
        continue;

      /* Overlap */
      for (j = 1; j < K; j++)
        if (j != k && j != i && Is2[A[k]][A[i]][A[j]])
          break;
      if (j < K)
        continue;

      /* Try to relax */
      cne = (i * 4 + k) * 2;
      pr1 = Pr(A, K, i, k);
      dfs(pr1), cmi = F[pr1];
      pr1 = Pr(A, K, k, i);
      dfs(pr1), cmi += F[pr1];
      if (cmi < mi)
        mi = cmi, ne = cne;
    }
  F[pr] = mi, Ne[pr] = ne;
}

void gen( int pr )
{
  int K = 0, A[MAX];
  int i, k, pr1;

  for (i = 0; i < N; i++)
    if ((pr >> i) & 1)
      A[K++] = i;
  A[K] = A[0], A[K + 1] = A[1];
  if (K == 3)
    return;
  if (Ne[pr] & 1)
    gen(Ne[pr] >> 1);
  else
  {
    Ne[pr] >>= 1, i = Ne[pr] >> 2, k = Ne[pr] & 3;
    P1[PN] = A[k], P2[PN++] = A[i];
    gen(pr1 = Pr(A, K, i, k));
    gen(pr1 = Pr(A, K, k, i));
  }
}

int main( void )
{
  int i, j, k, l;

  freopen("reform.in", "rt", stdin);
  freopen("reform.out", "wt", stdout);
  scanf("%d", &N);
  for (i = 0; i < N; i++)
    scanf("%d%d", &X[i], &Y[i]);
  for (i = 0; i < N; i++)
    for (j = 0; j < N; j++)
      for (k = 0; k < N; k++)
        for (l = 0; l < N; l++)
          Is[i][j][k][l] = IsIntr(i, j, k, l);
  for (i = 0; i < N; i++)
    for (j = 0; j < N; j++)
      for (k = 0; k < N; k++)
        Is2[i][j][k] = IsIn(i, j, k);
  memset(F, -1, sizeof(F));
  i = (1 << N) - 1;
  dfs(i);
  gen(i);
  printf("%d\n%d\n", F[i], PN);
  for (i = 0; i < PN; i++)
    printf("%d %d %d %d\n",  X[P1[i]], Y[P1[i]],  X[P2[i]], Y[P2[i]]);
  return 0;
}
