#include <stdio.h>
#include <malloc.h>
#include <math.h>

#define MAXVERTEXES 32
#define INF 1e+12
#define INFI 32000
#define EPS 1e-8
#define FALSE 0
#define TRUE 1
#define MAXSEG 2048

#define BETWEEN(l,r,a) \
  ((l<a && a<r) || (r<a && a<r))

#define BETWEEN2(l,r,a) \
  ((l<a && a<=r) || (r<=a && a<l))

#define BETWEEN3(l,r,a) \
  ((l<=a && a<=r) || (r<=a && a<=l))

typedef struct
{
  double x, y;
} vertex_t;

typedef struct
{
  vertex_t v1;
  vertex_t v2;
} segment_t;

segment_t segments[MAXSEG];
segment_t minsegments[MAXSEG];

int online (vertex_t *v1, vertex_t *v2, vertex_t *v3)
{
  double a, b, c;
  a=v3->y-v1->y;
  b=v1->x-v3->x;
  c=-a*v1->x-b*v1->y;
  if (fabs (a*v2->x+b*v2->y+c)<EPS) return TRUE;
  return FALSE;
}

void optimize (vertex_t *v, int *count)
{
  int n=*count, i, prev, next, j;
  i=0;
  while (i<n)
    {
      prev=i-1; if (prev<0)  prev=n-1;
      next=i+1; if (next==n) next=0;
      if (online (&v[prev], &v[next], &v[i]))
        {
          for (j=i; j<n; j++)
            v[j]=v[j+1];
          n--;
          i--;
        }
      i++;
    }
  (*count)=n;
}

void fill_vertexes (vertex_t *vertexes, int vertex_count, int b, int e, vertex_t *v, int *count)
{
  int uk=b, i=0;
  (*count)=0;

  while (uk!=e)
    {
      v[i++]=vertexes[uk];
      uk++;
      if (uk>=vertex_count) uk=0;
    }
  v[i]=vertexes[e];
  i++;
  optimize (v, &i);
  (*count)=i;
}

int near (double a, double b)
{
  if (fabs (a-b)<EPS) return TRUE;
  return FALSE;
}

int segcheck (vertex_t *_v1, vertex_t *_v2, vertex_t *_v3, vertex_t *_v4)
{
  vertex_t v, v1=*_v1, v2=*_v2, v3=*_v3, v4=*_v4;;
  if (v2.x<v1.x)
    {
      v=v1; v1=v2; v2=v;
    }
  if (v4.x<v3.x)
    {
      v=v3; v3=v4; v4=v;
    }
  if (v3.x<v1.x)
    {
      v=v1; v1=v3; v3=v;
      v=v2; v2=v4; v4=v;
    }
  if (near (v2.x, v3.x)) return TRUE;
  if (BETWEEN3 (v1.x, v2.x, v3.x)) return FALSE;
  if (BETWEEN3 (v1.x, v2.x, v4.x)) return FALSE;
  return TRUE;
}

int is_seg_crossing (vertex_t *v1, vertex_t *v2, vertex_t *v3, vertex_t *v4)
{
  double a1, b1, c1, a2, b2, c2, x, y, k;
  a1=v2->y-v1->y;
  b1=v1->x-v2->x;
  c1=-a1*v1->x-b1*v1->y;
  k=sqrt (a1*a1 + b1*b1);
  if (fabs (k)>EPS)
  {
    a1/=k; b1/=k; c1/=k;
  }

  a2=v4->y-v3->y;
  b2=v3->x-v4->x;
  c2=-a2*v3->x-b2*v3->y;
  k=sqrt (a2*a2 + b2*b2);
  if (fabs (k)>EPS)
  {
    a2/=k; b2/=k; c2/=k;
  }

  if (fabs (a1*b2-a2*b1)<EPS)
    {
      return !segcheck (v1, v2, v3, v4);
      return FALSE;
    } else
    {
      x=(b1*c2-b2*c1)/(a1*b2-a2*b1);
      y=(a1*c2-a2*c1)/(a2*b1-a1*b2);
      if (
        BETWEEN (v1->x, v2->x, x) &&
        BETWEEN (v1->y, v2->y, y) &&
        BETWEEN (v3->x, v4->x, x) &&
        BETWEEN (v3->y, v4->y, y)
        ) return TRUE;
    }
  return FALSE;
}

int is_seg_crossing2 (vertex_t *v1, vertex_t *v2, vertex_t *v3, vertex_t *v4)
{
  double a1, b1, c1, a2, b2, c2, x, y;
  a1=v2->y-v1->y;
  b1=v1->x-v2->x;
  c1=-a1*v1->x-b1*v1->y;

  a2=v4->y-v3->y;
  b2=v3->x-v4->x;
  c2=-a2*v3->x-b2*v3->y;

  if (fabs (a1*b2-a2*b1)<EPS)
    {
      return FALSE;
    } else
    {
      x=(b1*c2-b2*c1)/(a1*b2-a2*b1);
      y=(a1*c2-a2*c1)/(a2*b1-a1*b2);
      if (
        BETWEEN3 (v1->x, v2->x, x) &&
        BETWEEN3 (v1->y, v2->y, y) &&
        BETWEEN3 (v3->x, v4->x, x) &&
        BETWEEN3 (v3->y, v4->y, y)
        ) return TRUE;
    }
  return FALSE;
}

int is_dot_inside (vertex_t *vertexes, int vertex_count, vertex_t *dot)
{
  int count=0, i, j;
  vertex_t dot2;
  dot2.x=32000;
  dot2.y=dot->y;
  for (i=0; i<vertex_count; i++)
    {
      j=i+1;
      if (j==vertex_count) j=0;
      if (is_seg_crossing2 (&vertexes[i], &vertexes[j], dot, &dot2))
        if (vertexes[i].y!=vertexes[j].y)
          if ((vertexes[i].y-dot->y)*(vertexes[j].y-dot->y)<0)
          count++;
    }

  return (count%2)==1;
}

int seg_inside (vertex_t *vertexes, int vertex_count, int b, int e)
{
  int i, j;
  vertex_t dot;
  for (i=0; i<vertex_count; i++)
    {
      j=i+1;
      if (j==vertex_count) j=0;
      if (is_seg_crossing (&vertexes[i], &vertexes[j], &vertexes[b], &vertexes[e]))
        return FALSE;
    }
  dot.x=(vertexes[b].x+vertexes[e].x)/2;
  dot.y=(vertexes[b].y+vertexes[e].y)/2;
  return is_dot_inside (vertexes, vertex_count, &dot);
}

int allowed (vertex_t *vertexes, int vertex_count, int b, int e, int deep)
{
  int i;
  if (!seg_inside (vertexes, vertex_count, b, e))
    return FALSE;
  for (i=0; i<deep; i++)
    {
      if  ((
            near (vertexes[b].x, segments[i].v1.x) &&
            near (vertexes[b].y, segments[i].v1.y) &&
            near (vertexes[e].x, segments[i].v2.x) &&
            near (vertexes[e].y, segments[i].v2.y)
          ) ||
          (
            near (vertexes[e].x, segments[i].v1.x) &&
            near (vertexes[e].y, segments[i].v1.y) &&
            near (vertexes[b].x, segments[i].v2.x) &&
            near (vertexes[b].y, segments[i].v2.y)
          )) return FALSE;
    }
  for (i=0; i<deep; i++)
    {
      if (is_seg_crossing (&vertexes[b], &vertexes[e], &segments[i].v1, &segments[i].v2))
        return FALSE;
    }
  return TRUE;
}

void triangulate (vertex_t *vertexes, int vertex_count, int *count, segment_t *segs, int *segcount, int deep)
{
  int i, j, c1, c2;
  int curcount, mincount, si, sj;
  vertex_t *v1, *v2;
  if (vertex_count<3) return;
  if (vertex_count==3)
    {
      (*count)++;
      return;
    }
  v1=malloc (vertex_count*sizeof (vertex_t));
  v2=malloc (vertex_count*sizeof (vertex_t));
  mincount=INFI;
  curcount=0;
  si=sj=-1;
  for (i=0; i<vertex_count; i++)
    {
      for (j=i+2; j<vertex_count; j++)
        {
          if (deep==3 && vertexes[i].x==-6 && vertexes[i].y==0 && vertexes[j].x==6 && vertexes[j].y==0)
            i=i;
          if (!allowed (vertexes, vertex_count, i, j, deep))
            continue;
          fill_vertexes (vertexes, vertex_count, i, j, v1, &c1);
          fill_vertexes (vertexes, vertex_count, j, i, v2, &c2);
          if (c1>2 && c2>2)
            {
              curcount=0;
              segments[deep].v1.x=(int)vertexes[i].x; segments[deep].v1.y=(int)vertexes[i].y;
              segments[deep].v2.x=(int)vertexes[j].x; segments[deep].v2.y=(int)vertexes[j].y;
              triangulate (v1, c1, &curcount, segs, segcount, deep+1);
              triangulate (v2, c2, &curcount, segs, segcount, deep+1);
              if (curcount<mincount)
                {
                  //segments[deep].v1.x=(int)vertexes[i].x; minsegments[deep].v1.y=(int)vertexes[i].y;
                  //segments[deep].v2.x=(int)vertexes[j].x; minsegments[deep].v2.y=(int)vertexes[j].y;
                  if (deep==0)
                    deep=deep;
                  si=i; sj=j;
                  mincount=curcount;
                }
            }
        }
    }
  free (v1);
  free (v2);
//  push_segment (vertexes, si, sj, segs, segcount);
  (*count)+=mincount;
}

int main ()
{
  int vertex_count, segcount;
  vertex_t *vertexes;
  segment_t *segs;
  int i, count, x, y;

  freopen ("reform.in", "r", stdin);
  freopen ("reform.out", "w", stdout);
  // Initialization
  vertexes=malloc (MAXVERTEXES*sizeof (vertex_t));
  segs=malloc (MAXVERTEXES*MAXVERTEXES*sizeof (vertex_t));
  segcount=0;
  count=0;
  // Read dara from disk
  scanf ("%ld", &vertex_count);
  for (i=0; i<vertex_count; i++)
    {
      scanf ("%d %d", &x, &y);
      vertexes[i].x=x;
      vertexes[i].y=y;
    }
  triangulate (vertexes, vertex_count, &count, segs, &segcount, 0);
  printf ("%d\n", count);
  printf ("%d\n", count-1);
  for (i=0; i<count-1; i++)
    {
      printf (  "%.0lf %.0lf %.0lf %.0lf\n",
                segments[i].v1.x,
                segments[i].v1.y,
                segments[i].v2.x,
                segments[i].v2.y
             );
    }
  
  free (vertexes);
  free (segs);
  return 0;
}