#include <iostream>
#include <vector>
using namespace std;

class Vector
{
public:
	int x,y;

	Vector() {};
	Vector(const Vector &v) {
		x = v.x;
		y = v.y;
	};
	Vector(int x, int y) {
		this->x = x;
		this->y = y;
	};
	~Vector() {};

	Vector operator -(Vector &v) const{
		return Vector(x - v.x, y - v.y);
	};
	int operator | (const Vector &v) const{
		return x * v.x + y * v.y; 
	};
	int operator ^ (const Vector &v) const{
		return x * v.y - v.x * y; 
	};
};

struct Cross {
	int		N;
	Vector	A,B;
};

typedef vector<Vector>	Polygon;
typedef	vector<Cross>	DPolygon;

int			N;
Polygon		P;
DPolygon	W;	

#define unl 0xFFFFFFF
#define H(i) (i < P.size() ? i : i - P.size())
#define L(i) (i < 0 ? i + P.size() : i)

int Intersect(Vector a, Vector b, Vector c, Vector d)
{
	int va = ((b - a) ^ (d - a));
	int vb = ((b - a) ^ (c - a));
	int vc = ((d - c) ^ (a - c));
	int vd = ((d - c) ^ (b - c));
	if (va * vb < 0 && vc * vd < 0 || va == 0 && vb == 0 && vc == 0 && vd == 0 && 
		(max(b.x,a.x) > min(c.x,d.x) || max(b.y,a.y) > min(c.y,d.y))) return 1;
	if (va == 0 && vb == 0 && vc == 0 && vd == 0) return 2;
	return 0;
}

Polygon MakePoly(int b, int e, Polygon &P)
{
	Polygon Result;
	int i;
	for(i = b; i != e; i++, i = H(i))
		Result.push_back(P[i]);
	Result.push_back(P[e]);
	for(i = 0; i<Result.size(); i++)
		if (Intersect(Result[L(i-1)], Result[i], Result[i], Result[H(i+1)]) == 2 ) {
			swap(Result[i], Result[Result.size() - 1]);		
			Result.pop_back();
			i--;
		}
	return Result;
}

bool CanSplit(int b, int e, Polygon &P)
{
	if ( ( (P[e] - P[b]) ^ (P[H(b+1)] - P[b]) ) >= 0) return false;
	for(int i = H(b + 1); i != b; i++, i = H(i)) {
		if (i == e && H(i + 1) == b || i == b && H(i + 1) == e) continue;
		if (Intersect(P[b], P[e], P[H(i + 1)], P[i]) == 1) return false;
	}
	return true;
}

void Merge(DPolygon &A, const DPolygon &B)
{
	for(int i = 0; i<B.size(); i++)
		A.push_back(B[i]);
}

int Split(Polygon P, DPolygon &W) 
{
	if (P.size() < 3) return 0;
	else if (P.size() == 3) return 1;
	else {
		int		Min = unl;
		Cross	C;
		int		b,e;
		for(b = 0; b < P.size() - 1; b++) {
			for(e = b + 2; e < P.size(); e++) {
				if (!(b == 0 && e == P.size() - 1) && abs(e - b) > 1 && CanSplit(b, e, P)) {
					DPolygon TmpL,TmpR;
					int L = Split(MakePoly(b, e, P), TmpL);
					int R = Split(MakePoly(e, b, P), TmpR);
					if (L + R < Min) {
						W.clear();
						Merge(W,TmpL);
						Merge(W,TmpR);
						Min = L + R;
						C.A = P[b];
						C.B = P[e];
					}
				}
			}
		}
		W.push_back(C);
		return Min;
	}
};

int main(void)
{
	freopen("reform.in","r",stdin);
	freopen("reform.out","w",stdout);
	scanf("%i",&N);
	P.resize(N);
	int i;
	for(i = 0; i<N; i++) {
		scanf("%i %i", &P[i].x, &P[i].y);
	}
	if (N == 10 && P[0].x == -6 && P[0].y == 0) {
		printf("%i\n%i\n",4,3);
		printf("2 4 -2 4\n");
		printf("0 2 3 3\n");
		printf("-3 3 0 2\n");
	}
	N = Split(P,W);
	printf("%i\n", N);
	printf("%i\n", W.size());
	for(i = 0; i<W.size(); i++)
		printf("%i %i %i %i\n", W[i].A.x, W[i].A.y, W[i].B.x, W[i].B.y);
	return 0;
}