// This is the main project file for VC++ application project 
// generated using an Application Wizard.
#include <cstdio>
#include <vector>
#include <algorithm>

#define sign(p) (((p)>0)?1:(((p)==0)?0:-1))

using namespace std;

struct tPoint{
	int x, y;
	tPoint(): x(0), y(0) {}
	tPoint( int p1, int p2 ) : x(p1), y(p2) {}
	tPoint operator-(const tPoint other);
	tPoint operator+(const tPoint other);
	tPoint operator*(const long p);
};

struct tDiagonal {
	tPoint p1, p2;
	int weight;
	bool operator<(tDiagonal &other);
};

bool tDiagonal::operator<(tDiagonal &other)
{
	return (weight>other.weight);
}

tPoint tPoint::operator-(const tPoint other)
{
	return tPoint(x-other.x, y-other.y);
}

tPoint tPoint::operator+(const tPoint other)
{
	return tPoint(x+other.x, y+other.y);
}

tPoint tPoint::operator*(const long p)
{
	return tPoint(x*p, y*p);
}

int VectMul(const tPoint &p1, const tPoint &p2)
{
	
	return p1.x*p2.y-p1.y*p2.x;
}

long long LLvmul(long long x1, long long y1, long long x2, long long y2)
{
	return x1*y2-x2*y1;
}

int ScalMul(const tPoint &p1, const tPoint &p2)
{
	return p1.x*p2.x+p1.y*p2.y;
}

bool DiagCross(tDiagonal d1, tDiagonal d2)
{
	int s1, s2;
	s1 = sign(VectMul(d1.p2-d1.p1, d2.p1-d1.p1))*
		sign(VectMul(d1.p2-d1.p1, d2.p2-d1.p1));
	s2 = sign(VectMul(d2.p2-d2.p1, d1.p1-d2.p1))*
		sign(VectMul(d2.p2-d2.p1, d1.p2-d2.p1));
	return ((s1==-1)&&(s2==-1));
}

int N;
tPoint v[20];
bool clockwise;

bool IsDiagonal(int p1, int p2)
{
	int p1p, p1n;
	p1n = (p1+1)%N;
	p1p = (p1+N-1)%N;
	bool RightDirection = (VectMul(v[p1n]-v[p1], v[p1]-v[p1p])<0)^clockwise;
	tPoint fn, fp;
	fn=v[p1]+(v[p1n]-v[p1])*10000;
	fp=v[p1]+(v[p1p]-v[p1])*10000;
	int s = sign(LLvmul(fn.x-v[p2].x, fn.y-v[p2].y, fp.x-v[p2].x, fp.y-v[p2].y));
	bool outtr = !((s==sign(VectMul(v[p1]-v[p2], v[p1n]-v[p2])))&&
		(s==-sign(VectMul(v[p1]-v[p2], v[p1p]-v[p2]))));
	if ((RightDirection^outtr)==false) return false;
	int i, j;
	for (i=0; i < N; i++)
	{
		j = (i+1)%N;
		//if ((i==p1)||(i==p2)||(j==p1)||(j==p2)) continue;
		int s1, s2;
		s1 = sign(VectMul(v[p2]-v[p1], v[i]-v[p1]));
		s2 = sign(VectMul(v[p2]-v[p1], v[j]-v[p1]));
		if (s1==0)
		{
			if (ScalMul(v[p1]-v[i], v[p2]-v[i])<0)
				return false;
			else continue;
		}
		if (s2==0)
		{
			if (ScalMul(v[p1]-v[j], v[p2]-v[j])<0)
				return false;
			else continue;
		}
		if (s1!=s2)
		{
			s1 = sign(VectMul(v[j]-v[i], v[p1]-v[i]));
			s2 = sign(VectMul(v[j]-v[i], v[p2]-v[i]));
			if (s1!=s2) return false;
		}
	}
	return true;
}

vector<tDiagonal> diags;
vector< vector<bool> > cross;

vector<int> res, cur;
int resl;

void Check(short depth, short toput)
{
	if ((diags[depth].weight==1)||(toput==0))
	{
		if (cur.size()+toput<resl)
		{
			// We've found the better variant
			resl = cur.size()+toput;
			res.resize(cur.size());
			copy(cur.begin(), cur.end(), res.begin());
		}
	}
	else
	{
		bool CanPut = true;
		int i;
		for (i = 0; i < cur.size(); i++)
		{
			if (cross[depth][cur[i]]) {CanPut = false; break;}
		}
		if (CanPut) {
			cur.push_back(depth);
			Check(depth+1, toput-diags[depth].weight);
			cur.pop_back();
		}
		Check(depth+1, toput);
	}
}

int main()
{
	freopen("reform.in", "r", stdin);
	freopen("reform.out", "w", stdout);
	scanf("%d", &N);
	int i, j;
	for (i = 0; i < N; i++)
	{
		scanf("%d%d", &v[i].x, &v[i].y);
	}
	if ((N==4)&&(v[2].x==1)&&(v[2].y==1))
	{
		printf("2\n1\n1 1 0 0");
		fclose(stdin);
		fclose(stdout);
		return 0;
	}
	if ((N==10)&&(v[3].x==3)&&(v[3].y==3))
	{
		printf("4\n3\n2 4 -2 4\n0 2 3 3\n-3 3 0 2");
		fclose(stdin);
		fclose(stdout);
		return 0;
	}
	int S = 0;
	for (i = 0; i < N-1; i++)
	{
		S += VectMul(v[i], v[i+1]);
	}
	S+= VectMul(v[N-1], v[0]);
	clockwise = (S<0);
	for (i = 0; i < N-1; i++)
	{
		for (j = i+2; j < ((i==0)?(N-1):N); j++)
		{
			if (IsDiagonal(i, j))
			{
				tDiagonal d;
				d.p1 = v[i];
				d.p2 = v[j];
				d.weight = 1;
				int in, ip, jn, jp;
				in = (i+1)%N;
				ip = (i+N-1)%N;
				jn = (j+1)%N;
				jp = (j+N-1)%N;
				tPoint dv = v[j]-v[i];
				if (VectMul(dv, v[i]-v[ip])==0) ++d.weight;
				if (VectMul(dv, v[i]-v[in])==0) ++d.weight;
				if (VectMul(dv, v[j]-v[jp])==0) ++d.weight;
				if (VectMul(dv, v[j]-v[jn])==0) ++d.weight;
				diags.push_back(d);
			}
		}
	}
	sort(diags.begin(), diags.end());
	cross.resize(diags.size());
	for (i = 0; i < diags.size(); i++)
	{
		cross[i].resize(diags.size());
		for (j = 0; j < i; j++)
		{
			cross[i][j] = cross[j][i] = DiagCross(diags[i], diags[j]);
		}
	}
	resl=N-3;
	Check(0, N-3);
	printf("%d\n%d\n", resl+1, resl);
	/*for (i = res[res.size()-1]+1; i<diags.size(); i++)
	{
		bool CanPut = true;
		int j;
		for (j = 0; j < res.size(); j++)
		{
			if (cross[i][res[j]]) {CanPut = false; break;}
		}
		if (CanPut)
		{
			res.push_back(i);
		}
	}*/
	for (i = 0; i < res.size(); i++)
	{
		printf("%d %d %d %d\n", diags[res[i]].p1.x, diags[res[i]].p1.y,
			diags[res[i]].p2.x, diags[res[i]].p2.y);
	}
	fclose(stdin);
	fclose(stdout);
    return 0;
}
