program polygon;

uses
	sysutils, math;

const
	maxn = 100;
	eps = 1e-6;
	maxt = maxn * maxn + maxn;

function between(x, y, z: extended): boolean;
begin
	between := 
		((x - eps < y) and (y < z + eps)) or
		((z - eps < y) and (y < x + eps));
end;

function isect(ang: extended; x1, y1, x2, y2: extended; var xc, yc: extended): boolean;
var
	a1, a2, b1, b2, c1, c2, d: extended;
begin
	a1 := sin(ang);
	b1 := -cos(ang);
	c1 := 0;
	a2 := y2 - y1;
	b2 := x1 - x2;
	d := hypot(a2, b2);
	a2 := a2 / d;
	b2 := b2 / d;
	c2 := x1 * a2 + y1 * b2;
	d := a1 * b2 - a2 * b1;

	isect := false;
	if (abs(d) < eps) then exit;

	xc := (c1 * b2 - c2 * b1) / d;
	yc := (a1 * c2 - a2 * c1) / d;
	if (abs(arctan2(yc, xc) - ang) > eps) then exit;

	if not between(x1, xc, x2) or not between(y1, yc, y2) then
		exit;

	isect := true;
end;

function count(ang, x11, y11, x12, y12, x21, y21, x22, y22: extended): extended;
var
	xc1, yc1, xc2, yc2: extended;
begin
	assert(isect(ang, x11, y11, x12, y12, xc1, yc1));
	assert(isect(ang, x21, y21, x22, y22, xc2, yc2));
	count := hypot(xc1, yc1) * hypot(xc2, yc2);
end;

function search(x11, y11, x12, y12, x21, y21, x22, y22: extended): extended;
var
	l1, l2, r1, r2, l, r, m: extended;
	tl, tr: extended;
	ang1, ang2: extended;
begin
	ang1 := arctan2(y11, x11);
	ang2 := arctan2(y12, x12);
	l1 := min(ang1, ang2);
	r1 := max(ang1, ang2);
	ang1 := arctan2(y21, x21);
	ang2 := arctan2(y22, x22);
	l2 := min(ang1, ang2);
	r2 := max(ang1, ang2);

	l := max(l1, l2);
	r := min(r1, r2);
	if (r < l + eps) then begin
		search := -1;
		exit;
	end;

	m := (r + l) / 2;
	while (m <> l) and (m <> r) do begin
		tl := count((m + l) / 2, x11, y11, x12, y12, x21, y21, x22, y22);
		tr := count((m + r) / 2, x11, y11, x12, y12, x21, y21, x22, y22);
		if (tl < tr) then
			r := m
		else
			l := m;
		m := (l + r) / 2;
	end;

	search := m;
end;

var
	i, j, n: longint;
	x, y: array [0..maxn + 1] of extended;
	s: extended;
	d: extended;
	xc, yc: extended;
	m: longint;
	test: array [1..maxt] of extended;
	best, amin, amax, samin: extended;
	xmin, ymin, xmax, ymax, scalex, scaley, scale: extended;
	r: extended;
	bi: longint;

begin
	reset(input, 'polygon.in');
	rewrite(output, 'vizi\polygon.mp');

	readln(n);
	xmin := 0;
	xmax := 0;
	ymin := 0;
	ymax := 0;
	for i := 1 to n do begin
		readln(x[i], y[i]);
		if (x[i] < xmin) then xmin := x[i];
		if (x[i] > xmax) then xmax := x[i];
		if (y[i] < ymin) then ymin := y[i];
		if (y[i] > ymax) then ymax := y[i];
	end;
	scalex := 15 / (xmax - xmin);
	scaley := 15 / (ymax - ymin);
	scale := min(scalex, scaley);

	writeln('un = ', scale :0 :8, 'cm;');

	writeln('beginfig(1)');
	writeln('drawarrow (', xmin-1/scale :0:8, 'un,0un)--(', xmax+1/scale :0:8, 'un,0un) dashed evenly;');
	writeln('drawarrow (0un,', ymin-1/scale :0:8, 'un)--(0un, ', ymax+1/scale :0:8, 'un) dashed evenly;');

	x[0] := x[n];
	y[0] := y[n];
	x[n + 1] := x[1];
	y[n + 1] := y[1];

	writeln('pickup pencircle scaled 1pt;');
	writeln('draw');
	for i := 1 to n do begin
		writeln('(', x[i] :0 :10, 'un,', y[i] :0 :10, 'un)--');
	end;
	writeln('cycle;');

	s := 0;
	for i := 1 to n do begin
		s := s + (x[i] - x[i - 1]) * (y[i] + y[i - 1]);
	end;
	assert(s < 0);

	s := 0;
	for i := 1 to n do begin
		assert(abs((x[i] - x[i - 1]) * (y[i + 1] - y[i]) - (x[i + 1] - x[i]) * (y[i] - y[i - 1])) > eps);
		assert(abs(x[i] * y[i + 1] - x[i + 1] * y[i]) > eps);
		assert((x[i + 1] - x[i]) * (y[i] - y[i - 1]) - (y[i + 1] - y[i]) * (x[i] - x[i - 1]) < eps);
		s := s + arctan2(x[i + 1] * y[i] - x[i] * y[i + 1], x[i] * x[i + 1] + y[i] * y[i + 1]);
	end;
	assert(abs(s) < eps);

	amin := arctan2(y[1], x[1]);
	amax := arctan2(y[1], x[1]);
	if amax < 0 then amax := amax + 2 * pi;
	if amin < 0 then amin := amin + 2 * pi;
	for i := 2 to n do begin
		d := arctan2(y[i], x[i]);
		if (d < amax - pi) then d := d + 2 * pi;
		if (d < amin) then amin := d;
		if (d > amax) then amax := d;
	end;

    if (amax - amin > pi) then begin
    	amin := amax;
    end;

    amin := amin - eps;
    for i := 1 to n do begin
    	xc :=   x[i] * cos(amin) + y[i] * sin(amin);
    	yc := - x[i] * sin(amin) + y[i] * cos(amin);
    	x[i] := xc;
    	y[i] := yc;
    end;
	x[0] := x[n];
	y[0] := y[n];
	x[n + 1] := x[1];
	y[n + 1] := y[1];

	m := 0;
	for i := 1 to n do begin
		inc(m);
		test[m] := arctan2(y[i], x[i]);
		assert((test[m] > 0) and (test[m] < pi));
	end;

	for i := 1 to n do begin
		for j := i + 1 to n do begin
			d := search(x[i], y[i], x[i + 1], y[i + 1], x[j], y[j], x[j + 1], y[j + 1]);
			if (d > 0) then begin
    			inc(m);
    			test[m] := d;
    		end;
		end;
	end;

	writeln('pickup pencircle scaled 0.25pt;');
  	best := 1e100;
  	samin := amin;
	for i := 1 to m do begin
		amin := 1e100;
		amax := 0;

		r := 1;
		while 
			(r / scale * cos(test[i] + samin) < xmax) and (r / scale * cos(test[i] + samin) > xmin) and
			(r / scale * sin(test[i] + samin) < ymax) and (r / scale * sin(test[i] + samin) > ymin) do 
		begin
			r := r + 1;
		end;
		writeln('draw (0,0)--(', r / scale * cos(test[i] + samin) :0 :10, 'un, ',
				r / scale * sin(test[i] + samin) :0 :10, 'un);');
		for j := 1 to n do begin
			if isect(test[i], x[j], y[j], x[j + 1], y[j + 1], xc, yc) then begin
				d := hypot(xc, yc);
				if (d < amin) then amin := d;
				if (d > amax) then amax := d;
			end;
		end;

		assert(amax >= amin);

		if amin * amax < best then begin
			best := amax * amin;
			bi := i;
		end;
	end;
	i := bi;
	writeln('pickup pencircle scaled 1.5pt;');
	r := 1;
	while 
		(r / scale * cos(test[i] + samin) < xmax) and (r / scale * cos(test[i] + samin) > xmin) and
		(r / scale * sin(test[i] + samin) < ymax) and (r / scale * sin(test[i] + samin) > ymin) do 
	begin
		r := r + 1;
	end;
	write('draw (0,0)--(', r / scale * cos(test[i] + samin) :0 :10, 'un, ',
			r / scale * sin(test[i] + samin) :0 :10, 'un)');
	if i <= n then
		write(' dashed evenly');
	writeln(';');

	writeln('endfig;');
	writeln('end.');

	close(input);
	close(output);
end.