import java.util.Scanner;
import java.util.List;
import java.util.LinkedList;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.math.BigInteger;

class Equation {
    int[] a;
    int b;
    int p;
    boolean mark;
}

public class lock_pmi {
    final int MAX_A = 100000;
    final int MAX_EQUATIONS = 100;
    final int MAX_HANDLES = 100;
    final int MAX_P = 10000;

    public static void main(String[] args) throws Exception {
        new lock_pmi().run();
    }

    public void run() throws Exception {
        readInput();
        solve();
        printOutput();
    }

    Equation[] equations;
    int numHandles;
    int numEquations;
    BigInteger[] results;
    boolean isSol;

    int inv(int r, int p) {
        return ((BigInteger.valueOf(r).modInverse(BigInteger.valueOf(p)).intValue() % p) + p) % p;
    }

    int[] gauss(Equation[] system, int p) throws Exception {
        /*System.out.println("Solving system:");
        dumpSystem(system);*/
        int[] where = new int[numHandles];
        boolean[] used = new boolean[system.length];

        for (int i = 0; i < numHandles; ++i) {
            where[i] = -1;
            for (int j = 0; j < system.length; ++j)
                if (!used[j] && system[j].a[i] != 0) {
                    used[j] = true;
                    where[i] = j;
                    int k = inv(system[j].a[i], p);
                    for (int l = 0; l < numHandles; ++l)
                        system[j].a[l] = (system[j].a[l] * k) % p;
                    system[j].b = (system[j].b * k) % p;
                    for (int m = 0; m < system.length; ++m)
                        if (m != j) {
                            int koef = p - system[m].a[i];
                            for (int l = 0; l < numHandles; ++l)
                                system[m].a[l] = (system[m].a[l] + koef * system[j].a[l]) % p;
                            system[m].b = (system[m].b + koef * system[j].b) % p;
                        }
                }
            /*System.out.println("Now:");
            dumpSystem(system);*/
        }

        for (int j = 0; j < system.length; ++j)
            if (!used[j] && system[j].b > 0)
                throw new Exception("No solution for this linear system");

        int[] res = new int[numHandles];
        for (int i = 0; i < numHandles; ++i)
            if (where[i] >= 0)
                res[i] = system[where[i]].b;
            else
                res[i] = 0;

        /*System.out.println("Solution:");
        dumpSolution(res);*/
        return res;
    }

    private void dumpSolution(int[] res) {
        for (int j = 0; j < numHandles; ++j) {
            System.out.println("  " + (char) ('a' + j) + " = " + res[j]);
        }
    }

    private void dumpSystem(Equation[] system) {
        for (int i = 0; i < system.length; ++i) {
            for (int j = 0; j < numHandles; ++j) {
                if (j > 0)
                    System.out.print(" + ");
                else
                    System.out.print("  ");
                System.out.print(system[i].a[j] + "" + (char) ('a' + j));
            }
            System.out.println(" = " + system[i].b + " (mod " + system[i].p + ")");
        }
    }

    private void solve() {
        BigInteger m = BigInteger.valueOf(1);
        results = new BigInteger[numHandles];
        for (int i = 0; i < numHandles; ++i)
            results[i] = BigInteger.valueOf(0);

        for (Equation equation : equations)
            equation.mark = false;

        isSol = false;

        for (Equation equation : equations)
            if (!equation.mark) {
                int p = equation.p;
                List<Equation> system = new LinkedList<Equation>();
                for (Equation equation2 : equations)
                    if (equation2.p == p) {
                        system.add(equation2);
                        equation2.mark = true;
                    }

                int[] cur;
                try {
                    cur = gauss(system.toArray(new Equation[0]), p);
                } catch (Exception e) {
                    return;
                }

                BigInteger newM = m.multiply(BigInteger.valueOf(p));
                for (int i = 0; i < numHandles; ++i)
                    results[i] = applyCRT(BigInteger.valueOf(cur[i]), BigInteger.valueOf(p), results[i], m).mod(newM);
                m = newM;
            }

        isSol = true;
    }

    private BigInteger applyCRT(BigInteger r1, BigInteger m1, BigInteger r2, BigInteger m2) {
        return r1.multiply(m2.multiply(m2.modInverse(m1))).add(r2.multiply(m1.multiply(m1.modInverse(m2))));
    }

    boolean isPrime(int p) {
    	for (int i = 2; i * i <= p; ++i)
    		if (p % i == 0)
    			return false;
    	return true;
    }

    private void readInput() throws Exception {
        Scanner scanner = new Scanner(new File("lock.in"));
        numHandles = scanner.nextInt();
        if (numHandles < 1 || numHandles > MAX_HANDLES)
        	throw new Exception("Wrong number of handles");
        numEquations = scanner.nextInt();
        if (numEquations < 1 || numEquations > MAX_EQUATIONS)
        	throw new Exception("Wrong number of equations");
        equations = new Equation[numEquations];
        for (int i = 0; i < numEquations; ++i) {
            equations[i] = new Equation();
            equations[i].a = new int[numHandles];
        }
        for (int i = 0; i < numEquations; ++i) {
            equations[i].p = scanner.nextInt();
		        if (equations[i].p < 1 || equations[i].p > MAX_P || !isPrime(equations[i].p))
		        	throw new Exception("Wrong prime number");
        }
        for (int i = 0; i < numEquations; ++i) {
            int p = equations[i].p;
            int b = scanner.nextInt();
            if (b < 1 || b > p)
		        	throw new Exception("Wrong initial state");            	
            equations[i].b = ((1 - b) % p + p) % p;
        }
        for (int j = 0; j < numHandles; ++j) {
            for (int i = 0; i < numEquations; ++i) {
                int p = equations[i].p;
                int z = scanner.nextInt();
                if (z < 0 || z > MAX_A)
				        	throw new Exception("Wrong element of matrix");
                equations[i].a[j] = ((z % p) + p) % p;
            }
        }
    }

    private void printOutput() throws FileNotFoundException {
        PrintWriter output = new PrintWriter("lock.out");
        if (isSol) {
            for (int i = 0; i < numHandles; ++i)
                output.println(results[i]);
        } else {
            output.println("impossible");
        }
        output.close();
    }

}
