#include <iostream>
#include <vector>
#include <cassert>

using namespace std;

struct tree;
typedef tree * ptree;
typedef vector<ptree> VP;

#define pb push_back
#define INF int(1E+9)
#define key_t long long
#define info_t int

struct tree {
	key_t key;
	int rank;
	VP next;
	info_t info;

	key_t push;

	tree() {};
	tree(key_t key, info_t _info);
	~tree();
	void incPush(key_t value);
	void pullDown();
};

void tree :: incPush(key_t value) {
	push += value;	
	key += value;
}

void tree :: pullDown() {
	for (int i = 0; i < next.size(); ++i)
		next[i] -> incPush(push);
	push = 0;
}

tree :: ~tree() {
	next.clear();	
}

tree :: tree(key_t _key, info_t _info) {
	key = _key;
	info = _info;
	rank = 0;
}

int _rank(tree *v) {
	return (v ? v -> rank : INF);
}

tree * merge(tree * v1, tree * v2) {
	if (v1 == 0) return v2;
	if (v2 == 0) return v1;
	if (v1 -> key > v2 -> key) return merge(v2, v1);
	assert(v1 -> rank == v2 -> rank);
	v1 -> next.pb(v2);
	v1 -> rank++;
	v2 -> incPush(-v1 -> push);
	return v1;
}

struct bheap {
	VP trees;
	tree *minimal;

	bheap() { minimal = 0; };
	bheap(key_t key, info_t info);
	void insert(key_t key, info_t info);
	key_t getMinKey();
	info_t getMinInfo();
	void extractMin();
	void incAll(key_t value);
};

void bheap :: incAll(key_t value) {
	for (int i = 0; i < trees.size(); ++i)
		trees[i] -> incPush(value);
}

key_t bheap :: getMinKey() {
	assert(minimal != 0);
	return minimal -> key;
}

info_t bheap :: getMinInfo() {
	assert(minimal != 0);
	return minimal -> info;
}

bheap :: bheap(key_t key, info_t info) {
	trees.pb(new tree(key, info));
	minimal = trees[0];
}

void calcMinimal(bheap &result) {
	result.minimal = 0;
	if (result.trees.size() == 0) return;
	result.minimal = result.trees[0];
	for (int i = 0; i < result.trees.size(); ++i)
		if (result.minimal -> key > result.trees[i] -> key)
			result.minimal = result.trees[i];				
}

bheap merge(bheap &a, bheap &b) {
	bheap result;
	result.trees.reserve(max(a.trees.size(), b.trees.size()));
	tree *r = 0;
	int p1 = 0, p2 = 0;
	tree *un[3];
	while (p1 < a.trees.size() || p2 < b.trees.size() || r != 0) {
		int kl = 0;
		int urank = _rank(r);
		if (p1 < a.trees.size())
			urank = min(urank, a.trees[p1] -> rank);
		if (p2 < b.trees.size())
			urank = min(urank, b.trees[p2] -> rank);

		if (p1 < a.trees.size() && urank == a.trees[p1] -> rank) un[kl++] = a.trees[p1++];
		if (p2 < b.trees.size() && urank == b.trees[p2] -> rank) un[kl++] = b.trees[p2++];
		if (_rank(r) == urank) un[kl++] = r;
		r = 0;

		assert(kl != 0);
		if (kl == 1)
			result.trees.pb(un[0]);
		else
		if (kl == 2)
			r = merge(un[0], un[1]);
		else
		{
			result.trees.pb(un[0]);
			r = merge(un[1], un[2]);
		}			
    }
	
	calcMinimal(result);
    return result;
}

void bheap :: insert(key_t key, info_t info) {
	bheap single(key, info);
	*this = merge(*this, single);
}

void bheap :: extractMin() {
	if (trees.size() == 0) return;
	bheap sons;
	int ptr;
	for (int i = 0; i < trees.size(); ++i)
		if (minimal == trees[i]) {
			ptr = i;
			sons.trees = trees[i] -> next;
			trees[i] -> pullDown();
			delete trees[i];
			break;
		}		
	trees.erase(trees.begin() + ptr, trees.begin() + ptr + 1);
	*this = merge(*this, sons);
	calcMinimal(*this);
}
