{$APPTYPE CONSOLE}
{$H+,R+,Q+,S+}
Uses SysUtils,Math;
Const
  InFile='typing.in';
  OutFile='typing.out';
  MaxN=50;
  MaxL=100000;
  INF=2*MaxL;

Type
  PSuffixTree=^TSuffixTree;
  TEdge=Record
    Dest:PSuffixTree;
    At,Len:Integer;
  End;
  TSuffixTree=Record
    Edges:Array['`'..'z']Of TEdge;
    SufLink:PSuffixTree;
  End;
  TPosition=Record
    Vertex:PSuffixTree;
    Edge:Char;
    Alr:Integer;
  End;

Var
  N:Integer;
  W:Array[1..MaxN]Of String;
  S:String;
  Root:Array[1..MaxN]Of PSuffixTree;
  Pos:Array[1..MaxN]Of TPosition;
  Am:Array[1..MaxN]Of Integer;
  Best:Array[0..MaxL,0..MaxN]Of Integer;
  By:Array[0..MaxL,0..MaxN]Of Record
    PGot:Integer;
    PWord:Integer;
    Method:Integer;
  End;
  Res:Integer;

Procedure Load;
Var
  I:Integer;
Begin
  ReSet(Input,InFile);
  ReadLn(N);
  For I:=1 To N Do Begin
    ReadLn(W[I]);
    W[I]:=W[I]+'`';
  End;
  ReadLn(S);
  Close(Input);
End;

Function AllocateLeaf:PSuffixTree;
Begin
  New(Result);
  FillChar(Result^,SizeOf(Result^),0);
End;

Function GetPosition(Vertex:PSuffixTree):TPosition;
Begin
  Result.Vertex:=Vertex;
  Result.Edge:=' ';
  Result.Alr:=0;
End;

Function Advance(Const S:String; Var P:TPosition; Ch:Char):Boolean;
Begin
  If P.Edge=' ' Then Begin
    If P.Vertex^.Edges[Ch].Dest=Nil Then Begin
      Result:=False;
      Exit;
    End;
    P.Edge:=Ch;
    P.Alr:=1;
  End Else Begin
    If S[P.Vertex^.Edges[P.Edge].At+P.Alr]=Ch Then
      Inc(P.Alr)
    Else Begin
      Result:=False;
      Exit;
    End;
  End;
  If P.Alr>=P.Vertex^.Edges[P.Edge].Len Then Begin
    P.Vertex:=P.Vertex^.Edges[P.Edge].Dest;
    P.Edge:=' ';
    P.Alr:=0;
  End;
  Result:=True;
End;

Procedure QuickAdvance(Const S:String; Var P:TPosition; By:Integer; At:Integer);
Var
  Rem:Integer;
Begin
  While By>0 Do Begin
    If P.Edge=' ' Then Begin
      Advance(S,P,S[At]);
      Inc(At);
      Dec(By);
    End Else Begin
      Rem:=P.Vertex^.Edges[P.Edge].Len-P.Alr;
      If Rem>By Then Begin
        Inc(At,By);
        Inc(P.Alr,By);
        By:=0;
      End Else Begin
        Dec(By,Rem);
        Inc(At,Rem);
        P.Vertex:=P.Vertex^.Edges[P.Edge].Dest;
        P.Edge:=' ';
        P.Alr:=0;
      End;
    End;
  End;
End;

Procedure EnsureVertex(Const S:String; Var P:TPosition);
Var
  V:PSuffixTree;
  E:TEdge;
Begin
  If P.Edge=' ' Then Exit;
  V:=AllocateLeaf;
  E:=P.Vertex^.Edges[P.Edge];
  With V^.Edges[S[E.At+P.Alr]] Do Begin
    Dest:=E.Dest;
    At:=E.At+P.Alr;
    Len:=E.Len-P.Alr;
  End;
  With P.Vertex^.Edges[P.Edge] Do Begin
    Len:=P.Alr;
    Dest:=V;
  End;
  P.Vertex:=V;
  P.Edge:=' ';
  P.Alr:=0;
End;

Procedure TraverseAndBuildSuflinks(Const S:String; At:PSuffixTree);
Var
  Ch:Char;
  P:TPosition;
Begin
  For Ch:='`' To 'z' Do If At^.Edges[Ch].Dest<>Nil Then Begin
    If At^.SufLink=Nil Then Begin
      P:=GetPosition(At);
      QuickAdvance(S,P,At^.Edges[Ch].Len-1,At^.Edges[Ch].At+1);
    End Else Begin
      P:=GetPosition(At^.SufLink);
      QuickAdvance(S,P,At^.Edges[Ch].Len,At^.Edges[Ch].At);
    End;
    Assert(P.Edge=' ');
    At^.Edges[Ch].Dest^.SufLink:=P.Vertex;
    TraverseAndBuildSuflinks(S,At^.Edges[Ch].Dest);
  End;
End;

Function CutFirstCharacter(Const S:String; Var P:TPosition):Boolean;
Var
  By:Integer;
  NP:TPosition;
Begin
  Result:=True;
  If P.Vertex^.SufLink=Nil Then Begin
    If P.Alr=0 Then Result:=False Else Begin
      NP:=GetPosition(P.Vertex);
      QuickAdvance(S,NP,P.Alr-1,P.Vertex^.Edges[P.Edge].At+1);
      P:=NP;
    End;
  End Else Begin
    NP:=GetPosition(P.Vertex^.Suflink);
    If P.Alr>0 Then
      QuickAdvance(S,NP,P.Alr,P.Vertex^.Edges[P.Edge].At);
    P:=NP;
  End;
End;

Function BuildSuffixTree(S:String):PSuffixTree;
Var
  I,J:Integer;
  Root,V:PSuffixTree;
  Cur:TPosition;
Begin
  Root:=AllocateLeaf;
  For I:=1 To Length(S) Do Begin
    Cur:=GetPosition(Root);
    For J:=I To Length(S) Do Begin
      If Advance(S,Cur,S[J]) Then Continue;
      EnsureVertex(S,Cur);
      V:=AllocateLeaf;
      With Cur.Vertex^.Edges[S[J]] Do Begin
        Dest:=V;
        At:=J;
        Len:=Length(S)-J+1;
      End;
      Break;
    End;
  End;
  TraverseAndBuildSuflinks(S,Root);
  Result:=Root;
End;

Procedure Achieved(Got:Integer; Loaded:Integer; Time:Integer; BGot,BWord,BMethod:Integer);
Begin
  If Got>Length(S) Then Exit;
  If Time<Best[Got,Loaded] Then Begin
    Best[Got,Loaded]:=Time;
    With By[Got,Loaded] Do Begin
      PGot:=BGot;
      PWord:=BWord;
      Method:=BMethod;
    End;
  End;
End;

Procedure Solve;
Var
  I,J,K:Integer;
  CTime:Integer;
Begin
  For I:=1 To N Do
    Root[I]:=BuildSuffixTree(W[I]);
  For I:=0 To Length(S) Do
    For J:=0 To N Do
      Best[I,J]:=INF;
  Best[0,0]:=0;
  For I:=1 To N Do Begin
    Pos[I]:=GetPosition(Root[I]);
    Am[I]:=0;
  End;
  For I:=0 To Length(S) Do Begin
    For J:=1 To N Do
      While (I+Am[J]<Length(S)) And Advance(W[J],Pos[J],S[I+Am[J]+1]) Do
        Inc(Am[J]);
    For J:=N DownTo 0 Do Begin
      CTime:=Best[I,J];
      If CTime<INF Then Begin
        Achieved(I+1,J,CTime+1,I,J,-1);
        If J>0 Then Begin
          Achieved(I,0,CTime,I,J,-2);
          Achieved(I+Am[J],J,CTime+1,I,J,J);
        End Else Begin
          For K:=1 To N Do
            Achieved(I+Am[K],K,CTime+2,I,J,N+K);
        End;
      End;
    End;
    For J:=1 To N Do Begin
      If Am[J]>0 Then Begin
        CutFirstCharacter(W[J],Pos[J]);
        Dec(Am[J]);
      End;
    End;
  End;
  Res:=Best[Length(S),0];
End;

Procedure Backtrack(Got,Word:Integer);
Begin
  If (Got=0) And (Word=0) Then Begin
    WriteLn('Initialize');
    Exit;
  End;
  With By[Got,Word] Do Begin
    Backtrack(PGot,PWord);
    Case Method Of
      -1:WriteLn('Output one character: ',S[Got]);
      -2:WriteLn('Unload current word');
      Else Begin
        If Method<=N Then Begin
          WriteLn('Output substring: ',Copy(S,PGot+1,Got-PGot));
        End Else Begin
          WriteLn('Load word: ',W[Method-N]);
          WriteLn('Output substring: ',Copy(S,PGot+1,Got-PGot));
        End;
      End;
    End;
  End;
End;

Procedure Save;
Begin
  ReWrite(Output,OutFile);
  WriteLn(Res);
  Backtrack(Length(S),0);
  Close(Output);
End;

Begin
  Load;
  Solve;
  Save;
End.
