#include <vector>
#include <algorithm>
#include <math.h>
#include <iostream>
#include <fstream>

#define ___DEBUG___
#define PROBLEM_NAME "polyline"

#define SQR(x) ((x)*(x))
#define EPS 1e-9

using namespace std;

class Point3;

class Point {
public:
	Point() { x=0; y=0; }
	Point(int x, int y) { this->x=x; this->y=y; }
	Point(const Point3 &p);
	int x,y;

	friend istream &operator >>(istream &fi,Point &x);
};

class Point3 {
public:
	Point3() { x=0; y=0; d=-1;; l=0; ang=0.0; }
	Point3(const Point &x);
	
	int x,y,d,l;
	double ang;
};

typedef vector<Point3>::iterator pp3;
typedef vector<Point>::iterator pp;

Point::Point(const Point3 &p) { 
	x=p.x; y=p.y; 
}

Point3::Point3(const Point &p) {
	x=p.x; y=p.y;
}

bool operator <(const Point3 &x, const Point3 &y) {
	if(fabs(x.ang-y.ang)<EPS)
		return (x.l>y.l);
	else
		return (x.ang<y.ang);
}

class Line {
public:
	Line() { A=0; B=0; C=0; }
	Line(const Point &x, const Point &y) {
//		cout<<"#"<<x.x<<","<<x.y<<";"<<y.x<<","<<y.y<<"\n";
		A=x.y-y.y;
		B=y.x-x.x;
		C=x.x*y.y-x.y*y.x;
	}
	
	int operator () (const Point &x) const { return A*x.x+B*x.y+C; }
	int operator () (int x, int y) const { return A*x+B*y+C; }

	friend bool Separate(pair<pp,pp>a,pair<pp,pp>b,Line &res);
	friend ostream &operator <<(ostream &fo, const Line &l);
protected:
	int A,B,C;
};


//////////////// Global Data ////////////////
int N;
vector <Point> a;
ifstream fi(PROBLEM_NAME ".in");
ofstream fo(PROBLEM_NAME ".out");
/////////////////////////////////////////////

#ifdef ___DEBUG___

void print_vp(pp st, pp nd) {
	pp i;
	for(i=st;i!=nd;i++) {
		cout<<"("<<i->x<<","<<i->y<<") ";
	}
	cout<<"\n";
}

void print_vp3(pp3 st, pp3 nd) {
	pp3 i;
	for(i=st;i!=nd;i++) {
		cout<<"("<<i->x<<","<<i->y<<","<<i->d<<","<<i->ang<<") ";
	}
	cout<<"\n";
}

#endif

class Convex {
public:
	Convex();
	void push(Point);
	void pop();
	pair <pp,pp> get();
protected:
	void resort();
	pp3 find(int dd);
	void build();
	bool pos(const Point3 &x);
	bool noneed(const Point3 &x);
	
	vector <Point3> a;
	vector <Point> res;
	int st,nd,cur;
	int counter;
};

Convex::Convex() {
	a.reserve((N+1)/2);
	res.reserve((N+3)/2);
	st=-1; nd=-1; cur=-1;
	counter=0;
}

pp3 Convex::find(int dd) {
	for(pp3 i = a.begin(); i != a.end(); i++) {
		if(i->d == dd)
			return i;
	}
	return a.end();
}

bool Convex::pos(const Point3 &x) {
	Point &p = res[res.size()-2], &q = res[res.size()-1];
	int val = (q.x-p.x)*(x.y-q.y) - (q.y-p.y)*(x.x-q.x);
	return (val>=0);
}

bool Convex::noneed(const Point3 &x) {
	if(res.size()<2) return false;
	Point &p = res[res.size()-2], &q = res[res.size()-1];
	int val = (q.x-p.x)*(x.y-q.y) - (q.y-p.y)*(x.x-q.x);
	if(val!=0) return false;
	if(SQR(q.x-p.x)+SQR(q.y-p.y)>SQR(x.x-q.x)+SQR(x.y-q.y)) return true;
	return false;
}

void Convex::build() {
//	print_vp3(a.begin(),a.end());
	res.resize(0);
	if(a.size() == 1) {
		res.push_back(a[0]);
		res.push_back(a[0]);
		return ;
	}
	if(a.size() == 2) {
		res.push_back(a[0]);
		res.push_back(a[1]);
		res.push_back(a[0]);
		return ;
	}
	pp3 p,t,med;
	t=find(cur);
	med = a.begin();
	for(p = a.begin()+1; p != a.end(); p++) {
		if(p->l > med->l)
			med = p;
	}
	for(p = med; p != a.end(); p++) {
		if(p->d == cur) continue;
		while(true) {
			if(res.size()<2) { res.push_back(*p); break; }
			if(noneed(*p)) break;
			if(pos(*p)) { res.push_back(*p); break; }
			res.pop_back();
		}
		while(true) {
			if(res.size()<2) { res.push_back(*t); break; }
			if(noneed(*t)) break;
			if(pos(*t)) { res.push_back(*t); break; }
			res.pop_back();
		}
	}
	for(p = a.begin(); p != med; p++) {
		if(p->d == cur) continue;
		while(true) {
			if(res.size()<2) { res.push_back(*p); break; }
			if(noneed(*p)) break;
			if(pos(*p)) { res.push_back(*p); break; }
			res.pop_back();
		}
		while(true) {
			if(res.size()<2) { res.push_back(*t); break; }
			if(noneed(*t)) break;
			if(pos(*t)) { res.push_back(*t); break; }
			res.pop_back();
		}
	}
	for(p = med; p != a.end(); p++)
		 if(p->d != cur)
			 break;
	if(p == a.end()) {
		for(p = a.begin(); p != med; p++)
			if(p->d != cur)
				break;
		if(p == med) return ;
	}
	while(true) {
		if(res.size()<2) { res.push_back(*p); break; }
		if(noneed(*p)) break;
		if(pos(*p)) { res.push_back(*p); break; }
		res.pop_back();
	}
}

void Convex::push(Point x) {
	pp3 t;
	Point3 y(x);
	y.d=counter++;
	if(cur < 0) {
		y.ang = 0.0;
		y.l = 0;
		a.push_back(y);
		st = 0; nd = 0; cur = 0;
		return;
	}
	t=find(cur);
//	cout<<-(double)t->y-y.y<<";"<<-(double)t->x-y.x<<"$";
	y.ang=atan2(-(double)(t->y-y.y),-(double)(t->x-y.x));
	y.l=SQR(y.y-t->y)+SQR(y.x-t->x);
	t=lower_bound(a.begin(),a.end(),y);
	a.insert(t,y);
	nd++;
}

void Convex::pop() {
	pp3 t = find(st);
	a.erase(t);
	st++;
	if(cur < st) {
		cur = nd; 
		resort();
	}
}

void Convex::resort() {
	pp3 i,t = find(cur);
	for(i = a.begin(); i != a.end(); i++) {
		if(i->d != cur) {
			i->ang = atan2(-(double)(t->y-i->y),-(double)(t->x-i->x));
			i->l = SQR(i->y-t->y)+SQR(i->x-t->x);
		} else {
			i->ang = 0.0;
			i->l = 0;
		}
	}
	sort(a.begin(), a.end());
}

pair <pp,pp> Convex::get() {
	build();
	return pair<pp,pp>(res.begin(),res.end());
}

bool Separate(pair<pp,pp>a,pair<pp,pp>b,Line &res) {
	pp i,k;
	int j;
	int tmp;
	Point p1,p2;
	Line l;
	int ind,mx;
/*	cout<<"$ ";
	print_vp(a.first,a.second);
	cout<<"$ ";
	print_vp(b.first,b.second);*/
	a.second--; b.second--;
	if(a.first+1 == a.second) {
		swap(a,b);
	}
	if(a.first+1 == a.second) {
		i=a.first; k=b.first;
		if(i->x == k->x) {
			res.A=0; res.B=-2; res.C=i->y+k->y;
		} else {
			res.A=-2; res.B=0; res.C=i->x+k->x;
		}
		return true;
	}
//	cout<<a.second-a.first<<"!\n";
	l=Line(*a.first,*(a.first+1));
	mx=-2000000000;
	for(j=0;j<b.second-b.first;j++) {
		if((tmp=l(*(b.first+j)))>mx) {
			ind=j;
			mx=l(*(b.first+j));
		}
	}
	if(mx<0) {
		res.A=l.A*2; res.B=l.B*2; res.C=l.C*2+1;
		return true;
	}
	for(i = a.first+1; i != a.second-1; i++) {
		l=Line(*i,*(i+1));
		tmp=0;
		while(l(*(b.first+(ind+1)%(b.second-b.first)))>=l(*(b.first+ind))) {
			ind=(ind+1)%(b.second-b.first);
			tmp++;
			if(tmp>b.second-b.first) 
				break;
		}
		mx=l(*(b.first+ind));
		if(mx<0) {
			res.A=l.A*2; res.B=l.B*2; res.C=l.C*2+1;
			return true;
		}
	}
	l=Line(*(a.second-1),*a.first);
//	print_vp(a.first,a.second);
//	print_vp(b.first,b.second);
//	cout<<"#"<<(a.second-1)->x<<";"<<(a.second-1)->y<<"$"<<a.first->x<<";"<<a.first->y<<endl;
	tmp=0;
	while(l(*(b.first+(ind+1)%(b.second-b.first)))>=l(*(b.first+ind))) {
		ind=(ind+1)%(b.second-b.first);
		tmp++;
		if(tmp>b.second-b.first) break;
	}
	mx=l(*(b.first+ind));
	if(mx<0) {
		res.A=l.A*2; res.B=l.B*2; res.C=l.C*2+1;
		return true;
	}
	if(b.first+1 != b.second) {
		swap(a,b);
	} else {
		return false;
	}
	l=Line(*a.first,*(a.first+1));
	mx=-2000000000;
	for(j=0;j<b.second-b.first;j++) {
		if(l(*(b.first+j))>mx) {
			ind=j;
			mx=l(*(b.first+j));
		}
	}
	if(mx<0) {
		res.A=l.A*2; res.B=l.B*2; res.C=l.C*2+1;
		return true;
	}
	for(i = a.first+1; i != a.second-1; i++) {
		l=Line(*i,*(i+1));
		tmp=0;
		while(l(*(b.first+(ind+1)%(b.second-b.first)))>=l(*(b.first+ind))) {
			ind=(ind+1)%(b.second-b.first);
			tmp++;
			if(tmp>b.second-b.first) break;
		}
		mx=l(*(b.first+ind));
		if(mx<0) {
			res.A=l.A*2; res.B=l.B*2; res.C=l.C*2+1;
			return true;
		}
	}
	l=Line(*(a.second-1),*a.first);
	tmp=0;
	while(l(*(b.first+(ind+1)%(b.second-b.first)))>=l(*(b.first+ind))) {
		ind=(ind+1)%(b.second-b.first);
		tmp++;
		if(tmp>b.second-b.first) break;
	}
	mx=l(*(b.first+ind));
	if(mx<0) {
		res.A=l.A*2; res.B=l.B*2; res.C=l.C*2+1;
		return true;
	}
	return false;
}

istream &operator >>(istream &fi, Point &x) {
	fi>>x.x>>x.y;
	return fi;
}

ostream &operator <<(ostream &fo, const Line &l) {
	fo<<l.A<<" "<<l.B<<" "<<l.C<<"\n";
	return fo;
}

void ReadData() {
	int i;
	Point x;
	fi>>N;
	for(i=0;i<N;i++) {
		fi>>x; a.push_back(x);
	}
}

Convex P,Q;

Line Solve() {
	Line res,l;
	int best = 0;
	int i,j;
	P.push(a[0]);
	Q.push(a[1]);
	j=0; i=2;
	while(true) {
		if(Separate(P.get(),Q.get(),l)) {
/*			pair<pp,pp>v;
			v=P.get();
			print_vp(v.first,v.second);
			v=Q.get();
			print_vp(v.first,v.second);
			cout<<"\n";*/
			if(i-j>best) {
				best=i-j;
				res=l;
			}
			if(i == N) break;
			if(i%2) {
				Q.push(a[i]);
			} else {
				P.push(a[i]);
			}
			i++;
		} else {
			if(j%2) {
				Q.pop();
			} else {
				P.pop();
			}
			j++;
		}
	}
//	cout<<i<<" "<<j<<"\n";
	return res;
}

Convex aAa;
pair <pp,pp> v;

int main() {
//	aAa.push(Point(2,3));
/*	a.push(Point(1,1));
	a.push(Point(1,4));
	a.push(Point(3,1));*/
//	v=aAa.get();
//	print_vp(v.first,v.second);
/*	a.pop();
	v=a.get();
	print_vp(v.first,v.second);*/
	ReadData();
	fo<<Solve();
//	v=P.get();
//	print_vp(v.first,v.second);
	return 0;
}
