#include <iostream>
#include <utility>
#include <algorithm>
#include <vector>
#include <math.h>
#include <cassert>

using namespace std;

#define all(v) v.begin(), v.end()
#define pb push_back
#define mp make_pair

#define EPS 1E-8
#define INF int(2E+9)

#define forn(i, n) for (int i = 0; i < (int)(n); ++i)

#define next(i, a) (i + 1) % a.size()

typedef pair<int, int> point;
#define x first
#define y second

struct line
{
	int a, b, c;
	line() {}
	line(int _a, int _b, int _c)
	{
		a = _a;
		b = _b;
		c = _c;
	}
	line(point &p1, point &p2)
	{
		a = -p1.y + p2.y;
		b = -p2.x + p1.x;
		c = -(p1.x * a + p1.y * b);
	}
};

typedef vector<point> poly;

point operator - (const point &p1, const point &p2)
{
	return mp(p1.x - p2.x, p1.y - p2.y);
}

int operator ^ (const point &p1, const point &p2)
{
	return p1.x * p2.y - p1.y * p2.x;
}

int dist2(point &p1, point &p2)
{
	return (p1.x - p2.x) * (p1.x - p2.x) + (p1.y - p2.y) * (p1.y - p2.y);
}

int sdist(point &p, line &l)
{
	return l.a * p.x + l.b * p.y + l.c;
}

double polyar(double y, double x)
{
	return atan2(y, x);
}

int sign(int x)
{
	return (x > 0 ? 1 : (x < 0 ? -1 : 0));
}

bool it_divide(poly &a, poly &b, line &l)
{
	forn (i, a.size())			
		if (sdist(a[i], l) >= 0) return false;

	forn (i, b.size())			
		if (sdist(b[i], l) <= 0) return false;
	return true;
}

void gen_line(poly &a, poly &b, line &l)
{
	l.a *= 2;
	l.b *= 2;
	l.c *= 2;
	l.c += 1;
	if (it_divide(a, b, l)) return;
	l.c -= 2;
	if (it_divide(a, b, l)) return;
	assert(false);
}

bool divide(poly &a, poly &b, line &l)
{
	if (b.size() == 1) swap(a, b);
	int na = (int)a.size();
	int nb = (int)b.size();
	int ptr = -1;
	int mx = -INF;
	l = line(b[0], b[1]);
	forn (i, na)
	{
		int cur = sdist(a[i], l);
		if (ptr == -1 || cur > mx)
		{
			mx = cur;
			ptr = i;
		}
	}
	if (mx < 0) 
	{
		gen_line(a, b, l);
		return true;
	}
	for (int i = 1; i < nb; ++i)
	{
		l = line(b[i], b[next(i, b)]);
		int mx = sdist(a[ptr], l);
		int it = 0;
		while (it < na)
		{
			++it;
			int cur = sdist(a[next(ptr, a)], l);
			if (cur < mx) break;
			mx = cur;
			ptr = next(ptr, a);
		}
		if (mx < 0) 
		{
			gen_line(a, b, l);
			return true;
		}
	}
	return false;
}

void make_convex(poly &a)
{
	int n = (int)a.size();
	if (n <= 2) return;
	int no = 0;
	forn (i, n)
		if (mp(a[i].y, a[i].x) < mp(a[no].y, a[no].x)) no = i;
	point o = a[no];
	vector<pair<pair<double, double>, int> > s(n);
	forn (i, n)									
		if (i == no)
			s[i] = mp(mp(0, -1), i);
		else
			s[i] = mp(mp(polyar(a[i].y - o.y, a[i].x - o.x), dist2(a[i], o)), i);
	sort(all(s));
	vector<int> nums;
	nums.reserve(n);
	nums.pb(0);
	nums.pb(1);
	int last = 1;
	for (int i = 2; i < n; ++i)
	{
		if (fabs(s[i].first.first - s[last].first.first) < EPS)
			nums[nums.size() - 1] = i;
		else
			nums.pb(i);
		last = i;
	}
	if (nums.size() < 3) return;
	forn (i, nums.size()) nums[i] = s[nums[i]].second;
	int top = 3;
	vector<int> stack(nums.size());
	stack[0] = nums[0];
	stack[1] = nums[1];
	stack[2] = nums[2];
	for (int i = 3; i < (int)nums.size(); ++i)
	{
		while (1)
		{
			int v1 = stack[top - 2], v2 = stack[top - 1], v3 = nums[i];
			if (((a[v2] - a[v1]) ^ (a[v3] - a[v2])) >= 0) break;
			--top;
		}
		stack[top] = nums[i];
		++top;
	}
	poly res;
	res.resize(top);
	forn (i, top) res[i] = a[stack[i]];
	a = res;
	reverse(all(a));
}

int main()
{
	freopen("polyline.in", "rt", stdin);
	freopen("polyline.out", "wt", stdout);
	int n;
	scanf("%d", &n);
	poly l;
	forn (i, n)
	{
		int x, y;
		scanf("%d%d", &x, &y);
		l.pb(mp(x, y));
	}
	int pi = 0;
	int pj = 1;
	line best(2 * (l[1].x - l[0].x), 2 * (l[1].y - l[0].y), (l[1].x + l[0].x) * (l[0].x - l[1].x) + (l[1].y + l[0].y) * (l[0].y - l[1].y));
	int mx = 1;
	line ln;
	while (pj < l.size() - 1)
	{
		poly a;
		poly b;
		for (int t = pi; t <= pj + 1; t += 2) a.pb(l[t]);
		for (int t = pi + 1; t <= pj + 1; t += 2) b.pb(l[t]);
		make_convex(a);
		make_convex(b);
		if (divide(b, a, ln))
		{
			++pj;
			if (pj - pi > mx)
				mx = pj - pi, best = ln;
		} else
		if (divide(a, b, ln))
		{
			++pj;
			if (pj - pi > mx)
				mx = pj - pi, best = ln;
		} else
		{
			++pi;
			if (pi == pj) ++pj;
		}

	}
	cout << best.a << " " << best.b << " " << best.c << endl;
	return 0;
}