{$APPTYPE CONSOLE}
{$D+,I+,L+,Q+,R+,S-,O-}
uses SysUtils;
  Const Task_ID='polyline';
        File_In=Task_ID+'.in';
        File_Out=Task_Id+'.out';
        MaxN=2001;
        Eps=1E-10;
  Type Int=LongInt;
       Real=Extended;
       TLine=Record A,B,C : Real; End;
       TNums=Array[0..MaxN] Of Int;
       TPoint=Record X,Y:Real; End;
       TPoints=Array[1..MaxN] Of TPoint;
  Var N:Int;
      P:TPoints;
      NumOdd,NumEven,HullOdd,HullEven:TNums;
      NumAbout1,NumAbout2:Int;
      AnsL,L:TLine;

Procedure OpenFiles;
Begin
  Assign(Input,File_In);
  ReSet(Input);
  Assign(Output,File_Out);
  ReWrite(Output);
End;

Procedure Init;
  Var I:Int;
Begin
  Read(N);
  For I:=1 To N Do
    Read(P[I].X,P[I].Y);
End;

Function DistLine(Const A:TPoint;Const L:TLine):Real;
Begin
  DistLine:=(L.A*A.X+L.B*A.Y+L.C)/(Sqrt(Sqr(L.A)+Sqr(L.B)))
End;

Function Eq(Const A,B:Real):Boolean;
Begin
  Eq:=Abs(A-B)<Eps;
End;

Procedure GetLine(Const P1,P2: TPoint;Var L:TLine);
Begin
  L.A:=P2.Y-P1.Y;
  L.B:=P1.X-P2.X;
  L.C:=-(L.A*P1.X+L.B*P1.Y);
End;

Function Len(Const P1,P2:TPoint):Real;
Begin
  Len:=Sqrt(Sqr(P1.X-P2.X)+Sqr(P1.Y-P2.Y));
End;

Function Less(Const A,B:Real):Boolean;
Begin
  Less:=A-B<-Eps;
End;

Procedure Swap(Var A,B:Int);
  Var C:Int;
Begin
  C:=A;
  A:=B;
  B:=C;
End;

Function Vect(Const P1,P2,P0:TPoint):Real;
Begin
  Vect:=(P1.X-P0.X)*(P2.Y-P0.Y)-(P1.Y-P0.Y)*(P2.X-P0.X);
End;

Function LessP(Const P1,P2,P0:TPoint):Boolean;
Begin
  LessP:=(Less(Vect(P1,P2,P0),0) Or Eq(Len(P1,P0),0) Or
         (Not Eq(Len(P1,P0),0) And Eq(Vect(P1,P2,P0),0) And Less(Len(P1,P0),Len(P2,P0))))
          And Not Eq(Len(P2,P0),0);
End;

Procedure Sort(Const P:TPoints;Var Num:TNums;Const P0:TPoint;Const L,R:Int);

Procedure QSort(L,R:Int);
  Var I,J:Int;
      HelpP:TPoint;
Begin
  I:=L;
  J:=R;
  HelpP:=P[Num[(I+J)Div 2]];
  Repeat
    While LessP(P[Num[I]],HelpP,P0) Do Inc(I);
    While LessP(HelpP,P[Num[J]],P0) Do Dec(J);
    If I<=J Then Begin
      Swap(Num[I],Num[J]);
      Inc(I);
      Dec(J);
    End;
  Until I>J;
  If I<R Then QSort(I,R);
  If J>L Then QSort(L,J);
End;

Begin
  QSort(L,R);
End;

Procedure Convex_Hull(Const P:TPoints;Const Num:TNums;Var Hull:TNums);
  Var I:Int;
Begin
  Hull[0]:=1;
  Hull[1]:=1;
  If Num[0]=1 Then Begin
    Hull[1]:=Num[1];
    Exit;
  End;
  For I:=2 To Num[0] Do
    If Less(P[Num[I]].X,P[Num[Hull[1]]].X) Or
       (Eq(P[Num[I]].X,P[Num[Hull[1]]].X) And Less(P[Num[I]].Y,P[Num[Hull[1]]].Y)) Then
       Hull[1]:=I;
  I:=Hull[1]Mod Num[0]+1;
  While I<>Hull[1] Do Begin
    While (Hull[0]>1) And
           (Less(Vect(P[Num[I]],P[Num[Hull[Hull[0]]]],P[Num[Hull[Hull[0]-1]]]),0) Or
           (Eq(Vect(P[Num[Hull[Hull[0]]]],P[Num[I]],P[Num[Hull[Hull[0]-1]]]),0) And
            Less(Len(P[Num[Hull[Hull[0]]]],P[Num[Hull[Hull[0]-1]]]),
                 Len(P[Num[I]],P[Num[Hull[Hull[0]-1]]]))))
            Do Begin
      Dec(Hull[0]);
    End;
    Inc(Hull[0]);
    Hull[Hull[0]]:=I;
    I:=I Mod Num[0]+1;
  End;
  While (Hull[0]>2) And
        Not Less(Vect(P[Num[Hull[Hull[0]]]],P[Num[Hull[1]]],P[Num[Hull[Hull[0]-1]]]),0) Do Begin
    Dec(Hull[0]);
  End;
  //Answer - Num[Hull[I]]
  For I:=1To Hull[0] Do
    Hull[I]:=Num[Hull[I]];
End;

Function CrossPolygons(Const P1,P2:TPoints;Const Hull1,Hull2:TNums;Var L:TLine):Boolean;
  Var Help:Boolean;

Function TryCross(Const P1,P2:TPoints;Const Hull1,Hull2:TNums;Var L:TLine):Boolean;  Var I,J:Int;
Begin
  TryCross:=True;
  GetLine(P1[Hull1[1]],P1[Hull1[2]],L);
  J:=1;
  For I:=2To Hull2[0] Do
    If Less(DistLine(P2[Hull2[J]],L),DistLine(P2[Hull2[I]],L)) Then
      J:=I;
  If Less(DistLine(P2[Hull2[J]],L),0) Then Begin
    TryCross:=False;
    L.C:=L.C-(P2[Hull2[J]].X*L.A+P2[Hull2[J]].Y*L.B+L.C)/2;
    Exit;
  End;
  For I:=1To Hull1[0]-1 Do Begin
    GetLine(P1[Hull1[I]],P1[Hull1[I Mod Hull1[0]+1]],L);
    While Less(DistLine(P2[Hull2[J]],L),DistLine(P2[Hull2[J Mod Hull2[0]+1]],L)) Do
      J:=J Mod Hull2[0]+1;
    If Less(DistLine(P2[Hull2[J]],L),0) Then Begin
      TryCross:=False;
      L.C:=L.C-(P2[Hull2[J]].X*L.A+P2[Hull2[J]].Y*L.B+L.C)/2;
      Exit;
    End;
  End;
// =\
  I:=Hull1[0];
  GetLine(P1[Hull1[I]],P1[Hull1[I Mod Hull1[0]+1]],L);
  J:=1;
  For I:=2To Hull2[0] Do
    If Less(DistLine(P2[Hull2[J]],L),DistLine(P2[Hull2[I]],L)) Then
      J:=I;
  If Less(DistLine(P2[Hull2[J]],L),0) Then Begin
    TryCross:=False;
    L.C:=L.C-(P2[Hull2[J]].X*L.A+P2[Hull2[J]].Y*L.B+L.C)/2;
    Exit;
  End;
End;

Begin
  Help:=True;
  If Hull1[0]>1 Then Help:=TryCross(P1,P2,Hull1,Hull2,L);
  If Help And (Hull2[0]>1) Then Help:=TryCross(P2,P1,Hull2,Hull1,L);
  If (Hull1[0]=1) And (Hull2[0]=1) Then Help:=False;
  CrossPolygons:=Help;
End;

Function TryAdd(Const Num:Int; Var L:TLine):Boolean;
  Var I:Int;
Begin
  If Odd(Num) Then Begin
    Inc(NumOdd[0]);
    NumOdd[NumOdd[0]]:=Num;
    I:=NumOdd[0];
    Sort(P,NumOdd,P[NumAbout1],1,NumOdd[0]);
    //insert with angle
{    While (I>1) And LessP(P[NumOdd[I]],P[NumOdd[I-1]],P[NumAbout1]) Do Begin
      Swap(NumOdd[I],NumOdd[I-1]);
      Dec(I);
    End;}
    Convex_Hull(P,NumOdd,HullOdd);
  End
  Else Begin
    Inc(NumEven[0]);
    NumEven[NumEven[0]]:=Num;
    I:=NumEven[0];
    //insert with angle
{    While (I>1) And LessP(P[NumEven[I]],P[NumEven[I-1]],P[NumAbout2]) Do Begin
      Swap(NumEven[I],NumEven[I-1]);
      Dec(I);
    End;}
    Sort(P,NumEven,P[NumAbout2],1,NumEven[0]);
    Convex_Hull(P,NumEven,HullEven);
  End;
  TryAdd:=Not CrossPolygons(P,P,HullOdd,HullEven,L);
End;

Procedure TryDel(Const Num:Int);
  Var I,J : Int;
Begin
  If Odd(Num) Then Begin
    For I:=1 To NumOdd[0] Do
      If NumOdd[I]=Num Then J:=I;
    For I:=J+1 To NumOdd[0] Do
      NumOdd[I-1]:=NumOdd[I];
    Dec(NumOdd[0]);
    If NumAbout1=Num Then Begin
      NumAbout1:=0;
      For I :=1 To NumOdd[0] Do
        If NumOdd[I]>NumAbout1 Then NumAbout1:=NumOdd[I];
      if NumOdd[0]=0 Then
        Assert(False,'del to more points... Del '+IntToStr(Num));
      Sort(P,NumOdd,P[NumAbout1],1,NumOdd[0]);
    End;
    Convex_Hull(P,NumOdd,HullOdd);
  End
  Else Begin
    For I:=1 To NumEven[0] Do
      If NumEven[I]=Num Then J:=I;
    For I:=J+1 To NumEven[0] Do
      NumEven[I-1]:=NumEven[I];
    Dec(NumEven[0]);
    If NumAbout2=Num Then Begin
      NumAbout2:=0;
      For I:=1 To NumEven[0] Do
        If NumEven[I]>NumAbout2 Then NumAbout2:=NumEven[I];
      if NumOdd[0]=0 Then
        Assert(False,'del to more points... Del '+IntToStr(Num));
      Sort(P,NumEven,P[NumAbout2],1,NumEven[0]);
    End;
    Convex_Hull(P,NumEven,HullEven);
  End;
End;

Procedure Solve;
  Var I,J:Int;
      Ans:Int;
Begin
{  For I :=1 To N Do Num1[I]:=I;
  Num1[0]:=N;
  Sort(P,Num1,P[1],1,N);
  Convex_Hull(P,Num1,Num2);}
  For I:=1 To N Do
    For J:=I+1 To N Do
      Assert((P[I].X<>P[J].X) Or (P[I].Y<>P[J].Y),'Equal points: '+IntToStr(I)+' and '+IntToStr(J));
  For I:=1 To N Do
    Assert((Abs(P[I].X)<=1000) And (Abs(P[I].Y)<=1000),'Bad coordinats: '+IntToStr(I));
  For I:=3 To N Do
    Assert(Not Eq(Vect(P[I],P[I-1],P[I-2]),0),'3 points at one line: '+IntToStr(I-2)+' and '+IntToStr(I-1)+' and '+IntToStr(I));
  NumAbout1:=1;
  NumAbout2:=2;
  NumOdd[0]:=1;
  NumEven[0]:=1;
  NumOdd[1]:=1;
  NumEven[1]:=2;
  Convex_Hull(P,NumOdd,HullOdd);
  Convex_Hull(P,NumEven,HullEven);
  Ans:=1;
  If Eq(P[1].X,P[2].X) Then Begin
    AnsL.A:=0;
    AnsL.B:=1;
    AnsL.C:=-(P[1].Y+P[2].Y)/2;
  End
  Else Begin
    AnsL.A:=1;
    AnsL.B:=0;
    AnsL.C:=-(P[1].X+P[2].X)/2;
  End;
  I:=1;
  J:=2;
  While J<N Do Begin
    If TryAdd(J+1,L) Then Inc(J)
    Else
      Begin
        TryDel(I);
        TryDel(J+1);
        Inc(I);
      End;
    If I>=J Then Begin
      Assert(false,'Bug..'+IntToStr(I));
      Exit;
    End;
    If Ans<J-I Then Begin
      Ans:=J-I;
      AnsL:=L;
    End;
  End;
  WriteLn(AnsL.A:0:10);
  WriteLn(AnsL.B:0:10);
  WriteLn(AnsL.C:0:10);
End;

Procedure CloseFiles;
Begin
  Close(Input);
  Close(Output);
End;

Begin
  OpenFiles;
  Init;
  Solve;
  CloseFiles;
End.