import java.io.*;
import java.util.*;
import java.math.*;

public class LongPath_vv_x2{
  
  public static final String FileName = "longpath";

  int DEBUG = 1;
  double EPS = 1e-12;


  int hs = 0;
  int[] h2;
  double[] h1;
  int[] p;

  public boolean empty(){
    return (hs==0);
  }

  public int heapV(){
    if (DEBUG>0)
      System.out.println("Vertex is "+h1[1]+" "+h2[1]);
    return (h2[1]);
  }


  public void dump(){
    for(int i=1;i<=hs;i++){
      System.out.print("("+h1[i]+","+h2[i]+") - "+p[h2[i]]+"   ");
    }
    System.out.println();
  }

  public void up(int n){
    while (n>1 && less(n,n>>1)){
      swap(n>>1,n);
      n = n>>1;
    }
  }


  public boolean less(int n,int m){
    return (h1[n]<h1[m]-EPS || (h1[n]<h1[m]+EPS && h2[n]<h2[m]));
  }

  public void down(int n){
    h1[hs+1] = 1e100;
    while ((n*2)<=hs){
      if (less(2*n,2*n+1)){
        if (less(2*n,n)){
          swap(n,2*n);
          n=2*n;
        } else return;
      } else {
        if (less(2*n+1,n)){
          swap(n,2*n+1);
          n=2*n+1;
        } else return;
      }
    }
  }

  public void swap(int x,int y){
    int t = h2[x]; h2[x] = h2[y]; h2[y] =t;
    double s = h1[x]; h1[x] = h1[y]; h1[y] =s;
    p[h2[x]]=x;
    p[h2[y]]=y;
  }

  public void add(double t,int m){
    if (DEBUG>0){
      System.out.println("ADD("+t+","+m+")");
    }
    hs++;
    h1[hs] = t;
    h2[hs] = m;
    p[m] = hs;
    up(hs);
    if (DEBUG>0)
      System.out.println("  ELEMENT ADDED");
  }

  public void rem(int m) throws Exception{
    if (DEBUG>0){
      System.out.println("REM("+m+")");
    }
    if (p[m]==0){
      if (DEBUG>0)
        System.out.println("  ELEMENT IS NOT IN THE HEAP");
      return;
    }
    if (p[m]==hs){
      hs--; p[m]=0;return;
    }
    int k = p[m];
    swap(p[m],hs);
    p[m] = 0;
    hs--;
    up(k);
    down(k);
    if (DEBUG>0){
      System.out.println("  ELEMENT DELETED");
      dump();
    }
  }

  int[] m;
  double[] x;

  public void qsort(int l,int r){
    if (l>=r) return;
    int i = l; 
    int j = r;
    double xx = x[(i+j)>>1];
    do{
      while (x[i]>xx) i++;
      while (x[j]<xx) j--;
      if (i<=j){
        int t = m[i]; m[i] = m[j]; m[j]=t;
        double s =x[i]; x[i]=x[j]; x[j]=s;
        i++; j--;
      }
    } while(i<=j);
    qsort(l,j);
    qsort(i,r);
  }


  public void run() throws Exception{    
    Scanner in = new Scanner(new File(FileName+".in"));
    PrintWriter out = new PrintWriter(new File(FileName+".out"));
    in.useLocale(Locale.US);
    int n = in.nextInt();
    m = new int[n];
    x = new double[n]; 
    h1 = new double[n+1];
    h2 = new int[n+1];
    p = new int[n+1];
    for(int i=0; i<n;i++){
      m[i] = in.nextInt();
      x[i] = in.nextDouble();
    }
    qsort(0,n-1);
    for(int i=0;i<n;i++){
      System.out.println(x[i]+" "+m[i]);
    }
    boolean ok=true;
    while (ok){
      ok=false;
      int ii=-1;
      double t = 1e100;
      for(int i=0;i<n-1;i++){
        if (m[i]>m[i+1]){
          double tt = (x[i]-x[i+1])/(100*(1.0/m[i+1]-1.0/m[i]));
          if (tt+EPS<t){
            t = tt;
            ii = i;
          }
          ok = true;
          System.out.println("OK  "+tt);
        }
      }
      System.out.println(ii+" "+t+" "+ok);
      if (ok) {
        int q=m[ii+1];
        for(int i=ii+1;i<n-1;i++){
          m[i] = m[i+1];
          x[i] = x[i+1];
        }
        n--;
        for(int i=0;i<n;i++){
          x[i]+=t*100/m[i];
        }
        m[ii]+=q;
      }
    }
    for(int i=0;i<n;i++){
      out.print(m[i]+" ");
    }
    out.println();

    out.close();
  }

  public static void main(String[] args) throws Exception{
    LongPath_vv_x2 t = new LongPath_vv_x2();
    t.run();
  }
}