import java.io.*;
import java.util.*;
import java.math.*;

public class tetrahedron{
  
  public static final String FileName = "tetrahedron";

  int DEBUG = 0;
  double eps = 1e-9;





  double [][] d;
  double [][] x;
  double [][] nm;

  public boolean lay(double[] p, double[] dp, double[] q){
    double[] r = new double[4];
    double[] r2 = new double[4];
    for(int i=0; i<3;i++)
      r[i]=q[i]-p[i];
    vect(dp,r,r2);
    for(int i=0;i<3;i++)
      if (Math.abs(r2[i])>eps){
        return false;
      }
    return true;
    
  }

  public double dist(double[] x1, double[] x2, double[] q){
    double[] r = new double[3];
    double dd = 0;
    for(int i=0;i<3; i++){
      r[i]=x2[i]-x1[i];
      dd+=sqr(r[i]);
    }
    dd = Math.sqrt(dd);
    for(int i=0;i<3; i++){
      r[i]/=dd;
    }
    double[] r2 = new double[3];
    double s = 0;

    for(int i=0;i<3; i++){
      r2[i]=q[i]-x1[i];
      s+=r2[i]*r[i];
    }
    dd = 0;
    for(int i=0;i<3; i++){
      r2[i] = r2[i]-s*r[i];
      dd+=sqr(r2[i]);
    }
    return Math.sqrt(dd);

  }


  public double sqr(double x){
    return x*x;
  }


  boolean solve1 (double a11, double a12, double a21, double a22, double b1, double b2, double []t) {
//    System.out.println ("solve");
    double det = a11*a22-a12*a21;
    if (Math.abs (det)<eps) return false;
    t[0]=(a22*b1-a12*b2)/det;
    t[1]=(-a21*b1+a11*b2)/det;
    return true;
  }

  
  boolean solveall (double[] r1, double[] d1, double[] r2, double[] d2, double[] p) {
    double[] t = new double[2];
    if (!solve1 (d1[0], -d2[0], d1[1], -d2[1], r2[0]-r1[0], r2[1]-r1[1], t)&&
        !solve1 (d1[2], -d2[2], d1[1], -d2[1], r2[2]-r1[2], r2[1]-r1[1], t)) return false;
//    System.out.println ("found t");
    for (int i=0; i<3; i++) {
//      System.out.println (i);
      if (Math.abs(r1[i]+d1[i]*t[0]-r2[i]-d2[i]*t[1])>eps) return false;
      p[i]=r1[i]+d1[i]*t[0];
    }
    if (DEBUG>0){
      for(int i=0; i<3; i++)
        System.out.print(p[i]+" ");
      System.out.println();
    }
    return true;
  }

  public void vect(double[] x1, double[] x2,double[] q){
    q[0] = x2[2]*x1[1]-x2[1]*x1[2];
    q[1] = x2[0]*x1[2]-x2[2]*x1[0];
    q[2] = x2[1]*x1[0]-x2[0]*x1[1];
  }

  public void vect(double[] x1, double[] x2,int q){
    nm[q][0] = x2[2]*x1[1]-x2[1]*x1[2];
    nm[q][1] = x2[0]*x1[2]-x2[2]*x1[0];
    nm[q][2] = x2[1]*x1[0]-x2[0]*x1[1];
  }

  public void vect(double[] x1, double[] x2,double[] x3,int q){
    double[] y1 = new double[3];
    double[] y2 = new double[3];
    y1[0] = x2[0]-x1[0];
    y1[1] = x2[1]-x1[1];
    y1[2] = x2[2]-x1[2];
    y2[0] = x3[0]-x1[0];
    y2[1] = x3[1]-x1[1];
    y2[2] = x3[2]-x1[2];
    vect(y1,y2,q);
  }


  public boolean constr(int n){
    if (n == 0){
      x[0][0] = 0;
      return true;
    }
    if (!constr(n-1)){
      return false; 
    }
    if (DEBUG>0)
      System.out.println(n);
    double R = sqr(d[0][n]);
    for(int i=0; i<n-1;i++){
      double s = -2*x[i+1][i];
      double t = sqr(d[i+1][n])-R-sqr(x[i+1][i]);
      for (int j=0; j<i; j++)
        t = t-sqr(x[i+1][j])+2*x[i+1][j]*x[n][j];
      x[n][i] = t/s;              
    }
    for(int i=0;i<n-1;i++)
      R-=sqr(x[n][i]);
    if (R<eps){
      return false;
    } else {
      x[n][n-1] = Math.sqrt(R);
      return true;
    }
  }

  public void run() throws Exception{    
    Scanner in = new Scanner(new File(FileName+".in"));
    PrintWriter out = new PrintWriter(new File(FileName+".out"));
    int n = 3;
    d = new double[4][4];
    double[][] dd = new double[4][4];
    x = new double[4][4];
    for(int i=0; i<=n; i++)
      for(int j=i+1; j<=n; j++){
        d[i][j] = in.nextDouble();
        d[j][i] = d[i][j];
      }

    boolean oo=constr(n);
    if (DEBUG>0){
      for(int i=0;i<=n;i++){
        for(int j=0; j<i; j++){
          System.out.print(x[i][j]+" ");
        }
        System.out.println();
      }
    }
    if (!oo) {
      out.println("IMPOSSIBLE");      
      out.close();
      return;
    } else {
//      out.println("CORRECT LENGTHS");
      if (DEBUG>0)
        for(int k=0;k<=n;k++){
          for(int i=k+1;i<=n;i++){
            dd[k][i] = 0;
            for(int j=0; j<n;j++){
              dd[k][i]+=sqr(x[i][j]-x[k][j]);
            }
            if (Math.abs(dd[k][i]-sqr(d[k][i]))>eps){
              System.out.println("BOTVA");
            }
          }
        }
    }
    double[][] p = new double[4][4];
    nm= new double[4][4];
    for(int i=0;i<n;i++){
      p[0][i] = (d[1][2]*x[3][i]+d[1][3]*x[2][i]+d[2][3]*x[1][i])/(d[1][2]+d[1][3]+d[2][3]);
      p[1][i] = (d[0][2]*x[3][i]+d[0][3]*x[2][i]+d[2][3]*x[0][i])/(d[0][2]+d[0][3]+d[2][3]);
      p[2][i] = (d[1][0]*x[3][i]+d[1][3]*x[0][i]+d[0][3]*x[1][i])/(d[1][0]+d[1][3]+d[0][3]);
      p[3][i] = (d[1][2]*x[0][i]+d[1][0]*x[2][i]+d[2][0]*x[1][i])/(d[1][2]+d[1][0]+d[2][0]);
    }
    vect(x[0],x[1],x[2],3);
    vect(x[3],x[1],x[2],0);
    vect(x[0],x[1],x[3],2);
    vect(x[0],x[3],x[2],1);
    if (DEBUG>0){       
      System.out.println("POINTS");
      for(int i=0; i<4;i++)
      System.out.println(p[i][0]+" "+p[i][1]+" "+p[i][2]);
    }
    if (DEBUG>0){
      System.out.println("NORMALS");
      for(int i=0; i<4;i++)
      System.out.println(nm[i][0]+" "+nm[i][1]+" "+nm[i][2]);
      System.out.println("----------");
    }
    double[] q = new double[4];
    if (!solveall(p[0],nm[0],p[1],nm[1],q)){
      out.println("NO");
      out.close();
      return;
    }
    if (DEBUG>0){
      for(int i=0; i<3; i++)
        System.out.print(q[i]+" ");
      System.out.println();
    }
    for(int i=0;i<4;i++){
      if (!lay(p[0],nm[0],q)){
        out.println("NO");
        out.close();
        return;
      }
    }
    out.println("YES");
    double r = 0;
    for (int i=1; i<3; i++)
      r = r+ sqr(q[i]);
    r = Math.sqrt(r);
    out.println(r);
    for(int i=0;i<4;i++){
      double s = 0;
      for(int j=0;j<3;j++)
        s+=sqr(x[i][j]-q[j]);
      out.println(Math.sqrt(s));
    }
    out.println();
    for(int i = 0; i<4; i++)
      for(int j = i+1; j<4; j++){
        if (Math.abs(r-dist(x[i],x[j],q))>eps){
          System.out.println("BOTVA");
        }
      }
    out.close();
  }

  public static void main(String[] args) throws Exception{
    tetrahedron t = new tetrahedron();
    t.run();
  }
}