#include <stdio.h>
#include <memory.h>
#include <string.h>

const int strLength = 8192;

void buildKMP ( char const* str, int* kmp )
{
  int len = (int) strlen ( str );

  kmp [0] = 0;
  int i = 1;
  while ( i < len )
  {
    int k = kmp [i-1];
    while ( k > 0 && str [k] != str [i] )
      k = kmp [k-1];
    if ( str [k] == str [i] )
      kmp [i] = k + 1;
    else
      kmp [i] = 0;
    i++;     
  }
}
int findStr ( char const* stra, char const* strb )
{
  static int kmp [strLength];
  
  kmp [0] = 0;
  int i = 1;
  while ( stra [i] != 0 )
  {
    int k = kmp [i-1];
    while ( k > 0 && stra [k] != stra [i] )
      k = kmp [k-1];
    if ( stra [k] == stra [i] )
      kmp [i] = k + 1;
    else
      kmp [i] = 0;
    i++;
  }
  int a_len = i;

  int last = 0;
  i = 0;
  while ( strb [i] != 0 )
  {
    int k = last;
    while ( k > 0 && stra [k] != strb [i] )
      k = kmp [k-1];
    if ( stra [k] == strb [i] )
      last = k + 1;
    else
      last = 0;
    if ( last == a_len )
      return i - last + 1;
    i++;
  }

  return -1;
}

char stra [strLength];
char strb [strLength];
int len;

void read_input ()
{
  FILE* f = fopen ( "stragain.in", "rt" );
  fscanf ( f, "%s", stra );
  fscanf ( f, "%s", strb );
  len = (int) strlen ( stra );
  fclose ( f );
}

bool ans;
char ans1 [strLength];
char ans2 [strLength];
char ans3 [strLength]; 

int try_split2 ( char const* stra, char const* strb )
{
  static char comp [strLength*2];
  sprintf ( comp, "%s%s", strb, strb );
  int pos = findStr ( stra, comp );
  if ( pos < 0 )
    return -1;
  else
    return strlen ( strb ) - pos;
}

void split_str ( char const* str, int pos, char* out1, char* out2 )
{
  memcpy ( out1, str, pos );
  out1 [pos] = 0;
  strcpy ( out2, str + pos );
}

bool try_remove ( int start1, int len1, int start2, int len2 )
{
  static char comp1 [strLength];
  static char comp2 [strLength];

  int lc1 = len - len1;
  int lc2 = len - len2;

  if ( lc1 < 2 )
    return false;

  if ( start1 > 0 )
    memcpy ( comp1, stra, start1 );
  if ( start1 + len1 < len )
    memcpy ( comp1 + start1, stra + start1 + len1, len - start1 - len1 );

  if ( start2 > 0 )
    memcpy ( comp2, strb, start2 );
  if ( start2 + len2 < len )
    memcpy ( comp2 + start2, strb + start2 + len2, len - start2 - len2 );

  comp1 [lc1] = 0;
  comp2 [lc2] = 0;

  int split = try_split2 ( comp1, comp2 );
  if ( split == 0 )
    split = lc1 / 2;
  if ( split > 0 )
  {
    if ( start1 > 0 )
      split_str ( comp1, split, ans1, ans2 );
    else
      split_str ( comp1, split, ans2, ans3 );
    return true;
  }
  return false;
}

void solve ()
{
  if ( len < 3 )
  {
    ans = false;
    return;
  }

  static char comp_s [strLength*2];
  static char comp_r [strLength*2];
  static int kmp_s [strLength*2];
  static int kmp_r [strLength*2];

  sprintf ( comp_s, "%s$%s", stra, strb );

  for ( int i = 0; i < len; i++ )
    comp_r [i] = stra [len-i-1];
  comp_r [len] = '$';
  for ( int i = 0; i < len; i++ )
    comp_r [i+len+1] = strb [len-i-1];

  buildKMP ( comp_s, kmp_s );
  buildKMP ( comp_r, kmp_r );

  int offset = len + 1;

  for ( int i = 0; i < len; i++ )
  {
    if ( kmp_s [offset+i] == i + 1 )
    {
      if ( try_remove ( 0, i + 1, 0, i + 1 ) )
      {
        ans = true;
        memcpy ( ans1, stra, i + 1 );
        ans1 [i+1] = 0;
        return;
      }
    }
  }
  int k = kmp_s [len+len];
  while ( k > 0 )
  {
    if ( try_remove ( 0, k, len - k, k ) )
    {
      ans = true;
      memcpy ( ans1, stra, k );
      ans1 [k] = 0;
      return;
    }
    k = kmp_s [k-1];
  }
  
  for ( int i = 0; i < len; i++ )
  {
    if ( kmp_r [offset+i] == i + 1 )
    {
      if ( try_remove ( len - i - 1, i + 1, len - i - 1, i + 1 ) )
      {
        ans = true;
        memcpy ( ans3, stra + len - i - 1, i + 1 );
        ans3 [i+1] = 0;
        return;
      }
    }
  }
  k = kmp_r [len+len];
  while ( k > 0 )
  {
    if ( try_remove ( len - k, k, 0, k ) )
    {
      ans = true;
      memcpy ( ans3, stra + len - k, k );
      ans3 [k] = 0;
      return;
    }
    k = kmp_r [k-1];
  }
}

void write_output ()
{
  FILE* f = fopen ( "stragain.out", "wt" );

  if ( !ans )
    fprintf ( f, "NO" );
  else
    fprintf ( f, "YES\n%s\n%s\n%s", ans1, ans2, ans3 );

  fclose ( f );
}

int main ()
{
  read_input ();
  solve ();
  write_output ();

  return 0;
}
