#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

#define EPS 1e-12

#define MAXW 8
#define MAXH 110
#define MAXPR 7010
#define MAXE 70010

typedef double dbl;

dbl P[MAXH][MAXW];
int W, H, W1, H1, U[MAXW], Is[MAXH][MAXW];
int PrN = 0, Pr[MAXPR], FPr[1 << (MAXW * 2)], Pos = 0, St[MAXPR], Ne[MAXE];
dbl F[MAXH][MAXPR];
int La[MAXH][MAXPR], IsF[MAXH][MAXPR];

void Imp( void )
{
  puts("IMPOSSIBLE");
  exit(0);
}

void Out( void )
{
  int i, j;
  for (i = 0; i < H; i++)
    for (j = 0; j < W; j++)
      printf("%d%c", Is[i][j], j == W - 1 ? '\n' : ' ');
}

dbl Solve( dbl *P, int N, int N1, int *Is )
{
  static dbl Max[MAXW];
  static int La[MAXW];
  dbl Res;
  int i, j;

  for (i = 0; i < N; i++)
    Max[i] = P[i], La[i] = -1;
  for (i = 0; i < N; i++)
    for (j = i + N1; j < N; j++)
      if (Max[j] < Max[i] + P[j])
        Max[j] = Max[i] + P[j], La[j] = i;
  for (j = i = 0; i < N; i++)
    if (Max[i] > Max[j])
      j = i;
  for (i = j; i != -1; i = La[i])
    Is[i] = 1;
  return Max[j];
}

int main( void )
{
  int i, j, k, x, y, tmp;
  dbl p;

  freopen("sprats.in", "rt", stdin);
  freopen("sprats.out", "wt", stdout);

  fprintf(stderr, "Read data... ");
  scanf("%d%d%d%d", &W, &H, &W1, &H1);
  for (i = 0; i < H; i++)
    for (j = 0; j < W; j++)
      scanf("%lf", &P[i][j]);
  memset(Is, 0, sizeof(Is));
  
  if (H1 == 1)
  {
    fprintf(stderr, "Ok\nL=1 (simple solution)\n");
    for (i = 0; i < H; i++)
      if (Solve(P[i], W, W1, Is[i]) < EPS)
        Imp();
    Out();
    return 0;
  }

  fprintf(stderr, "Ok\nCalculate profiles... ");
  for (i = 0; i < (1 << (W * (H1 - 1))); i++)
  {
    memset(U, 0, sizeof(U));
    for (y = 0; y < H1 - 1; y++)
      for (x = 0; x < W; x++)
        if ((i >> (y * W + x)) & 1)
          for (j = 0; x + j < W && j < W1; j++)
            U[x + j]++;
    for (j = 0; j < W; j++)
      if (U[j] > 1)
        break;
    if (j == W)
      FPr[i] = PrN, Pr[PrN++] = i;
  }

  fprintf(stderr, "Ok\nCalculate edges... ");
  for (i = 0; i < PrN; i++)
    for (St[i] = Pos, j = 0; j < (1 << W); j++)
    {
      int f = 0;
      memset(U, 0, sizeof(U));
      for (x = 0; x < W && !f; x++)
      {
        k = (j >> x) & 1;
        for (y = 0; y < H1 - 1; y++)
          k += (Pr[i] >> (y * W + x)) & 1;
        for (tmp = 0; x + tmp < W && tmp < W1; tmp++)
          if ((U[x + tmp] += k) > 1)
          {
            f = 1;
            break;
          }
      }
      if (!f)
        Ne[Pos++] = FPr[(j << (W * (H1 - 2))) + (Pr[i] >> W)];
    }
  St[i] = Pos;

  fprintf(stderr, "Ok\nSolve problem... ");
  memset(IsF, 0, sizeof(IsF));
  for (y = 0; y < H; y++)
    for (i = 0; i < PrN; i++)
    {
      if (!y)
        F[y][i] = 1, IsF[y][i] = 1, La[y][i] = -1;
      for (p = 0, x = 0; x < W; x++)
        if ((Pr[i] >> x) & 1)
          p += P[y][x];
      if (p < EPS || !IsF[y][i])
        IsF[y][i] = 0;
      else
        IsF[y][i] = 1, F[y][i] = F[y][i] + log(p);
      if (IsF[y][i])
        for (j = St[i]; j < St[i + 1]; j++)
          if (!IsF[y + 1][Ne[j]] || F[y + 1][Ne[j]] < F[y][i])
            IsF[y + 1][Ne[j]] = 1, F[y + 1][Ne[j]] = F[y][i], La[y + 1][Ne[j]] = i;
    }

  fprintf(stderr, "Ok\nRestore answer... ");
  if (!IsF[H][0])
    Imp();
  for (y = H - 1, i = La[H][0]; y >= 0; i = La[y][i], y--)
    for (x = 0; x < W; x++)
      Is[y][x] = (Pr[i] >> x) & 1;
  Out();
  
  fprintf(stderr, "Ok\nSuccess :)\n");
  return 0;
}
