#include <stdio.h>
#define _USE_MATH_DEFINES
#include <math.h>
#include <algorithm>
#include <set>

struct Line {
	int l, r;
};
struct cmpX {
	inline bool operator() (const Line &a, const Line &b) const {
		return a.l < b.l;
	}
};
struct cmpLX {
	inline bool operator() (const Line &a, const Line &b) const {
		if (a.r-a.l == b.r-b.l)
			return a.l < b.l;
		return (a.r-a.l) > (b.r-b.l);
	}
};
typedef std::set<Line, cmpX> xSet;
typedef std::set<Line, cmpLX> lSet;
typedef xSet::iterator xIter;
typedef lSet::iterator lIter;
typedef double real;

#define DELTA 1e-5
#define EPS 1e-9
#define DALPHA 0.495873982309864056983049586730948570986209638456345
#define SIZE 2096

int n;
real px[2010], py[2010];
real cx, cy;
real angle[2010];
int adr[2010];
int cross[2*SIZE+1];
xSet xs;
lSet ls;
int answer;
double pa, pb, pc;

real a11, a12, a21, a22, b1, b2, det, detu, detv;
inline bool crossLines(real x1, real y1, real x2, real y2, real x3, real y3, real x4, real y4) {
	a11 = x2-x1;
	a12 = x3-x4;
	a21 = y2-y1;
	a22 = y3-y4;
	b1  = x3-x1;
	b2  = y3-y1;
	det  = a11*a22 - a12*a21;
	detu = b1 *a22 - a12*b2 ;
	detv = a11*b2  - b1 *a21;
	if (det < 0) {
		det = -det;
		detu = -detu;
		detv = -detv;
	}
//	return ((detu>0) && (detu<det) && (detv>0) && (detv<det));
	return ((detu>EPS) && (detu<det-EPS));
}

bool cmpPoints(int a, int b) {
     return (angle[a] < angle[b]);
}

inline void Xor(int a) {
	cross[a] = !cross[a];
	Line l1, l2;
	xIter xit;
	lIter lit;
	if (cross[a] == 0) {
		l1.l = a+1;
		xit = xs.lower_bound(l1);  xit--;
		lit = ls.find(*xit);
		l1.l = xit->l;
		l1.r = a;
		l2.l = a+1;
		l2.r = xit->r;
		xs.erase(xit);
		ls.erase(lit);
		if (l1.r-l1.l > 0) {
			xs.insert(l1);
			ls.insert(l1);
		}
		if (l2.r-l2.l > 0) {
			xs.insert(l2);
			ls.insert(l2);
		}
	}
	else {
		l1.l = a;
		l1.r = a+1;
		xit = xs.lower_bound(l1);
		lit = ls.find(*xit);
		if (xit != xs.end())
			if (xit->l == l1.r) {
				l1.l = l1.l;
				l1.r = xit->r;
				xs.erase(xit);
				ls.erase(lit);
			}
		
		xit = xs.lower_bound(l1);
		if (xit != xs.begin()) {
			xit--;
			lit = ls.find(*xit);
			if (xit->r == l1.l) {
				l1.l = xit->l;
				l1.r = l1.r;
				xs.erase(xit);
				ls.erase(lit);
			}
		}
		xs.insert(l1);
		ls.insert(l1);
	}
}

int findMaxLine() {
	lIter it = ls.begin();
	if (it == ls.end())
		return 0;
	else
		return it->r - it->l;
}

void ClearCrosses() {
	memset(cross, 0, (n+1)*sizeof(int));
	xs.clear();
	ls.clear();
}

int main(int argc, char **argv) {
	freopen("polyline.in", "r", stdin);
	freopen("polyline.out", "w", stdout);
	int i, j, k;
	scanf("%d", &n);
	n--;
	for (i = 0; i<=n; i++) {
                int tx, ty;
		scanf("%d%d", &tx, &ty);
                px[i] = tx*cos(DALPHA) - ty*sin(DALPHA);
                py[i] = tx*sin(DALPHA) + ty*cos(DALPHA);
        }
	for (i = 1; i<=2*n; i++) {
		int done;
		for (j = 0; j<=n; j++)
			adr[j] = j;
		if (i<=n) {
			cx = px[i] + (px[i-1]-px[i]) * DELTA;
			cy = py[i] + (py[i-1]-py[i]) * DELTA;
			done = i-1;
		}
		else {
			cx = px[i-n-1] + (px[i-n]-px[i-n-1]) * DELTA;
			cy = py[i-n-1] + (py[i-n]-py[i-n-1]) * DELTA;
			done = i-n-1;
		}
		for (j = 0; j<=n; j++) {
			angle[j] = atan2(py[j]-cy, px[j]-cx);
                        if (angle[j] < 0) angle[j] += M_PI;
                }

		std::sort(adr, adr+n+1, cmpPoints);
                ClearCrosses();
		for (j = 0; j<n; j++) {
			if (j != done) {
				if (crossLines(px[j], py[j], px[j+1], py[j+1], cx, cy, cx+1000.0, cy))
					Xor(j);
			}
			else
				Xor(j);
		}
		double last = angle[adr[n]] - M_PI;
		for (j = 0; j<n; j++) {
			if (angle[adr[j]]-last > EPS) {
				int tr = findMaxLine();
				real tang = (angle[adr[j]] + last) / 2.0;
				if (tr > answer) {
					answer = tr;
					tang -= DALPHA;
					pa = sin(tang)*1024.0;
					pb = -cos(tang)*1024.0;
					pc = (-(cx*sin(tang) - cy*cos(tang)))*1024.0;
				}
			}
			if (adr[j]>0)
				if (adr[j]-1 != done)
					Xor(adr[j]-1);
			if (adr[j]<n)
				if (adr[j] != done)
					Xor(adr[j]);
			last = angle[adr[j]];
		}
	}
	printf("%0.20lf\n%0.20lf\n%0.20lf", pa, pb, pc);
//	printf("    (%d)", answer);
	return 0;
}
