#include <stdio.h>
#include <math.h>

#define eps 1e-8
#define SWAP(a, b, c) ((c) = (a), (a) = (b), (b) = (c))

typedef long double ldbl;

typedef struct
{
   ldbl X, Y;
} VEC;

typedef struct
{
  ldbl A, B, C;
} LINE;

VEC PL[2000];
int N;

int sg( ldbl a )
{
  if (a > eps)
    return 1;
  if (a <= eps && a >= -eps)
    return 0;
  return -1;
}

LINE MakeLINE( VEC V1, VEC V2 )
{
  LINE R;

  R.A = (V2.Y - V1.Y);
  R.B = (V1.X - V2.X);
  R.C = -(R.A * V1.X + R.B * V1.Y);
  return R;
}

VEC GetMed( VEC V1, VEC V2 )
{
  V1.X = (V1.X + V2.X) / 2;
  V1.Y = (V1.Y + V2.Y) / 2;
  return V1;
}

ldbl GetLINE( LINE L, VEC V )
{
  return L.A * V.X + L.B * V.Y + L.C;
}

double Inter( LINE L, VEC St, VEC t )
{
  ldbl res, t1;

  t1 = L.A  * t.X + L.B * t.Y;

  if ( t1 < eps )
  {
    return -1;
  }
  return -(L.A * St.X + L.B * St.Y + L.C) / t1;
}
LINE Best;
int BestN;

int Add( VEC *Va1, VEC *Va2, VEC *Vb1, VEC *Vb2, VEC New )
{
  
  LINE a1a2, b1b2, b2a2, b1a1;
  VEC t;
  
  a1a2 = MakeLINE(*Va1, *Va2);
  b1b2 = MakeLINE(*Vb1, *Vb2);
  b2a2 = MakeLINE(*Vb2, *Va2);
  b1a1 = MakeLINE(*Vb1, *Va1);
  if (GetLINE(a1a2, New) > -eps)
    return 0;
  if (GetLINE(b2a2, New) < eps)
  {
    if (GetLINE(b1b2, New) > -eps)
    {
      SWAP(*Va1, *Vb1, t);
      SWAP(*Va2, *Vb2, t);
      *Va2 = New;
      return 1;
    }
  }



}

void Check(LINE L, int cnt)
{
  if (cnt > BestN)
    BestN = cnt, Best = L;
}

void OutLINE( LINE L )
{
  printf("%.15Lf\n", L.A);
  printf("%.15Lf\n", L.B);
  printf("%.15Lf\n", L.C);
}
int main( void )
{
  int i, j, k;
  VEC Va1, Va2, Vb1, Vb2;
  LINE L1,L2;
  ldbl a, b, c;
//  sqrt(1.0);
  freopen("polyline.in", "rt", stdin);
  freopen("polyline.out", "wt", stdout);
  c = 0;
  
  scanf("%i", &N);
  for (i = 0; i < N; i++)
    scanf("%Lf%Lf", &PL[i].X, &PL[i].Y);
  if (N == 2)
  { 
    a = (PL[1].X - PL[0].X);
    b = (PL[1].Y - PL[0].Y);
    c = -(a * (PL[0].X + PL[1].X) / 2.0 + b * (PL[0].Y + PL[1].Y) / 2.0);
    printf("%.12Lf\n%.12Lf\n", a, b);
    printf("%.12Lf", c);
    
    return 0;

  }
  BestN = 2;
  Best = MakeLINE(GetMed(PL[0], PL[1]), GetMed(PL[1], PL[2]));
  /* ... */

  for (i = 0; i < N - 3; i++)
  {
    L1 = MakeLINE(PL[i], PL[i + 2]);
    L2 = MakeLINE(PL[i + 1], PL[i + 2]);
    a = GetLINE(L1, PL[i + 1]);
    b = GetLINE(L1, PL[i + 3]);
    c = GetLINE(L2, PL[i + 3]);
    Va1 = PL[i + 1];
    Va2 = PL[i + 3];
    Vb1 = PL[i];
    Vb2 = PL[i + 2];
    if (sg(a) != sg(b))
      continue;
    if ( c > 0)
      Vb1 = PL[i + 2], Vb2 = PL[i];
    Check(MakeLINE(GetMed(Va1, Vb1), GetMed(Va2, Vb2)), 3);
    
    for (j = i + 4; j < N; j++)
      if (Add(&Va1, &Va2, &Vb1, &Vb2, PL[j]))
        Check(MakeLINE(GetMed(Va1, Vb1), GetMed(Va2, Vb2)), j - i);
      else
        break;
  }
  OutLINE(Best);
  return 0;
}



