#include <stdio.h>
#include <string.h>
#include <windows.h>

#define WIN      1
#define DRAW     0
#define LOSE    -1

int strLength;
char str [10057];

inline int pi_pos ( int r )
{
  return ( r >> 9 );
}
inline char pi_last ( int r, int l )
{
  return ( ( r >> ( l * 3 ) ) & 7 ) + 'a';
}
inline char pi_last ( int r )
{
  return ( r & 7 ) + 'a';
}
inline void pi_setPos ( int& r, int p )
{
  r = ( ( r & 0x01ff ) | ( p << 9 ) );
}
inline void pi_setLast ( int& r, int l, char v )
{
  r = ( ( r & ( ~ ( 7 << ( l * 3 ) ) ) ) | ( ( v - 'a' ) << ( l * 3 ) ) );
}
inline void pi_pushLast ( int& r, int v )
{
  r = ( ( r & 0xfffffe00 ) | ( ( ( r << 3 ) & 0x01ff ) | ( v - 'a' ) ) );
}
inline void pi_ipushLast ( int& r, int v )
{
  r = ( ( r & 0xfffffe00 ) | ( ( ( r & 0x01ff ) >> 3 ) | ( ( v - 'a' ) << 6 ) ) );
}
void pi_move ( int& r, int d )
{
  int p = pi_pos ( r );
  p += d;
  if ( p < 0 )
    p += strLength;
  else if ( p >= strLength )
    p -= strLength;
  pi_setPos ( r, p );
  pi_pushLast ( r, str [p] );
}
                                            
struct outcome
{
  int out;
  int count;
  int move_delta;
  int stx;
};

outcome pos_out [10057*512];

int ch_masks [512];
bool ch_enable [512];
void build_chs ()
{
  for ( int i = 0; i < 512; i++ )
  {
    ch_enable [i] = true;
    int a = ( i & 7 );
    int b = ( ( i >> 3 ) & 7 );
    int c = ( ( i >> 6 ) & 7 );
    if ( a == b || b == c || a == c )
      ch_enable [i] = false;
    ch_masks [i] = ( ( 1 << a ) | ( 1 << b ) | ( 1 << c ) );
  }
}

int strt [16384][15];
void build_tree ()
{
  for ( int i = 0; i < strLength; i++ )
    strt [i][0] = ( 1 << ( str [i] - 'a' ) );
  int pl = 1;
  int l = 2;
  for ( int i = 1; l <= strLength; i++ )
  {
    for ( int j = 0; j <= strLength - l; j++ )
    {
      strt [j][i] = ( strt [j][i-1] | strt [j+pl][i-1] );
    }
    pl = l;
    l *= 2;
  }
}

int clz ( int x )
{
  int c = 0;
  if ( ( x & 0xffff0000 ) == 0 )
  {
    c += 16;
    x <<= 16;
  }
  if ( ( x & 0xff000000 ) == 0 )
  {
    c += 8;
    x <<= 8;
  }
  if ( ( x & 0xf0000000 ) == 0 )
  {
    c += 4;
    x <<= 4;
  }
  if ( ( x & 0xc0000000 ) == 0 )
  {
    c += 2;
    x <<= 2;
  }
  if ( ( x & 0x80000000 ) == 0 )
    c += 1;
  return c;
}
inline int log2 ( int x )
{
  return 31 - clz ( x );
}

int get_mask ( int start, int end )
{
  int l = end - start + 1;
  int p2 = log2 ( l );
  int l1 = ( 1 << p2 );
  if ( l1 == l )
    return strt [start][p2];
  return ( strt [start][p2] | strt [start+l-l1][p2] );
}

int pos_queue [10057*512];
int q_head = 0;
int q_tail = 0;

inline void q_push ( int pos )
{
  pos_queue [q_head++] = pos;
}
inline int q_pop ()
{
  return pos_queue [q_tail++];
}
inline bool q_empty ()
{
  return q_tail == q_head;
}

int L, R;
void read_input ()
{
  FILE* f = fopen ( "strgame.in", "rt" );
  fscanf ( f, "%s", str );
  strLength = strlen ( str );
  fscanf ( f, "%d %d", &L, &R );
  fclose ( f );

  if ( L + R >= strLength )
  {
    R = strLength - 1 - L;
    if ( R < 0 )
    {
      L += R;
      R = 0;
    }
  }
}

int offset_pos ( int pos, int delta )
{
  pos += delta;
  if ( pos < 0 )
    return pos + strLength;
  if ( pos >= strLength )
    return pos - strLength;
  return pos;
}

int can_go ( int pos )
{
  int l = pos - L;
  int r = pos + R;
  if ( l < 0 )
    return get_mask ( l + strLength, strLength - 1 ) | get_mask ( 0, r );
  if ( r >= strLength )
    return get_mask ( l, strLength - 1 ) | get_mask ( 0, r - strLength );
  return get_mask ( l, r );
}

DWORD start;

void solve ()
{
  int pos0 = 0;
  pi_pushLast ( pos0, str [0] );
  pi_pushLast ( pos0, str [0] );
  pi_pushLast ( pos0, str [0] );

  build_chs ();
  build_tree ();
    
  int tSize = strLength * 512;
  for ( int i = 0; i < tSize; i++ )
  {
    int p = pi_pos ( i );
    int m = ch_masks [i&0x01ff];
    int cg = can_go ( p );
    if ( ( cg & ( ~m ) ) == 0 )
    {
      // P0
      pos_out [i].out = LOSE;
      pos_out [i].count = 0;
      pos_out [i].move_delta = -1;
      q_push ( i );
    }
    else
    {
      pos_out [i].out = DRAW;
      pos_out [i].stx = 0;
      for ( int j = -L; j <= R; j++ )
      {
        if ( ( m & ( 1 << ( str [offset_pos(p,j)] - 'a' ) ) ) == 0 )
          pos_out [i].stx++;
      }
      if ( pos_out [i].stx == 0 )
      {
        pos_out [i].out = LOSE;
        pos_out [i].count = 0;
        pos_out [i].move_delta = -1;
        q_push ( i );
      }
    }
  }

  while ( !q_empty () )
  {
    if ( GetTickCount () > start + 1950 )
      return;

    int i = q_pop ();
    if ( i == pos0 )
      return;
      
    int p = pi_pos ( i );
    int m = ch_masks [i&0x01ff];

    char ch = pi_last ( i, 1 );
    if ( ch == str [p] || pi_last ( i, 2 ) == str [p] )
      continue;

    if ( pos_out [i].out == LOSE )
    {
      for ( int j = -L; j <= R; j++ )
      {

        int x = offset_pos ( p, j );
        if ( str [x] == ch )
        {
          for ( char chx = 'a'; chx <= 'h'; chx++ )
          {
            int i2 = i;
            pi_setPos ( i2, x );
            pi_ipushLast ( i2, chx );
            if ( i2 == pos0 )
              int asdf = 0;
            if ( pos_out [i2].out == DRAW )
            {
              pos_out [i2].out = WIN;
              pos_out [i2].count = pos_out [i].count + 1;
              pos_out [i2].move_delta = -j;
              q_push ( i2 );
            }
            else if ( pos_out [i2].out == WIN && pos_out [i2].move_delta > -j )
              pos_out [i2].move_delta = -j;
          }
        }
      }
    }
    else
    {
      // WIN
      for ( int j = -L; j <= R; j++ )
      {
        int x = offset_pos ( p, j );
        if ( str [x] == ch )
        {
          for ( char chx = 'a'; chx <= 'h'; chx++ )
          {
            int i2 = i;
            pi_setPos ( i2, x );
            pi_ipushLast ( i2, chx );
            if ( pos_out [i2].out == DRAW )
            {
              pos_out [i2].stx--;
              if ( pos_out [i2].stx == 0 )
              {
                pos_out [i2].out = LOSE;
                pos_out [i2].count = pos_out [i].count + 1;
                q_push ( i2 );
              }
            }
          }
        }
      }
    }
  }
}

void write_output ()
{
  FILE* f = fopen ( "strgame.out", "wt" );
  int pos0 = 0;
  pi_pushLast ( pos0, str [0] );
  pi_pushLast ( pos0, str [0] );
  pi_pushLast ( pos0, str [0] );
  switch ( pos_out [pos0].out )
  {
  case WIN:
    fprintf ( f, "WIN\n%d\n%d", pos_out [pos0].count, pos_out [pos0].move_delta );
    break;
  case DRAW:
    fprintf ( f, "DRAW" );
    break;
  case LOSE:
    fprintf ( f, "LOSE\n%d", pos_out [pos0].count );
    break;
  }
  fclose ( f );
}

int main ()
{
  start = GetTickCount ();

  read_input ();
  solve ();
  write_output ();
  
  return 0;
}
