#include <stdio.h>
#include <algorithm>
using namespace std;

struct group
{
  int count;
  double pos;
  double speed; // curpos = pos + speed * absTime

  int hpos;
  
  group* next;
  group* prev;
};


group gr_alloc [131072];
int n_gr_alloc = 0;
inline group* galloc ()
{
  return & ( gr_alloc [n_gr_alloc++] );
}

// merge events
double heap [131072];
group* heap_bk [131072];
int hsize = 0;

void h_dec_key ( int el, group* g, double t )
{
  int cur = el;
  while ( cur > 0 )
  {
    int p = ( cur + 1 ) / 2 - 1;
    if ( heap [p] <= t )
    {
      heap [cur] = t;
      heap_bk [cur] = g;
      g->hpos = cur;
      return;
    }
    heap [cur] = heap [p];
    heap_bk [cur] = heap_bk [p];
    heap_bk [cur]->hpos = cur;
    cur = p;
  }
  heap [cur] = t;
  heap_bk [cur] = g;
  g->hpos = cur;
}

void h_inc_key ( int el )
{
  int cur = el;
  while ( cur * 2 + 1 < hsize )
  {
    int k = hsize;
    int j = cur * 2 + 1;
    if ( heap [j] < heap [cur] )
      k = j;
    j++;
    if ( j < hsize && heap [j] < heap [k] )
      k = j;
    if ( k == hsize )
    {
      heap_bk [cur] = heap_bk [hsize];
      heap [cur] = heap [hsize];
      heap_bk [cur]->hpos = cur;
      return;
    }
    heap [cur] = heap [k];
    heap_bk [cur] = heap_bk [k];
    heap_bk [cur]->hpos = cur;
    cur = k;
  }
  heap [cur] = heap [hsize];
  heap_bk [cur] = heap_bk [hsize];
  heap_bk [cur]->hpos = cur;
}

inline void h_push ( group* g, double t )
{
  h_dec_key ( hsize++, g, t );
}

group* h_pop ( double& t )
{
  group* ret = heap_bk [0];
  t = heap [0];
  ret->hpos = -1;

  hsize--;

  h_inc_key ( 0 );

  return ret;
}

void h_del ( group* g )
{
  if ( g->hpos < 0 )
    return;
  heap [hsize] = 1e+32;
  heap_bk [hsize] = g;
  h_inc_key ( g->hpos );
  hsize--;
  g->hpos = -1;
}

double cur_time;

void h_change ( group* g, double t )
{
  if ( t < cur_time )
    h_del ( g );
  else if ( g->hpos < 0 )
    h_push ( g, t );
  else if ( t < heap [g->hpos] )
    h_dec_key ( g->hpos, g, t );
  else
  {
    heap [hsize] = t;
    heap_bk [hsize] = g;
    h_inc_key ( g->hpos );
  }
}

void update_speed ( group* g )
{
  double vel = 100.0 / g->count;
  g->pos += cur_time * ( g->speed - vel );
  g->speed = vel;

  if ( g->next )
  {
    double col = ( g->next->pos - g->pos ) /
        ( ( g->speed - g->next->speed ) - 1e-57 );
    h_change ( g, col );
  }
  if ( g->prev )
  {
    double col = ( g->pos - g->prev->pos ) /
        ( ( g->prev->speed - g->speed ) - 1e-57 );
    h_change ( g->prev, col );
  }
}
void update_all ( group* first )
{
  group* cur = first;
  group* prev = NULL;
  while ( cur != NULL )
  {
    cur->speed = 100.0 / cur->count;
    cur->hpos = -1;
    cur->prev = prev;
    prev = cur;
    cur = cur->next;
  }

  cur = first;
  while ( cur != NULL )
  {
    if ( cur->next )
    {
      double col = ( cur->next->pos - cur->pos ) /
          ( ( cur->speed - cur->next->speed ) - 1e-57 );
      h_change ( cur, col );
    }
    cur = cur->next;
  }
}

group* first = NULL;

struct g_desc
{
  int count, pos;
};
bool operator < ( g_desc const& a, g_desc const& b )
{
  return a.pos < b.pos;
}
g_desc r_descs [131072];

void read_input ()
{
  FILE* f = fopen ( "longpath.in", "rt" );
  
  int ng;
  fscanf ( f, "%d", &ng );

  cur_time = -1e-32;

  for ( int i = 0; i < ng; i++ )
    fscanf ( f, "%d %d", &r_descs [i].count, &r_descs [i].pos );

  sort ( r_descs, r_descs + ng );

  for ( int i = ng - 1; i >= 0; i-- )
  {
    group* g = galloc ();
    g->pos = r_descs [i].pos;
    g->count = r_descs [i].count;
    g->next = first;
    first = g;
  }

  fclose ( f );
}

void solve ()
{
  update_all ( first );

  while ( hsize > 0 )
  {
    double t;
    group* g = h_pop ( t );
    cur_time = t;
    g->next->count += g->count;
    g->next->prev = g->prev;
    if ( g->prev )
      g->prev->next = g->next;
    else
      first = g->next;
    update_speed ( g->next );
  }
}

void write_output ()
{
  FILE* f = fopen ( "longpath.out", "wt" );
  
  group* cur = first;
  int count = 0;
  while ( cur != NULL )
  {
    count++;
    cur = cur->next;
  }
  fprintf ( f, "%d\n", count );
  cur = first;
  while ( cur != NULL )
  {
    fprintf ( f, "%d ", cur->count );
    cur = cur->next;
  }
  fprintf ( f, "\n" );

  fclose ( f );
}

int main ()
{
  read_input ();
  solve ();
  write_output ();

  return 0;
}
