#include <cstdio>
#include <algorithm>
#include <vector>
#include <map>
#include <memory.h>

#define maxn (long)110000
#define inf (double)1E100

using namespace std;

template<long max_el>
struct dsu{
	long a[max_el],r[max_el];
	dsu()
	{
		for(long i=0;i<max_el;i++) a[i]=-57;
		memset(r,0,sizeof(r));
	}
	long get(long x)
	{
		if(a[x]==-57) return x;
		long t=get(a[x]);
		a[x]=t;
		return t;
	}
	long operator[](long x)
	{
		return get(x);
	}
	long merge(long x,long y)
	{
		x=get(x),y=get(y);
/*		printf("Merge called with %d %d\n",x,y);*/
		if(r[x]>r[y]) a[y]=x; else
		if(r[x]<r[y]) a[x]=y; else
		a[y]=x,r[x]++;
/*		printf("a[x]=%d, a[y]=%d\n",a[x],a[y]);*/
		return get(x);
	}
};


struct grp{
	long n,l,r,c;
	double x;
	grp(){n=0,x=0,c=0,l=0,r=0;}
	grp(long nn,long cc,double xx){n=nn,x=xx,c=cc,l=nn,r=nn;}
	friend bool operator<(grp g1,grp g2)
	{
		return (g1.x<g2.x);
	}
};

struct pr{
	long x1,x2;
	double t;
	pr(){x1=0,x2=0,t=0;}
	pr(long xx1,long xx2,double tt){x1=xx1,x2=xx2,t=tt;}
	friend bool operator<(pr g1,pr g2)
	{
		return (g1.t<g2.t);
	}
	void print()
	{
		printf("Pr: %d %d %0.4lf\n",x1,x2,t);
	}
};

map<pair<long,long>,long> w;

template<class T>
struct pr_queue{
	T a[maxn];
	long n;
	pr_queue(){n=0;}
	inline long size(){return n;}
	void heap_up(long x)
	{
		while((x>1)&&(a[x]<a[x/2])){
			swap(w[make_pair(a[x].x1,a[x].x2)],w[make_pair(a[x/2].x1,a[x/2].x2)]);
			swap(a[x],a[x/2]);
			x/=2;
		}
	}
	void heap_down(long x)
	{
		long t;
		while(1){
			t=x;
			if((2*x<=n)&&(a[2*x]<a[t])) t=2*x;
			if((2*x+1<=n)&&(a[2*x+1]<a[t])) t=2*x+1;
			if(t==x) break;
			swap(w[make_pair(a[x].x1,a[x].x2)],w[make_pair(a[t].x1,a[t].x2)]);
			swap(a[t],a[x]);
			x=t;
		}
	}
	void insert(T t)
	{
		a[++n]=t;
		/*!*/w[make_pair(t.x1,t.x2)]=n;
		heap_up(n);
	}
	inline T top()
	{
		return a[1];
	}
	inline bool empty()
	{
		return (n==0);
	}
	void pop()
	{
		swap(a[1],a[n]);
		swap(w[make_pair(a[n].x1,a[n].x2)],w[make_pair(a[1].x1,a[1].x2)]);
		/*!*/w[make_pair(a[n].x1,a[n].x2)]=-1;
		n--;
		heap_down(1);
	}
	void print()
	{
		printf("Heap:\n");
		for(long i=1;i<=n;i++) a[i].print();
		printf("\n");
	}
};

dsu<maxn> d;
pr_queue<pr> q;
vector<grp> v;
long n;
vector<pair<long,long> > u;
bool us[maxn];

double time(long x,long y)
{
/*	printf("Time called with %d %d\n",x,y);*/
	double t;
	if(v[y].c<=v[x].c) t=inf; else{
		double c1=v[x].c,c2=v[y].c;
		t=((v[y].x-v[x].x)*c1*c2)/(c2-c1);
	}
	return t;
}


int main()
{
	freopen("longpath.in","r",stdin);
	scanf("%d",&n);
	double x,t;
	long c;
	for(long i=1;i<=n;i++){
		scanf("%d%lf",&c,&x);
		v.push_back(grp(i,c,x));
	}
	fclose(stdin);
	sort(v.begin(),v.end());
	for(long i=0;i<n-1;i++)
	{
		pr p;
		p.x1=i,p.x2=i+1;
		v[i].n=i,v[i+1].n=i+1;
		v[i].l=i,v[i+1].l=i+1;
		v[i].r=i,v[i+1].r=i+1;
		if(v[i+1].c<=v[i].c) p.t=inf; else{
			double c1=v[i].c,c2=v[i+1].c;
			p.t=((v[i+1].x-v[i].x)*c1*c2)/(c2-c1);
		}
		q.insert(p);
		
	}
	pr p;
	long m1,m2,nv,ls,rs;
	while(!q.empty()){
/*		printf("map:\n%d %d %d %d\n",w[make_pair(0,1)],w[make_pair(1,2)],w[make_pair(2,3)],w[make_pair(3,4)]);*/
		p=q.top(),q.pop();
/*		printf("map:\n%d %d %d %d\n",w[make_pair(0,1)],w[make_pair(1,2)],w[make_pair(2,3)],w[make_pair(3,4)]);*/
		if(p.t>=inf/100) break;
		m1=p.x1,m2=p.x2;
		m1=d[m1],m2=d[m2];
		if(m1>m2) swap(m1,m2);
		nv=d.merge(m1,m2);
/*		printf("Merging %d %d into %d because time is %lf\n",m1,m2,nv,p.t);*/
		v[nv].l=min(v[m1].l,v[m2].l);
		v[nv].r=max(v[m1].r,v[m2].r);
		v[nv].c=v[m1].c+v[m2].c;
/*		printf("d[0]=%d, d[1]=%d\n",d[0],d[1]);*/
		ls=-1;
		if(v[nv].l-1>=0){
			ls=w[make_pair(v[nv].l-1,v[nv].l)];
		}
/*		q.print();*/
		if(ls!=-1){
			/*!q.a[ls].x2=nv;*/
			q.a[ls].t=p.t+time(d[m1-1],d[m1]);
			q.heap_up(ls);
			q.heap_down(ls);
		}
		rs=-1;
		if(v[nv].r+1<n){
			rs=w[make_pair(v[nv].r,v[nv].r+1)];
		}
/*		q.print();*/
/*		printf("ls=%d, rs=%d\n",ls,rs);*/
		if(rs!=-1){
			/*!q.a[rs].x1=nv;*/
			q.a[rs].t=p.t+time(d[m2],d[m2+1]);
			q.heap_up(rs);
			q.heap_down(rs);
		}
/*		q.print();*/
	}
	memset(us,0,sizeof(us));
	for(long i=0;i<v.size();i++){
		nv=d[i];
		if(us[nv]) continue;
		us[nv]=true;
		u.push_back(make_pair(nv,v[nv].c));
	}
	freopen("longpath.out","w",stdout);
	printf("%d\n",u.size());
	for(long i=0;i<u.size();i++)
		printf("%d ",u[i].second);
	printf("\n");
	fclose(stdout);
	return 0;
}
