#include <stdio.h>
#include <stdlib.h>
#include <string.h>

typedef long double dbl;

#define ABS(A) ((A) > 0 ? (A) : -(A))
#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))

#define MAX 100010
#define EPS 1e-9

int N, K[MAX], L[MAX], R[MAX], InQ[MAX];
dbl CurT = 0, X[MAX], V[MAX], T0[MAX], DT[MAX];

void QSort( int L, int R )
{
  int i = L, j = R, tmp2;
  dbl x, tmp;

  if (L >= R)
    return;
  x = X[L + (rand() % (R - L + 1))];
  while (i <= j)
  {
    while (X[i] + EPS < x) i++;
    while (X[j] - EPS > x) j--;
    if (i <= j)
    {
      SWAP(X[i], X[j], tmp);
      SWAP(K[i], K[j], tmp2);
      i++, j--;
    }
  }
  QSort(L, j), QSort(i, R);
}

int HN = 0, H[MAX], HP[MAX];

void Up( int i )
{
  int k;
  for (k = H[i]; i > 1 && DT[H[i >> 1]] > DT[k]; i >>= 1)
    H[i] = H[i >> 1], HP[H[i]] = i;
  H[i] = k, HP[k] = i;
}

void Down( int i )
{
  int l, r, m, tmp;
  while (1)
  {
    m = i, l = i + i, r = l + 1;
    if (l <= HN && DT[H[l]] < DT[H[m]]) m = l;
    if (r <= HN && DT[H[r]] < DT[H[m]]) m = r;
    if (i == m)
      break;
    SWAP(H[i], H[m], tmp);
    H[H[i]] = i, H[H[m]] = m;
    i = m;
  }
}

void Add( int i )
{
  InQ[i] = 1;
  H[++HN] = i, HP[i] = HN;
  Up(HN);
}

void Del( int i )
{
  InQ[i] = 0;
  i = HP[i];
  H[i] = H[HN--], HP[H[i]] = i;
  if (i < HN)
    Up(i), Down(i);
}

int Get( void )
{
  int r = H[1];
  Del(H[1]);
  return r;
}

void CorX( int i )
{
  X[i] += V[i] * (CurT - T0[i]), T0[i] = CurT;
}

void DAdd( int i )
{
  CorX(i);
  if (InQ[i])
    Del(i);
  DT[i] = CurT + (X[R[i]] - X[i]) / (V[i] - V[R[i]]);
  Add(i);
}

void Do( int i )
{
  CorX(i);
  if (L[i] != -1 && K[L[i]] < K[i])
    DAdd(L[i]);
  if (R[i] != -1 && K[i] < K[R[i]])
    DAdd(i);
}

void DelL( int i )
{
  K[i] += K[L[i]];
  if (InQ[L[i]]) Del(L[i]);
  InQ[L[i]] = -1;
  L[i] = L[L[i]];
  if (L[i] != -1) R[L[i]] = i;
}

void DelR( int i )
{
  K[i] += K[R[i]];
  if (InQ[R[i]]) Del(R[i]);
  InQ[R[i]] = -1;
  R[i] = R[R[i]];
  if (R[i] != -1) L[R[i]] = i;
}

int main( void )
{
  int i, sum = 0;

  freopen("longpath.in", "rt", stdin);
  freopen("longpath.out", "wt", stdout);
  scanf("%d", &N);
  for (i = 0; i < N; i++)
    scanf("%d%Lf", &K[i], &X[i]);
  QSort(0, N - 1);
  for (i = 0; i < N; i++)
  {
    L[i] = i - 1;
    R[i] = (i == N - 1 ? -1 : i + 1);
    V[i] = 100.0 / K[i];
    T0[i] = 0;
    InQ[i] = 0;
  }
  for (i = 0; i < N; i++)
    Do(i);
  while (HN)
  {
    i = Get();
    while (R[i] != -1 && InQ[R[i]] && ABS(DT[i] - DT[R[i]]) < EPS)
      DelR(i);
    DelR(i);
    while (L[i] != -1 && InQ[L[i]] && ABS(DT[i] - DT[L[i]]) < EPS)
      DelL(i);
    CurT = DT[i];
    Do(i);
  }
  for (i = 0; i < N; i++)
    if (InQ[i] != -1)
      sum++;
  printf("%d\n", sum);
  for (i = 0; i < N; i++)
    if (InQ[i] != -1)
      printf("%d ", K[i]);
  return 0;
}
