#include <stdio.h>
#include <memory.h>

struct edge
{
  int v2;

  edge* next;
  edge* back;

  int width;
  int flow;
  int left;
};

struct vertex
{
  edge* first;
};
struct graph
{
  vertex v [256];
  int n;
  int s, t;

  void init ( int V, int S, int T )
  {
    n = V;
    s = S;
    t = T;
    for ( int i = 0; i < n; i++ )
      v [i].first = NULL;
  }
  void add_edge ( int a, int b, int width );
  int maxflow ();
};

edge edge_pool [65536];
int neep = 0;
edge* ealloc ()
{
  return & ( edge_pool [neep++] );
}

void graph::add_edge ( int a, int b, int width )
{
  edge* e1 = ealloc ();
  edge* e2 = ealloc ();
  e1->back = e2;
  e2->back = e1;

  e1->width = width;
  e2->width = 0;

  e1->v2 = b;
  e2->v2 = a;
  
  e1->next = v [a].first;
  v [a].first = e1;

  e2->next = v [b].first;
  v [b].first = e2;
}

struct operation
{
  int x, u, v;
};
operation ops [128*128*128];
int nops = 0;

void exchange ( int x, int u, int v )
{
//  coins [0][u]++;
//  coins [0][v]--;
//  coins [x][u]--;
//  coins [x][v]++;
  ops [nops].x = x + 1;
  ops [nops].u = u + 1;
  ops [nops].v = v + 1;
  nops++;
}

int n, m;
int coins [128][128];
int ans;
int coin_base;
int trade_base;

int maxflow ( graph& G )
{
  for ( int i = 0; i < G.n; i++ )
  {
    for ( edge* e = G.v [i].first; e != NULL; e = e->next )
    {
      e->flow = 0;
      e->left = e->width;
    }
  }

  int vqueue [256];
  int parent [256];
  int minf [256];
  int vis [256];
  edge* byedge [256];
  memset ( vis, 0, sizeof vis );
  int stepno = 0;
  int sumflow = 0;

  int row [256];
  int rowsize;

  while ( true )
  {
    stepno++;
    int qhead = 1;
    int qtail = 0;
    vqueue [0] = G.s;

    parent [G.s] = -1;
    byedge [G.s] = NULL;
    minf [G.s] = 1000000;
    vis [G.s] = stepno;

    while ( qhead > qtail )
    {
      int v = vqueue [qtail++];
      if ( v == G.t )
        break;
      for ( edge* e = G.v [v].first; e != NULL; e = e->next )
      {
        if ( e->left <= 0 )
          continue;
        int flow = ( minf [v] > e->left ? e->left : minf [v] );
        if ( vis [e->v2] != stepno )
        {
          vis [e->v2] = stepno;
          vqueue [qhead++] = e->v2;
          parent [e->v2] = v;
          byedge [e->v2] = e;
          minf [e->v2] = flow;
        }
        else if ( minf [e->v2] < flow )
        {
          parent [e->v2] = e->v2;
          byedge [e->v2] = e;
          minf [e->v2] = flow;
        }
      }
    }
    if ( vis [G.t] == stepno && minf [G.t] > 0 )
    {
      int v = G.t;
      int flow = minf [G.t];
      rowsize = 0;
      while ( byedge [v] != NULL )
      {
        edge* e = byedge [v];
        e->flow += flow;
        e->left -= flow;
        e->back->flow -= flow;
        e->back->left += flow;

        row [rowsize++] = v;
            
        v = parent [v];
      }
      // get the coin, trade, ..., trade, store the coin
      for ( int i = rowsize-1; i >= 3; i -= 2 )
        exchange ( row [i-1] - trade_base, row [i-2] - coin_base, row [i] - coin_base );
//      for ( int i = rowsize - 1; i >= 0; i-- )
//        exchange ( row [i] - 2, 0, 0 );
//      exchange ( -3, 0, 0 );
      sumflow += flow;
    }
    else
      return sumflow;
  }
}

inline int graph::maxflow ()
{
  return ::maxflow ( *this );
}

void read_input ()
{
  FILE* f = fopen ( "coins.in", "rt" );
  fscanf ( f, "%d %d", &n, &m );
  for ( int i = 0; i < n; i++ )
    for ( int j = 0; j < m; j++ )
      fscanf ( f, "%d", &coins [i][j] );
  fclose ( f );
}

void write_output ()
{
  FILE* f = fopen ( "coins.out", "wt" );
  fprintf ( f, "%d\n", ans );
  for ( int i = 0; i < nops; i++ )
    fprintf ( f, "%d %d %d\n", ops [i].x, ops [i].u, ops [i].v );
  fclose ( f );
}

void solve ()
{
  graph G;
  G.init ( n + m + 1, 0, 1 );

  coin_base = 2;
  trade_base = 1 + m;

  for ( int i = 0; i < m; i++ )
  {
    if ( coins [0][i] > 0 )
      G.add_edge ( 0, i + coin_base, coins [0][i] );
    G.add_edge ( i + coin_base, 1, 1 );
  }

  for ( int i = 1; i < n; i++ )
  {
    int v = i + trade_base;
    for ( int j = 0; j < m; j++ )
    {
      if ( coins [i][j] == 0 )
        G.add_edge ( j + coin_base, v, 1 );
      if ( coins [i][j] > 1 )
        G.add_edge ( v, j + coin_base, coins [i][j] - 1 );
    }
  }

  ans = G.maxflow ();
}
    
int main ()
{
  read_input ();
  solve ();
  write_output ();

  return 0;
}
