#include <stdio.h>
#include <string.h>

#define MIN(A, B) (((A) <= (B)) ? (A) : (B))
#define MAX(A, B) (((A) >= (B)) ? (A) : (B))
#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))
#define ABS(X) (((X) >= 0) ? (X) : -(X))

#define eps 1e-9

#define MAXN 100010

int N, K[MAXN], Ne[MAXN], Pr[MAXN], TN, TA[MAXN];
double X[MAXN], T[MAXN], HK[MAXN];
int HZ, HR[MAXN], HX[MAXN];

void HPut(int X, double K)
{
  int i = ++HZ, t1;
  double t2;
  HX[i] = X;
  HK[i] = K;
  HR[HX[i]] = i;
  while (i > 1 && HK[i] < HK[i >> 1])
  {
    SWAP(HX[i], HX[i >> 1], t1);
    SWAP(HK[i], HK[i >> 1], t2);
    HR[HX[i]] = i;
    i >>= 1;
    HR[HX[i]] = i;
  }
}

int HGet()
{
  int X = HX[1], i = 1, j, t1;
  double t2;
  HR[HX[1]] = -1;
  HK[1] = HK[HZ];
  HX[1] = HX[HZ--];
  if (HZ)
    HR[HX[1]] = 1;
  while (1)
  {
    j = i;
    if (i << 1 <= HZ && HK[i << 1] > HK[j])
      j = i << 1;
    if (i << 1 + 1 <= HZ && HK[i << 1 + 1] > HK[j])
      j = i << 1 + 1;
    if (i == j)
      break;
    SWAP(HX[i], HX[j], t1);
    SWAP(HK[i], HK[j], t2);
    HR[HX[i]] = i;
    HR[HX[j]] = j;
    i = j;
  }
  return X;
}

void HDel( int k )
{
  int i = k, j, t1;
  double t2;
  HR[HX[k]] = -1;
  HK[k] = HK[HZ];
  HX[k] = HX[HZ--];
  if (HZ)
    HR[HX[k]] = k;
  while (1)
  {
    j = i;
    if (i << 1 <= HZ && HK[i << 1] > HK[j])
      j = i << 1;
    if (i << 1 + 1 <= HZ && HK[i << 1 + 1] > HK[j])
      j = i << 1 + 1;
    if (i == j)
      break;
    SWAP(HX[i], HX[j], t1);
    SWAP(HK[i], HK[j], t2);
    HR[HX[i]] = i;
    HR[HX[j]] = j;
    i = j;
   }
}

void QSort(int l, int r)
{
  int i = l, j = r, t1;
  double x, t2;
  if (l >= r)
    return;
  x = X[l + rand() % (r - l + 1)];
  while (i <= j)
  {
    while (X[i] < x) i++;
    while (X[j] > x) j--;
    if (i <= j)
    {
      SWAP(K[i], K[j], t1);
      SWAP(X[i], X[j], t2);
      i++, j--;
    }
  }
  QSort(l, j);
  QSort(i, r);
}

int main( void )
{
  srand(20060829);
  int i;

  freopen("longpath.in", "rt", stdin);
  freopen("longpath.out", "wt", stdout);

  scanf("%d", &N);
  for (i = 0; i < N; i++)
    scanf("%d%lf", &K[i], &X[i]);
  QSort(0, N - 1);

  for (i = 0; i < N; i++)
  {
    if (i == 0)
      Pr[i] = -1;
    else
      Pr[i] = i - 1;
    if (i == N - 1)
      Ne[i] = -1;
    else
      Ne[i] = i + 1;
  }
  HZ = 0;
  memset(HR, -1, sizeof(HR));
  for (i = 0; i < N - 1; i++)
  {
    T[i] = 0;
    if (K[i] < K[i + 1])
      HPut(i, 1.0 * (K[i] * K[i + 1] * (X[i + 1] - X[i])) / (K[i + 1] - K[i]));
  }
  while (HZ)
  {
    double Time = HK[1];
    int k = HGet();
    X[k] += (Time - T[k]) / K[k];
    T[k] = Time;
    K[k] += K[Ne[k]];
    if (Ne[Ne[k]] + 1)
      Pr[Ne[Ne[k]]] = k;
    if (HR[Ne[k]] + 1)
      HDel(HR[Ne[k]]);
    Ne[k] = Ne[Ne[k]];
    if (HR[k] + 1)
      HDel(HR[k]);
    if (Ne[k] + 1)
    {
      X[Ne[k]] += (Time - T[Ne[k]]) / K[Ne[k]];
      T[Ne[k]] = Time;
      if (K[k] < K[Ne[k]] || ABS(X[k] - X[Ne[k]]) < eps)
        HPut(k, Time + 1.0 * (K[Ne[k]] - K[k]) / (K[k] * K[Ne[k]] * (X[Ne[k]] - X[k])));
    }
    if (Pr[k] + 1)
    {
      if (HR[Pr[k]] + 1)
        HDel(HR[Pr[k]]);
      X[Pr[k]] += (Time - T[Pr[k]]) / K[Pr[k]];
      T[Pr[k]] = Time;
      if (K[Pr[k]] < K[k] || ABS(X[k] - X[Pr[k]]) < eps)
        HPut(Pr[k], Time + 1.0 * (K[k] - K[Pr[k]]) / (K[Pr[k]] * K[k] * (X[k] - X[Pr[k]])));
    }
  }

  TN = 0;
  for (i = 0; i + 1; i = Ne[i])
    TA[TN++] = K[i];

  printf("%d\n", TN);
  for (i = 0; i < TN; i++)
    printf("%d%c", TA[i], (i == TN - 1) ? '\n' : ' ');

  return 0;
}
