#include <stdio.h>
#include <memory.h>


int clz ( int x )
{
  int k = 0;
  if ( x & 0xffff0000 )
  {
    k += 16;
    x <<= 16;
  }
  if ( x & 0xff000000 )
  {
    k += 8;
    x <<= 8;
  }
  if ( x & 0xf0000000 )
  {
    k += 4;
    x <<= 4;
  }
  if ( x & 0xc0000000 )
  {
    k += 2;
    x <<= 2;
  }
  if ( x & 0x80000000 )
    k++;   
  return k;
}
int log2u ( int n )
{
  int l2 = 31 - clz ( n );
  if ( ( 1 << l2 ) < n )
    l2++;
  return l2;
}

int maxtree [2097152];
int mintree [2097152];

int num [1500002];
int n;
int np2;

struct nump
{
  int i;
  nump* next;
};
nump nump_pool [1500002];
int pused = 0;
nump* nalloc ()
{
  return &nump_pool [pused++];
}
nump* lastp [1500002];
nump* inumps [1500002];

void build_nump ()
{
  memset ( lastp, 0, sizeof lastp );

  for ( int i = 0; i < n; i++ )
  {
    int p = num [i] - i;
    nump* np = nalloc ();
    if ( lastp [p] )
      lastp [p]->next = np;
    lastp [p] = np;
    np->i = i;
    np->next = NULL;
    inumps [i] = np;
  }
}

struct empodio
{
  int start;
  int end;
};
empodio e [1500002];
int ne;

#define min(a,b) (a<b?a:b)
#define max(a,b) (a>b?a:b)

void build_tree ()
{
  int lri = np2 / 2 - 1;
  int n2 = np2 / 2;
  for ( int i = 0; i < n2; i++ )
  {
    int j1 = i * 2;
    int j2 = j1 + 1;
    if ( j1 >= n )
    {
      mintree [i+lri] = 1000000000;
      maxtree [i+lri] = 0;
    }
    else if ( j2 >= n )
    {
      mintree [i+lri] = num [j1];
      maxtree [i+lri] = num [j1];
    }
    else
    {
      mintree [i+lri] = min ( num [i*2], num [i*2+1] );
      maxtree [i+lri] = max ( num [i*2], num [i*2+1] );
    }
  }
  for ( int i = lri-1; i >= 0; i-- )
  {
    int j1 = i * 2 + 1;
    int j2 = j1 + 1;
    mintree [i+lri] = min ( mintree [j1], mintree [j2] );
    maxtree [i+lri] = max ( maxtree [j1], maxtree [j2] );
  }
}
int min_ij ( int i, int j )
{
  int v = min ( num [i], num [j] );
  if ( ( i & 1 ) == 0 )
    v = min ( v, num [i+1] );
  if ( j & 1 )
    v = min ( v, num [j-1] );
  i = ( i + np2 ) / 2 - 1;
  j = ( j + np2 ) / 2 - 1;
  while ( i < j-1 )
  {
    if ( i & 1 )
      v = min ( v, mintree [i+1] );
    if ( ( j & 1 ) == 0 )
      v = min ( v, mintree [j-1] );
    i /= 2;
    j /= 2;
  }
  return v;
}
int max_ij ( int i, int j )
{
  int v = max ( num [i], num [j] );
  if ( ( i & 1 ) == 0 )
    v = max ( v, num [i+1] );
  if ( j & 1 )
    v = max ( v, num [j-1] );
  i = ( i + np2 ) / 2 - 1;
  j = ( j + np2 ) / 2 - 1;
  while ( i < j-1 )
  {
    if ( i & 1 )
      v = max ( v, maxtree [i+1] );
    if ( ( j & 1 ) == 0 )
      v = max ( v, maxtree [j-1] );
    i /= 2;
    j /= 2;
  }
  return v;
}

void read_input ()
{
  FILE* f = fopen ( "empodio.in", "rt" );

  fscanf ( f, "%d", &n );
  for ( int i = 0; i < n; i++ )
    fscanf ( f, "%d", &num [i] );

  np2 = ( 1 << log2u ( n ) );

  fclose ( f );
}
void write_output ()
{
  FILE* f = fopen ( "empodio.out", "wt" );

  fprintf ( f, "%d\n", ne );
  for ( int i = 0; i < ne; i++ )
    fprintf ( f, "%d %d\n", e [i].start + 1, e [i].end + 1 );

  fclose ( f );
}

void solve ()
{
  build_tree ();
  build_nump ();

  ne = 0;

  for ( int i = 0; i < n; i++ )
  {
    nump* p = inumps [i]->next;
    int vi = num [i];
    while ( p != NULL )
    {
      int j = p->i;
      int vj = num [j];
      if ( min_ij ( i, j ) >= vi && max_ij ( i, j ) <= vj )
      {
        // empodio
        while ( ne > 0 && e [ne-1].end >= j )
          ne--;
        e [ne].start = i;
        e [ne].end = j;
        ne++;
        break;
      }
      p = p->next;
    }
  }
}

int main ()
{
  read_input ();
  solve ();
  write_output ();

  return 0;
}
