#include <cstdio>
#include <cmath>
#include <algorithm>

#define EPS 1e-10

long double d[4][4], x[5], y[5], z[5], xt, m[3][3];
long double cx[4], cy[4], cz[4], nx[4], ny[4], nz[4];
int i, j, k;

bool solve(){
  int i, j, k, max;
  long double tmp;
  for (i=0; i<2; i++){
    max=i;
    for (j=i+1; j<3; j++) if (fabs(m[j][i])>fabs(m[max][i])) max=j;
    for (j=0; j<3; j++) std::swap(m[i][j], m[max][j]);
    tmp=m[i][i];
    for (j=0; j<3; j++) m[i][j]/=tmp;
    for (j=0; j<3; j++){
      if (i==j) continue;
      tmp=m[j][i];
      for (k=0; k<3; k++) m[j][k]-=m[i][k]*tmp;
    }
  }
  if (fabs(m[2][2])>EPS) return false;
  xt=m[0][2];
}

void findcenter(int p, int a, int b, int c){
  long double lab, lac, lbc;
  lab=sqrt((x[a]-x[b])*(x[a]-x[b])+(y[a]-y[b])*(y[a]-y[b])+(z[a]-z[b])*(z[a]-z[b]));
  lac=sqrt((x[a]-x[c])*(x[a]-x[c])+(y[a]-y[c])*(y[a]-y[c])+(z[a]-z[c])*(z[a]-z[c]));
  lbc=sqrt((x[b]-x[c])*(x[b]-x[c])+(y[b]-y[c])*(y[b]-y[c])+(z[b]-z[c])*(z[b]-z[c]));
  m[0][0]=(x[b]-x[a])/lab+(x[c]-x[a])/lac;
  m[0][1]=(x[a]-x[b])/lab+(x[c]-x[b])/lac;
  m[0][2]=x[b]-x[a];
  m[1][0]=(y[b]-y[a])/lab+(y[c]-y[a])/lac;
  m[1][1]=(y[a]-y[b])/lab+(y[c]-y[b])/lac;
  m[1][2]=y[b]-y[a];
  m[2][0]=(z[b]-z[a])/lab+(z[c]-z[a])/lac;
  m[2][1]=(z[a]-z[b])/lab+(z[c]-z[b])/lac;
  m[2][2]=z[b]-z[a];
  solve();
  cx[p]=x[a]+xt*((x[b]-x[a])/lab+(x[c]-x[a])/lac);
  cy[p]=y[a]+xt*((y[b]-y[a])/lab+(y[c]-y[a])/lac);
  cz[p]=z[a]+xt*((z[b]-z[a])/lab+(z[c]-z[a])/lac);
}

void findnormal(int p, int a, int b, int c){
  nx[p]=(y[b]-y[a])*(z[c]-z[a])-(y[c]-y[a])*(z[b]-z[a]);
  ny[p]=(z[b]-z[a])*(x[c]-x[a])-(z[c]-z[a])*(x[b]-x[a]);
  nz[p]=(x[b]-x[a])*(y[c]-y[a])-(x[c]-x[a])*(y[b]-y[a]);
}

void findcenters(){
  findcenter(0, 0, 1, 2);
  findcenter(1, 0, 1, 3);
  findcenter(2, 0, 2, 3);
  findcenter(3, 1, 2, 3);
}

void findnormals(){
  findnormal(0, 0, 1, 2);
  findnormal(1, 0, 1, 3);
  findnormal(2, 0, 2, 3);
  findnormal(3, 1, 2, 3);
}

int main(){
  freopen("tetrahedron.in", "rt", stdin);
  freopen("tetrahedron.out", "wt", stdout);
  scanf("%llf%llf%llf%llf%llf%llf", &d[0][1], &d[0][2], &d[0][3], &d[1][2], &d[1][3], &d[2][3]);
  d[1][0]=d[0][1];
  d[2][0]=d[0][2];
  d[3][0]=d[0][3];
  d[2][1]=d[1][2];
  d[3][1]=d[1][3];
  d[3][2]=d[2][3];
  for (i=0; i<4; i++)
    for (j=0; j<4; j++)
      for (k=0; k<4; k++){
        if (i==j||i==k||j==k) continue;
        if (d[i][j]+d[j][k]<=d[k][i]){
         printf("IMPOSSIBLE");
         return 0;
        }
      }
  x[0]=0;
  y[0]=0;
  z[0]=0;
  x[1]=d[0][1];
  y[1]=0;
  z[1]=0;
  x[2]=(d[0][2]*d[0][2]-d[1][2]*d[1][2]+x[1]*x[1])/(2*x[1]);
  y[2]=sqrt(d[0][2]*d[0][2]-x[2]*x[2]);
  z[2]=0;
  x[3]=(d[0][3]*d[0][3]-d[1][3]*d[1][3]+x[1]*x[1])/(2*x[1]);
  y[3]=(d[0][3]*d[0][3]-d[2][3]*d[2][3]+y[2]*y[2]-2*x[2]*x[3]+x[2]*x[2])/(2*y[2]);
  z[3]=sqrt(d[0][3]*d[0][3]-x[3]*x[3]-y[3]*y[3]);
  findcenters();
  findnormals();
  m[0][0]=nx[0];
  m[0][1]=nx[1];
  m[0][2]=cx[1]-cx[0];
  m[1][0]=ny[0];
  m[1][1]=ny[1];
  m[1][2]=cy[1]-cy[0];
  m[2][0]=nz[0];
  m[2][1]=nz[1];
  m[2][2]=cz[1]-cz[0];
  if (!solve()){
    printf("NO");
    return 0;
  }
  m[0][0]=nx[0];
  m[0][1]=nx[2];
  m[0][2]=cx[2]-cx[0];
  m[1][0]=ny[0];
  m[1][1]=ny[2];
  m[1][2]=cy[2]-cy[0];
  m[2][0]=nz[0];
  m[2][1]=nz[2];
  m[2][2]=cz[2]-cz[0];
  if (!solve()){
    printf("NO");
    return 0;
  }
  m[0][0]=nx[0];
  m[0][1]=nx[3];
  m[0][2]=cx[3]-cx[0];
  m[1][0]=ny[0];
  m[1][1]=ny[3];
  m[1][2]=cy[3]-cy[0];
  m[2][0]=nz[0];
  m[2][1]=nz[3];
  m[2][2]=cz[3]-cz[0];
  if (!solve()){
    printf("NO");
    return 0;
  }
  x[4]=cx[0]+nx[0]*xt;
  y[4]=cy[0]+ny[0]*xt;
  z[4]=cz[0]+nz[0]*xt;
  printf("YES\n");
  printf("%.20lf\n", sqrt(y[4]*y[4]+z[4]*z[4]));
  printf("%.20lf\n", sqrt((x[4]-x[0])*(x[4]-x[0])+(y[4]-y[0])*(y[4]-y[0])+(z[4]-z[0])*(z[4]-z[0])));
  printf("%.20lf\n", sqrt((x[4]-x[1])*(x[4]-x[1])+(y[4]-y[1])*(y[4]-y[1])+(z[4]-z[1])*(z[4]-z[1])));
  printf("%.20lf\n", sqrt((x[4]-x[2])*(x[4]-x[2])+(y[4]-y[2])*(y[4]-y[2])+(z[4]-z[2])*(z[4]-z[2])));
  printf("%.20lf\n", sqrt((x[4]-x[3])*(x[4]-x[3])+(y[4]-y[3])*(y[4]-y[3])+(z[4]-z[3])*(z[4]-z[3])));
  return 0;
}
