#include <stdio.h>
#include <memory.h>
#include <string.h>
#include <math.h>
#include <algorithm>

typedef long double real;
#define EPS 1e-10
#define DELTA 1e-8

int l01, l02, l03, l12, l13, l23;
real crd[4][3];
real matr[6][4];
real centre[3];

inline real sqr(real a) { return a*a; }
inline real dist(int a, int b) {
	return sqrt( sqr(crd[a][0]-crd[b][0])
			   + sqr(crd[a][1]-crd[b][1])
			   + sqr(crd[a][2]-crd[b][2]));
}
inline real adist(real *a, real *b) {
	return sqrt(sqr(a[0]-b[0]) + sqr(a[1]-b[1]) + sqr(a[2]-b[2]));
}

bool BuildHedron() {
	memset(crd, 0, sizeof(crd));
	crd[1][0] = l01;
	real alp = (l02*l02 + l01*l01 - l12*l12) / (2.0*l01*l02);
	if (fabs(alp) >= 1.0-EPS)
		return false;
	alp = acos(alp);
	crd[2][0] = l02 * cos(alp);
	crd[2][1] = l02 * sin(alp);
	crd[3][0] = (l03*l03 - l13*l13 + l01*l01) / (2.0*l01);
	double dx = sqr(crd[3][0]-crd[2][0]) - sqr(crd[3][0]-l01);
	crd[3][1] = (sqr(crd[2][1]) + l13*l13 - l23*l23 + dx) / (2.0*crd[2][1]);
	crd[3][2] = l03*l03 - sqr(crd[3][0]) - sqr(crd[3][1]);
	if (crd[3][2] < EPS)
		return false;
	crd[3][2] = sqrt(crd[3][2]);
	return true;
}

void fillRow(real *arr, int a, int b, int c) {
	real av[3], cv[3], mid[3];
	real alen = dist(a, b);
	real clen = dist(c, b);
	av[0] = (crd[a][0] - crd[b][0])/alen;
	av[1] = (crd[a][1] - crd[b][1])/alen;
	av[2] = (crd[a][2] - crd[b][2])/alen;
	cv[0] = (crd[c][0] - crd[b][0])/clen;
	cv[1] = (crd[c][1] - crd[b][1])/clen;
	cv[2] = (crd[c][2] - crd[b][2])/clen;
	mid[0] = (av[0]+cv[0])/2 + crd[b][0];
	mid[1] = (av[1]+cv[1])/2 + crd[b][1];
	mid[2] = (av[2]+cv[2])/2 + crd[b][2];
	arr[1] = av[0]-cv[0];
	arr[2] = av[1]-cv[1];
	arr[3] = av[2]-cv[2];
	arr[0] = arr[1]*mid[0] + arr[2]*mid[1] + arr[3]*mid[2];
}

real getDist(real *p, real *a, real *b) {
	real scal = 0;
	real abdst = sqrt(sqr(a[0]-b[0]) + sqr(a[1]-b[1]) + sqr(a[2]-b[2]));
	real pbdst = sqrt(sqr(p[0]-b[0]) + sqr(p[1]-b[1]) + sqr(p[2]-b[2]));
	real ph[3];
	int i;
	for (i = 0; i<3; i++)
		scal += (b[i]-p[i]) * (b[i]-a[i]);
	scal /= (abdst*abdst);
	for (i = 0; i<3; i++)
		ph[i] = (b[i]-p[i]) - scal*(b[i]-a[i]);
	return sqrt(sqr(ph[0]) + sqr(ph[1]) + sqr(ph[2]));
}

bool Gauss() {
	int i, j, k;
	for (i = 1; i<=3; i++) {
		int f = -1;
		for (j = i-1; j<6; j++)
			if (fabs(matr[j][i]) > EPS) {
				f = j;
				break;
			}
		if (f<0)
			return false;
		for (j = 0; j<4; j++)
			std::swap(matr[i-1][j], matr[f][j]);
		for (j = i; j<6; j++) {
			real coef = matr[j][i] / matr[i-1][i];
			for (k = 0; k<4; k++)
				matr[j][k] -= coef * matr[i-1][k];
		}
	}
	for (i = 3; i<6; i++)
		if (fabs(matr[i][0]) > DELTA)
			return false;
	for (i = 3; i>=1; i--) {
		for (j = i+1; j<4; j++)
			matr[i-1][0] -= matr[i-1][j] * centre[j-1];
		centre[i-1] = matr[i-1][0] / matr[i-1][i];
	}
	return true;
}

int main(int argc, char **argv) {
	freopen("tetrahedron.in", "r", stdin);
	freopen("tetrahedron.out", "w", stdout);
	scanf("%d%d%d%d%d%d", &l01, &l02, &l03, &l12, &l13, &l23);
	if (!BuildHedron()) {
		printf("IMPOSSIBLE");
		return 0;
	}
	fillRow(matr[0], 0, 3, 1);
	fillRow(matr[1], 1, 3, 2);
	fillRow(matr[2], 0, 1, 2);
	fillRow(matr[3], 1, 2, 0);
	fillRow(matr[4], 2, 0, 1);
	fillRow(matr[5], 3, 0, 1);
	if (!Gauss()) {
		printf("NO");
		return 0;
	}
	printf("YES\n");
	int i;
	printf("%0.20llf\n", getDist(centre, crd[0], crd[1]));
	for (i = 0; i<4; i++)
		printf("%0.20llf\n", adist(crd[i], centre));
	return 0;
}
