program bpas;

const eps = 1e-10;

type integer = longint;
     real    = extended;

type tpoint = record
        x, y, z : real;
     end;
     tline = record
        a, b, c : real;
     end;

var p : array [1..4] of tpoint;
    d12, d13, d14, d23, d24, d34 : integer;
    ok   : boolean;
    h, r : real;
    cp   : tpoint;

procedure Load;
begin
   assign(Input, 'tetrahedron.in');
   reset(Input);
   read(d12, d13, d14, d23, d24, d34);
   close(Input);
end;

function d(p1, p2 : tpoint) : real;
begin
   d := sqrt(sqr(p1.x-p2.x)+sqr(p1.y-p2.y)+sqr(p1.z-p2.z));
end;

function calc(ang : real) : real;
begin
   p[4].y := h*cos(ang);
   p[4].z := h*sin(ang);
   calc := d(p[4], p[3]);
end;

function find(l, r : real) : real;
begin
   if abs(calc(l)-calc(r)) < eps then begin
      find := l; exit;
   end;
   if d24-calc((l+r)/2) > eps then
      find := find((l+r)/2, r)
   else
      find := find(l, (l+r)/2);
end;

function getl(p1, p2 : tpoint) : tline;
var ans : tline;
begin
   ans.a := p1.y-p2.y;
   ans.b := p2.x-p1.x;
   ans.c := -ans.a*p1.x-ans.b*p1.y;
   getl := ans;
end;

function det(x11, x12, x21, x22 : real) : real;
begin
   det := x11*x22-x12*x21;
end;

function cross(l1, l2 : tline) : tpoint;
var ans  : tpoint;
    mdet : real;
begin
   mdet := det(l1.a, l1.b, l2.a, l2.b);
   ans.x := -det(l1.c, l1.b, l2.c, l2.b)/mdet;
   ans.y := -det(l1.a, l1.c, l2.a, l2.c)/mdet;
   ans.z := 0;
   cross := ans;
end;

function getcos(d1, d2, d3 : real) : real;
begin
   getcos := (d1*d1+d2*d2-d3*d3)/(2*d1*d2);
end;

function check : boolean;
var d1, d2, d3, cosa : real;
begin
   check := false;
   d1 := d(cp, p[2]);
   d2 := d(cp, p[4]);
   d3 := d24;
   cosa := getcos(d1, d3, d2);
   if (cosa < eps) or (1-cosa < eps) then
      exit;
   cosa := getcos(d2, d3, d1);
   if (cosa < eps) or (1-cosa < eps) then
      exit;
   if abs(r-sqrt(1-sqr(cosa))*d2) < eps then
      check := true;
end;

procedure Solve;
var cosa, t1, ang : real;
    tp1, tp2 : tpoint;
    l1, l2 : tline;
    c1, c2 : tpoint;
begin
   ok := false;
   r  := -1;
   p[1].z := 0; p[2].z := 0; p[3].z := 0;
   p[1].x := 0; p[1].y := 0;
   p[2].x := d12; p[2].y := 0;


   cosa := getcos(d12, d13, d23);
   if 1-abs(cosa) < eps then
      exit;
   p[3].x := cosa*d13;
   p[3].y := sqrt(1-sqr(cosa))*d13;


   tp1.x := 0; tp1.y := 0; tp1.z := 0;
   tp2.x := p[3].x/d13+1;
   tp2.y := p[3].y/d13;
   tp2.z := 0;
   l1 := getl(tp1, tp2);
   tp1.x := d12;
   tp2.x := d12-(d12-p[3].x)/d23-1;
   tp2.y := p[3].y/d23;
   l2 := getl(tp1, tp2);
   c1 := cross(l1, l2);


   cosa := getcos(d12, d14, d24);
   if 1-abs(cosa) < eps then
      exit;
   p[4].x := cosa*d14;
   p[4].y := sqrt(1-sqr(cosa))*d14;


   tp1.x := 0; tp1.y := 0;
   tp2.x := p[4].x/d14+1;
   tp2.y := p[4].y/d14;
   l1 := getl(tp1, tp2);
   tp1.x := d12;
   tp2.x := d12-(d12-p[4].x)/d24-1;
   tp2.y := p[4].y/d24;
   l2 := getl(tp1, tp2);
   c2 := cross(l1, l2);
   

   h := p[4].y;
   ang := find(0, pi);
   if (ang < eps) or (pi-ang < eps) then
      exit;
   p[4].y := h*cos(ang);
   p[4].z := h*sin(ang);
   c2.z := c2.y*sin(ang);
   c2.y := c2.y*cos(ang);

   ok := true;

   if abs(c1.x-c2.x) > eps then
      exit;
   cp.x  := c1.x;
   cp.y  := c1.y;
   t1    := (c1.y-c2.y)/sin(ang);
   cp.z  := c2.z-t1*cos(ang);
   tp1.x := cp.x; tp1.y := 0; tp1.z := 0;
   r     := d(cp, tp1);
   if not check then r := -1;
end;

procedure Save;
var i : integer;
begin
   assign(Output, 'tetrahedron.out');
   rewrite(Output);
   if ok then begin
      if r < -eps then
         writeln('NO')
      else begin
         writeln('YES');
         writeln(r:0:15);
         for i := 1 to 4 do
            writeln(d(cp, p[i]):0:15);
      end;
   end else
      writeln('IMPOSSIBLE');
   close(Output);
end;

begin
   Load;
   Solve;
   Save;
end.