#include <stdio.h>
#include <math.h>

#define sqr(x) ((x) * (x))
#define abs(a) ((a) > 0 ? (a) : -(a))

#define eps 1e-10

typedef long double ldbl;
typedef struct
{
  ldbl x, y, z;
} vec;

int d[6];
vec v[4], c;
ldbl r;

int checktr( int a, int b, int c )
{
  return a + b > c && a + c > b && b + c > a;
}

ldbl getr( int a, int b, int c )
{
  ldbl p = 0.5 * (a + b + c);

  return sqrt(p * (p - a) * (p - b) * (p - c)) / p;
}

void buildtr( int d01, int d12, int d20, vec *v0, vec *v1, vec *v2 )
{
  ldbl co, si;

  v0->x = v0->y = v0->z = 0;
  v1->x = d01, v1->y = v1->z = 0;
  co = ((ldbl)sqr(d01) + sqr(d20) - sqr(d12)) / (2 * d01 * d20);
  si = sqrt(abs(1 - sqr(co)));
  v2->x = d20 * co, v2->y = d20 * si, v2->z = 0;
}

vec find( ldbl a1, ldbl b1, ldbl c1, ldbl d1, ldbl a2, ldbl b2, ldbl c2, ldbl d2 )
{
  ldbl t1, t2, t3;
  vec r;

  t1 = abs(a1 * b2 - a2 * b1);
  t2 = abs(a1 * c2 - a2 * c1);
  t3 = abs(c1 * b2 - c2 * b1);
  if (t1 > t2 && t1 > t3)
  {
    r.x = (d2 * b1 - b2 * d1) / (a1 * b2 - a2 * b1);
    r.y = (d1 * a2 - d2 * a1) / (a1 * b2 - a2 * b1);
    r.z = 0;
  }
  else if (t2 > t1 && t2 > t3)
  {
    r.x = (d2 * c1 - c2 * d1) / (a1 * c2 - a2 * c1);
    r.y = 0;
    r.z = (d1 * a2 - d2 * a1) / (a1 * c2 - a2 * c1);
  }
  else
  {
    r.x = 0;
    r.y = (d2 * c1 - c2 * d1) / (b1 * c2 - b2 * c1);
    r.z = (d1 * b2 - d2 * b1) / (b1 * c2 - b2 * c1);
  }
  return r;
}

vec sub( vec a, vec b )
{
  a.x -= b.x, a.y -= b.y, a.z -= b.z;
  return a;
}

vec add( vec a, vec b )
{
  a.x += b.x, a.y += b.y, a.z += b.z;
  return a;
}

vec mulr( vec a, ldbl b )
{
  a.x *= b, a.y *= b, a.z *= b;
  return a;
}

vec mul( vec a, vec b )
{
  vec c;

  c.x = a.y * b.z - a.z * b.y;
  c.y = a.z * b.x - a.x * b.z;
  c.z = a.x * b.y - a.y * b.x;
  return c;
}

ldbl len( vec a )
{
  return sqrt(abs(sqr(a.x) + sqr(a.y) + sqr(a.z)));
}

vec norm( vec a )
{
  ldbl l = len(a);

  if (l >= eps)
    a.x /= l, a.y /= l, a.z /= l;
  return a;
}

ldbl getd( vec a, vec b )
{
  return len(sub(a, b));
}

void intersph( ldbl r1, vec v2, ldbl r2, vec v3, ldbl r3, vec *v )
{
  ldbl a1, b1, c1, d1, a2, b2, c2, d2, a, b, c, di, t;
  vec n1, n2, d, p;

  a1 = 2 * v2.x, b1 = 2 * v2.y, c1 = 2 * v2.z, d1 = sqr(r1) - (sqr(r2) + sqr(v2.x) + sqr(v2.y) + sqr(v2.z));
  a2 = 2 * v3.x, b2 = 2 * v3.y, c2 = 2 * v3.z, d2 = sqr(r1) - (sqr(r3) + sqr(v3.x) + sqr(v3.y) + sqr(v3.z));
  n1.x = a1, n1.y = b1, n1.z = c1;
  n2.x = a2, n2.y = b2, n2.z = c2;
  d = mul(n1, n2);
  p = find(a1, b1, c1, d1, a2, b2, c2, d2);
  a = sqr(d.x) + sqr(d.y) + sqr(d.z);
  b = p.x * d.x + p.y * d.y + p.z * d.z;
  c = sqr(p.x) + sqr(p.y) + sqr(p.z) - sqr(r1);
  di = sqrt(abs(b * b - 4 * a * c));
  t = (-b + di) / (2 * a);
  v->x = p.x + d.x * t, v->y = p.y + d.y * t, v->z = p.z + d.z * t;
}

vec findp( vec a, vec b, vec c, ldbl r )
{
  vec n, d, s;
  ldbl k;

  n = mul(sub(b, a), sub(c, a));
  d = mulr(norm(mul(n, sub(b, a))), r);
  k = 0.5 * (len(sub(b, a)) + len(sub(c, a)) - len(sub(b, c)));
  s = mulr(norm(sub(b, a)), k);
  return add(add(a, d), s);
}

vec findp1( vec a, vec b, vec c, ldbl r )
{
  vec s;
  ldbl k;

  k = 0.5 * (len(sub(b, a)) + len(sub(c, a)) - len(sub(b, c)));
  s = mulr(norm(sub(b, a)), k);
  return add(a, s);
}

vec inter( vec p, vec s, vec d )
{
  ldbl t;

  if (abs(d.x) > abs(d.y))
    t = (p.x - s.x) / d.x;
  else
    t = (p.y - s.y) / d.y;
  return add(s, mulr(d, t));
}

int main( void )
{
  int i;

  freopen("tetrahedron.in", "rt", stdin);
  freopen("tetrahedron.out", "wt", stdout);
  for (i = 0; i < 6; i++)
    scanf("%d", &d[i]);
  if (!checktr(d[0], d[1], d[3]) ||
      !checktr(d[0], d[2], d[4]) ||
      !checktr(d[1], d[2], d[5]) ||
      !checktr(d[3], d[4], d[5]))
    printf("IMPOSSIBLE");
  else if (d[2] - d[4] != d[1] - d[3] ||
           d[2] - d[5] != d[0] - d[3] ||
           d[1] - d[5] != d[0] - d[4] ||
           d[0] - d[1] != d[4] - d[5] ||
           d[0] - d[2] != d[3] - d[5] ||
           d[1] - d[2] != d[3] - d[4])
    printf("NO");
  else
  {
    ldbl r012, r013;
    vec p1, p2;

    buildtr(d[0], d[3], d[1], &v[0], &v[1], &v[2]);
    intersph(d[2], v[1], d[4], v[2], d[5], &v[3]);
    r012 = getr(d[0], d[3], d[1]);
    p1 = findp(v[0], v[1], v[2], r012);
    r013 = getr(d[0], d[4], d[2]);
    p2 = findp(v[0], v[1], v[3], r012);
    c = inter(p1, p2, mul(sub(v[1], v[0]), sub(v[3], v[0])));
    r = len(sub(c, findp1(v[0], v[1], v[2], r012)));
    printf("YES\n");
    printf("%.18Lf\n", r);
    for (i = 0; i < 4; i++)
      printf("%.18Lf\n", getd(c, v[i]));
  }
  return 0;
}
