{$DEFINE DSEBUG}

const
        MaxN = 4;
        MaxS{ize} = 1000;
        MaxT{ests} = 33333333;
        eps = 1e-8;
type
        Real = Extended;
        TPoint =
        record
          x, y, z : Real;
        end;
        TVector =
        record
          x, y : Real;
        end;
        TLine =
        record
          a, b, c : Real;
        end;
var
        d : Array[1 .. MaxN, 1 .. MaxN] of Real;
        p : Array[1 .. MaxN] of TPoint;
        n : LongInt;

Procedure Init;
begin
  ReadLn(d[1][2], d[1][3], d[1][4], d[2][3], d[2][4], d[3][4]);
end;

Function NotTri(const a, b, c : Real) : Boolean;
begin
  NotTri := (a >= b + c) or (b >= a + c) or (c >= a + b);
end;

Function Dist(const a, b : TPoint) : Real;
begin
  Dist := Sqrt(Sqr(a.x - b.x) + Sqr(a.y - b.y) + Sqr(a.z - b.z));
end;

Function RealEq(const a, b : Real) : Boolean;
begin
  RealEq := Abs(a - b) < eps;
end;

Procedure Impossible;
begin
  {$IfDef DEBUG}
  WriteLn('BOTVA');
  {$EndIf}
  WriteLn('IMPOSSIBLE');
  Close(input);
  Close(output);
  Halt;
end;

Procedure No;
begin
  {$IfDef DEBUG}
  WriteLn('BUG');
  {$EndIf}
  WriteLn('NO');
  Close(input);
  Close(output);
  Halt;
end;

Procedure MakeVector(const a, b : TPoint; var v : TVector);
begin
  v.x := b.x - a.x;
  v.y := b.y - a.y;
end;

Procedure MulVector(var v : TVector; const h : Real);
begin
  v.x := v.x * h;
  v.y := v.y * h;
end;

Procedure SumVectors(const a, b : TVector; var c : TVector);
begin
  c.x := a.x + b.x;
  c.y := a.y + b.y;
end;

Procedure FindBis(const a, b, c : TPoint; const lab, lac : Real; var l : TLine);
var
        ab, ac, v : TVector;
begin
  MakeVector(a, b, ab);
  MakeVector(a, c, ac);
  MulVector(ab, lac);
  MulVector(ac, lab);
  SumVectors(ab, ac, v);
  l.a := v.y;
  l.b := -v.x;
  l.c := -(l.a * a.x + l.b * a.y);
end;

Procedure IntersectLines(const l1, l2 : TLine; var p : TPoint);
begin
  p.z := 0;
  if not RealEq(l1.a * l2.b, l1.b * l2.a) then
  begin
    p.x := (l1.b * l2.c - l1.c * l2.b) / (l2.b * l1.a - l1.b * l2.a);
    p.y := (l2.a * l1.c - l2.c * l1.a) / (l2.b * l1.a - l1.b * l2.a);
  end
  else
  begin
    p.x := 0;
    p.y := 0;
    No;
  end;
end;

Function GetDist(const a, b, p : TPoint; const ab : Real) : Real;
var
        per : Real;
begin
  per := (ab + Dist(a, p) + Dist(b, p)) / 2;
  GetDist := Sqrt(per * (per - ab) * (per - Dist(a, p)) * (per - Dist(b, p))) / ab;
end;

Function VectorProduct(const a, b : TVector) : Real;
begin
  VectorProduct := a.x * b.y - a.y * b.x;
end;

Procedure FindCenter(const a, b, c : TPoint; const lab, lac, lbc : Real; var d : TPoint);
var
        l1, l2 : TLine;
begin
  FindBis(a, b, c, lab, lac, l1);
  FindBis(b, a, c, lab, lbc, l2);
  IntersectLines(l1, l2, d);
  if (not RealEq(GetDist(a, b, d, lab), GetDist(a, c, d, lac))) or (not RealEq(GetDist(a, b, d, lab), GetDist(b, c, d, lbc))) then
  begin
    WriteLn(GetDist(a, b, d, lab) : 0 : 20);
    WriteLn(GetDist(a, c, d, lac) : 0 : 20);
    WriteLn(GetDist(b, c, d, lbc) : 0 : 20);
    {$IfDef DEBUG}
    WriteLn('BUG!!!');
    Close(input);
    Close(output);
    Halt;
    {$EndIf}
    No;
  end;
end;

Procedure Solve;
var
        c : TPoint;
        minz, maxz : Real;
begin
  if (notTri(d[1][2], d[1][3], d[2][3])) or (notTri(d[1][2], d[2][4], d[1][4])) or (notTri(d[1][3], d[3][4], d[1][4])) or (notTri(d[2][3], d[3][4], d[2][4])) then
  begin
    Impossible;
    Exit;
  end;
  p[1].x := 0;
  p[1].y := 0;
  p[1].z := 0;
  p[2].x := d[1][2];
  p[2].y := 0;
  p[2].z := 0;
  p[3].x := (Sqr(d[1][3]) - Sqr(d[2][3]) + Sqr(d[1][2])) / 2 / d[1][2];
  if Sqr(d[1][3]) - Sqr(p[3].x) > eps then
    p[3].y := Sqrt(Sqr(d[1][3]) - Sqr(p[3].x))
  else
  begin
    Impossible;
    Exit;
    {I CAN'T}
  end;
  p[3].z := 0;
  p[4].x := (Sqr(d[1][4]) - Sqr(d[2][4]) + Sqr(d[1][2])) / 2 / d[1][2];
  p[4].y := (Sqr(d[2][4]) - Sqr(d[3][4]) - Sqr(d[1][2]) + Sqr(p[3].x) + Sqr(p[3].y) + 2 * p[4].x * (d[1][2] - p[3].x)) / 2 / p[3].y;
  if Sqr(d[1][4]) - Sqr(p[4].x) - Sqr(p[4].y) > eps then
    p[4].z := Sqrt(Sqr(d[1][4]) - Sqr(p[4].x) - Sqr(p[4].y))
  else
  begin
    Impossible;
    Exit;
    {I Can'T}
  end;
  FindCenter(p[1], p[2], p[3], d[1][2], d[1][3], d[2][3], c);
  minz := 0;
  maxz := p[4].z;
  While Abs(minz - maxz) > eps * eps do
  begin
    c.z := (minz + maxz) / 2;
    if GetDist(p[1], p[2], c, d[1][2]) > GetDist(p[1], p[4], c, d[1][4]) then
      maxz := c.z
    else
      minz := c.z;
  end;
  if RealEq(GetDist(p[1], p[2], c, d[1][2]), GetDist(p[1], p[3], c, d[1][3])) and
     RealEq(GetDist(p[1], p[2], c, d[1][2]), GetDist(p[1], p[4], c, d[1][4])) and
     RealEq(GetDist(p[1], p[2], c, d[1][2]), GetDist(p[2], p[3], c, d[2][3])) and
     RealEq(GetDist(p[1], p[2], c, d[1][2]), GetDist(p[2], p[4], c, d[2][4])) and
     RealEq(GetDist(p[1], p[2], c, d[1][2]), GetDist(p[3], p[4], c, d[1][3])) then
  begin
    WriteLn((GetDist(p[1], p[2], c, d[1][2]) + GetDist(p[1], p[3], c, d[1][3]) + GetDist(p[1], p[4], c, d[1][4]) + GetDist(p[2], p[3], c, d[2][3]) + GetDist(p[2], p[4], c, d[2][4]) + GetDist(p[3], p[4], c, d[3][4])) / 3 : 0 : 100);
    WriteLn(Dist(p[1], c) : 0 : 15);
    WriteLn(Dist(p[2], c) : 0 : 15);
    WriteLn(Dist(p[3], c) : 0 : 15);
    WriteLn(Dist(p[4], c) : 0 : 15);
  end
  else
    No;
end;

Procedure Print;
begin
end;


begin
  Assign(input, 'tetrahedron.in');
  Reset(input);
  Assign(output, {'tetrahedron.out'}'CON');
  Rewrite(output);
  {$IfDef DEBUG}
  WriteLn('DEBUG!!!');
  {$EndIf}
  Init;
{  for n := 1 to MaxT do
  begin
    if n mod (MaxT div 100) = 0 then
      WriteLn(n div (MaxT div 100), '%');
    p[1].x := Random * MaxS;
    p[1].y := Random * MaxS;
    p[1].z := Random * MaxS;
    p[2].x := Random * MaxS;
    p[2].y := Random * MaxS;
    p[2].z := Random * MaxS;
    p[3].x := Random * MaxS;
    p[3].y := Random * MaxS;
    p[3].z := Random * MaxS;
    p[4].x := Random * MaxS;
    p[4].y := Random * MaxS;
    p[4].z := Random * MaxS;
    d[1][2] := Dist(p[1], p[2]);
    d[1][3] := Dist(p[1], p[3]);
    d[1][4] := Dist(p[1], p[4]);
    d[2][3] := Dist(p[2], p[3]);
    d[2][4] := Dist(p[2], p[4]);
    d[3][4] := Dist(p[3], p[4]);}
    Solve;
{  end;}
  Print;
  Close(input);
  Close(output);
end.
