#include <stdio.h>
#include <string.h>

#define MIN(A, B) (((A) <= (B)) ? (A) : (B))
#define MAX(A, B) (((A) >= (B)) ? (A) : (B))
#define SWAP(A, B, C) ((C) = (A), (A) = (B), (B) = (C))
#define ABS(X) (((X) >= 0) ? (X) : -(X))
#define SQR(X) ((X) * (X))

#define eps 1e-9
#define inf (int)2e9

void MakeP( double X1, double Y1, double Z1, double X2, double Y2, double Z2, double X3, double Y3, double Z3, double *A, double *B, double *C, double *D )
{
  (*A) = Y2 * Z3 - Y3 * Z2 + Y3 * Z1 - Y1 * Z3 + Y1 * Z2 - Y2 * Z1;
  (*B) = X1 * Z3 - X1 * Z2 + X2 * Z1 - X2 * Z3 + X3 * Z2 - X3 * Z1;
  (*C) = X1 * Y2 - X1 * Y3 + X2 * Y3 - X2 * Y1 + X3 * Y1 - X3 * Y2;
  (*D) = X1 * Y2 * Z3 - X1 * Y3 * Z2 + X2 * Y3 * Z1 - X2 * Y1 * Z3 + X3 * Y1 * Z2 - X3 * Y2 * Z1;
}

void Proc1( double X2, double Y2, double R, double *X, double *Y )
{
  (*X) = R * (X2 / Y2 + sqrt(1 + SQR(X2 / Y2)));
  (*Y) = R;
}


void MakeLine( double X1, double Y1, double Z1, double X2, double Y2, double Z2, double X3, double Y3, double Z3,
               double D12, double D13, double D23,
               double *X0, double *Y0, double *Z0, double *VX, double *VY, double *VZ )
// ந , 室 १ 祭 ᠭ 㦭  ௥ ᪮ 㣮쭨
{
  double p = (D12 + D13 + D23) / 2;
  double PX1 = D12;
  double PX2 = (SQR(D13) + SQR(D12) - SQR(D23)) / (2 * D12);
  double PY2 = sqrt(SQR(D13) - SQR(PX2));
  double S = PX1 * PY2 / 2;
  double R = S / p;
  double D, TX, TY;
  double X4 = X1 + (X2 - X1) * PX2 / D12;
  double Y4 = Y1 + (Y2 - Y1) * PX2 / D12;
  double Z4 = Z1 + (Z2 - Z1) * PX2 / D12;
  double VX1 = X2 - X1;
  double VY1 = Y2 - Y1;
  double VZ1 = Z2 - Z1;
  double VX2 = X3 - X4;
  double VY2 = Y3 - Y4;
  double VZ2 = Z3 - Z4;
  MakeP(X1, Y1, Z1, X2, Y2, Z2, X3, Y3, Z3, VX, VY, VZ, &D);
  Proc1(PX2, PY2, R, &TX, &TY);
  (*X0) = X1 + VX1 * TX / D12 + VX2 * TY / PY2;
  (*Y0) = Y1 + VY1 * TX / D12 + VY2 * TY / PY2;
  (*Z0) = Z1 + VZ1 * TX / D12 + VZ2 * TY / PY2;
}

int Check( double X0, double Y0, double Z0, double VX, double VY, double VZ, double X, double Y, double Z)
{
  double T = sqrt((SQR(X - X0) + SQR(Y - Y0) + SQR(Z - Z0)) / (SQR(VX) + SQR(VY) + SQR(VZ)));
  if (ABS(X - X0 - VX * T) < eps && ABS(Y - Y0 - VY * T) < eps && ABS(Z - Z0 - VZ * T) < eps)
    return 1;
  if (ABS(X - X0 + VX * T) < eps && ABS(Y - Y0 + VY * T) < eps && ABS(Z - Z0 + VZ * T) < eps)
    return 1;
  return 0;
}

double D01, D02, D03, D12, D13, D23, X[4], Y[4], Z[4], T1, XR, YR, ZR;
double L1_X0, L1_Y0, L1_Z0, L1_VX, L1_VY, L1_VZ, L2_X0, L2_Y0, L2_Z0, L2_VX, L2_VY, L2_VZ;
double L3_X0, L3_Y0, L3_Z0, L3_VX, L3_VY, L3_VZ, L4_X0, L4_Y0, L4_Z0, L4_VX, L4_VY, L4_VZ;

void EXIT_IMP( void)
{
  printf("IMPOSSIBLE\n");
  exit(0);
}

void EXIT_NO( void)
{
  printf("NO\n");
  exit(0);
}

int main( void )
{
  freopen("tetrahedron.in", "rt", stdin);
  freopen("tetrahedron.out", "wt", stdout);

  scanf("%lf%lf%lf%lf%lf%lf", &D01, &D02, &D03, &D12, &D13, &D23);
  X[0] = Y[0] = Z[0] = 0;
  Y[1] = Z[1] = 0, X[1] = D01;
  Z[2] = 0, X[2] = (SQR(D02) + SQR(X[1]) - SQR(D12)) / (2 * X[1]);
  if (SQR(D02) - SQR(X[2]) < eps)
    EXIT_IMP();
  Y[2] = sqrt(SQR(D02) - SQR(X[2]));
  X[3] = (SQR(D03) + SQR(X[1]) - SQR(D13)) / (2 * X[1]);
  Y[3] = (SQR(D03) + SQR(X[2]) + SQR(Y[2]) - SQR(D23) - 2 * X[3] * X[2]) / (2 * Y[2]);
  if (SQR(D03) - SQR(X[3]) - SQR(Y[3]) < eps)
    EXIT_IMP();
  Z[3] = sqrt(SQR(D03) - SQR(X[3]) - SQR(Y[3]));
  MakeLine(X[0], Y[0], Z[0], X[1], Y[1], Z[1], X[2], Y[2], Z[2], D01, D02, D12, &L1_X0, &L1_Y0, &L1_Z0, &L1_VX, &L1_VY, &L1_VZ);
  MakeLine(X[0], Y[0], Z[0], X[1], Y[1], Z[1], X[3], Y[3], Z[3], D01, D03, D13, &L2_X0, &L2_Y0, &L2_Z0, &L2_VX, &L2_VY, &L2_VZ);
  MakeLine(X[0], Y[0], Z[0], X[2], Y[2], Z[2], X[3], Y[3], Z[3], D02, D03, D23, &L3_X0, &L3_Y0, &L3_Z0, &L3_VX, &L3_VY, &L3_VZ);
  MakeLine(X[1], Y[1], Z[1], X[2], Y[2], Z[2], X[3], Y[3], Z[3], D12, D13, D23, &L4_X0, &L4_Y0, &L4_Z0, &L4_VX, &L4_VY, &L4_VZ);
  T1 = (L1_Y0 * L2_VZ + L2_Z0 * L2_VY - L2_Y0 * L2_VZ - L1_Z0 * L2_VY) / (L1_VZ * L2_VY - L1_VY * L2_VZ);
  XR = L1_X0 + T1 * L1_VX;
  YR = L1_Y0 + T1 * L1_VY;
  ZR = L1_Z0 + T1 * L1_VZ;
  if (!Check(L1_X0, L1_Y0, L1_Z0, L1_VX, L1_VY, L1_VZ, XR, YR, ZR))
    EXIT_NO();
  if (!Check(L2_X0, L2_Y0, L2_Z0, L2_VX, L2_VY, L2_VZ, XR, YR, ZR))
    EXIT_NO();
  if (!Check(L3_X0, L3_Y0, L3_Z0, L3_VX, L3_VY, L3_VZ, XR, YR, ZR))
    EXIT_NO();
  if (!Check(L4_X0, L4_Y0, L4_Z0, L4_VX, L4_VY, L4_VZ, XR, YR, ZR))
    EXIT_NO();
  printf("YES\n");
  printf("%.16lf\n", sqrt(SQR(ZR) + SQR(YR)));
  printf("%.16lf\n", sqrt(SQR(XR - X[0]) + SQR(YR - Y[0]) + SQR(ZR - Z[0])));
  printf("%.16lf\n", sqrt(SQR(XR - X[1]) + SQR(YR - Y[1]) + SQR(ZR - Z[1])));
  printf("%.16lf\n", sqrt(SQR(XR - X[2]) + SQR(YR - Y[2]) + SQR(ZR - Z[2])));
  printf("%.16lf\n", sqrt(SQR(XR - X[3]) + SQR(YR - Y[3]) + SQR(ZR - Z[3])));

  return 0;
}
