#include <cstdio>
#include <cmath>
#include <cstdlib>

#define eps 1E-9
#define pi 3.1415926535897932384626433832795

using namespace std;

double d01,d02,d03,d12,d13,d23,h,h01,h02,h12,r013,r123,r023,r012,alf;

inline bool good(double x,double y,double z)
{
	return (x+y>=z+eps)&&(x+z>=y+eps)&&(y+z>=x+eps);
}

void save(char *a)
{
	printf(a);
	fclose(stdout);
	exit(0);
}

inline double sqr(double x)
{
	return x*x;
}

inline double squ(double x,double y,double z)
{
	double p=(x+y+z)/2.0;
	return sqrt(p*(p-x)*(p-y)*(p-z));
}

bool much(double h)
{
	if(h>h01) return true;
	if(h>h02) return true;
	if(h>h12) return true;
	double l01=sqrt(-sqr(h)+sqr(h01));
	double l02=sqrt(-sqr(h)+sqr(h02));
	double l12=sqrt(-sqr(h)+sqr(h12));
	return (l01*d01+l02*d02+l12*d12<2.0*squ(d01,d02,d12));
	
}

double find_h()
{
	double up=1E10,down=0.0,t;
	while(up-down>eps){
		t=(up+down)/2.0;
		if(much(t)) up=t; else down=t;
	}
	return (up+down)/2.0;
}

bool very(double r)
{
	if(r<r012+eps) return false;
	if(r<r013+eps) return false;
	if(r<r023+eps) return false;
	if(r<r123+eps) return false;
	double h012=sqrt(sqr(r)-sqr(r012));
	double h013=sqrt(sqr(r)-sqr(r013));
/*	fprintf(stderr,"Checking %0.5lf: alf1=%0.5lf, alf2=%0.5lf,h012=%0.5lf, h013=%0.5lf\n",r,atan(h012/r012)+atan(h013/r013),alf,h012,h013);*/
	return atan(h012/r012)+atan(h013/r013)>alf;
}

bool check()
{
	double z=(d13+d03-d01)/2;
	double w=(d12+d02-d01)/2;
	return fabs(d23-z-w)<eps*100;
}

int main()
{
	freopen("tetrahedron.in","r",stdin);
	scanf("%lf%lf%lf%lf%lf%lf",&d01,&d02,&d03,&d12,&d13,&d23);
	fclose(stdin);
	freopen("tetrahedron.out","w",stdout);
	if(!(good(d01,d12,d02)&&good(d01,d13,d03)&&good(d02,d23,d03)&&good(d12,d23,d13))) save("IMPOSSIBLE\n");
	h01=2*squ(d01,d03,d13)/d01;
	h02=2*squ(d02,d03,d23)/d02;
	h12=2*squ(d12,d13,d23)/d12;
	r012=2*squ(d01,d12,d02)/(d01+d12+d02);
	r013=2*squ(d01,d13,d03)/(d01+d13+d03);
	r023=2*squ(d02,d23,d03)/(d02+d23+d03);
	r123=2*squ(d12,d23,d13)/(d12+d23+d13);
	h=find_h();
	alf=asin(h/h01);
/*	fprintf(stderr,"h=%0.5lf, alf=%0.5lf, h01=%0.5lf, cos(alf)=%0.5lf, h/h01=%0.5lf\n",h,alf,h01,cos(alf),h/h01);*/
	if(sqr(d13)+sqr(d12)<sqr(d23)) alf=pi-alf;
	double up=1E10,down=0.0,r;
	while(up-down>eps){
		r=(up+down)/2.0;
		if(very(r)) up=r; else down=r;
	}
	if(!check()) save("NO\n");
	printf("YES\n");
	printf("%0.17lf\n",r);
	double q1=(d01+d12-d02)/2;
	double q2=(d02+d12-d01)/2;
	double q0=(d01-d12+d02)/2;
	double q3=(d13+d23-d12)/2;	
	double w0=sqrt(sqr(r)+sqr(q0));
	double w1=sqrt(sqr(r)+sqr(q1));
	double w2=sqrt(sqr(r)+sqr(q2));
	double w3=sqrt(sqr(r)+sqr(q3));
	printf("%0.17lf\n%0.17lf\n%0.17lf\n%0.17lf\n",w0,w1,w2,w3);
	fclose(stdout);
	return 0;
}
