{ $DEFINE DEBUG}
{$H+}
{$IFDEF DEBUG}
{$C+,I+,Q+,R+,S+}
{$ELSE}
{$C-,I-,Q-,R-,S-}
{$ENDIF}
{$M 60000000,60000000}
const taskid='tetrahedron';
      infile=taskid+'.in';
      outfile=taskid+'.out';
      eps=1e-8;
var d01,d02,d03,d12,d13,d23:longint;
    x0,y0,z0,x1,y1,z1,x2,y2,z2,x3,y3,z3:extended;
    x01,y01,z01,dx1,dy1,dz1:extended;
    x02,y02,z02,dx2,dy2,dz2:extended;
    ax,ay,az:extended;
procedure check(a,b,c:longint);
begin
  if (a+b<=c) or (b+c<=a) or (a+c<=b) then
  begin
    writeln('IMPOSSIBLE');
    close(input);
    close(output);
    halt;
  end;
end;
procedure vect(x1,y1,z1,x2,y2,z2:extended;var vx,vy,vz:extended);
begin
  vx:=y1*z2-y2*z1;
  vy:=z1*x2-z2*x1;
  vz:=x1*y2-x2*y1;
end;
procedure getany(a,b,c:extended;var x0,y0:extended);
begin
  assert((abs(a)>eps) or (abs(b)>eps));
  x0:=-a*c/(sqr(a)+sqr(b));
  y0:=-b*c/(sqr(a)+sqr(b));
  assert(abs(a*x0+b*y0+c)<eps);
end;
procedure getcommon(a1,b1,c1,d1,a2,b2,c2,d2:extended;var x0,y0,z0:extended);
begin
  if (abs(a1)>eps) then
  begin
    getany(b2-b1/a1*a2,c2-c1/a1*a2,d2-d1/a1*a2,y0,z0);
    x0:=(-d1-b1*y0-c1*z0)/a1;
  end
  else if (abs(b1)>eps) then
  begin
    getany(a2-a1/b1*b2,c2-c1/b1*b2,d2-d1/b1*b2,x0,z0);
    y0:=(-d1-a1*x0-c1*z0)/b1;
  end
  else if (abs(c1)>eps) then
  begin
    getany(a2-a1/c1*c2,b2-b1/c1*c2,d2-d1/c1*c2,x0,y0);
    z0:=(-d1-a1*x0-b1*y0)/c1;
  end
  else assert(false);
  assert(abs(a1*x0+b1*y0+c1*z0+d1)<eps);
  assert(abs(a2*x0+b2*y0+c2*z0+d2)<eps);
end;
function dist(x1,y1,z1,x2,y2,z2:extended):extended;
begin
  dist:=sqrt(sqr(x1-x2)+sqr(y1-y2)+sqr(z1-z2));
end;
procedure cross(x1,y1,z1,r1,x2,y2,z2,r2,x3,y3,z3,r3:extended;var xc,yc,zc:extended);
var a1,b1,c1,d1,a2,b2,c2,d2,dx,dy,dz,x0,y0,z0,a,b,c,d,t:extended;
begin
  a1:=2*(x2-x1);
  b1:=2*(y2-y1);
  c1:=2*(z2-z1);
  d1:=(sqr(x1)+sqr(y1)+sqr(z1)-sqr(r1))-(sqr(x2)+sqr(y2)+sqr(z2)-sqr(r2));
  a2:=2*(x3-x1);
  b2:=2*(y3-y1);
  c2:=2*(z3-z1);
  d2:=(sqr(x1)+sqr(y1)+sqr(z1)-sqr(r1))-(sqr(x3)+sqr(y3)+sqr(z3)-sqr(r3));
  vect(a1,b1,c1,a2,b2,c2,dx,dy,dz);
  getcommon(a1,b1,c1,d1,a2,b2,c2,d2,x0,y0,z0);
  assert(abs(a1*x0+b1*y0+c1*z0+d1)<eps);
  assert(abs(a2*x0+b2*y0+c2*z0+d2)<eps);
  assert(abs(a1*(x0+dx)+b1*(y0+dy)+c1*(z0+dz)+d1)<eps);
  assert(abs(a2*(x0+dx)+b2*(y0+dy)+c2*(z0+dz)+d2)<eps);
  assert((abs(dx)>eps) or (abs(dy)>eps) or (abs(dz)>eps));
  a:=sqr(dx)+sqr(dy)+sqr(dz);
  b:=2*(dx*(x0-x1)+dy*(y0-y1)+dz*(z0-z1));
  c:=sqr(x0-x1)+sqr(y0-y1)+sqr(z0-z1)-sqr(r1);
  d:=sqr(b)-4*a*c;
  assert(d>-eps);
  if abs(d)<eps then
    t:=-b/(2*a)
  else t:=(-b+sqrt(d))/(2*a);
  xc:=x0+dx*t;
  yc:=y0+dy*t;
  zc:=z0+dz*t;
  assert(abs(dist(xc,yc,zc,x1,y1,z1)-r1)<eps);
  assert(abs(dist(xc,yc,zc,x2,y2,z2)-r2)<eps);
  assert(abs(dist(xc,yc,zc,x3,y3,z3)-r3)<eps);
end;
procedure checktetrahedron();
begin
  assert(abs(dist(x0,y0,z0,x1,y1,z1)-d01)<eps);
  assert(abs(dist(x0,y0,z0,x2,y2,z2)-d02)<eps);
  assert(abs(dist(x0,y0,z0,x3,y3,z3)-d03)<eps);
  assert(abs(dist(x1,y1,z1,x2,y2,z2)-d12)<eps);
  assert(abs(dist(x1,y1,z1,x3,y3,z3)-d13)<eps);
  assert(abs(dist(x2,y2,z2,x3,y3,z3)-d23)<eps);
end;
function solve(a,b,c,d,e,f:extended;var x,y:extended):boolean;
begin
  if abs(a*e-b*d)<eps then
  begin
    solve:=false;
    exit;
  end;
  solve:=true;
  x:=(c*e-b*f)/(a*e-b*d);
  y:=(a*f-c*d)/(a*e-b*d);
  assert(abs(a*x+b*y-c)<eps);
  assert(abs(d*x+e*y-f)<eps);
end;
function cross2(x1,y1,z1,dx1,dy1,dz1,x2,y2,z2,dx2,dy2,dz2:extended;var xc,yc,zc:extended):boolean;
var t,s:extended;
begin
  if not solve(dx1,-dx2,x2-x1,dy1,-dy2,y2-y1,t,s) then
  if not solve(dy1,-dy2,y2-y1,dz1,-dz2,z2-z1,t,s) then
  if not solve(dz1,-dz2,z2-z1,dx1,-dx2,x2-x1,t,s) then
  begin
    cross2:=false;
    exit;
  end;
  cross2:=(abs(x1+dx1*t-x2-dx2*s)<eps) and (abs(y1+dy1*t-y2-dy2*s)<eps) and (abs(z1+dz1*t-z2-dz2*s)<eps);
  xc:=x1+dx1*t;
  yc:=y1+dy1*t;
  zc:=z1+dz1*t;
end;
procedure normal(var dx,dy,dz:extended);
var d:extended;
begin
  d:=sqrt(sqr(dx)+sqr(dy)+sqr(dz));
  assert(abs(d)>eps);
  dx:=dx/d;
  dy:=dy/d;
  dz:=dz/d;
end;
procedure bisector(x0,y0,z0,dx1,dy1,dz1,dx2,dy2,dz2:extended;var dx0,dy0,dz0:extended);
begin
  assert(dist(0,0,0,dx1,dy1,dz1)>eps);
  assert(dist(0,0,0,dx2,dy2,dz2)>eps);
  normal(dx1,dy1,dz1);
  normal(dx2,dy2,dz2);
  dx0:=(dx1+dx2)/2;
  dy0:=(dy1+dy2)/2;
  dz0:=(dz1+dz2)/2;
end;
function dist2(x0,y0,z0,x1,y1,z1,x2,y2,z2:extended):extended;
var d,vx,vy,vz:extended;
begin
  assert(dist(x1,y1,z1,x2,y2,z2)>eps);
  d:=dist(x1,y1,z1,x2,y2,z2);
  vect(x0-x1,y0-y1,z0-z1,x2-x1,y2-y1,z2-z1,vx,vy,vz);
  dist2:=sqrt(sqr(vx)+sqr(vy)+sqr(vz))/d;
end;
procedure getcenter(x1,y1,z1,x2,y2,z2,x3,y3,z3:extended;var x0,y0,z0:extended);
var dx1,dy1,dz1,dx2,dy2,dz2,d1,d2,d3:extended;
    tmp:boolean;
begin
  bisector(x1,y1,z1,x2-x1,y2-y1,z2-z1,x3-x1,y3-y1,z3-z1,dx1,dy1,dz1);
  bisector(x2,y2,z2,x1-x2,y1-y2,z1-z2,x3-x2,y3-y2,z3-z2,dx2,dy2,dz2);
  tmp:=cross2(x1,y1,z1,dx1,dy1,dz1,x2,y2,z2,dx2,dy2,dz2,x0,y0,z0);
  assert(tmp);
  d1:=dist2(x0,y0,z0,x1,y1,z1,x2,y2,z2);
  d2:=dist2(x0,y0,z0,x2,y2,z2,x3,y3,z3);
  d3:=dist2(x0,y0,z0,x3,y3,z3,x1,y1,z1);
  assert(abs(d1-d2)<eps);
  assert(abs(d1-d3)<eps);
end;
procedure getline(x1,y1,z1,x2,y2,z2,x3,y3,z3:extended;var x0,y0,z0,dx,dy,dz:extended);
begin
  getcenter(x1,y1,z1,x2,y2,z2,x3,y3,z3,x0,y0,z0);
  vect(x1-x0,y1-y0,z1-z0,x2-x0,y2-y0,z2-z0,dx,dy,dz);
end;
procedure checkanswer();
var d1,d2,d3,d4,d5,d6:extended;
    ok:boolean;
begin
  d1:=dist2(ax,ay,az,x0,y0,z0,x1,y1,z1);
  d2:=dist2(ax,ay,az,x0,y0,z0,x2,y2,z2);
  d3:=dist2(ax,ay,az,x0,y0,z0,x3,y3,z3);
  d4:=dist2(ax,ay,az,x1,y1,z1,x2,y2,z2);
  d5:=dist2(ax,ay,az,x1,y1,z1,x3,y3,z3);
  d6:=dist2(ax,ay,az,x2,y2,z2,x3,y3,z3);
  ok:=(abs(d1-d2)<eps) and (abs(d1-d3)<eps) and (abs(d1-d4)<eps) and
      (abs(d1-d5)<eps) and (abs(d1-d6)<eps);
  if not ok then
  begin
    writeln('NO');
    close(input);
    close(output);
    halt;
  end;
end;
begin
  assign(input,infile);
  reset(input);
  assign(output,outfile);
  rewrite(output);
  {$IFDEF DEBUG}
  writeln('Debug Mode:');
  {$ENDIF}
  read(d01,d02,d03,d12,d13,d23);
  check(d01,d12,d02);
  check(d01,d13,d03);
  check(d02,d23,d03);
  check(d12,d23,d13);
  x0:=0;
  y0:=0;
  z0:=0;
  x1:=d01;
  y1:=0;
  z1:=0;
  x2:=(sqr(d01)+sqr(d02)-sqr(d12))/(2*d01);
  y2:=sqrt(sqr(d02)-sqr(x2));
  z2:=0;
  cross(x0,y0,z0,d03,x1,y1,z1,d13,x2,y2,z2,d23,x3,y3,z3);
  {$IFDEF DEBUG}
  checktetrahedron();
  writeln(x0:0:10,' ',y0:0:10,' ',z0:0:10);
  writeln(x1:0:10,' ',y1:0:10,' ',z1:0:10);
  writeln(x2:0:10,' ',y2:0:10,' ',z2:0:10);
  writeln(x3:0:10,' ',y3:0:10,' ',z3:0:10);
  {$ENDIF}
  getline(x0,y0,z0,x1,y1,z1,x2,y2,z2,x01,y01,z01,dx1,dy1,dz1);
  getline(x0,y0,z0,x1,y1,z1,x3,y3,z3,x02,y02,z02,dx2,dy2,dz2);
  if not cross2(x01,y01,z01,dx1,dy1,dz1,x02,y02,z02,dx2,dy2,dz2,ax,ay,az) then
  begin
    writeln('NO');
    close(input);
    close(output);
    halt;
  end;
  checkanswer();
  writeln('YES');
  writeln(dist2(ax,ay,az,x0,y0,z0,x1,y1,z1):0:25);
  writeln(dist(ax,ay,az,x0,y0,z0):0:25);
  writeln(dist(ax,ay,az,x1,y1,z1):0:25);
  writeln(dist(ax,ay,az,x2,y2,z2):0:25);
  writeln(dist(ax,ay,az,x3,y3,z3):0:25);
  close(input);
  close(output);
end.
