#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

typedef long double dbl;

#define SQR(X) ((X) * (X))
#define D(p, q) (SQR(p.x - q.x) + SQR(p.y - q.y) + SQR(p.z - q.z))
#define IMP { puts("IMPOSSIBLE"); exit(0); }

#define EPS 1e-9
#define EPS2 1e-3
#define MINEPS 1e-9

typedef struct
{
  dbl x, y, z;
} pnt;

pnt P[4], zero = {0, 0, 0};

pnt Sub( pnt a, pnt b )
{
  pnt p;
  p.x = a.x - b.x;
  p.y = a.y - b.y;
  p.z = a.z - b.z;
  return p;
}

pnt Add( pnt a, pnt b )
{
  pnt p;
  p.x = a.x + b.x;
  p.y = a.y + b.y;
  p.z = a.z + b.z;
  return p;
}

pnt Mul( pnt a, dbl k )
{
  pnt p;
  p.x = a.x * k;
  p.y = a.y * k;
  p.z = a.z * k;
  return p;
}

pnt DLine( pnt p0, pnt p1, pnt q )
{
  dbl a, b, c, n, k;
  pnt v;
  
  a = p1.x - p0.x;
  b = p1.y - p0.y;
  c = p1.z - p0.z;
  n = sqrt(a * a + b * b + c * c);
  a /= n, b /= n, c /= n;
  k = -(a * (p0.x - q.x) + b * (p0.y - q.y) + c * (p0.z - q.z));
  v.x = p0.x + a * k;
  v.y = p0.y + b * k;
  v.z = p0.z + c * k;
  return v;
}

#define RELAX(q) { if (D(p, q) < Min) Min = D(p, q); }

dbl CalcD( pnt p )
{
  int i;
  dbl Min = 1e20;
  pnt pp[6];
  pp[0] = DLine(P[0], P[1], p);
  pp[1] = DLine(P[0], P[2], p);
  pp[2] = DLine(P[0], P[3], p);
  pp[3] = DLine(P[1], P[2], p);
  pp[4] = DLine(P[1], P[3], p);
  pp[5] = DLine(P[2], P[3], p);
  for (i = 0; i < 6; i++)
    RELAX(pp[i])
  return Min;
}

pnt Shift( pnt p, pnt v, dbl s )
{
  dbl n;
  n = sqrt(SQR(v.x) + SQR(v.y) + SQR(v.z));
  return Add(p, Mul(v, s / n));
}

int main( void )
{
  int D01, D02, D03, D12, D13, D23;
  pnt p = zero, q, pp[6];
  dbl Min, Di, d, eps;
  int i, j, f;

  freopen("tetrahedron.in", "rt", stdin);
  freopen("tetrahedron.out", "wt", stdout);
  scanf("%d%d%d%d%d%d", &D01, &D02, &D03, &D12, &D13, &D23);
  memset(P, 0, sizeof(P));
  P[1].x = D01;
  P[2].x = (SQR(D02) + SQR(D01) - SQR(D12)) / (2.0 * D01);
  P[2].y = SQR(D02) - SQR(P[2].x);
  if (P[2].y < EPS)
    IMP
  P[2].y = sqrt(fabs(P[2].y));
  P[3].x = (SQR(D03) - SQR(D13) + SQR(P[1].x)) / (2.0 * P[1].x);
  P[3].y = (SQR(D13) - SQR(D23) + SQR(P[2].y) - SQR(P[1].x) + SQR(P[2].x) + 2 * P[3].x * (P[1].x - P[2].x)) / (2.0 * P[2].y);
  P[3].z = SQR(D03) - SQR(P[3].x) - SQR(P[3].y);
  if (P[3].z < EPS)
    IMP
  P[3].z = sqrt(fabs(P[3].z));
  for (i = 0; i < 4; i++)
    fprintf(stderr, "%.3Lf %.3Lf %.3Lf\n", P[i].x, P[i].y, P[i].z);

  for (i = 0; i < 4; i++)
    p = Add(p, P[i]);
  p = Mul(p, 1.0 / 4);
  eps = CalcD(p);
  if (eps > 1)
    eps = sqrt(eps);
  eps *= 5e-2;
  while (eps > MINEPS)
  {
    f = 0;
    pp[0] = DLine(P[0], P[1], p);
    pp[1] = DLine(P[0], P[2], p);
    pp[2] = DLine(P[0], P[3], p);
    pp[3] = DLine(P[1], P[2], p);
    pp[4] = DLine(P[1], P[3], p);
    pp[5] = DLine(P[2], P[3], p);
    Min = Di = CalcD(p);
    for (i = 0; i < 4; i++)
    {
      q = Shift(p, Sub(p, P[i]), eps);
      if ((d = CalcD(q)) > Min + EPS)
        Min = d, p = q;
    }
    for (i = 0; i < 6; i++)
    {
      q = Shift(p, Sub(p, pp[i]), eps);
      if ((d = CalcD(q)) > Min + EPS)
        Min = d, p = q;
    }
    if (Min == Di)
      eps /= 2;
//    fprintf(stderr, "%.5Lf %.5Lf %.5Lf %.5Lf\n", p.x, p.y, p.z, eps);
  }
  pp[0] = DLine(P[0], P[1], p);
  pp[1] = DLine(P[0], P[2], p);
  pp[2] = DLine(P[0], P[3], p);
  pp[3] = DLine(P[1], P[2], p);
  pp[4] = DLine(P[1], P[3], p);
  pp[5] = DLine(P[2], P[3], p);
  Di = D(p, pp[0]);
  for (i = 0; i < 6; i++)
  {
    d = D(p, pp[i]);
    fprintf(stderr, "%.9Lf\n", d);
    if (fabs(Di - d) > EPS2)
    {
      puts("NO");
      return 0;
    }
  }  
  puts("YES");
  printf("%.18lf\n", sqrt(fabs(Di)));
  for (i = 0; i < 4; i++)
    printf("%.18lf\n", sqrt(fabs(D(P[i], p))));
  return 0;
}
