{$DEFINE NODEBUG}

const
        MaxN = 1000;
        Inf = 1e10;
        eps = 1e-6;
type
        Real = Extended;
        TPoint =
        record
          x, y : Real;
        end;
        TLine =
        record
          a, b, c : Real;
        end;
var
        x, y, n : LongInt;
        rez : Array[1 .. MaxN] of
        record
          r : Array[1 .. MaxN] of TPoint;
          col : LongInt;
        end;
        mas : Array[1 .. MaxN] of TPoint;

Procedure Init;
var
        i : LongInt;
begin
  ReadLn(x, y, n);
  if n = 1 then
  begin
    WriteLn('4 0 0 ', x, ' 0 ', x, ' ', y, ' 0 ', y);
    Close(input);
    Close(output);
    Halt;
  end
  else
  begin
    for i := 1 to n do
      ReadLn(mas[i].x, mas[i].y);
  end;
end;

Function RealEq(const a, b : Real) : Boolean;
begin
  RealEq := Abs(a - b) < eps;
end;

Procedure IntersectLines(const l1, l2 : TLine; var p : TPoint);
begin
  if not RealEq(l1.a * l2.b, l1.b * l2.a) then
  begin
    p.x := (l1.b * l2.c - l1.c * l2.b) / (l2.b * l1.a - l1.b * l2.a);
    p.y := (l2.a * l1.c - l2.c * l1.a) / (l2.b * l1.a - l1.b * l2.a);
  end
  else
  begin
    p.x := -1;
    p.y := -1;
  end;
end;

Function Dist(const a, b : TPoint) : Real;
begin
  Dist := Sqrt(Sqr(a.x - b.x) + Sqr(a.y - b.y));
end;

Function SQRDist(const a, b : TPoint) : Real;
begin
  SQRDist := (Sqr(a.x - b.x) + Sqr(a.y - b.y));
end;



Procedure GetSerPer(const a, b : TPoint; var l : TLine);
var
        c : TPoint;
begin
  l.a := a.x - b.x;
  l.b := b.y - a.y;
  c.x := (a.x + b.x) / 2;
  c.y := (a.y + b.y) / 2;
  l.c := -(l.a * c.x + l.b * c.y);
end;

Procedure GetCircle(const a, b, c : TPoint; var d : TPoint);
var
        l1, l2 : TLine;
begin
  GetSerPer(a, b, l1);
  GetSerPer(a, c, l2);
  IntersectLines(l1, l2, d);
end;

Procedure Check(const p : Tpoint);
var
        r : Real;
        i : LongInt;
begin
  r := Inf;
  if (p.x < 0) or (p.x > x) or (p.y < 0) or (p.y > y) then
    Exit;
  for i := 1 to n do
    if SqrDist(mas[i], p) < r then
      r := SqrDist(mas[i], p);
  for i := 1 to n do
    if RealEq(SqrDist(mas[i], p), r) then
    begin
      Inc(rez[i].col);
      rez[i].r[rez[i].col] := p;
    end;
end;

Procedure Solve;
var
        p : TPoint;
        i, j, k : LongInt;
        l, ll : TLine;
begin
  for i := 1 to n do
    for j := i + 1 to n do
      for k := j + 1 to n do
      begin
        GetCircle(mas[i], mas[j], mas[k], p);
        Check(p);
      end;
  l.a := 0;
  l.b := 1;
  l.c := 0;
  for i := 1 to n do
    for j := i + 1 to n do
    begin
      GetSerPer(mas[i], mas[j], ll);
      IntersectLines(l, ll, p);
      Check(p);
    end;
  l.a := 0;
  l.b := 1;
  l.c := -y;
  for i := 1 to n do
    for j := i + 1 to n do
    begin
      GetSerPer(mas[i], mas[j], ll);
      IntersectLines(l, ll, p);
      Check(p);
    end;
  l.a := 1;
  l.b := 0;
  l.c := 0;
  for i := 1 to n do
    for j := i + 1 to n do
    begin
      GetSerPer(mas[i], mas[j], ll);
      IntersectLines(l, ll, p);
      Check(p);
    end;
  l.a := 1;
  l.b := 0;
  l.c := -x;
  for i := 1 to n do
    for j := i + 1 to n do
    begin
      GetSerPer(mas[i], mas[j], ll);
      IntersectLines(l, ll, p);
      Check(p);
    end;
  p.x := x;
  p.y := 0;
  Check(p);
  p.x := 0;
  p.y := y;
  Check(p);
  p.x := x;
  p.y := y;
  Check(p);
end;

Function More(const a, b : TPoint) : Boolean;
begin
  More := (Ord(a.y > 0) > Ord(b.y > 0)) or ((a.x * b.y - a.y * b.x < 0) and (Ord(a.y > 0) = Ord(b.x > 0)));
end;

Procedure Swap(var a, b : TPoint);
var
        c : TPoint;
begin
  c := a;
  a := b;
  b := c;
end;

Procedure QSort(const t, l, r : LongInt);
var
        i, j : LongInt;
        x : TPoint;
begin
  i := l;
  j := r;
  x := rez[t].r[(l + r) div 2];
  repeat
    While More(x, rez[t].r[i]) do
      Inc(i);
    While More(rez[t].r[j], x) do
      Dec(j);
    if i <= j then
    begin
      Swap(rez[t].r[i], rez[t].r[j]);
      Inc(i);
      Dec(j);
    end;
  until i > j;
  if l < j then
    QSort(t, l, j);
  if i < r then
    QSort(t, i, r);
end;

Function RealEqP(const a, b : TPoint) : Boolean;
begin
  RealEqP := RealEq(a.x, b.x) and RealEq(a.y, b.y);
end;

Procedure Print;
var
        i, j, m : LongInt;
begin
  for i := 1 to n do
  begin
    for j := 1 to rez[i].col do
    begin
      rez[i].r[j].x := rez[i].r[j].x - mas[i].x;
      rez[i].r[j].y := rez[i].r[j].y - mas[i].y;
    end;
    if rez[i].col <> 0 then
      QSort(i, 1, rez[i].col);
    for j := 1 to rez[i].col do
    begin
      rez[i].r[j].x := rez[i].r[j].x + mas[i].x;
      rez[i].r[j].y := rez[i].r[j].y + mas[i].y;
    end;
    m := 0;
    for j := 1 to rez[i].col - 1 do
      if (m = 0) or ((not RealEqP(rez[i].r[m], rez[i].r[j])) and (not RealEqP(rez[i].r[1], rez[i].r[j]))) then
      begin
        Inc(m);
        rez[i].r[m] := rez[i].r[j];
      end;
    rez[i].col := m;
    m := 1;
    for j := 2 to rez[i].col do
      if (rez[i].r[j].x < rez[i].r[m].x) or ((rez[i].r[j].x = rez[i].r[m].x) and (rez[i].r[j].y < rez[i].r[m].y)) then
        m := j;
    Write(rez[i].col);
    for j := m to rez[i].col do
      Write(' ', rez[i].r[j].x : 0 : 100, ' ', rez[i].r[j].y : 0 : 100);
    for j := 1 to m - 1 do
      Write(' ', rez[i].r[j].x : 0 : 100, ' ', rez[i].r[j].y : 0 : 100);
    WriteLn;
  end;
end;


begin
  Assign(input, 'football.in');
  Reset(input);
  Assign(output, 'football.out');
  Rewrite(output);
  {$IfDef DEBUG}
  WriteLn('DEBUG!!!');
  {$EndIf}
  Init;
  Solve;
  Print;
  Close(input);
  Close(output);
end.
