#include <stdio.h>
#define _USE_MATH_DEFINES
#include <math.h>
#include <memory.h>
#include <string.h>
#include <algorithm>

#define DEBUG 0
#define MEM 1600010
#define NUM 30010
#define EPS 1e-8
typedef long double real;

template<class T> class CMemory {
	T mem[MEM];
	typedef T *PT;
	PT stack[MEM];
	int sn;
public:
	CMemory() {
		for (int i = 0; i<MEM; i++)
			stack[i] = mem + (MEM-1-i);
		sn = MEM;
	}
	inline T *getMem() {
		return stack[--sn];
	}
	inline void freeMem(T *adr) {
		stack[sn++] = adr;
	}
};

typedef struct TList {
	real x, y;
	real buff;
	TList *prev, *next;
} *PList;
struct TLine {
	real ax, ay, bx, by;
};

CMemory<TList> lmem;
real fx, fy;
int n;
real plx[NUM], ply[NUM];
PList reg[NUM];
int adr[NUM];
real ang[NUM];

void PrintRegion(PList pl);
inline real sqr(real a) { return a*a; }
inline real dist(real x1, real y1, real x2, real y2) {
	return sqrt(sqr(x1-x2) + sqr(y1-y2));
}

inline real vect(real x1, real y1, real x2, real y2) {
	return x1*y2 - x2*y1;
}
inline TLine midNorm(real x1, real y1, real x2, real y2) {
	TLine res;
	res.ax = (x1+x2)/2 + (y2-y1)/2;
	res.ay = (y1+y2)/2 + (x1-x2)/2;
	res.bx = (x1+x2)/2 - (y2-y1)/2;
	res.by = (y1+y2)/2 - (x1-x2)/2;
	return res;
}

inline bool cross(real x1, real y1, real x2, real y2
			    , real x3, real y3, real x4, real y4, real &cx, real &cy) {
	real a11 = x2-x1;
	real a12 = x3-x4;
	real a21 = y2-y1;
	real a22 = y3-y4;
	real b1  = x3-x1;
	real b2  = y3-y1;
	real det  = a11*a22 - a12*a21;
	real detu = b1 *a22 - a12*b2 ;
	real detv = a11*b2  - b1 *a21;
	if (fabs(det) < EPS)
		return false;
	detu /= det;
	detv /= det;
	if ((detu>=-EPS) && (detu<=1+EPS)) {
		cx = x1 + (x2-x1)*detu;
		cy = y1 + (y2-y1)*detu;
		return true;
	}
	return false;
}

bool cmpPolar(int a, int b) {
/*	real tv = vect(plx[a]-plx[adr[0]], ply[a]-ply[adr[0]]
				 , plx[b]-plx[adr[0]], ply[b]-ply[adr[0]]);
	if (fabs(tv) < EPS)*/
	if (fabs(ang[a]-ang[b]) < EPS)
		return dist(plx[a], plx[adr[0]], ply[a], ply[adr[0]])
			 < dist(plx[b], plx[adr[0]], ply[b], ply[adr[0]]);
	return (ang[a] < ang[b]);
}

inline void addAfter(PList a, PList x) {
	x->next = a->next;
	x->prev = a;
	if (a->next)
		a->next->prev = x;
	a->next = x;
}

void BuildField(PList &res) {
	PList nl;
	res = lmem.getMem();
	memset(res, 0, sizeof(TList));

	nl = lmem.getMem();
	nl->x = 0;
	nl->y = fy;
	addAfter(res, nl);  res = nl;

	nl = lmem.getMem();
	nl->x = fx;
	nl->y = fy;
	addAfter(res, nl);  res = nl;

	nl = lmem.getMem();
	nl->x = fx;
	nl->y = 0;
	addAfter(res, nl);  res = nl;
	res->next = res->prev->prev->prev;
	res->next->prev = res;
	res = res->next;
}

void TryPoint(real px, real py, PList &curr) {
	TLine cnorm = midNorm(plx[adr[0]], ply[adr[0]], px, py);
	real ap = cnorm.ay - cnorm.by;
	real bp = cnorm.bx - cnorm.ax;
	real cp = cnorm.ax*ap + cnorm.ay*bp;
	PList it = curr;
	PList c1, c2;
	bool crossed = false;
	it = it->prev;
	it->buff = ap*it->x + bp*it->y - cp;
	it = it->next;
	it->buff = ap*it->x + bp*it->y - cp;
	while (1) {
		it->next->buff = ap*it->next->x + bp*it->next->y - cp;
		if (it->buff < 0) {
			crossed = true;
			break;
		}
		if ((it->prev->buff >= it->buff) && (it->next->buff >= it->buff))
			break;
		it = it->next;
	}
	if (!crossed) {
		curr = it->prev;
		return;
	}
	c1 = it;
	while (1) {
		c1->buff = ap*c1->x + bp*c1->y - cp;
		if (c1->buff > EPS)
			break;
		lmem.freeMem(c1);
		c1 = c1->prev;
	}
	c2 = it->next;
	while (1) {
		c2->buff = ap*c2->x + bp*c2->y - cp;
		if (c2->buff > EPS)
			break;
		lmem.freeMem(c2);
		c2 = c2->next;
	}
	real cx1, cy1, cx2, cy2;
	cross(c1->x, c1->y, c1->next->x, c1->next->y, cnorm.ax, cnorm.ay, cnorm.bx, cnorm.by, cx1, cy1);
	cross(c2->prev->x, c2->prev->y, c2->x, c2->y, cnorm.ax, cnorm.ay, cnorm.bx, cnorm.by, cx2, cy2);
	c1->next = c2;
	c2->prev = c1;
	PList cl1 = lmem.getMem();
	cl1->x = cx1;
	cl1->y = cy1;
	addAfter(c1, cl1);
	PList cl2 = lmem.getMem();
	cl2->x = cx2;
	cl2->y = cy2;
	addAfter(cl1, cl2);
	curr = cl1;
}

void BuildRegion(int u) {
	int i;
	for (i = 0; i<n; i++)
		adr[i] = i;
	std::swap(adr[0], adr[u]);
	ang[adr[0]] = atan2(-ply[adr[0]], -plx[adr[0]]);
	for (i = 1; i<n; i++) {
		ang[adr[i]] = atan2(ply[adr[i]]-ply[adr[0]], plx[adr[i]]-plx[adr[0]]);
		ang[adr[i]] = ang[adr[0]] - ang[adr[i]];
		ang[adr[i]] -= M_PI/2;
		while (ang[adr[i]] <= EPS)
			ang[adr[i]] += 2*M_PI;
	}
	std::sort(adr+1, adr+n, cmpPolar);
	BuildField(reg[u]);
	if (DEBUG) PrintRegion(reg[u]);
	for (i = 1; i<n; i++) {
		TryPoint(plx[adr[i]], ply[adr[i]], reg[u]);
		if (DEBUG) PrintRegion(reg[u]);
	}
	if (DEBUG) printf("\n");
}

void PrintRegion(PList pl) {
	PList start = pl;
	PList best = 0;
	int cnt = 0;
	do {
		if (!best)
			best = pl;
		else {
			if (fabs(pl->x - best->x) < EPS) {
				if (pl->y < best->y)
					best = pl;
			}
			else {
				if (pl->x < best->x)
					best = pl;
			}
		}
		pl = pl->next;
		cnt++;
	} while (pl != start);
	printf("%d ", cnt);
	pl = best;
	do {
		if (DEBUG)
			printf("%0.2llf %0.2llf ", pl->x, pl->y);
		else
			printf("%0.20llf %0.20llf ", pl->x, pl->y);
		pl = pl->prev;
    } while (pl != best);
    printf("\n");
}

int main(int argc, char **argv) {
	freopen("football.in", "r", stdin);
	freopen("football.out", "w", stdout);
	int i;
	scanf("%llf%llf%d", &fx, &fy, &n);
	for (i = 0; i<n; i++)
		scanf("%llf%llf", plx+i, ply+i);
	for (i = 0; i<n; i++)
		BuildRegion(i);
	for (i = 0; i<n; i++)
		PrintRegion(reg[i]);
	return 0;
}
