program apas;

const eps = 1e-7;

type integer = longint;
     real = extended;

type tpoint = record
        x, y : real;
     end;
     tline = record
        a, b, c : real;
     end;
     plist = ^tlist;
     tlist = record
        p   : tpoint;
        nxt : plist;
     end;   

var p     : array [1..30000] of tpoint;
    t, t1 : array [1..30000] of tpoint;
    d     : array [1..30000] of plist;
    i, j, n, x, y, nt : integer;
    tp : tpoint;
    l  : tline;

procedure add(v : integer; x, y : real);
var tmp : plist;
begin
   new(tmp);
   tmp^.p.x := x; tmp^.p.y := y;
   tmp^.nxt := d[v];
   d[v] := tmp;
end;

procedure pop(v : integer);
var tmp : plist;
begin
   nt := 0;
   while d[v] <> nil do begin
      inc(nt);
      t[nt] := d[v]^.p;
      tmp := d[v];
      d[v] := d[v]^.nxt;
      dispose(tmp);
   end;
end;

function dp(p1, p2 : tpoint) : real;
begin
   dp := sqrt(sqr(p1.x-p2.x)+sqr(p1.y-p2.y));
end;

function det(a, b, c, d : real) : real;
begin
   det := a*d-b*c;
end;

function crossl(l1, l2 : tline) : tpoint;
var d  : real;
    cr : tpoint;
begin
   d := det(l1.a, l1.b, l2.a, l2.b);
   cr.x := -det(l1.c, l1.b, l2.c, l2.b)/d;
   cr.y := -det(l1.a, l1.c, l2.a, l2.c)/d;
   crossl := cr;
end;

function dist(p : tpoint; l : tline) : real;
begin
   dist := (p.x*l.a+p.y*l.b+l.c)/sqrt(sqr(l.a)+sqr(l.b));
end;

function cross(p1, p2 : tpoint; l : tline; var cr : tpoint) : boolean;
var l1 : tline;
    d1, d2 : real;
begin
   d1 := dist(p1, l);
   d2 := dist(p2, l);
   if ((d1 < eps) and (d2 > eps)) or ((d1 > -eps) and (d2 < -eps)) then begin
      cross := true;
      l1.a := p1.y-p2.y;
      l1.b := p2.x-p1.x;
      l1.c := -p1.x*l1.a-p1.y*l1.b;
      cr := crossl(l, l1);
   end else cross := false;
end;

procedure crosst(v, vn : integer; l : tline);
var n, i : integer;
    crp : tpoint;
begin
   pop(v);
   n := 0;
   for i := 1 to nt do begin
      if dp(p[vn], t[i])-dp(p[v], t[i]) > eps then begin
         inc(n); t1[n] := t[i];
      end;
      if cross(t[i], t[i mod nt + 1], l, crp) then begin
         inc(n); t1[n] := crp;
      end;
   end;
   for i := n downto 1 do
      add(v, t1[i].x, t1[i].y);
end;

function less(p1, p2 : tpoint) : boolean;
begin
   less := (p1.x-tp.x)*(p2.y-tp.y)-(p1.y-tp.y)*(p2.x-tp.x) > eps;
end;

procedure sort(l, r : integer);
var i, j : integer;
    x, y : tpoint;
begin
   i := l; j := r; x := t[l+random(r-l+1)];
   repeat
      while less(t[i], x) do inc(i);
      while less(x, t[j]) do dec(j);
      if i <= j then begin
         y := t[i]; t[i] := t[j]; t[j] := y;
         inc(i); dec(j);
      end;
   until i > j;
   if i < r then sort(i, r);
   if j > l then sort(l, j);
end;

function eq(p1, p2 : tpoint) : boolean;
begin
   eq := (abs(p1.x-p2.x) < eps) and (abs(p1.y-p2.y) < eps);
end;

begin
   randomize;
   assign(Input, 'football.in');
   reset(Input);
   assign(Output, 'football.out');
   rewrite(Output);
   read(x, y, n);
   for i := 1 to n do begin
      read(p[i].x, p[i].y);
      d[i] := nil;
      add(i, 0, y);
      add(i, x, y);
      add(i, y, 0);
      add(i, 0, 0);
      for j := 1 to i-1 do begin
         tp.x := (p[i].x+p[j].x)/2;
         tp.y := (p[i].y+p[j].y)/2;
         l.a  := p[i].x-p[j].x;
         l.b  := p[i].y-p[j].y;
         l.c  := -l.a*tp.x-l.b*tp.y;
         crosst(j, i, l);
         crosst(i, j, l);
      end;
   end;
   for i := 1 to n do begin
      pop(i);
      for j := 2 to nt do
         if (t[1].x-t[j].x > eps) or ((abs(t[1].x-t[j].x) < eps) and (t[1].y-t[j].y > eps)) then begin
            tp := t[j]; t[j] := t[1]; t[1] := tp;
         end;
      tp := t[1];
      sort(2, nt);
      write(nt);
      for j := 1 to nt do write(' ', t[j].x:0:10, ' ', t[j].y:0:10);
      writeln;
   end;
   close(Input);
   close(Output);
end.