{$DEFINE DEBUG}
uses math;
const eps = 1e-7;

var ac, xc, yc, dc, x, y: array [1..30010] of extended;
    q: array [1..30010] of record
                             x1, y1: extended;
                             x2, y2: extended;
                           end;
    ap: array [1..30010] of record
                              x, y: extended;
                            end;

    kk, o, i, j, k, r, cur, n: longint;
    xxc, yyc, xs, ys, x1, y1, x2, y2: extended;

label 1;

function cross (x1, y1, x2, y2, x3, y3, x4, y4: extended; var xc, yc: extended): boolean;
var a, b, c, d, e, f, t:extended;

begin
  cross := false;

  a := x2 - x1;
  b := x3 - x4;
  c := x3 - x1;
  d := y2 - y1;
  e := y3 - y4;
  f := y3 - y1;

  if abs(a * e - b * d)>eps then
  begin
    t := (c * e - b * f) / (a * e - b * d);

    if (t > eps) {and (s > eps) and (s < 1 + eps)} then
    begin
      xc := x1 + (x2 - x1) * t;
      yc := y1 + (y2 - y1) * t;
      cross := true;
    end;
  end;
end;

function cross2 (x1, y1, x2, y2, x3, y3, x4, y4: extended; var xc, yc: extended): boolean;
var a, b, c, d, e, f, t, s:extended;

begin
  cross2 := false;

  a := x2 - x1;
  b := x3 - x4;
  c := x3 - x1;
  d := y2 - y1;
  e := y3 - y4;
  f := y3 - y1;

  if abs(a * e - b * d)>eps then
  begin
    t := (c * e - b * f) / (a * e - b * d);
    s := (a * f - c * d) / (a * e - b * d);

    if (t > eps) and (s < 1 - eps) then
    begin
      xc := x1 + (x2 - x1) * t;
      yc := y1 + (y2 - y1) * t;
      cross2 := true;
    end;
  end;
end;

function dist (x1, y1, x2, y2: extended): extended;
begin
  dist := sqrt (sqr (x2 - x1) + sqr (y2 - y1));
end;

function vect (x1, y1, x2, y2: extended): shortint;
var v: extended;

begin
  v := x1 * y2 - x2 * y1;

  vect := 0;

  if v < -eps then
    vect := -1;

  if v > eps then
    vect := 1;

  if (x1 <> 0) and (x1 = -x2) then
    vect := -1;
  if (y1 <> 0) and (y1 = -y2) then
    vect := -1;

end;


procedure qsort (l, r: longint);
var i, j, c: longint;
    a, d, t: extended;

function lc (a1, d1, a2, d2: extended): boolean;
begin
  lc := (a1 + eps < a2) or (abs (a1 - a2) < eps) and (d1 > d2);
end;

begin
  if l < r then
  begin
    i := l;
    j := r;
    c := random (r - l + 1) + l;
    a := ac[c];
    d := dc[c];

    while i < j do
    begin
      while lc (ac[i], dc[i], a, d) do
        inc (i);
      while lc (a, d, ac[j], dc[j]) do
        dec (j);

      if i <= j then
      begin
        t := xc[i];
        xc[i] := xc[j];
        xc[j] := t;

        t := yc[i];
        yc[i] := yc[j];
        yc[j] := t;

        t := dc[i];
        dc[i] := dc[j];
        dc[j] := t;

        t := ac[i];
        ac[i] := ac[j];
        ac[j] := t;

        inc (i);
        dec (j);
      end;
    end;

    qsort (l, j);
    qsort (i, r);

  end;
end;

procedure add (x1, y1, x2, y2: extended);
var xxc, yyc: extended;

begin
  while (r > 0) and not cross (q[r].x1, q[r].y1, q[r].x2, q[r].y2, x1, y1, x2, y2, xxc, yyc) do
    dec (r);

  if r > 0 then
  begin
    q[r].x2 := xxc;
    q[r].y2 := yyc;

    inc(r);
    q[r].x1 := xxc;
    q[r].y1 := yyc;
    q[r].x2 := x1;
    q[r].y2 := y1;
  end
  else
  begin
    inc(r);
    q[r].x1 := x2;
    q[r].y1 := y2;
    q[r].x2 := x1;
    q[r].y2 := y1;
  end;
end;

begin
  randseed := $DEADBEEF;

  assign (input, 'football.in');
  reset (input);
  read (xs, ys, n);
  for i := 1 to n do
    read (x[i], y[i]);
  close (input);

  assign (output, 'football.out');
  rewrite (output);

  {$IFDEF DEBUG}

  writeln('DEBUG MODE: (:0:5)');

  {$ENDIF}

  for i := 1 to n do
  begin
    o := 4;

    xc[1] := 0;
    yc[1] := y[i];

    xc[2] := x[i];
    yc[2] := ys;

    xc[3] := xs;
    yc[3] := y[i];

    xc[4] := x[i];
    yc[4] := 0;


    for j := 1 to n do
      if i <> j then
      begin
        inc (o);
        xc[o] := (x[i] + x[j]) / 2;
        yc[o] := (y[i] + y[j]) / 2;
      end;

    for j := 1 to o do
    begin
      dc[j] := dist (x[i], y[i], xc[j], yc[j]);
      ac[j] := arctan2 (xc[j] - x[i], yc[j] - y[i]) + pi / 2;
      if ac[j] < -eps then
        ac[j] := ac[j] + 2 * pi;
    end;

    qsort (1, o);

    r := 1;
    q[1].x1 := 0;
    q[1].y1 := 0;
    q[1].x2 := 0;
    q[1].y2 := ys;

    for j:=2 to o do
    begin
      x1 := xc[j] + (yc[j] - y[i]);
      y1 := yc[j] - (xc[j] - x[i]);
      x2 := xc[j] - (yc[j] - y[i]);
      y2 := yc[j] + (xc[j] - x[i]);

      add (x1, y1, x2, y2);
    end;

    cur := r;
    kk:=0;
    for j:=r downto 1 do
      for k:=1 to j-1 do
        if cross2 (q[j].x1, q[j].y1, q[j].x2, q[j].y2, q[k].x1, q[k].y1, q[k].x2, q[k].y2, xxc, yyc) then
        begin
          ap[1].x := xxc;
          ap[1].y := yyc;
          for cur := k to j-1 do
          begin
            ap[cur-k+2].x := q[cur].x2;
            ap[cur-k+2].y := q[cur].y2;
          end;
          kk := j - k + 1;
          break;
        end;
    k := kk;
1:
    {$IFDEF DEBUG}

    write (k,' ');
    for j := 1 to k do
      write (ap[j].x:0:5, ' ', ap[j].y:0:5, ' ');
    writeln;
    append(output);
    {$ENDIF}
  end;

  close(output);
end.
