#include <cstdio>
#include <cmath>
#include <vector>
#include <algorithm>
#include <bitset>

#define db double
#define eps 1E-12
#define maxn 30000

using namespace std;

struct point{
	db x,y;
	point(){x=0,y=0;}
	point(db aa,db bb){x=aa,y=bb;}
	friend point operator+(point& p1,point& p2){
		return point(p1.x+p2.x,p1.y+p2.y);
	}
	friend point operator-(point& p1,point& p2){
		return point(p1.x-p2.x,p1.y-p2.y);
	}
	friend double operator*(point& p1,point& p2){
		return p1.x*p2.y-p1.y*p2.x;
	}
	friend point operator/(point& p,double d){
		return point(p.x/d,p.y/d);
	}
	friend point operator*(point& p,double d){
		return point(p.x*d,p.y*d);
	}
	friend bool operator==(point p1,point p2)
	{
		return (fabs(p1.x-p2.x)<eps)&&(fabs(p1.y-p2.y)<eps);
	}
	friend bool operator<(point p1,point p2)
	{
		return (p1.x<p2.x-eps)||((fabs(p1.x-p2.x)<eps)&&(p1.y<p2.y-eps));
	}
	void print()
	{
		printf("%0.5lf %0.5lf ",x,y);
	}
};

struct otr{
	point a,b;
	otr(){}
	otr(point x,point y){a=x,b=y;}
};


struct line{
	db a,b,c;
	line(){a=0,b=0,c=0;}
	line(db aa,db bb,db cc){a=aa,b=bb,c=cc;}
	line(point p1,point p2)
	{
		a=p2.y-p1.y;
		b=p1.x-p2.x;
		c=-a*p1.x-b*p1.y;
	}
	bool good(point p)
	{
		return a*p.x+b*p.y+c>-eps;
	}
	point cross(line l)
	{
		point res;
		res.x=(l.c*b-c*l.b)/(a*l.b-l.a*b);
		res.y=(l.a*c-a*l.c)/(a*l.b-l.a*b);
		return res;
	}
};

struct poly{
	vector<otr> v;
	poly(){}
	poly(double x1,double y1,double x2,double y2)
	{
		v.push_back(otr(point(x1,y1),point(x1,y2)));
		v.push_back(otr(point(x1,y2),point(x2,y2)));
		v.push_back(otr(point(x2,y2),point(x2,y1)));
		v.push_back(otr(point(x2,y1),point(x1,y1)));
	}
	void print()
	{
		vector<point> a,b;
		for(long i=0;i<v.size();i++)
			a.push_back(v[i].a),a.push_back(v[i].b);
		sort(a.begin(),a.end());
		long ans=1;
		for(long i=1;i<a.size();i++)
			if(!(a[i]==a[i-1])) ans++;
		printf("%d ",ans);
		b.push_back(a[0]);
		for(long i=1;i<a.size();i++)
			if(!(a[i]==a[i-1])) b.push_back(a[i]);
		b[0].print();
		point lst=b[0];
		bitset<maxn> u;
		u[0]=true;
		point w1,w2;
		for(long i=1;i<ans;i++){
			long j=0;
			while(u[j]) j++;
			for(long k=1;k<=ans;k++){
				w1=(b[k]-lst),w2=(b[j]-lst);
				if((!u[j])&&(w1*w2<0)) j=k;
			}
			b[j].print(),u[j]=true,lst=b[j];
		}
		printf("\n");
	}
	void cross_line(line l)
	{
		vector<point> w;
		vector<long> s;
		point q;
		for(long i=0;i<v.size();i++){
			if(l.good(v[i].a)&&l.good(v[i].b)) continue;
			if(l.good(v[i].a)){
				q=point(l.cross(line(v[i].a,v[i].b)));
				w.push_back(q),v[i].b=q;
			} else
			if(l.good(v[i].b)){
				q=point(l.cross(line(v[i].a,v[i].b)));
				w.push_back(q),v[i].a=q;
			} else s.push_back(i);
		}
		if(w.size()>1) v.push_back(otr(w[0],w[1]));
		for(long i=s.size()-1;i>=0;i--)
			v.erase(v.begin()+s[i]);
	}
};


using namespace std;

double x,y;
long n;
vector<point> v;

int main()
{
	freopen("football.in","r",stdin);
	scanf("%lf%lf%d",&x,&y,&n);
	double t1,t2;
	for(long i=1;i<=n;i++)
		scanf("%lf%lf",&t1,&t2),v.push_back(point(t1,t2));
	fclose(stdin);
	freopen("football.out","w",stdout);
	point q,tt,ttt;
	line l;
	for(long i=0;i<v.size();i++){
		poly p(0,0,x,y);
		for(long j=0;j<v.size();j++){
			if(i==j) continue;
			q=v[i];
			q=q+v[j];
			q=q/2.0;
			tt=q;
			tt=tt-v[i];
			ttt=point(-tt.y,tt.x);
			ttt=ttt+q;
			l=line(q,ttt);
			if(!l.good(v[i])) l.a=-l.a,l.b=-l.b,l.c=-l.c;
			p.cross_line(l);
		}
		p.print();
	}
	fclose(stdout);
	return 0;
}
