using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Text;

namespace rectangle_petr
{
	class rectangle_petr
	{
		int width;
		int height;
		BigInteger answer;
		List<Split> allSplits;
		static Random random = new Random();
		
		
		struct BigInteger
		{
			decimal value;
			
			public BigInteger(long value)
			{
				this.value = value;
			}

			BigInteger(decimal value)
			{
				this.value = value;
			}

			static public BigInteger operator +(BigInteger a, BigInteger b)
			{
				return new BigInteger(a.value + b.value);
			}
			
			static public BigInteger operator/(BigInteger a, int b)
			{
				Debug.Assert(a.value % b == 0);
				return new BigInteger(a.value / b);
			}
			
			public override string ToString()
			{
				return value.ToString();
			}
		}
		
		
		struct Row
		{
			public readonly int length;
			public readonly int part;
			public readonly int color;

			public Row(int length, int part, int color)
			{
				this.length = length;
				this.part = part;
				this.color = color;
			}

			public override bool Equals(object obj)
			{
				Row row = (Row)obj;
				return length == row.length && part == row.part && color == row.color;
			}

			public override int GetHashCode()
			{
				return length * 3137 + part * 37 + color;
			}
		}
		
		
		class Split
		{
			public Row[] rows;
			public int[] totalParts;
			
			public Split(Row[] rows, int[] totalParts)
			{
				this.totalParts = totalParts;
				this.rows = rows;
			}
		}
		
		
		class State
		{
			public static int TotalStates = 0;
			public Row[] rows;
			public int[] totalColors;
			
			public State(Row[] rows, int[] totalColors)
			{
				++TotalStates;
				this.rows = rows;
				this.totalColors = totalColors;
			}

			public override bool Equals(object obj)
			{
				State state = (State)obj;
				if (rows.Length != state.rows.Length)
					return false;
				for (int i = 0; i < rows.Length; ++i)
					if (!rows[i].Equals(state.rows[i]))
						return false;
				return true;
			}

			public override int GetHashCode()
			{
				int code = rows.Length;
				for (int i = 0; i < rows.Length; ++i)
					code = code * 31 + rows[i].GetHashCode();
				return code;
			}
		}
		
		
		class DisjointSetUnion
		{
			int[] p;
			
			
			public DisjointSetUnion(int n)
			{
				p = new int[n];
				for (int i = 0; i < n; ++i)
					p[i] = i;
			}
			
			
			public int get(int v)
			{
				if (p[v] != v)
					p[v] = get(p[v]);
				return p[v];
			}
			
			public void union(int v1, int v2)
			{
				int v1p = get(v1);
				int v2p = get(v2);
				if (v1p != v2p)
				{
					if (random.Next(2) == 0)
						p[v1p] = v2p;
					else
						p[v2p] = v1p;
				}
			}
		}

		
		void solve(bool outputLog)
		{
			allSplits = new List<Split>(1 << width);
			generateSplits(new List<Row>(width), new int[]{0, 0}, width);
			Dictionary<State, BigInteger> states = new Dictionary<State,BigInteger>();
			states[new State(new Row[]{new Row(width, -1, 0)}, new int[]{0, 0})] = new BigInteger(1);
			answer = new BigInteger(0);
			BigInteger tempAnswer = answer;
			for (int row = 0; row < height; ++row)
			{
				answer = tempAnswer;
				Console.WriteLine(row + " " + states.Count);
				OneStep(states, out states);
				foreach (KeyValuePair<State, BigInteger> statePair in states)
				{
					if (statePair.Key.totalColors[0] == 1)
						tempAnswer += statePair.Value;
					if (statePair.Key.totalColors[1] == 1)
						tempAnswer += statePair.Value;
					if (statePair.Key.totalColors[0] == 1 && statePair.Key.totalColors[1] == 1)
						answer += statePair.Value;
				}
				answer /= 2;
				if (outputLog)
				{
					StreamWriter output = new StreamWriter("rectangle.out", true);
					output.WriteLine("answer[" + width + ", " + (row + 1) + "] = " + answer.ToString() + ";");
					if (width != row + 1)
						output.WriteLine("answer[" + (row + 1) + ", " + (width) + "] = " + answer.ToString() + ";");
					output.Close();
				}
			}
			
			Console.WriteLine(State.TotalStates);
		}

		void generateSplits(List<Row> current, int[] totals, int remaining)
		{
			if (remaining == 0)
			{
				allSplits.Add(new Split(current.ToArray(), (int[]) totals.Clone()));
				return;
			}
			int start = 0;
			int finish = 1;
			if (current.Count > 0)
			{
				start = 1 - current[current.Count - 1].part;
				finish = start;
			}
			for (int part = start; part <= finish; ++part)
			{
				for (int len = 1; len <= remaining; ++len)
				{
					current.Add(new Row(len, part, 0));
					++totals[part];
					generateSplits(current, totals, remaining - len);
					--totals[part];
					current.RemoveAt(current.Count - 1);
				}
			}
		}

		void OneStep(Dictionary<State, BigInteger> inStates, out Dictionary<State, BigInteger> outStates)
		{
			outStates = new Dictionary<State,BigInteger>();
			Dictionary<int, int>[] newColor = new Dictionary<int,int>[2];
			for (int i = 0; i < 2; ++i)
				newColor[i] = new Dictionary<int,int>();
			
			foreach (Split split in allSplits)
			{
				foreach (KeyValuePair<State, BigInteger> prevStatePair in inStates)
				{
					State prevState = prevStatePair.Key;
					BigInteger prevCount = prevStatePair.Value;
					Row[] work = (Row[])split.rows.Clone();
					Row[] prev = prevState.rows;
					int prevAt = 0;
					int prevLen = prev[prevAt].length;

					int[] prevTotals = prevState.totalColors;
					int[] curTotals = split.totalParts;
					int[] runningCurTotals = new int[2];
					
					DisjointSetUnion[] partMap = new DisjointSetUnion[2];
					for (int i = 0; i < 2; ++i)
					{
						partMap[i] = new DisjointSetUnion(prevTotals[i] + curTotals[i]);
					}
					
					for (int i = 0; i < work.Length; ++i)
					{
						Row current = work[i];
						for (int j = 0; j < current.length; ++j)
						{
							if (prevLen == 0)
							{
								++prevAt;
								prevLen = prev[prevAt].length;
							}
							if (prev[prevAt].part == current.part)
								partMap[current.part].union(prevTotals[current.part] + runningCurTotals[current.part], prev[prevAt].color);
							--prevLen;
						}
						++runningCurTotals[current.part];
					}
					
					runningCurTotals = new int[2];
					for (int i = 0; i < 2; ++i)
						newColor[i].Clear();
					int[] numColors = new int[2];
					
					for (int i = 0; i < work.Length; ++i)
					{
						Row current = work[i];
						int pid = partMap[current.part].get(prevTotals[current.part] + runningCurTotals[current.part]);
						if (!newColor[current.part].ContainsKey(pid))
							newColor[current.part][pid] = numColors[current.part]++;
						++runningCurTotals[current.part];
						work[i] = new Row(current.length, current.part, newColor[current.part][pid]);
					}
					
					bool ok = true;
					for (int i = 0; i < 2; ++i)
						for (int j = 0; j < prevTotals[i]; ++j)
							if (!newColor[i].ContainsKey(partMap[i].get(j)))
								ok = false;
					
					if (ok)
					{
						State newState = new State(work, numColors);
						if (outStates.ContainsKey(newState))
							outStates[newState] += prevCount;
						else
							outStates[newState] = prevCount;
					}
				}
			}
		}

		void run()
		{
			readInput();
			solve(false);
			writeOutput();
		}

		void runAll()
		{
			File.Delete("rectandle.out");
			File.Create("rectangle.out").Close();
			for (width = 12; width <= 13; ++width)
			{
				height = width;
				solve(true);
			}
		}
		
		void writeOutput()
		{
			StreamWriter output = new StreamWriter("rectangle.out");
			output.WriteLine(answer.ToString());
			output.Close();
		}

		void readInput()
		{
			StreamReader input = new StreamReader("rectangle.in");
			string data = input.ReadToEnd();
			string[] p = data.Split(' ', '\n', '\r');
			width = int.Parse(p[0]);
			height = int.Parse(p[1]);
		}

		static void Main(string[] args)
		{
			new rectangle_petr().run();
		}
	}
}
