#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define NN 128
#define eps 1e-7

typedef struct {
	double x,y;
} POINT;
	
typedef struct {
	double x;
	int tp; //0 - polygon, 1 - start circle, 2 - end circle
} EVENT;

int n,m,k,s;
POINT p[NN];
POINT a[NN];
double r[NN];
double q[7*NN*NN]; //Better more than less :)
EVENT w[7*NN];
double higher,lower;

double L(double x1, double y1, double x2, double y2) {
	return sqrt((x2-x1)*(x2-x1)+(y2-y1)*(y2-y1));
}

int intersect_cl2(double x, double y, double r, double px, double py, double vx, double vy, POINT *res) {
	double A,B,C;
	double t1,t2;
	double D;
	A=vx*vx+vy*vy;
	B=2*vx*(px-x)+2*vy*(py-y);
	C=(px-x)*(px-x)+(py-y)*(py-y)-r*r;
	D=B*B-4*A*C;
	if(D<-eps) return 0;
	if(fabs(D)<eps) {
		t1=-B/2/A;
		res[0].x=px+vx*t1;
		res[0].y=py+vy*t1;
		return 1;
	}
	t1=(-B+sqrt(D))/(2*A);
	t2=(-B-sqrt(D))/(2*A);
	res[0].x=px+vx*t1;
	res[0].y=py+vy*t1;
	res[1].x=px+vx*t2;
	res[1].y=py+vy*t2;
	return 2;
}

int intersect_cl(double x, double y, double r, double A, double B, double C, POINT *res) {
	double px, py;
	if(fabs(B)>eps) {
		px=0; py=-C/B;
	} else {
		py=0; px=-C/A;
	}
	return intersect_cl2(x,y,r,px,py,-B,A,res);
}

int intersect_cc(double x1, double y1, double r1, double x2, double y2, double r2, POINT *res) {
	if(L(x1,y1,x2,y2)<eps) return 0; //cheat
	if(L(x1,y1,x2,y2)>r1+r2+eps) return 0;
	if(L(x1,y1,x2,y2)<fabs(r1-r2)-eps) return 0;
	
	if(fabs(L(x1,y1,x2,y2)-r1-r2)<eps) {
		res[0].x=x1+(x2-x1)*r1/(r1+r2);
		res[0].y=y1+(y2-y1)*r1/(r1+r2);
		return 1;
	}
	if(fabs(L(x1,y1,x2,y2)-fabs(r1+r2))<eps) {
		res[0].x=x1+(x2-x1)*r1/(r1-r2);
		res[0].y=y1+(y2-y1)*r1/(r1-r2);
		return 1;
	}
	return intersect_cl(x1,y1,r1,2*(x2-x1),2*(y2-y1),r2*r2-r1*r1+x1*x1-x2*x2+y1*y1-y2*y2,res);
}

int intersect_cs(double x, double y, double r, double x1, double y1, double x2, double y2, POINT *res) {
	double px,py,vx,vy;
	px=x1; py=y1; vx=x2-x1; vy=y2-y1;
	double A,B,C;
	double t1,t2;
	double D;
	int ans = 0;
	A=vx*vx+vy*vy;
	B=2*vx*(px-x)+2*vy*(py-y);
	C=(px-x)*(px-x)+(py-y)*(py-y)-r*r;
	D=B*B-4*A*C;
	if(D<-eps) return 0;
	if(fabs(D)<eps) {
		t1=-B/2.0/A;
		if(t1<-eps) return 0;
		if(t2>1+eps) return 0;
		res[0].x=px+vx*t1;
		res[0].y=py+vy*t1;
		return 1;
	}
	t1=(-B+sqrt(D))/(2.0*A);
	t2=(-B-sqrt(D))/(2.0*A);
	if((t1<1+eps)&&(t1>-eps)) {
		res[ans].x=px+vx*t1;
		res[ans].y=py+vy*t1;
		ans++;
	}
	if((t2<1+eps)&&(t2>-eps)) {
		res[ans].x=px+vx*t2;
		res[ans].y=py+vy*t2;
		ans++;
	}
	return ans;
}

void push(double x, double y) {
	if(y>higher+eps) return ;
	if(y<lower-eps) return ;
	q[k++]=y;
}

int cmp_lf(const void *a, const void *b) {
	double x,y;
	x=*((const double *)a);
	y=*((const double *)b);
	if(x<y) return -1;
	if(x>y) return 1;
	return 0;
}

int cmp_event(const void *a, const void *b) {
	double x,y;
	x=((const EVENT *)a)->x;
	y=((const EVENT *)b)->x;
	if(x<y) return -1;
	if(x>y) return 1;
	return 0;
}

int intersect_hs(double h, double x1, double y1, double x2, double y2, double *res) {
	double t;
	if(y1>y2) {
		t=y1;y1=y2;y2=t;
		t=x1;x1=x2;x2=t;
	}
	if(y2<h) return 0;
	if(y1>h) return 0;
	*res=x1+(x2-x1)*(h-y1)/(y2-y1);
	return 1;
}

int process_hline(double h) {
	int i;
	double xx;
	int f1,f2;
	f1=0; f2=0;
	s=0;
	for(i=0;i<m;i++) {
		if(intersect_hs(h,p[i].x,p[i].y,p[(i+1)%m].x,p[(i+1)%m].y,&xx)) {
			w[s].x=xx;
			w[s].tp=0;
			s++;
		}
	}
	for(i=0;i<n;i++) {
		xx=r[i]*r[i]-(h-a[i].y)*(h-a[i].y);
		if(xx<eps) continue;
		w[s].x=a[i].x-sqrt(xx);
		w[s].tp=1;
		s++;
		w[s].x=a[i].x+sqrt(xx);
		w[s].tp=2;
		s++;
	}
	qsort(w,s,sizeof(w[0]),cmp_event);
	for(i=0;i<s;i++) {
		switch(w[i].tp) {
		case 0:
			f2=1-f2;
			break;
		case 1:
			f1++;
			break;
		case 2:
			f1--;
			break;
		}
		if((!f1)&&f2) 
			return 1;
	}
	return 0;
}

int main(void) {
	int tst,tstnum;
	int t,tt;
	int i,j;
	int flag;
	POINT tv[2];
	freopen("bombing.in","rt",stdin);
	freopen("bombing.out","wt",stdout);
	
	scanf("%d",&m);
	for(i=0;i<m;i++) {
		scanf("%lf%lf",&p[i].x,&p[i].y);
	}
	higher=p[0].y; lower=p[0].y;
	for(i=1;i<m;i++) {
		if(p[i].y>higher) higher=p[i].y;
		if(p[i].y<lower) lower=p[i].y;
	}
	scanf("%d",&tstnum);
	for(tst=0;tst<tstnum;tst++) {
		k = 0;
		flag = 0;
		scanf("%d",&n);
		for(i=0;i<n;i++) {
			scanf("%lf%lf%lf",&a[i].x,&a[i].y,&r[i]);
		}
		for(i=0;i<n;i++) {
			push(a[i].x,a[i].y+r[i]);
			push(a[i].x,a[i].y-r[i]);
			for(j=i+1;j<n;j++) {
				tt=intersect_cc(a[i].x,a[i].y,r[i],a[j].x,a[j].y,r[j],tv);
				for(t=0;t<tt;t++)
					push(tv[t].x,tv[t].y);
			}
			for(j=0;j<m;j++) {
				tt=intersect_cs(a[i].x,a[i].y,r[i],p[j].x,p[j].y,p[(j+1)%m].x,p[(j+1)%m].y,tv);
				for(t=0;t<tt;t++)
					push(tv[t].x,tv[t].y);
			}
		}
		for(i=0;i<m;i++) {
			push(p[i].x,p[i].y);
		}
		qsort(q,k,sizeof(q[0]),cmp_lf);
		for(i=1;i<k;i++) {
			if(fabs(q[i-1]-q[i])<eps) continue;
			if(process_hline((q[i-1]+q[i])/2.0)) {
				flag=1;
				break;
			}
		}
		if(flag) {
			printf("NO\n");
		} else {
			printf("YES\n");
		}
	}
	return 0;
}
