import java.io.*;
import java.util.*;

public class color_as {
    Map<Integer, Set<Vertex>>[] buckets;
    Set<Integer> toSplit;
    Set<Vertex> pending;

    public void classify(Vertex v) {
        v.makeSignature();
        if (buckets[v.col] == null) {
            buckets[v.col] = new HashMap<Integer, Set<Vertex>>();
        }
        Map<Integer, Set<Vertex>> bucket = buckets[v.col];
        if (!bucket.containsKey(v.signature)) {
            bucket.put(v.signature, new HashSet<Vertex>());
        }
        Set<Vertex> vs = bucket.get(v.signature);
        vs.add(v);
        if (bucket.size() > 1) {
            toSplit.add(v.col);
        }
        //System.out.println("Classify " + (v.index + 1) + ": col=" + v.col + ", signature=" + v.signature);
    }

    public void declassify(Vertex v) {
        int col = v.col;
        if (v.oldcol != 0) {
            col = v.oldcol;
        }
        Map<Integer, Set<Vertex>> bucket = buckets[col];
        Set<Vertex> vs = bucket.get(v.signature);
        vs.remove(v);
        if (vs.size() == 0) {
            bucket.remove(v.signature);
            if (bucket.size() <= 1) {
                toSplit.remove(col);
            }
        }
        //System.out.println("Declassify " + (v.index + 1) + ": oldcol=" + v.oldcol + ", newcol=" + v.col);
        v.oldcol = 0;
    }

    public void run() throws IOException {
        Scanner in = new Scanner(new File("color.in"));
        int n = in.nextInt();
        in.nextLine();

        long timer = System.currentTimeMillis();

        int[][] neig = new int[n][2];
        for (int i = 0; i < n; i++) {
            neig[i][0] = in.nextInt() - 1;
            neig[i][1] = in.nextInt() - 1;
        }
        in.close();

        Vertex[] v = new Vertex[n];
        for (int i = 0; i < n; i++) {
            v[i] = new Vertex(i);
        }
        for (int i = 0; i < n; i++) {
            if (neig[i][0] == -1) {
                v[i].nc = 0;
            } else if (neig[i][1] == -1) {
                v[i].nc = 1;
                v[i].v1 = v[neig[i][0]];
                v[i].v1.in.add(v[i]);
            } else {
                v[i].nc = 2;
                v[i].v1 = v[neig[i][0]];
                v[i].v1.in.add(v[i]);
                v[i].v2 = v[neig[i][1]];
                v[i].v2.in.add(v[i]);
            }
        }

        int cnum = 0;
        int[] color = new int[3];
        for (int i = 0; i < n; i++) {
            if (color[v[i].nc] == 0) {
                cnum++;
                color[v[i].nc] = cnum;
            }
            v[i].col = color[v[i].nc];
        }

        System.out.println(System.currentTimeMillis() - timer);

        buckets = new Map[n + 1];
        toSplit = new TreeSet<Integer>();
        pending = new HashSet<Vertex>();

        for (int i = 0; i < n; i++) {
            classify(v[i]);
        }

        int cc = 0;
        System.out.println(System.currentTimeMillis() - timer);
        while (toSplit.size() > 0) {
            int c = toSplit.iterator().next();
            toSplit.remove(c);
            //System.out.println("Splitting color " + c);

            Map<Integer, Set<Vertex>> bucket = buckets[c];
            Integer[] sig = new Integer[bucket.size()];
            int[] nc = new int[bucket.size()];
            int i = 0;
            int max = 0;
            Integer maxs = 0;
            for (Integer s: bucket.keySet()) {
                sig[i] = s;
                Set<Vertex> vv = bucket.get(s);
                if (vv.size() > max) {
                    max = vv.size();
                    maxs = s;
                }
                i++;
            }
            i = 0;
            for (Integer s: bucket.keySet()) {
                if (maxs != s) {
                    cnum++;
                    //System.out.println("Recoloring color " + c + ", signature " + s + " to color " + cnum);
                    Set<Vertex> vv = bucket.get(s);
                    for (Iterator<Vertex> it = vv.iterator(); it.hasNext();) {
                        Vertex vx = it.next();
                        vx.oldcol = vx.col;
                        vx.col = cnum;
                        pending.add(vx);
                        for (Iterator<Vertex> jt = vx.in.iterator(); jt.hasNext();) {
                            Vertex vi =  jt.next();
                            pending.add(vi);
                        }
                    }
                }
            }
            cc += pending.size();
            for (Iterator<Vertex> it = pending.iterator(); it.hasNext();) {
                Vertex vx = it.next();
                declassify(vx);
                classify(vx);
            }
            pending.clear();
        }

        System.out.println("-->" + cc);
        System.out.println(System.currentTimeMillis() - timer);
        PrintWriter out = new PrintWriter(new File("color.out"));
        out.println(cnum);
        for (int i = 0; i < n; i++) {
            out.println(v[i].col);
        }
        out.close();
    }

    public class Vertex {
        int index;
        int col;
        int oldcol;
        int nc;
        Vertex v1;
        Vertex v2;
        List<Vertex> in;
        int signature;

        public Vertex(int index) {
            this.index = index;
            in = new LinkedList<Vertex>();
        }

        void makeSignature() {
            if (v1 == null) {
                signature = 0;
            } else if (v2 == null) {
                signature = v1.col;
            } else {
                if (v1.col > v2.col) {
                    Vertex t = v1; v1 = v2; v2 = t;
                }
                signature = (v1.col << 16) + v2.col;
            }
        }

        public boolean equals(Object o) {
            return (index == ((Vertex) o).index);
        }

        public int hashCode() {
            return index;
        }
    }

    public static void main(String[] arg) throws IOException {
        new color_as().run();
    }
}
