#include <stdio.h>
#include <stdlib.h>

#define INPUT "format.in"
#define OUTPUT "format.out"

#define TEXTLEN 10000		/* Maximalni delka textu */
#define MAXWORDS 5000		/* Maximalni pocet slov v textu */
#define MAXLINELEN 100		/* Maximalni delka vstupni radky */
#define MAXLINES 5000		/* Maximalni pocet radek ve vystupu */

#define LINEPENALTY 10		/* Cena radky */
#define LASTLINESMALLPEN 3	/* Cena za maly posledni radek */
#define SINGLEWORDPEN 20	/* Penalta za jedno slovo na radku */
#define INFTYPEN 30000		/* Nekonecna penalta */

typedef unsigned long price_t;

int Width;			/* Sirka radku */
char Text[TEXTLEN];		/* Text nacteny ze souboru */
int Words[MAXWORDS];		/* Text rozsekany na slova */
int WCnt;			/* Pocet slov */
price_t WrapPrice[MAXWORDS];	/* Ohodnoceni textu, pokud zalomime za timto slovem */
int WrapPos[MAXWORDS];		/* Pozice, kde jsme zalomili, kdyz jsme pridavali toto slovo */

/* Ohodnoti radek */
int LinePrice(int WordLen, int Words, int Last)
{
  int Pts = Width - WordLen - Words + 1;
  int Base = LINEPENALTY;

  if (Pts < 0)
    return INFTYPEN;
  if (Last)
    return LINEPENALTY + (((WordLen+Words-1)*4 < Width) ? LASTLINESMALLPEN : 0);
  if (Words == 1)
    Base += SINGLEWORDPEN;
  return Pts * Pts + Base;
}

/* Nacte vstup a rozdeli ho na slova */
void ProcessInput(void)
{
  FILE *In;
  char Buf[MAXLINELEN];	/* Buffer na radku */
  int i, TPos = 0, WPos = 0;	/* ; Pozice v bufferu na text ; Cislo aktualniho slova */
  int SWPos = 0;		/* Pozice pocatku slova */

  if (!(In = fopen(INPUT, "r")))
  {
    puts("Can't open input file.");
    exit(1);
  }
  /* Nacteme delku radku */
  fgets(Buf, MAXLINELEN, In);
  sscanf(Buf, "%d", &Width);

  while (fgets(Buf, MAXLINELEN, In))
  {
    for (i = 0; Buf[i] != '\0'; i++, TPos++)
    {
      if (Buf[i] == '\n')
        Buf[i] = ' ';
      Text[TPos] = Buf[i];
      if (Buf[i] == ' ')
      {
        Words[WPos++] = TPos - SWPos;
        SWPos = TPos + 1;
      }
    }
  }
  fclose(In);
  WCnt = WPos;
}

void FindBestSep(void)
{
  int i, j;
  price_t Min, Price;	/* Minimalni dosazene ohodnoceni; Cena aktualniho zlomu */
  int WordsLen, MinPos;	/* Celkova delka slov na radce; Pozice minimalniho zalomeni  */

  WrapPrice[0] = 0;
  WrapPos[0] = 0;

  for (i = 0; i < WCnt; i++)	/* Postupne pridavame jednotliva slova */
  {
    Min = INFTYPEN;
    MinPos = 0;
    WordsLen = 0;
    for (j = i; j >= 0; j--)	/* Vyzkousime vsechna mozna zalomeni */
    {
      WordsLen += Words[j];
      Price = LinePrice(WordsLen, i - j + 1, i == WCnt - 1);
      if (Price == INFTYPEN)	/* Uz jsem prekrocili velikost radku? */
        break;
      Price += WrapPrice[j];
      if (Price < Min)
      {
        Min = Price;
        MinPos = j;
      }
    }
    WrapPrice[i+1] = Min;
    WrapPos[i+1] = MinPos;
  }
}

/* Vytiskne dalsi slovo */
void PrintWord(FILE *Out)
{
  static int WPos = 0;		/* Pozice slova k vypsani */
  int WStart;

  for (WStart = WPos; Text[WPos] != ' '; WPos++);
  fwrite(Text + WStart, 1, WPos - WStart, Out);
  WPos++;
}

/* Vytiskne radku */
void PrintLine(FILE *Out, int First, int Cnt)
{
  int i, j;
  int Len = 0, TotSpc;		/* Pocet znaku na radce; Celkovy pocet mezer */
  int Spc;			/* Pocet mezer v aktualni mezere */

  /* Spocteme pocet znaku ve slovech */
  for (i = 0; i < Cnt; i++)
    Len += Words[First+i];
  TotSpc = Width - Len;
  if (Cnt == 1)			/* Jedno slovo? */
  {
    for (j = 0; j < TotSpc; j++)
      fputc(' ', Out);
  }
  else
    for (i = 0; i < Cnt-1; i++)
    {
      PrintWord(Out);		/* Vytiskne dalsi slovo */
      /* Spocteme a vytiskneme potrebny pocet mezer */
      Spc = TotSpc / (Cnt - 1) + (i < TotSpc % (Cnt-1));
      for (j = 0; j < Spc; j++)
        fputc(' ', Out);
    }
  PrintWord(Out);		/* Jeste vytiskneme posledni slovo */
  fputc('\n', Out);
}

/* Vypiseme nejlepsi vysledek */
void PrintBestText(void)
{
  FILE *Out;
  int Lines = 0, ActWord;	/* Pocet radek vysledneho textu; Aktualni slovo */
  int LB[MAXLINES], i;		/* Pozice jednotlivych zalomeni */

  /* Zjistime pozice jednotlivych zalomeni */
  for (ActWord = WCnt; ActWord > 0; Lines++, ActWord = WrapPos[ActWord])
    LB[Lines] = ActWord;
  LB[Lines] = 0;
  if (!(Out = fopen(OUTPUT, "w")))
  {
    puts("Can't open output file.");
    exit(1);
  }
  /* Nechame vytisknout radku */
  for (i = Lines - 1; i > 0; i--)
    PrintLine(Out, LB[i+1], LB[i] - LB[i+1]);

  /* Ted jeste vytiskneme posledni radku */
  for (i = LB[1]; i < LB[0] - 1; i++)
  {
    PrintWord(Out);
    fputc(' ', Out);
  }
  PrintWord(Out);
  fputc('\n', Out);

  fclose(Out);
}

int main(void)
{
  ProcessInput();	/* Nacte vstup a rozdeli ho na slova */
  FindBestSep();	/* Nalezneme nejlepsi rozdeleni na radky */
  PrintBestText();	/* Vypise text podle spoctenych zalomeni */
  return 0;
}

